\qt@newcmd\qurantrans@en@i{%
In the Name of God, the Merciful, the Compassionate\qt@no{1}}%
\qt@newcmd\qurantrans@en@ii{%
Praise belongs to God, the Lord of all Being,\qt@no{2}}%
\qt@newcmd\qurantrans@en@iii{%
the All-merciful, the All-compassionate,\qt@no{3}}%
\qt@newcmd\qurantrans@en@iv{%
the Master of the Day of Doom.\qt@no{4}}%
\qt@newcmd\qurantrans@en@v{%
Thee only we serve; to Thee alone we pray for succour.\qt@no{5}}%
\qt@newcmd\qurantrans@en@vi{%
Guide us in the straight path,\qt@no{6}}%
\qt@newcmd\qurantrans@en@vii{%
the path of those whom Thou hast blessed, not of those against whom Thou art wrathful, nor of those who are astray.\qt@no{7}}%
\qt@newcmd\qurantrans@en@viii{%
\basmalahen Alif Lam Mim\qt@no{1}}%
\qt@newcmd\qurantrans@en@ix{%
That is the Book, wherein is no doubt, a guidance to the godfearing\qt@no{2}}%
\qt@newcmd\qurantrans@en@x{%
who believe in the Unseen, and perform the prayer, and expend of that We have provided them;\qt@no{3}}%
\qt@newcmd\qurantrans@en@xi{%
who believe in what has been sent down to thee and what has been sent down before thee, and have faith in the Hereafter;\qt@no{4}}%
\qt@newcmd\qurantrans@en@xii{%
those are upon guidance from their Lord, those are the ones who prosper.\qt@no{5}}%
\qt@newcmd\qurantrans@en@xiii{%
As for the unbelievers, alike it is to them whether thou hast warned them or hast not warned them, they do not believe.\qt@no{6}}%
\qt@newcmd\qurantrans@en@xiv{%
God has set a seal on their hearts and on their hearing, and on their eyes is a covering, and there awaits them a mighty chastisement.\qt@no{7}}%
\qt@newcmd\qurantrans@en@xv{%
And some men there are who say, 'We believe in God and the Last Day'; but they are not believers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@xvi{%
They would trick God and the believers, and only themselves they deceive, and they are not aware.\qt@no{9}}%
\qt@newcmd\qurantrans@en@xvii{%
In their hearts is a sickness, and God has increased their sickness, and there awaits them a painful chastisement for that they have cried lies.\qt@no{10}}%
\qt@newcmd\qurantrans@en@xviii{%
When it is said to them, 'Do not corruption in the land', they say, 'We are only ones that put things right.'\qt@no{11}}%
\qt@newcmd\qurantrans@en@xix{%
Truly, they are the workers of corruption but they are not aware.\qt@no{12}}%
\qt@newcmd\qurantrans@en@xx{%
When it is said to them, 'Believe as the people believe', they say, 'Shall we believe, as fools believe?' Truly, they are the foolish ones, but they do not know.\qt@no{13}}%
\qt@newcmd\qurantrans@en@xxi{%
When they meet those who believe, they say, 'We believe'; but when they go privily to their Satans, they say, 'We are with you; we were only mocking.'\qt@no{14}}%
\qt@newcmd\qurantrans@en@xxii{%
God shall mock them, and shall lead them on blindly wandering in their insolence.\qt@no{15}}%
\qt@newcmd\qurantrans@en@xxiii{%
Those are they that have bought error at the price of guidance, and their commerce has not profited them, and they are not right-guided.\qt@no{16}}%
\qt@newcmd\qurantrans@en@xxiv{%
The likeness of them is as the likeness of a man who kindled a fire, and when it lit all about him God took away their light, and left them in darkness unseeing\qt@no{17}}%
\qt@newcmd\qurantrans@en@xxv{%
deaf, dumb, blind -- so they shall not return;\qt@no{18}}%
\qt@newcmd\qurantrans@en@xxvi{%
or as a cloudburst out of heaven in which is darkness, and thunder, and lightning -- they put their fingers in their ears against the thunderclaps, fearful of death; and God encompasses the unbelievers;\qt@no{19}}%
\qt@newcmd\qurantrans@en@xxvii{%
the lightning wellnigh snatches away their sight; whensoever it gives them light, they walk in it, and when the darkness is over them, they halt; had God willed, He would have taken away their hearing and their sight. Truly, God is powerful over everything.\qt@no{20}}%
\qt@newcmd\qurantrans@en@xxviii{%
O you men, serve your Lord Who created you, and those that were before you; haply so you will be godfearing;\qt@no{21}}%
\qt@newcmd\qurantrans@en@xxix{%
who assigned to you the earth for a couch, and heaven for an edifice, and sent down out of heaven water, wherewith He brought forth fruits for your provision; so set not up compeers to God wittingly.\qt@no{22}}%
\qt@newcmd\qurantrans@en@xxx{%
And if you are in doubt concerning that We have sent down on Our servant, then bring a sura like it, and call your witnesses, apart from God, if you are truthful.\qt@no{23}}%
\qt@newcmd\qurantrans@en@xxxi{%
And if you do not -- and you will not -- then fear the Fire, whose fuel is men and stones, prepared for unbelievers.\qt@no{24}}%
\qt@newcmd\qurantrans@en@xxxii{%
Give thou good tidings to those who believe and do deeds of righteousness, that for them await gardens underneath which rivers flow; whensoever they are provided with fruits therefrom they shall say, 'This is that wherewithal we were provided before'; that they shall be given in perfect semblance; and there for them shall be spouses purified; therein they shall dwell forever.\qt@no{25}}%
\qt@newcmd\qurantrans@en@xxxiii{%
God is not ashamed to strike a similitude even of a gnat, or aught above it. As for the believers, they know it is the truth from their Lord; but as for unbelievers, they say, 'What did God desire by this for a similitude?' Thereby He leads many astray, and thereby He guides many; and thereby He leads none astray save the ungodly\qt@no{26}}%
\qt@newcmd\qurantrans@en@xxxiv{%
such as break the covenant of God after its solemn binding, and such as cut what God has commanded should be joined, and such as do corruption in the land -- they shall be the losers.\qt@no{27}}%
\qt@newcmd\qurantrans@en@xxxv{%
How do you disbelieve in God, seeing you were dead and He gave you life, then He shall make you dead, then He shall give you life, then unto Him you shall be returned?\qt@no{28}}%
\qt@newcmd\qurantrans@en@xxxvi{%
It is He who created for you all that is in the earth, then He lifted Himself to heaven and levelled them seven heavens; and He has knowledge of everything.\qt@no{29}}%
\qt@newcmd\qurantrans@en@xxxvii{%
And when thy Lord said to the angels, 'I am setting in the earth a viceroy.' They said, 'What, wilt Thou set therein one who will do corruption there, and shed blood, while We proclaim Thy praise and call Thee Holy?' He said, 'Assuredly I know that you know not.'\qt@no{30}}%
\qt@newcmd\qurantrans@en@xxxviii{%
And He taught Adam the names, all of them; then He presented them unto the angels and said, 'Now tell Me the names of these, if you speak truly.'\qt@no{31}}%
\qt@newcmd\qurantrans@en@xxxix{%
They said, 'Glory be to Thee! We know not save what Thou hast taught us. Surely Thou art the All-knowing, the All-wise.'\qt@no{32}}%
\qt@newcmd\qurantrans@en@xl{%
He said, 'Adam, tell them their names.' And when he had told them their names He said, 'Did I not tell you I know the unseen things of the heavens and earth? And I know what things you reveal, and what you were hiding.'\qt@no{33}}%
\qt@newcmd\qurantrans@en@xli{%
And when We said to the angels, 'Bow yourselves to Adam'; so they bowed themselves, save Iblis; he refused, and waxed proud, and so he became one of the unbelievers.\qt@no{34}}%
\qt@newcmd\qurantrans@en@xlii{%
And We said, 'Adam, dwell thou, and thy wife, in the Garden, and eat thereof easefully where you desire; but draw not nigh this tree, lest you be evildoers.'\qt@no{35}}%
\qt@newcmd\qurantrans@en@xliii{%
Then Satan caused them to slip therefrom and brought them out of that they were in; and We said, 'Get you all down, each of you an enemy of each; and in the earth a sojourn shall be yours, and enjoyment for a time.'\qt@no{36}}%
\qt@newcmd\qurantrans@en@xliv{%
Thereafter Adam received certain words from his Lord, and He turned towards him; truly He turns, and is All-compassionate.\qt@no{37}}%
\qt@newcmd\qurantrans@en@xlv{%
We said, 'Get you down out of it, all together; yet there shall come to you guidance from Me, and whosoever follows My guidance, no fear shall be on them, neither shall they sorrow.\qt@no{38}}%
\qt@newcmd\qurantrans@en@xlvi{%
As for the unbelievers who cry lies to Our signs, those shall be the inhabitants of the Fire, therein dwelling forever.'\qt@no{39}}%
\qt@newcmd\qurantrans@en@xlvii{%
Children of Israel, remember My blessing wherewith I blessed you, and fulfil My covenant and I shall fulfil your covenant; and have awe of Me.\qt@no{40}}%
\qt@newcmd\qurantrans@en@xlviii{%
And believe in that I have sent down, confirming that which is with you, and be not the first to disbelieve in it. And sell not My signs for a little price; and fear you Me.\qt@no{41}}%
\qt@newcmd\qurantrans@en@xlix{%
And do not confound the truth with vanity, and do not conceal the truth wittingly.\qt@no{42}}%
\qt@newcmd\qurantrans@en@l{%
And perform the prayer, and pay the alms, and bow with those that bow.\qt@no{43}}%
\qt@newcmd\qurantrans@en@li{%
Will you bid others to piety, and forget yourselves while you recite the Book? Do you not understand?\qt@no{44}}%
\qt@newcmd\qurantrans@en@lii{%
Seek you help in patience and prayer, for grievous it is, save to the humble\qt@no{45}}%
\qt@newcmd\qurantrans@en@liii{%
who reckon that they shall meet their Lord and that unto Him they are returning.\qt@no{46}}%
\qt@newcmd\qurantrans@en@liv{%
Children of Israel, remember My blessing wherewith I blessed you, and that I have preferred you above all beings;\qt@no{47}}%
\qt@newcmd\qurantrans@en@lv{%
and beware of a day when no soul for another shall give satisfaction, and no intercession shall be accepted from it, nor any counterpoise be taken, neither shall they be helped.\qt@no{48}}%
\qt@newcmd\qurantrans@en@lvi{%
And when We delivered you from the folk of Pharaoh who were visiting you with evil chastisement, slaughtering your sons, and sparing your women; and in that was a grievous trial from your Lord.\qt@no{49}}%
\qt@newcmd\qurantrans@en@lvii{%
And when We divided for you the sea and delivered you, and drowned Pharaoh's folk while you were beholding.\qt@no{50}}%
\qt@newcmd\qurantrans@en@lviii{%
And when We appointed with Moses forty nights then you took to yourselves the Calf after him and you were evildoers;\qt@no{51}}%
\qt@newcmd\qurantrans@en@lix{%
then We pardoned you after that, that haply you should be thankful.\qt@no{52}}%
\qt@newcmd\qurantrans@en@lx{%
And when We gave to Moses the Book and the Salvation, that haply you should be guided.\qt@no{53}}%
\qt@newcmd\qurantrans@en@lxi{%
And when Moses said to his people, 'My people, you have done wrong against yourselves by your taking the Calf; now turn to your Creator and slay one another. That will be better for you in your Creator's sight, and He will turn to you; truly He turns, and is All-compassionate.'\qt@no{54}}%
\qt@newcmd\qurantrans@en@lxii{%
And when you said, 'Moses, we will not believe thee till we see God openly'; and the thunderbolt took you while you were beholding.\qt@no{55}}%
\qt@newcmd\qurantrans@en@lxiii{%
Then We raised you up after you were dead, that haply you should be thankful.\qt@no{56}}%
\qt@newcmd\qurantrans@en@lxiv{%
And We outspread the cloud to overshadow you, and We sent down manna and quails upon you: 'Eat of the good things wherewith We have provided you. And they worked no wrong upon Us, but themselves they wronged.\qt@no{57}}%
\qt@newcmd\qurantrans@en@lxv{%
And when We said, 'Enter this township, and eat easefully of it wherever you will, and enter in at the gate, prostrating, and say, Unburdening; We will forgive you your transgressions, and increase the good-doers.'\qt@no{58}}%
\qt@newcmd\qurantrans@en@lxvi{%
Then the evildoers substituted a saying other than that which had been said to them; so We sent down upon the evildoers wrath out of heaven for their ungodliness.\qt@no{59}}%
\qt@newcmd\qurantrans@en@lxvii{%
And when Moses sought water for his people, so We said, 'Strike with thy staff the rock'; and there gushed forth from it twelve fountains; all the people knew now their drinking-place. 'Eat and drink of God's providing, and mischief not in the earth, doing corruption.'\qt@no{60}}%
\qt@newcmd\qurantrans@en@lxviii{%
And when you said, 'Moses, we will not endure one sort of food; pray to thy Lord for us, that He may bring forth for us of that the earth produces - green herbs, cucumbers, corn, lentils, onions.' He said, 'Would you have in exchange what is meaner for what is better? Get you down to Egypt; you shall have there that you demanded.' And abasement and poverty were pitched upon them, and they were laden with the burden of God's anger; that, because they had disbelieved the signs of God and slain the Prophets unrightfully; that, because they disobeyed, and were transgressors.\qt@no{61}}%
\qt@newcmd\qurantrans@en@lxix{%
Surely they that believe, and those of Jewry, and the Christians, and those Sabaeans, whoso believes in God and the Last Day, and works righteousness -- their wage awaits them with their Lord, and no fear shall be on them; neither shall they sorrow.\qt@no{62}}%
\qt@newcmd\qurantrans@en@lxx{%
And when We took compact with you, and raised above you the Mount: 'Take forcefully what We have given you, and remember what is in it; haply you shall be godfearing.'\qt@no{63}}%
\qt@newcmd\qurantrans@en@lxxi{%
Then you turned away thereafter, and but for the bounty and mercy of God towards you, you had been of the losers.\qt@no{64}}%
\qt@newcmd\qurantrans@en@lxxii{%
And well you know there were those among you that transgressed the Sabbath, and We said to them, 'Be you apes, miserably slinking!'\qt@no{65}}%
\qt@newcmd\qurantrans@en@lxxiii{%
And We made it a punishment exemplary for all the former times and for the latter, and an admonition to such as are godfearing.\qt@no{66}}%
\qt@newcmd\qurantrans@en@lxxiv{%
And when Moses said to his people, 'God commands you to sacrifice a cow.' They said, 'Dost thou take us in mockery?' He said, 'I take refuge with God, lest I should be one of the ignorant.'\qt@no{67}}%
\qt@newcmd\qurantrans@en@lxxv{%
They said, 'Pray to thy Lord for us, that He may make clear to us what she may be.' He said, 'He says she is a cow neither old, nor virgin, middling between the two; so do that you are bidden.'\qt@no{68}}%
\qt@newcmd\qurantrans@en@lxxvi{%
They said, 'Pray to thy Lord for us, that He make clear to us what her colour may be.' He said, 'He says she shall be a golden cow, bright her colour, gladdening the beholders.'\qt@no{69}}%
\qt@newcmd\qurantrans@en@lxxvii{%
They said, 'Pray to thy Lord for us, that He make clear to us what she may be; cows are much alike to us; and, if God will, we shall then be guided.'\qt@no{70}}%
\qt@newcmd\qurantrans@en@lxxviii{%
He said, 'He says she shall be a cow not broken to plough the earth or to water the tillage, one kept secure, with no blemish on her.' They said, 'Now thou hast brought the truth'; and therefore they sacrificed her, a thing they had scarcely done.\qt@no{71}}%
\qt@newcmd\qurantrans@en@lxxix{%
And when you killed a living soul, and disputed thereon -- and God disclosed what you were hiding --\qt@no{72}}%
\qt@newcmd\qurantrans@en@lxxx{%
so We said, 'Smite him with part of it'; even so God brings to life the dead, and He shows you His signs, that haply you may have understanding.\qt@no{73}}%
\qt@newcmd\qurantrans@en@lxxxi{%
Then your hearts became hardened thereafter and are like stones, or even yet harder; for there are stones from which rivers come gushing, and others split, so that water issues from them, and others crash down in the fear of God. And God is not heedless of the things you do.\qt@no{74}}%
\qt@newcmd\qurantrans@en@lxxxii{%
Are you then so eager that they should believe you, seeing there is a party of them that heard God's word, and then tampered with it, and that after they had comprehended it, wittingly?\qt@no{75}}%
\qt@newcmd\qurantrans@en@lxxxiii{%
And when they meet those who believe, they say 'We believe'; and when they go privily one to another, they say, 'Do you speak to them of what God has revealed to you, that they may thereby dispute with you before your Lord? Have you no understanding?'\qt@no{76}}%
\qt@newcmd\qurantrans@en@lxxxiv{%
Know they not that God knows what they keep secret and what they publish?\qt@no{77}}%
\qt@newcmd\qurantrans@en@lxxxv{%
And some there are of them that are common folk not knowing the Book, but only fancies and mere conjectures.\qt@no{78}}%
\qt@newcmd\qurantrans@en@lxxxvi{%
So woe to those who write the Book with their hands, then say, 'This is from God,' that they may sell it for a little price; so woe to them for what their hands have written, and woe to them for their earnings.\qt@no{79}}%
\qt@newcmd\qurantrans@en@lxxxvii{%
And they say, 'The Fire shall not touch us save a number of days.' Say: 'Have you taken with God a covenant? God will not fail in His covenant; or say you things against God of which you know nothing?\qt@no{80}}%
\qt@newcmd\qurantrans@en@lxxxviii{%
Not so; whoso earns evil, and is encompassed by his transgression -- those are the inhabitants of the Fire; there they shall dwell forever.\qt@no{81}}%
\qt@newcmd\qurantrans@en@lxxxix{%
And those that believe, and do deeds of righteousness -- those are the inhabitants of Paradise; there they shall dwell forever.'\qt@no{82}}%
\qt@newcmd\qurantrans@en@xc{%
And when We took compact with the Children of Israel: 'You shall not serve any save God; and to be good to parents, and the near kinsman, and to orphans, and to the needy; and speak good to men, and perform the prayer, and pay the alms.' Then you turned away, all but a few of you, swerving aside.\qt@no{83}}%
\qt@newcmd\qurantrans@en@xci{%
And when We took compact with you: 'You shall not shed your own blood, neither expel your own from your habitations'; then you confirmed it and yourselves bore witness.\qt@no{84}}%
\qt@newcmd\qurantrans@en@xcii{%
Then there you are killing one another, and expelling a party of you from their habitations, conspiring against them in sin and enmity; and if they come to you as captives, you ransom them; yet their expulsion was forbidden you. What, do you believe in part of the Book, and disbelieve in part? What shall be the recompense of those of you who do that, but degradation in the present life, and on the Day of Resurrection to be returned unto the most terrible of chastisement? And God is not heedless of the things you do.\qt@no{85}}%
\qt@newcmd\qurantrans@en@xciii{%
Those who have purchased the present life at the price of the world to come -- for them the chastisement shall not be lightened, neither shall they be helped.\qt@no{86}}%
\qt@newcmd\qurantrans@en@xciv{%
And We gave to Moses the Book, and after him sent succeeding Messengers; and We gave Jesus son of Mary the clear signs, and confirmed him with the Holy Spirit; and whensoever there came to you a Messenger with that your souls had not desire for, did you become arrogant, and some cry lies to, and some slay?\qt@no{87}}%
\qt@newcmd\qurantrans@en@xcv{%
And they say, 'Our hearts are uncircumcised.' Nay, but God has cursed them for their unbelief; little will they believe.\qt@no{88}}%
\qt@newcmd\qurantrans@en@xcvi{%
When there came to them a Book from God, confirming what was with them -- and they aforetimes prayed for victory over the unbelievers -- when there came to them that they recognized, they disbelieved in it; and the curse of God is on the unbelievers.\qt@no{89}}%
\qt@newcmd\qurantrans@en@xcvii{%
Evil is the thing they have sold themselves for, disbelieving in that which God sent down, grudging that God should send down of His bounty on whomsoever He will of His servants, and they were laden with anger upon anger; and for unbelievers awaits a humbling chastisement.\qt@no{90}}%
\qt@newcmd\qurantrans@en@xcviii{%
And when they were told, 'Believe in that God has sent down,' they said, 'We believe in what was sent down on us'; and they disbelieve in what is beyond that, yet it is the truth confirming what is with them. Say: 'Why then were you slaying the Prophets of God in former time, if you were believers?'\qt@no{91}}%
\qt@newcmd\qurantrans@en@xcix{%
And Moses came to you with the clear signs, then you took to yourselves the Calf after him and you were evildoers.\qt@no{92}}%
\qt@newcmd\qurantrans@en@c{%
And when We took compact with you, and raised over you the Mount: 'Take forcefully what We have given you and give ear.' They said, 'We hear, and rebel'; and they were made to drink the Calf in their hearts for their unbelief. Say: 'Evil is the thing your faith bids you to, if you are believers.'\qt@no{93}}%
\qt@newcmd\qurantrans@en@ci{%
Say: 'If the Last Abode with God is yours exclusively, and not for other people, then long for death -- if you speak truly.'\qt@no{94}}%
\qt@newcmd\qurantrans@en@cii{%
But they will never long for it, because of that their hands have forwarded; God knows the evildoers;\qt@no{95}}%
\qt@newcmd\qurantrans@en@ciii{%
and thou shalt find them the eagerest of men for life. And of the idolaters; there is one of them wishes if he might be spared a thousand years, yet his being spared alive shall not remove him from the chastisement. God sees the things they do.\qt@no{96}}%
\qt@newcmd\qurantrans@en@civ{%
Say: 'Whosoever is an enemy to Gabriel -- he it was that brought it down upon thy heart by the leave of God, confirming what was before it, and for a guidance and good tidings to the believers.\qt@no{97}}%
\qt@newcmd\qurantrans@en@cv{%
Whosoever is an enemy to God and His angels and His Messengers, and Gabriel, and Michael - surely God is an enemy to the unbelievers.'\qt@no{98}}%
\qt@newcmd\qurantrans@en@cvi{%
And We have sent down unto thee signs, clear signs, and none disbelieves in them except the ungodly.\qt@no{99}}%
\qt@newcmd\qurantrans@en@cvii{%
Why, whensoever they have made a covenant, does a party of them reject it? Nay, but the most of them are unbelievers.\qt@no{100}}%
\qt@newcmd\qurantrans@en@cviii{%
When there has come to them a Messenger from God confirming what was with them, a party of them that were given the Book reject the Book of God behind their backs, as though they knew not,\qt@no{101}}%
\qt@newcmd\qurantrans@en@cix{%
and they follow what the Satans recited over Solomon's kingdom. Solomon disbelieved not, but the Satans disbelieved, teaching the people sorcery, and that which was sent down upon Babylon's two angels, Harut and Marut; they taught not any man, without they said, 'We are but a temptation; do not disbelieve.' From them they learned how they might divide a man and his wife, yet they did not hurt any man thereby, save by the leave of God, and they learned what hurt them, and did not profit them, knowing well that whoso buys it shall have no share in the world to come; evil then was that they sold themselves for, if they had but known.\qt@no{102}}%
\qt@newcmd\qurantrans@en@cx{%
Yet had they believed, and been godfearing, a recompense from God had been better, if they had but known.\qt@no{103}}%
\qt@newcmd\qurantrans@en@cxi{%
O believers, do not say, 'Observe us,' but say, 'Regard us'; and give ear; for unbelievers awaits a painful chastisement.\qt@no{104}}%
\qt@newcmd\qurantrans@en@cxii{%
Those unbelievers of the People of the Book and the idolaters wish not that any good should be sent down upon you from your Lord; but God singles out for His mercy whom He will; God is of bounty abounding.\qt@no{105}}%
\qt@newcmd\qurantrans@en@cxiii{%
And for whatever verse We abrogate or cast into oblivion, We bring a better or the like of it; knowest thou not that God is powerful over everything?\qt@no{106}}%
\qt@newcmd\qurantrans@en@cxiv{%
Knowest thou not that to God belongs the kingdom of the heavens and the earth, and that you have none, apart from God, neither protector nor helper?\qt@no{107}}%
\qt@newcmd\qurantrans@en@cxv{%
Or do you desire to question your Messenger as Moses was questioned in former time? Whoso exchanges belief for unbelief has surely strayed from the right way.\qt@no{108}}%
\qt@newcmd\qurantrans@en@cxvi{%
Many of the People of the Book wish they might restore you as unbelievers, after you have believed, in the jealousy of their souls, after the truth has become clear to them; yet do you pardon and be forgiving, till God brings His command; truly God is powerful over everything.\qt@no{109}}%
\qt@newcmd\qurantrans@en@cxvii{%
And perform the prayer, and pay the alms; whatever good you shall forward to your souls' account, you shall find it with God; assuredly God sees the things you do.\qt@no{110}}%
\qt@newcmd\qurantrans@en@cxviii{%
And they say, 'None shall enter Paradise except that they be Jews or Christians.' Such are their fancies. Say: 'Produce your proof, if you speak truly.'\qt@no{111}}%
\qt@newcmd\qurantrans@en@cxix{%
Nay, but whosoever submits his will to God, being a good-doer, his wage is with his Lord, and no fear shall be on them, neither shall they sorrow.\qt@no{112}}%
\qt@newcmd\qurantrans@en@cxx{%
The Jews say, 'The Christians stand not on anything'; the Christians say, 'The Jews stand not on anything'; yet they recite the Book. So too the ignorant say the like of them. God shall decide between them on the Day of Resurrection touching their differences.\qt@no{113}}%
\qt@newcmd\qurantrans@en@cxxi{%
And who does greater evil than he who bars God's places of worship, so that His Name be not rehearsed in them, and strives to destroy them? Such men might never enter them, save in fear; for them is degradation in the present world, and in the world to come a mighty chastisement.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cxxii{%
To God belong the East and the West; whithersoever you turn, there is the Face of God; God is All-embracing, All-knowing.\qt@no{115}}%
\qt@newcmd\qurantrans@en@cxxiii{%
And they say, 'God has taken to Him a son. Glory be to Him! Nay, to Him belongs all that is in the heavens and the earth; all obey His will --\qt@no{116}}%
\qt@newcmd\qurantrans@en@cxxiv{%
the Creator of the heavens and the earth; and when He decrees a thing, He but says to it 'Be,' and it is.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cxxv{%
And they that know not say, 'Why does God not speak to us? Why does a sign not come to us?' So spoke those before them as these men say; their hearts are much alike. Yet We have made clear the signs unto a people who are sure\qt@no{118}}%
\qt@newcmd\qurantrans@en@cxxvi{%
We have sent thee with the truth, good tidings to bear, and warning. Thou shalt not be questioned touching the inhabitants of Hell.\qt@no{119}}%
\qt@newcmd\qurantrans@en@cxxvii{%
Never will the Jews be satisfied with thee, neither the Christians, not till thou followest their religion. Say: 'God's guidance is the true guidance.' If thou followest their caprices, after the knowledge that has come to thee, thou shalt have against God neither protector nor helper.\qt@no{120}}%
\qt@newcmd\qurantrans@en@cxxviii{%
Those to whom We have given the Book and who recite it with true recitation, they believe in it; and whoso disbelieves in it, they shall be the losers.\qt@no{121}}%
\qt@newcmd\qurantrans@en@cxxix{%
Children of Israel, remember My blessing wherewith I blessed you, and that I have preferred you above all beings;\qt@no{122}}%
\qt@newcmd\qurantrans@en@cxxx{%
and beware a day when no soul for another shall give satisfaction, and no counterpoise shall be accepted from it, nor any intercession shall be profitable to it, neither shall they be helped.\qt@no{123}}%
\qt@newcmd\qurantrans@en@cxxxi{%
And when his Lord tested Abraham with certain words, and he fulfilled them. He said, 'Behold, I make you a leader for the people.' Said he, 'And of my seed?' He said 'My covenant shall not reach the evildoers.'\qt@no{124}}%
\qt@newcmd\qurantrans@en@cxxxii{%
And when We appointed the House to be a place of visitation for the people, and a sanctuary, and: 'Take to yourselves Abraham's station for a place of prayer.' And We made covenant with Abraham and Ishmael: 'Purify My House for those that shall go about it and those that cleave to it, to those who bow and prostrate themselves.'\qt@no{125}}%
\qt@newcmd\qurantrans@en@cxxxiii{%
And when Abraham said, 'My Lord, make this a land secure, and provide its people with fruits, such of them as believe in God and the Last Day.' He said, 'And whoso disbelieves, to him I shall give enjoyment a little, then I shall compel him to the chastisement of the Fire -- how evil a homecoming!'\qt@no{126}}%
\qt@newcmd\qurantrans@en@cxxxiv{%
And when Abraham, and Ishmael with him, raised up the foundations of the House: 'Our Lord, receive this from us; Thou art the All-hearing, the All-knowing;\qt@no{127}}%
\qt@newcmd\qurantrans@en@cxxxv{%
and, our Lord, make us submissive to Thee, and of our seed a nation submissive to Thee; and show us our holy rites, and turn towards us; surely Thou turnest, and art All-compassionate;\qt@no{128}}%
\qt@newcmd\qurantrans@en@cxxxvi{%
and, our Lord, do Thou send among them a Messenger, one of them, who shall recite to them Thy signs, and teach them the Book and the Wisdom, and purify them; Thou art the All-mighty, the All-wise.'\qt@no{129}}%
\qt@newcmd\qurantrans@en@cxxxvii{%
Who therefore shrinks from the religion of Abraham, except he be foolish-minded? Indeed, We chose him in the present world, and in the world to come he shall be among the righteous.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cxxxviii{%
When his Lord said to him, 'Surrender,' he said, 'I have surrendered me to the Lord of all Being.'\qt@no{131}}%
\qt@newcmd\qurantrans@en@cxxxix{%
And Abraham charged his sons with this and Jacob likewise: 'My sons, God has chosen for you the religion; see that you die not save in surrender.'\qt@no{132}}%
\qt@newcmd\qurantrans@en@cxl{%
Why, were you witnesses, when death came to Jacob? When he said to his sons, 'What will you serve after me?' They said, 'We will serve thy God and the God of thy fathers Abraham, Ishmael and Isaac, One God; to Him we surrender.'\qt@no{133}}%
\qt@newcmd\qurantrans@en@cxli{%
That is a nation that has passed away; there awaits them that they have earned, and there awaits you that you have earned; you shall not be questioned concerning the things they did.\qt@no{134}}%
\qt@newcmd\qurantrans@en@cxlii{%
And they say, 'Be Jews or Christians and you shall be guided.' Say thou: 'Nay, rather the creed of Abraham, a man of pure faith; he was no idolater.'\qt@no{135}}%
\qt@newcmd\qurantrans@en@cxliii{%
Say you: 'We believe in God, and in that which has been sent down on us and sent down on Abraham, Ishmael, Isaac and Jacob, and the Tribes, and that which was given to Moses and Jesus and the Prophets, of their Lord; we make no division between any of them, and to Him we surrender.'\qt@no{136}}%
\qt@newcmd\qurantrans@en@cxliv{%
And if they believe in the like of that you believe in, then they are truly guided; but if they turn away, then they are clearly in schism; God will suffice you for them; He is the All-hearing, the All-knowing;\qt@no{137}}%
\qt@newcmd\qurantrans@en@cxlv{%
the baptism of God; and who is there that baptizes fairer than God? Him we are serving.\qt@no{138}}%
\qt@newcmd\qurantrans@en@cxlvi{%
Say: 'Would you then dispute with us concerning God, who is our Lord and your Lord? Our deeds belong to us, and to you belong your deeds; Him we serve sincerely.\qt@no{139}}%
\qt@newcmd\qurantrans@en@cxlvii{%
Or do you say, ``Abraham, Ishmael, Isaac and Jacob, and the Tribes -- they were Jews, or they were Christians"?' Say: 'Have you then greater knowledge, or God? And who does greater evil than he who conceals a testimony received from God? And God is not heedless of the things you do.'\qt@no{140}}%
\qt@newcmd\qurantrans@en@cxlviii{%
That is a nation that has passed away; there awaits them that they have earned, and there awaits you that you have earned; you shall not be questioned concerning the things they did.\qt@no{141}}%
\qt@newcmd\qurantrans@en@cxlix{%
The fools among the people will say, 'What has turned them from the direction they were facing in their prayers aforetime?' Say: ``To God belong the East and the West; He guides whomsoever He will to a straight path.'\qt@no{142}}%
\qt@newcmd\qurantrans@en@cl{%
Thus We appointed you a midmost nation that you might be witnesses to the people, and that the Messenger might be a witness to you; and We did not appoint the direction thou wast facing, except that We might know who followed the Messenger from him who turned on his heels -- though it were a grave thing save for those whom God has guided; but God would never leave your faith to waste - truly, God is All-gentle with the people, All-compassionate.\qt@no{143}}%
\qt@newcmd\qurantrans@en@cli{%
We have seen thee turning thy face about in the heaven; now We will surely turn thee to a direction that shall satisfy thee. Turn thy face towards the Holy Mosque; and wherever you are, turn your faces towards it. Those who have been given the Book know it is the truth from their Lord; God is not heedless of the things they do.\qt@no{144}}%
\qt@newcmd\qurantrans@en@clii{%
Yet if thou shouldst bring to those that have been given the Book every sign, they will not follow thy direction; thou art not a follower of their direction, neither are they followers of one another's direction. If thou followest their caprices, after the knowledge that has come to thee, then thou wilt surely be among the evildoers\qt@no{145}}%
\qt@newcmd\qurantrans@en@cliii{%
whom We have given the Book, and they recognize as they recognize their sons, even though there is a party of them conceal the truth and that wittingly.\qt@no{146}}%
\qt@newcmd\qurantrans@en@cliv{%
The truth comes from thy Lord; then be not among the doubters.\qt@no{147}}%
\qt@newcmd\qurantrans@en@clv{%
Every man has his direction to which he turns; so be you forward in good works. Wherever you may be, God will bring you all together; surely God is powerful over everything.\qt@no{148}}%
\qt@newcmd\qurantrans@en@clvi{%
From whatsoever place thou issuest, turn thy face towards the Holy Mosque; it is the truth from thy Lord. God is not heedless of the things you do.\qt@no{149}}%
\qt@newcmd\qurantrans@en@clvii{%
From whatsoever place thou issuest, turn thy face towards the Holy Mosque; and wherever you may be, turn your faces towards it, that the people may not have any argument against you, excepting the evildoers of them; and fear you them not, but fear you Me; and that I may perfect My blessing upon you, and that haply so you may be guided;\qt@no{150}}%
\qt@newcmd\qurantrans@en@clviii{%
as also We have sent among you, of yourselves, a Messenger, to recite Our signs to you and to purify you, and to teach you the Book and the Wisdom, and to teach you that you knew not.\qt@no{151}}%
\qt@newcmd\qurantrans@en@clix{%
So remember Me, and I will remember you; and be thankful to Me; and be you not ungrateful towards Me.\qt@no{152}}%
\qt@newcmd\qurantrans@en@clx{%
O all you who believe, seek you help in patience and prayer; surely God is with the patient.\qt@no{153}}%
\qt@newcmd\qurantrans@en@clxi{%
And say not of those slain in God's way, 'They are dead'; rather they are living, but you are not aware.\qt@no{154}}%
\qt@newcmd\qurantrans@en@clxii{%
Surely We will try you with something of fear and hunger, and diminution of goods and lives and fruits; yet give thou good tidings unto the patient\qt@no{155}}%
\qt@newcmd\qurantrans@en@clxiii{%
who, when they are visited by an affliction, say, 'Surely we belong to God, and to Him we return';\qt@no{156}}%
\qt@newcmd\qurantrans@en@clxiv{%
upon those rest blessings and mercy from their Lord, and those -- they are the truly guided.\qt@no{157}}%
\qt@newcmd\qurantrans@en@clxv{%
Safa and Marwa are among the waymarks of God; so whosoever makes the Pilgrimage to the House, or the Visitation, it is no fault in him to circumambulate them; and whoso volunteers good, God is All-grateful, All-knowing\qt@no{158}}%
\qt@newcmd\qurantrans@en@clxvi{%
Those who conceal the clear signs and the guidance that We have sent down, after We have shown them clearly in the Book -- they shall be cursed by God and the cursers,\qt@no{159}}%
\qt@newcmd\qurantrans@en@clxvii{%
save such as repent and make amends, and show clearly -- towards them I shall turn; I turn, All-compassionate.\qt@no{160}}%
\qt@newcmd\qurantrans@en@clxviii{%
But those who disbelieve, and die disbelieving -- upon them shall rest the curse of God and the angels, and of men altogether,\qt@no{161}}%
\qt@newcmd\qurantrans@en@clxix{%
therein dwelling forever; the chastisement shall not be lightened for them; no respite shall be given them.\qt@no{162}}%
\qt@newcmd\qurantrans@en@clxx{%
Your God is One God; there is no god but He, the All-merciful, the All-compassionate.\qt@no{163}}%
\qt@newcmd\qurantrans@en@clxxi{%
.. Surely in the creation of the heavens and the earth and the alternation of night and day and the ship that runs in the sea with profit to men, and the water God sends down from heaven therewith reviving the earth after it is dead and His scattering abroad in it all manner of crawling thing, and the turning about of the winds and the clouds compelled between heaven and earth -- surely there are signs for a people having understanding.\qt@no{164}}%
\qt@newcmd\qurantrans@en@clxxii{%
Yet there be men who take to themselves compeers apart from God, loving them as God is loved; but those that believe love God more ardently. O if the evildoers might see, when they see the chastisement, that the power altogether belongs to God, and that God is terrible in chastisement,\qt@no{165}}%
\qt@newcmd\qurantrans@en@clxxiii{%
when those that were followed disown their followers, and they see the chastisement, and their cords are cut asunder,\qt@no{166}}%
\qt@newcmd\qurantrans@en@clxxiv{%
and those that followed say, 'O if only we might return again and disown them, as they have disowned us!' Even so God shall show them their works. O bitter regrets for them! Never shall they issue from the Fire.\qt@no{167}}%
\qt@newcmd\qurantrans@en@clxxv{%
O men, eat of what is in the earth lawful and good; and follow not the steps of Satan; he is a manifest foe to you.\qt@no{168}}%
\qt@newcmd\qurantrans@en@clxxvi{%
He only commands you to evil and indecency, and that you should speak against God such things as you know not.\qt@no{169}}%
\qt@newcmd\qurantrans@en@clxxvii{%
And when it is said to them, 'Follow what God has sent down,' they say, 'No; but we will follow such things as we found our fathers doing.' What? And if their fathers had no understanding of anything, and if they were not guided?\qt@no{170}}%
\qt@newcmd\qurantrans@en@clxxviii{%
The likeness of those who disbelieve is as the likeness of one who shouts to that which hears nothing, save a call and a cry; deaf, dumb, blind -- they do not understand.\qt@no{171}}%
\qt@newcmd\qurantrans@en@clxxix{%
O believers, eat of the good things wherewith We have provided you, and give thanks to God, if it be Him that you serve.\qt@no{172}}%
\qt@newcmd\qurantrans@en@clxxx{%
These things only has He forbidden you: carrion, blood, the flesh of swine, what has been hollowed to other than God. Yet who so is constrained, not desiring nor transgressing, no sin shall be on him; God is All-forgiving, All-compassionate.\qt@no{173}}%
\qt@newcmd\qurantrans@en@clxxxi{%
Those who conceal what of the Book God has sent down on them, and sell it for a little price - they shall eat naught but the Fire in their bellies; God shall not speak to them on the Day of Resurrection neither purify them; there awaits them a painful chastisement.\qt@no{174}}%
\qt@newcmd\qurantrans@en@clxxxii{%
Those are they that have bought error at the price of guidance, and chastisement at the price of pardon; how patiently they shall endure the Fire!\qt@no{175}}%
\qt@newcmd\qurantrans@en@clxxxiii{%
That, because God has sent down the Book with the truth; and those that are at variance regarding the Book are in wide schism.\qt@no{176}}%
\qt@newcmd\qurantrans@en@clxxxiv{%
It is not piety, that you turn your faces to the East and to the West. True piety is this: to believe in God, and the Last Day, the angels, the Book, and the Prophets, to give of one's substance, however cherished, to kinsmen, and orphans, the needy, the traveller, beggars, and to ransom the slave, to perform the prayer, to pay the alms. And they who fulfil their covenant when they have engaged in a covenant, and endure with fortitude misfortune, hardship and peril, these are they who are true in their faith, these are the truly godfearing.\qt@no{177}}%
\qt@newcmd\qurantrans@en@clxxxv{%
O believers, prescribed for you is retaliation, touching the slain; freeman for freeman, slave for slave, female for female. But if aught is pardoned a man by his brother, let the pursuing be honourable, and let the payment be with kindliness. That is a lightening granted you by your Lord, and a mercy; and for him who commits aggression after that -- for him there awaits a painful chastisement.\qt@no{178}}%
\qt@newcmd\qurantrans@en@clxxxvi{%
In retaliation there is life for you, men possessed of minds; haply you will be godfearing.\qt@no{179}}%
\qt@newcmd\qurantrans@en@clxxxvii{%
Prescribed for you, when any of you is visited by death, and he leaves behind some goods, is to make testament in favour of his parents and kinsmen honourably -- an obligation on the godfearing.\qt@no{180}}%
\qt@newcmd\qurantrans@en@clxxxviii{%
Then if any man changes it after hearing it, the sin shall rest upon those who change it; surely God is All-hearing, All-knowing.\qt@no{181}}%
\qt@newcmd\qurantrans@en@clxxxix{%
But if any man fears injustice or sin from one making testament, and so makes things right between them, then sin shall not rest upon him; surely God is All-forgiving, All-compassionate.\qt@no{182}}%
\qt@newcmd\qurantrans@en@cxc{%
O believers, prescribed for you is the Fast, even as it was prescribed for those that were before you -- haply you will be godfearing --\qt@no{183}}%
\qt@newcmd\qurantrans@en@cxci{%
for days numbered; and if any of you be sick, or if he be on a journey, then a number of other days; and for those who are able to fast, a redemption by feeding a poor man. Yet better it is for him who volunteers good, and that you should fast is better for you, if you but know;\qt@no{184}}%
\qt@newcmd\qurantrans@en@cxcii{%
the month of Ramadan, wherein the Koran was sent down to be a guidance to the people, and as clear signs of the Guidance and the Salvation. So let those of you, who are present at the month, fast it; and if any of you be sick, or if he be on a journey, then a number of other days; God desires ease for you, and desires not hardship for you; and that you fulfil the number, and magnify God that He has guided you, and haply you will be thankful.\qt@no{185}}%
\qt@newcmd\qurantrans@en@cxciii{%
And when My servants question thee concerning Me -- I am near to answer the call of the caller, when he calls to Me; so let them respond to Me, and let them believe in Me; haply so they will go aright.\qt@no{186}}%
\qt@newcmd\qurantrans@en@cxciv{%
Permitted to you, upon the night of the Fast, is to go in to your wives; -- they are a vestment for you, and you are a vestment for them. God knows that you have been betraying yourselves, and has turned to you and pardoned you. So now lie with them, and seek what God has prescribed for you. And eat and drink, until the white thread shows clearly to you from the black thread at the dawn; then complete the Fast unto the night, and do not lie with them while you cleave to the mosques. Those are God's bounds; keep well within them. So God makes clear His signs to men; haply they will be godfearing.\qt@no{187}}%
\qt@newcmd\qurantrans@en@cxcv{%
Consume not your goods between you in vanity; neither proffer it to the judges, that you may sinfully consume a portion of other men's goods, and that wittingly.\qt@no{188}}%
\qt@newcmd\qurantrans@en@cxcvi{%
They will question thee concerning the new moons. Say: 'They are appointed times for the people, and the Pilgrimage.' It is not piety to come to the houses from the backs of them; but piety is to be godfearing; so come to the houses by their doors, and fear God; haply so you will prosper.\qt@no{189}}%
\qt@newcmd\qurantrans@en@cxcvii{%
And fight in the way of God with those; who fight with you, but aggress not: God loves not the aggressors.\qt@no{190}}%
\qt@newcmd\qurantrans@en@cxcviii{%
And slay them wherever you come upon them, and expel them from where they expelled you; persecution is more grievous than slaying. But fight them not by the Holy Mosque until they should fight you there; then, if they fight you, slay them -- such is the recompense of unbelievers --\qt@no{191}}%
\qt@newcmd\qurantrans@en@cxcix{%
but if they give over, surely God is All-forgiving, All-compassionate.\qt@no{192}}%
\qt@newcmd\qurantrans@en@cc{%
Fight them, till there is no persecution and the religion is God's; then if they give over, there shall be no enmity save for evildoers.\qt@no{193}}%
\qt@newcmd\qurantrans@en@cci{%
The holy month for the holy month; holy things demand retaliation. Whoso commits aggression against you, do you commit aggression against him like as he has committed against you, and fear you God, and know that God is with the godfearing.\qt@no{194}}%
\qt@newcmd\qurantrans@en@ccii{%
And expend in the way of God; and cast not yourselves by your own hands into destruction, but be good-doers; God loves the good-doers.\qt@no{195}}%
\qt@newcmd\qurantrans@en@cciii{%
Fulfil the Pilgrimage and the Visitation unto God; but if you are prevented, then such offering as may be feasible. And shave not your heads, till the offering reaches its place of sacrifice. If any of you is sick, or injured in his head, then redemption by fast, or freewill offering, or ritual sacrifice. When you are secure, then whosoever enjoys the Visitation until the Pilgrimage, let his offering be such as may be feasible; or if he finds none, then a fast of three days in the Pilgrimage, and of seven when you return, that is ten completely; that is for him whose family are not present at the Holy Mosque. And fear God, and know that God is terrible in retribution.\qt@no{196}}%
\qt@newcmd\qurantrans@en@cciv{%
The Pilgrimage is in months well-known; whoso undertakes the duty of Pilgrimage in them shall not go in to his womenfolk nor indulge in ungodliness and disputing in the Pilgrimage. Whatever good you do, God knows it. And take provision; but the best provision is godfearing, so fear you Me, men possessed of minds!\qt@no{197}}%
\qt@newcmd\qurantrans@en@ccv{%
It is no fault in you, that you should seek bounty from your Lord; but when you press on from Arafat, then remember God at the Holy Waymark, and remember Him as He has guided you, though formerly you were gone astray.\qt@no{198}}%
\qt@newcmd\qurantrans@en@ccvi{%
Then press on from where the people press on, and pray for God's forgiveness; God is All-forgiving, All-compassionate.\qt@no{199}}%
\qt@newcmd\qurantrans@en@ccvii{%
And when you have performed your holy rites remember God, as you remember your fathers or yet more devoutly. Now some men there are who say, 'Our Lord, give to us in this world'; such men shall have no part in the world to come.\qt@no{200}}%
\qt@newcmd\qurantrans@en@ccviii{%
And others there are who say, 'Our Lord, give to us in this world good, and good in the world to come, and guard us against the chastisement of the fire';\qt@no{201}}%
\qt@newcmd\qurantrans@en@ccix{%
those -- they shall have a portion from what they have earned; and God is swift at the reckoning.\qt@no{202}}%
\qt@newcmd\qurantrans@en@ccx{%
And remember God during certain days numbered. If any man hastens on in two days, that is no sin in him; and if any delays, it is not a sin in him, if he be godfearing. And fear you God, and know that unto Him you shall be mustered.\qt@no{203}}%
\qt@newcmd\qurantrans@en@ccxi{%
And some men there are whose saying upon the present world pleases thee, and such a one calls on God to witness what is in his heart, yet he is most stubborn in altercation,\qt@no{204}}%
\qt@newcmd\qurantrans@en@ccxii{%
and when he turns his back, he hastens about the earth, to do corruption there and to destroy the tillage and the stock; and God loves not corruption;\qt@no{205}}%
\qt@newcmd\qurantrans@en@ccxiii{%
and when it is said to him, 'Fear God', vainglory seizes him in his sin. So Gehenna shall be enough for him -- how evil a cradling!\qt@no{206}}%
\qt@newcmd\qurantrans@en@ccxiv{%
But other men there are that sell themselves desiring God's good pleasure; and God is gentle with His servants.\qt@no{207}}%
\qt@newcmd\qurantrans@en@ccxv{%
O believers, enter the peace, all of you, and follow not the steps of Satan; he is a manifest foe to you.\qt@no{208}}%
\qt@newcmd\qurantrans@en@ccxvi{%
But if you slip, after the clear signs have come to you, know then that God is All-mighty, All-wise.\qt@no{209}}%
\qt@newcmd\qurantrans@en@ccxvii{%
What do they look for, but that God shall come to them in the cloud -- shadows, and the angels? The matter is determined, and unto God all matters are returned.\qt@no{210}}%
\qt@newcmd\qurantrans@en@ccxviii{%
Ask the Children of Israel how many a clear sign We gave them. Whoso changes God's blessing after it has come to him, God is terrible in retribution.\qt@no{211}}%
\qt@newcmd\qurantrans@en@ccxix{%
Decked out fair to the unbelievers is the present life, and they deride the believers; but those who were godfearing shall be above them on the Resurrection Day; and God provides whomsoever He will without reckoning.\qt@no{212}}%
\qt@newcmd\qurantrans@en@ccxx{%
The people were one nation; then God sent forth the Prophets, good tidings to bear and warning, and He sent down with them the Book with the truth, that He might decide between the people touching their differences; and only those who had been given it were at variance upon it, after the clear signs had come to them, being insolent one to another; then God guided those who believed to the truth, touching which they were at variance, by His leave; and God guides whomsoever He will to a straight path.\qt@no{213}}%
\qt@newcmd\qurantrans@en@ccxxi{%
Or did you suppose you should enter Paradise without there had come upon you the like of those who passed away before you? They were afflicted by misery and hardship and were so convulsed, that the Messenger and those who believed with him said, 'When comes God's help?' Ah, but surely God's help is nigh.\qt@no{214}}%
\qt@newcmd\qurantrans@en@ccxxii{%
They will question thee concerning what they should expend. Say: 'Whatsoever good you expend is for parents and kinsmen, orphans, the needy, and the traveller; and whatever good you may do, God has knowledge of it.'\qt@no{215}}%
\qt@newcmd\qurantrans@en@ccxxiii{%
Prescribed for you is fighting, though it be hateful to you. Yet it may happen that you will hate a thing which is better for you; and it may happen that you will love a thing which is worse for you; God knows, and you know not.\qt@no{216}}%
\qt@newcmd\qurantrans@en@ccxxiv{%
They will question thee concerning the holy month, and fighting in it. Say: 'Fighting in it is a heinous thing, but to bar from God's way, and disbelief in Him, and the Holy Mosque, and to expel its people from it -- that is more heinous in God's sight; and persecution is more heinous than slaying.' They will not cease to fight with you, till they turn you from your religion, if they are able; and whosoever of you turns from his religion, and dies disbelieving -- their works have failed in this world and the next; those are the inhabitants of the Fire; therein they shall dwell forever.\qt@no{217}}%
\qt@newcmd\qurantrans@en@ccxxv{%
But the believers, and those who emigrate and struggle in God's way -- those have hope of God's compassion; and God is All-forgiving, All-compassionate.\qt@no{218}}%
\qt@newcmd\qurantrans@en@ccxxvi{%
They will question thee concerning wine, and arrow-shuffling. Say: 'In both is heinous sin; and uses for men, but the sin in them is more heinous than the usefulness.' They will question thee concerning what they should expend. Say: 'The abundance.' So God makes clear His signs to you; haply you will reflect;\qt@no{219}}%
\qt@newcmd\qurantrans@en@ccxxvii{%
in this world, and the world to come. They will question thee concerning the orphans. Say: 'To set their affairs aright is good. And if you intermix with them, they are your brothers. God knows well him who works corruption from him who sets aright; and had He willed He would have harassed you. Surely God is All-mighty, All-wise.'\qt@no{220}}%
\qt@newcmd\qurantrans@en@ccxxviii{%
Do not marry idolatresses, until they believe; a believing slavegirl is better than an idolatress, though you may admire her. And do not marry idolaters, until they believe. A believing slave is better than an idolater, though you may admire him. Those call unto the Fire; and God calls unto Paradise, and pardon, by His leave, and He makes clear His signs to the people; haply they will remember.\qt@no{221}}%
\qt@newcmd\qurantrans@en@ccxxix{%
They will question thee concerning the monthly course. Say: 'It is hurt; so go apart from women during the monthly course, and do not approach them till they are clean. When they have cleansed themselves, then come unto them as God has commanded you.' Truly, God loves those who repent, and He loves those who cleanse themselves.\qt@no{222}}%
\qt@newcmd\qurantrans@en@ccxxx{%
Your women are a tillage for you; so come unto your tillage as you wish, and forward for your souls; and fear God, and know that you shall meet Him. Give thou good tidings to the believers.\qt@no{223}}%
\qt@newcmd\qurantrans@en@ccxxxi{%
Do not make God a hindrance, through your oaths, to being pious and godfearing, and putting things right between men. Surely God is All-hearing, All-knowing.\qt@no{224}}%
\qt@newcmd\qurantrans@en@ccxxxii{%
God will not take you to task for a slip in your oaths; but He will take you to task for what your hearts have earned; and God is All-forgiving, All-clement.\qt@no{225}}%
\qt@newcmd\qurantrans@en@ccxxxiii{%
For those who forswear their women a wait of four months; if they revert, God is All-forgiving, All-compassionate;\qt@no{226}}%
\qt@newcmd\qurantrans@en@ccxxxiv{%
but if they resolve on divorce, surely God is All-hearing, All-knowing.\qt@no{227}}%
\qt@newcmd\qurantrans@en@ccxxxv{%
Divorced women shall wait by themselves for three periods; and it is not lawful for them to hide what God has created in their wombs; if they believe in God and the Last Day. In such time their mates have better right to restore them, if they desire to set things right. Women have such honourable rights as obligations, but their men have a degree above them; God is All-mighty, All-wise.\qt@no{228}}%
\qt@newcmd\qurantrans@en@ccxxxvi{%
Divorce is twice; then honourable retention or setting free kindly. It is not lawful for you to take of what you have given them unless the couple fear they may not maintain God's bounds; if you fear they may not maintain God's bounds, it is no fault in them for her to redeem herself. Those are God's bounds; do not transgress them. Whosoever transgresses the bounds of God -- those are the evildoers.\qt@no{229}}%
\qt@newcmd\qurantrans@en@ccxxxvii{%
If he divorces her finally, she shall not be lawful to him after that, until she marries another husband. If he divorces her, then it is no fault in them to return to each other, if they suppose that they will maintain God's bounds. Those are God's bounds; He makes them clear unto a people that have knowledge.\qt@no{230}}%
\qt@newcmd\qurantrans@en@ccxxxviii{%
When you divorce women, and they have reached their term, then retain them honourably or set them free honourably; do not retain them by force, to transgress; whoever does that has wronged himself. Take not God's signs in mockery, and remember God's blessing upon you, and the Book and the Wisdom He has sent down on you, to admonish you. And fear God, and know that God has knowledge of everything.\qt@no{231}}%
\qt@newcmd\qurantrans@en@ccxxxix{%
When you divorce women, and they have reached their term, do not debar them from marrying their husbands, when they have agreed together honourably. That is an admonition for whoso of you believes in God and the Last Day; that is cleaner and purer for you; God knows, and you know not.\qt@no{232}}%
\qt@newcmd\qurantrans@en@ccxl{%
Mothers shall suckle their children two years completely, for such as desire to fulfil the suckling. It is for the father to provide them and clothe them honourably. No soul is charged save to its capacity; a mother shall not be pressed for her child, neither a father for his child. The heir has a like duty. But if the couple desire by mutual consent and consultation to wean, then it is no fault in them. And if you desire to seek nursing for your children, it is no fault in you provide you hand over what you have given honourably; and fear God, and know that God sees the things you do.\qt@no{233}}%
\qt@newcmd\qurantrans@en@ccxli{%
And those of you who die, leaving wives, they shall wait by themselves for four months and ten nights; when they have reached their term then it is no fault in you what they may do with themselves honourably. God is aware of the things you do.\qt@no{234}}%
\qt@newcmd\qurantrans@en@ccxlii{%
There is no fault in you touching the proposal to women you offer, or hide in your hearts; God knows that you will be mindful of them; but do not make troth with them secretly without you speak honourable words. And do not resolve on the knot of marriage until the book has reached its term; and know that God knows what is in your hearts, so be fearful of Him; and know that God is All-forgiving, All-clement.\qt@no{235}}%
\qt@newcmd\qurantrans@en@ccxliii{%
There is no fault in you, if you divorce women while as yet you have not touched them nor appointed any marriage-portion for them; yet make provision for them, the affluent man according to his means, and according to his means the needy man, honourably -- an obligation on the good-doers.\qt@no{236}}%
\qt@newcmd\qurantrans@en@ccxliv{%
And if you divorce them before you have touched them, and you have already appointed for them a marriage-portion, then one-half of what you have appointed, unless it be they make remission, or he makes remission in whose hand is the knot of marriage; yet that you should remit is nearer to godfearing. Forget not to be bountiful one towards another. Surely God sees the things you do.\qt@no{237}}%
\qt@newcmd\qurantrans@en@ccxlv{%
Be you watchful over the prayers, and the middle prayer; and do you stand obedient to God.\qt@no{238}}%
\qt@newcmd\qurantrans@en@ccxlvi{%
And if you are in fear, then afoot or mounted; but when you are secure, then remember God, as He taught you the things that you knew not.\qt@no{239}}%
\qt@newcmd\qurantrans@en@ccxlvii{%
And those of you who die, leaving wives, let them make testament for their wives, provision for a year without expulsion; but if they go forth, there is no fault in you what they may do with themselves honourably; God is All-mighty, All-wise.\qt@no{240}}%
\qt@newcmd\qurantrans@en@ccxlviii{%
There shall be for divorced women provision honourable -- an obligation on the godfearing.\qt@no{241}}%
\qt@newcmd\qurantrans@en@ccxlix{%
So God makes clear His signs for you; haply you will understand.\qt@no{242}}%
\qt@newcmd\qurantrans@en@ccl{%
Hast thou not regarded those who went forth from their habitations in their thousands fearful of death? God said to them, 'Die!' Then He gave them life. Truly God is bounteous to the people, but most of the people are not thankful.\qt@no{243}}%
\qt@newcmd\qurantrans@en@ccli{%
So fight in God's way, and know that God is All-hearing, All-knowing.\qt@no{244}}%
\qt@newcmd\qurantrans@en@cclii{%
Who is he that will lend God a good loan, and He will multiply it for him manifold? God grasps, and outspreads; and unto Him you shall be returned.\qt@no{245}}%
\qt@newcmd\qurantrans@en@ccliii{%
Hast thou not regarded the Council of the Children of Israel, after Moses, when they said to a Prophet of theirs, 'Raise up for us a king, and we will fight in God's way.' He said, 'Might it be that, if fighting is prescribed for you, you will not fight?' They said, 'Why should we not fight in God's way, who have been expelled from our habitations and our children?' Yet when fighting was prescribed for them, they turned their backs except a few of them; and God has knowledge of the evildoers.\qt@no{246}}%
\qt@newcmd\qurantrans@en@ccliv{%
Then their Prophet said to them, 'Verily God has raised up Saul for you as king.' They said, 'How should he be king over us who have better right than he to kingship, seeing he has not been given amplitude of wealth?' He said, 'God has chosen him over you, and has increased him broadly in knowledge and body. God gives the kingship to whom He will; and God is All-embracing, All-knowing.'\qt@no{247}}%
\qt@newcmd\qurantrans@en@cclv{%
And their Prophet said to them, 'The sign of his kingship is that the Ark will come to you, in it a Shechina from your Lord, and a remnant of what the folk of Moses and Aaron's folk left behind, the angels bearing it. Surely in that shall be a sign for you, if you are believers.'\qt@no{248}}%
\qt@newcmd\qurantrans@en@cclvi{%
And when Saul went forth with the hosts he said, 'God will try you with a river; whosoever drinks of it is not of me, and whoso tastes it flot, he is of me, saving him who scoops up with his hand.' But they drank of it, except a few of them; and when he crossed it, and those who believed with him, they said, 'We have no power today against Goliath and his hosts.' Said those who reckoned they should meet God, 'How often a little company has overcome a numerous company, by God's leave! And God is with the patient.'\qt@no{249}}%
\qt@newcmd\qurantrans@en@cclvii{%
So, when they went forth against Goliath and his hosts, they said, 'Our Lord, pour out upon us patience, and make firm our feet, and give us aid against the people of the unbelievers!'\qt@no{250}}%
\qt@newcmd\qurantrans@en@cclviii{%
And they routed them, by the leave of God, and David slew Goliath; and God gave him the kingship, and Wisdom, and He taught him such as He willed. Had God not driven back the people, some by the means of others, the earth had surely corrupted; but God is bounteous unto all beings.\qt@no{251}}%
\qt@newcmd\qurantrans@en@cclix{%
These are the signs of God We recite to thee in truth, and assuredly thou art of the number of the Envoys.\qt@no{252}}%
\qt@newcmd\qurantrans@en@cclx{%
And those Messengers, some We have preferred above others; some there are to whom God spoke, and some He raised in rank. And We gave Jesus son of Mary the clear signs, and confirmed him with the Holy Spirit. And had God willed, those who came after him would not have fought one against the other after the clear signs had come to them; but they fell into variance, and some of them believed, and some disbelieved; and had God willed they would not have fought one against the other; but God does whatsoever He desires.\qt@no{253}}%
\qt@newcmd\qurantrans@en@cclxi{%
O believers, expend of that wherewith We have provided you, before there comes a day wherein shall be neither traffick, nor friendship, nor intercession; and the unbelievers -- they are the evildoers.\qt@no{254}}%
\qt@newcmd\qurantrans@en@cclxii{%
God there is no god but He, the Living, the Everlasting. Slumber seizes Him not, neither sleep; to Him belongs all that is in the heavens and the earth. Who is there that shall intercede with Him save by His leave? He knows what lies before them and what is after them, and they comprehend not anything of His knowledge save such as He wills. His Throne comprises the heavens and earth; the preserving of them oppresses Him not; He is the All-high, the All-glorious.\qt@no{255}}%
\qt@newcmd\qurantrans@en@cclxiii{%
No compulsion is there in religion. Rectitude has become clear from error. So whosoever disbelieves in idols and believes in God, has laid hold of the most firm handle, unbreaking; God is All-hearing, All-knowing.\qt@no{256}}%
\qt@newcmd\qurantrans@en@cclxiv{%
God is the Protector of the believers; He brings them forth from the shadows into the light. And the unbelievers -- their protectors are idols, that bring them forth from the light into the shadows; those are the inhabitants of the Fire, therein dwelling forever.\qt@no{257}}%
\qt@newcmd\qurantrans@en@cclxv{%
Hast thou not regarded him who disputed with Abraham, concerning his Lord, that God had given him the kingship? When Abraham said, 'My Lord is He who gives life, and makes to die,' he said, 'I give life, and make to die.' Said Abraham, 'God brings the sun from the east; so bring thou it from the west.' Then the unbeliever was confounded. God guides not the people of the evildoers.\qt@no{258}}%
\qt@newcmd\qurantrans@en@cclxvi{%
Or such as he who passed by a city that was fallen down upon its turrets; he said, 'How shall God give life to this now it is dead?' So God made him die a hundred years, then He raised him up, saying, 'How long hast thou tarried?' He said, 'I have tarried a day, or part of a day.' Said He, 'Nay; thou hast tarried a hundred years. Look at thy food and drink -- it has not spoiled; and look at thy ass. So We would make thee a sign for the people. And look at the bones; how We shall set them up, and then clothe them with flesh.' So, when it was made clear to him, he said, 'I know that God is powerful over everything.'\qt@no{259}}%
\qt@newcmd\qurantrans@en@cclxvii{%
And when Abraham said, 'My Lord, show me how Thou wilt give life to the dead,' He said, 'Why, dost thou not believe?' 'Yes,' he said, 'but that my heart may be at rest.' Said He, 'Take four birds, and twist them to thee, then set a part of them on every hill, then summon them, and they will come to thee running. And do thou know that God is All-mighty, All-wise.'\qt@no{260}}%
\qt@newcmd\qurantrans@en@cclxviii{%
The likeness of those who expend their wealth in the way of God is as the likeness of a grain of corn that sprouts seven ears, in every ear a hundred grains. So God multiplies unto whom He will; God is All-embracing, All-knowing.\qt@no{261}}%
\qt@newcmd\qurantrans@en@cclxix{%
Those who expend their wealth in the way of God then follow not up what they have expended with reproach and injury, their wage is with their Lord, and no fear shall be on them, neither shall they sorrow.\qt@no{262}}%
\qt@newcmd\qurantrans@en@cclxx{%
Honourable words, and forgiveness, are better than a freewill offering followed by injury; and God is All-sufficient, All-clement.\qt@no{263}}%
\qt@newcmd\qurantrans@en@cclxxi{%
O believers, void not your freewill offerings with reproach and injury, as one who expends of his substance to show off to men and believes not in God and the Last Day. The likeness of him is as the likeness of a smooth rock on which is soil, and a torrent smites it, and leaves it barren. They have no power over anything that they have earned. God guides not the people of the unbelievers.\qt@no{264}}%
\qt@newcmd\qurantrans@en@cclxxii{%
But the likeness of those who expend their wealth, seeking God's good pleasure, and to confirm themselves, is as the likeness of a garden upon a hill; a torrent smites it and it yields its produce twofold; if no torrent smites it, yet dew; and God sees the things you do.\qt@no{265}}%
\qt@newcmd\qurantrans@en@cclxxiii{%
Would any of you wish to have a garden of palms and vines, with rivers flowing beneath it, and all manner of fruit there for him, then old age smites him, and he has seed, but weaklings, then a whirlwind with fire smites it, and it is consumed? So God makes clear the signs to you; haply you will reflect.\qt@no{266}}%
\qt@newcmd\qurantrans@en@cclxxiv{%
O believers, expend of the good things you have earned, and of that We have produced for you from the earth, and intend not the corrupt of it for your expending; for you would never take it yourselves, except you closed an eye on it; and know that God is All-sufficient, All-laudable.\qt@no{267}}%
\qt@newcmd\qurantrans@en@cclxxv{%
Satan promises you poverty, and bids you unto indecency; but God promises you His pardon and His bounty; and God is All-embracing, All-knowing.\qt@no{268}}%
\qt@newcmd\qurantrans@en@cclxxvi{%
He gives the Wisdom to whomsoever He will, and whoso is given the Wisdom, has been given much good; yet none remembers but men possessed of minds.\qt@no{269}}%
\qt@newcmd\qurantrans@en@cclxxvii{%
And whatever expenditure you expend, and whatever vow you vow, surely God knows it. No helpers have the evildoers.\qt@no{270}}%
\qt@newcmd\qurantrans@en@cclxxviii{%
If you publish your freewill offerings, it is excellent; but if you conceal them, and give them to the poor, that is better for you, and will acquit you of your evil deeds; God is aware of the things you do.\qt@no{271}}%
\qt@newcmd\qurantrans@en@cclxxix{%
Thou art not responsible for guiding them; but God guides whomsoever He will. And whatever good you expend is for yourselves, for then you are expending, being desirous only of God's Face; and whatever good you expend shall be repaid to you in full, and you will not be wronged,\qt@no{272}}%
\qt@newcmd\qurantrans@en@cclxxx{%
it being for the poor who are restrained in the way of God, and are unable to journey in the land; the ignorant man supposes them rich because of their abstinence, but thou shalt know them by their mark -- they do not beg of men importunately. And whatever good you expend, surely God has knowledge of it.\qt@no{273}}%
\qt@newcmd\qurantrans@en@cclxxxi{%
Those who expend their wealth night and day, secretly and in public, their wage awaits them with their Lord, and no fear shall be on them, neither shall they sorrow.\qt@no{274}}%
\qt@newcmd\qurantrans@en@cclxxxii{%
Those who devour usury shall not rise again except as he rises, whom Satan of the touch prostrates; that is because they say, 'Trafficking (trade) is like usury.' God has permitted trafficking, and forbidden usury. Whosoever receives an admonition from his Lord and gives over, he shall have his past gains, and his affair is committed to God; but whosoever reverts -- those are the inhabitants of the Fire, therein dwelling forever.\qt@no{275}}%
\qt@newcmd\qurantrans@en@cclxxxiii{%
God blots out usury, but freewill offerings He augments with interest. God loves not any guilty ingrate.\qt@no{276}}%
\qt@newcmd\qurantrans@en@cclxxxiv{%
Those who believe and do deeds of righteousness, and perform the prayer, and pay the alms -- their wage awaits them with their Lord, and no fear shall be on them, neither shall they sorrow.\qt@no{277}}%
\qt@newcmd\qurantrans@en@cclxxxv{%
O believers, fear you God; and give up the usury that is outstanding, if you are believers.\qt@no{278}}%
\qt@newcmd\qurantrans@en@cclxxxvi{%
But if you do not, then take notice that God shall war with you, and His Messenger; yet if you repent, you shall have your principal, unwronging and unwronged.\qt@no{279}}%
\qt@newcmd\qurantrans@en@cclxxxvii{%
And if any man should be in difficulties, let him have respite till things are easier; but that you should give freewill offerings is better for you, did you but know.\qt@no{280}}%
\qt@newcmd\qurantrans@en@cclxxxviii{%
And fear a day wherein you shall be returned to God, and every soul shall be paid in full what it has earned; and they shall not be wronged.\qt@no{281}}%
\qt@newcmd\qurantrans@en@cclxxxix{%
O believers, when you contract a debt one upon another for a stated term, write it down, and let a writer write it down between you justly, and let not any writer refuse to write it down, as God has taught him; so let him write, and let the debtor dictate, and let him fear God his Lord and not diminish aught of it. And if the debtor be a fool, or weak, or unable to dictate himself, then let his guardian dictate justly. And call in to witness two witnesses, men; or if the two be not men, then one man and two women, such witnesses as you approve of, that if one of the two women errs the other will remind her; and let the witnesses not refuse, whenever they are summoned. And be not loth to write it down, whether it be small or great, with its term; that is more equitable in God's sight, more upright for testimony, and likelier that you will not be in doubt. Unless it be merchandise present that you give and take between you; then it shall be no fault in you if you do not write it down. And take witnesses when you are trafficking one with another. And let not either writer or witness be pressed; or if you do, that is ungodliness in you. And fear God; God teaches you, and God has knowledge of everything.\qt@no{282}}%
\qt@newcmd\qurantrans@en@ccxc{%
And if you are upon a journey, and you do not find a writer, then a pledge in hand. But if one of you trusts another, let him who is trusted deliver his trust, and let him fear God his Lord. And do not conceal the testimony; whoso conceals it, his heart is sinful; and God has knowledge of the things you do.\qt@no{283}}%
\qt@newcmd\qurantrans@en@ccxci{%
To God belongs all that is in the heavers and earth. Whether you publish what is in your hearts or hide it, God shall make reckoning with you for it. He will forgive whom He will, and chastise whom He will; God is powerful over everything.\qt@no{284}}%
\qt@newcmd\qurantrans@en@ccxcii{%
The Messenger believes in what was sent down to him from his Lord, and the believers; each one believes in God and His angels, and in His Books and His Messengers; we make no division between any one of His Messengers. They say, 'We hear, and obey. Our Lord, grant us Thy forgiveness; unto Thee is the homecoming.'\qt@no{285}}%
\qt@newcmd\qurantrans@en@ccxciii{%
God charges no soul save to its capacity; standing to its account is what it has earned, and against its account what it has merited. Our Lord, take us not to task if we forget, or make mistake. Our Lord; charge us not with a load such as Thou didst lay upon those before us. Our Lord, do Thou not burden us beyond what we have the strength to bear. And pardon us, and forgive us, and have mercy on us; Thou art our Protector. And help us against the people of the unbelievers.\qt@no{286}}%
\qt@newcmd\qurantrans@en@ccxciv{%
\basmalahen Alif Lam Mim\qt@no{1}}%
\qt@newcmd\qurantrans@en@ccxcv{%
God, there is no god but He, the Living, the Everlasting.\qt@no{2}}%
\qt@newcmd\qurantrans@en@ccxcvi{%
He has sent down upon thee the Book with the truth, confirming what was before it, and He sent down the Torah and the Gospel\qt@no{3}}%
\qt@newcmd\qurantrans@en@ccxcvii{%
aforetime, as guidance to the people, and He sent down the Salvation. As for those who disbelieve in God's signs, for them awaits a terrible chastisement; God is All-mighty, Vengeful.\qt@no{4}}%
\qt@newcmd\qurantrans@en@ccxcviii{%
From God nothing whatever is hidden in heaven and earth.\qt@no{5}}%
\qt@newcmd\qurantrans@en@ccxcix{%
It is He who forms you in the womb as He will. There is no god but He, the All-mighty, the All-wise.\qt@no{6}}%
\qt@newcmd\qurantrans@en@ccc{%
It is He who sent down upon thee the Book, wherein are verses clear that are the Essence of the Book, and others ambiguous. As for those in whose hearts is swerving, they follow the ambiguous part, desiring dissension, and desiring its interpretation; and none knows its interpretation, save only God. And those firmly rooted in knowledge say, 'We believe in it; all is from our Lord'; yet none remembers, but men possessed of minds.\qt@no{7}}%
\qt@newcmd\qurantrans@en@ccci{%
Our Lord, make not our hearts to swerve after that Thou hast guided us; and give us mercy from Thee; Thou art the Giver.\qt@no{8}}%
\qt@newcmd\qurantrans@en@cccii{%
Our Lord, it is Thou that shall gather mankind for a day whereon is no doubt; verily God will not fail the tryst.\qt@no{9}}%
\qt@newcmd\qurantrans@en@ccciii{%
As for the unbelievers, their riches will not avail them, neither their children, aught against God; those -- they shall be fuel for the Fire\qt@no{10}}%
\qt@newcmd\qurantrans@en@ccciv{%
like Pharaoh's folk, and the people before them, who cried lies to Our signs; God seized them because of their sins; God is terrible in retribution.\qt@no{11}}%
\qt@newcmd\qurantrans@en@cccv{%
Say to the unbelievers: 'You shall be overthrown, and mustered into Gehenna -- an evil cradling!'\qt@no{12}}%
\qt@newcmd\qurantrans@en@cccvi{%
There has already been a sign for you in the two companies that encountered, one company fighting in the way of God and another unbelieving; they saw them twice the like of them, as the eye sees, but God confirms with His help whom He will. Surely in that is a lesson for men possessed of eyes.\qt@no{13}}%
\qt@newcmd\qurantrans@en@cccvii{%
Decked out fair to men is the love of lusts -- women, children, heaped-up heaps of gold and silver, horses of mark, cattle and tillage. That is the enjoyment of the present life; but God -- with Him is the fairest resort.\qt@no{14}}%
\qt@newcmd\qurantrans@en@cccviii{%
Say: 'Shall I tell you of a better than that?' For those that are godfearing, with their Lord are gardens underneath which rivers flow, therein dwelling forever, and spouses purified, and God's good pleasure. And God sees His servants\qt@no{15}}%
\qt@newcmd\qurantrans@en@cccix{%
who say, 'Our Lord, we believe; forgive us our sins, and guard us against the chastisement of the Fire' --\qt@no{16}}%
\qt@newcmd\qurantrans@en@cccx{%
men who are patient, truthful, obedient, expenders in alms, imploring God's pardon at the daybreak.\qt@no{17}}%
\qt@newcmd\qurantrans@en@cccxi{%
God bears witness that there is no god but He -- and the angels, and men possessed of knowledge -- upholding justice; there is no god but He, the All-mighty, the All-wise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@cccxii{%
The true religion with God is Islam. Those who were given the Book were not at variance except after the knowledge came to them, being insolent one to another. And whoso disbelieves in God's signs. God is swift at the reckoning.\qt@no{19}}%
\qt@newcmd\qurantrans@en@cccxiii{%
So if they dispute with thee, say: 'I have surrendered my will to God, and whosoever follows me. And say to those who have been given the Book and to the common folk: 'Have you surrendered?' If they have surrendered, they are right guided; but if they turn their backs, thine it is only to deliver the Message; and God sees His servants.\qt@no{20}}%
\qt@newcmd\qurantrans@en@cccxiv{%
Those who disbelieve in the signs of God and slay the Prophets without right, and slay such men as bid to justice -- do thou give them the good tidings of a painful chastisement;\qt@no{21}}%
\qt@newcmd\qurantrans@en@cccxv{%
their works have failed in this world and the next; they have no helpers.\qt@no{22}}%
\qt@newcmd\qurantrans@en@cccxvi{%
Hast thou not regarded those who were given a portion of the Book, being called to the Book of God, that it might decide between them, and then a party of them turned away, swerving aside?\qt@no{23}}%
\qt@newcmd\qurantrans@en@cccxvii{%
That, because they said, 'The Fire shall not touch us, except for a number of days'; and the lies they forged has deluded them in their religion.\qt@no{24}}%
\qt@newcmd\qurantrans@en@cccxviii{%
But how will it be, when We gather them for a day whereon is no doubt, and every soul shall be paid in full what it has earned, and they shall not be wronged?\qt@no{25}}%
\qt@newcmd\qurantrans@en@cccxix{%
Say: 'O God, Master of the Kingdom, Thou givest the Kingdom to whom Thou wilt, and seizest the Kingdom from whom Thou wilt, Thou exaltest whom Thou wilt, and Thou abasest whom Thou wilt; in Thy hand is the good; Thou art powerful over everything.\qt@no{26}}%
\qt@newcmd\qurantrans@en@cccxx{%
Thou makest the night to enter into the day and Thou makest the day to enter into the night, Thou bringest forth the living from the dead and Thou bringest forth the dead from the living, and Thou providest whomsoever Thou wilt without reckoning.\qt@no{27}}%
\qt@newcmd\qurantrans@en@cccxxi{%
Let not the believers take the unbelievers for friends, rather than the believers -- for whoso does that belongs not to God in anything -- unless you have a fear of them. God warns you that You beware of Him, and unto God is the homecoming.\qt@no{28}}%
\qt@newcmd\qurantrans@en@cccxxii{%
Say: 'Whether you hide what is in your breasts or publish it, God knows it. God knows what is in the heavens and what is in the earth; and God is powerful over everything.'\qt@no{29}}%
\qt@newcmd\qurantrans@en@cccxxiii{%
The day every soul shall find what it has done of good brought forward, and what it has done of evil; it will wish if there were only a far space between it and that day. God warns you that you beware of Him; and God is gentle with His servants.\qt@no{30}}%
\qt@newcmd\qurantrans@en@cccxxiv{%
Say: 'If you love God, follow me, and God will love you, and forgive you your sins; God is All-forgiving, All-compassionate.'\qt@no{31}}%
\qt@newcmd\qurantrans@en@cccxxv{%
Say: 'Obey God, and the Messenger.' But if they turn their backs, God loves not the unbelievers.\qt@no{32}}%
\qt@newcmd\qurantrans@en@cccxxvi{%
God chose Adam and Noah and the House of Abraham and the House of Imran above all beings, the\qt@no{33}}%
\qt@newcmd\qurantrans@en@cccxxvii{%
seed of one another; God hears, and knows.\qt@no{34}}%
\qt@newcmd\qurantrans@en@cccxxviii{%
When the wife of Imran said, 'Lord, I have vowed to Thee, in dedication, what is within my womb. Receive Thou this from me; Thou hearest, and knowest.'\qt@no{35}}%
\qt@newcmd\qurantrans@en@cccxxix{%
And when she gave birth to her she said, 'Lord, I have given birth to her, a female.' (And God knew very well what she had given birth to; the male is not as the female.) 'And I have named her Mary, and commend her to Thee with her seed, to protect them from the accursed Satan.'\qt@no{36}}%
\qt@newcmd\qurantrans@en@cccxxx{%
Her Lord received the child with gracious favour, and by His goodness she grew up comely, Zachariah taking charge of her. Whenever Zachariah went in to her in the Sanctuary, he found her provisioned. 'Mary,' he said, 'how comes this to thee?' 'From God,' she said. Truly God provisions whomsoever He will without reckoning.\qt@no{37}}%
\qt@newcmd\qurantrans@en@cccxxxi{%
Then Zachariah prayed to his Lord saying, 'Lord, give me of Thy goodness a goodly offspring. Yea, Thou hearest prayer.'\qt@no{38}}%
\qt@newcmd\qurantrans@en@cccxxxii{%
And the angels called to him, standing in the Sanctuary at worship, 'Lo, God gives thee good tidings of John, who shall confirm a Word of God, a chief, and chaste, a Prophet, righteous.'\qt@no{39}}%
\qt@newcmd\qurantrans@en@cccxxxiii{%
'Lord,' said Zachariah, 'how shall I have a son, seeing I am an old man and my wife is barren?' 'Even so,' God said, 'God does what He will.'\qt@no{40}}%
\qt@newcmd\qurantrans@en@cccxxxiv{%
'Lord,' said Zachariah, 'appoint to me a sign.' 'Thy sign,' God said, 'is that thou shalt not speak, save by tokens, to men for three days. And mention thy Lord oft, and give glory at evening and dawn.'\qt@no{41}}%
\qt@newcmd\qurantrans@en@cccxxxv{%
And when the angels said, 'Mary, God has chosen thee, and purified thee; He has chosen thee above all women.\qt@no{42}}%
\qt@newcmd\qurantrans@en@cccxxxvi{%
Mary; be obedient to thy Lord, prostrating and bowing before Him.'\qt@no{43}}%
\qt@newcmd\qurantrans@en@cccxxxvii{%
(That is of the tidings of the Unseen, that We reveal to thee; for thou wast not with them, when they were casting quills which of them should have charge of Mary; thou wast not with them, when they were disputing.)\qt@no{44}}%
\qt@newcmd\qurantrans@en@cccxxxviii{%
When the angels said, 'Mary, God gives thee good tidings of a Word from Him whose name is Messiah, Jesus, son of Mary; high honoured shall he be in this world and the next, near stationed to God.\qt@no{45}}%
\qt@newcmd\qurantrans@en@cccxxxix{%
He shall speak to men in the cradle, and of age, and righteous he shall be.'\qt@no{46}}%
\qt@newcmd\qurantrans@en@cccxl{%
'Lord,' said Mary, 'how shall I have a son seeing no mortal has touched me?' 'Even so,' God said, God creates what He will. When He decrees a thing He does but say to it ``Be," and it is.\qt@no{47}}%
\qt@newcmd\qurantrans@en@cccxli{%
And He will teach him the Book, the Wisdom, the Torah, the Gospel,\qt@no{48}}%
\qt@newcmd\qurantrans@en@cccxlii{%
to be a Messenger to the Children of Israel saying, ``I have come to you with a sign from your Lord. I will create for you out of clay as the likeness of a bird; then I will breathe into it, and it will be a bird, by the leave of God. I will also heal the blind and the leper, and bring to life the dead, by the leave of God. I will inform you too of what things you eat, and what you treasure up in your houses. Surely in that is a sign for you, if you are believers.\qt@no{49}}%
\qt@newcmd\qurantrans@en@cccxliii{%
Likewise confirming the truth of the Torah that is before me, and to make lawful to you certain things that before were forbidden unto you. I have come to you with a sign from your Lord; so fear you God, and obey you me.\qt@no{50}}%
\qt@newcmd\qurantrans@en@cccxliv{%
Surely God is my Lord and your Lord; so serve Him. This is a straight path".'\qt@no{51}}%
\qt@newcmd\qurantrans@en@cccxlv{%
And when Jesus perceived their unbelief, he said, 'Who will be my helpers unto God?' The Apostles said, 'We will be helpers of God; we believe in God; witness thou our submission.\qt@no{52}}%
\qt@newcmd\qurantrans@en@cccxlvi{%
Lord, we believe in that Thou hast sent down, and we follow the Messenger. Inscribe us therefore with those who bear witness.'\qt@no{53}}%
\qt@newcmd\qurantrans@en@cccxlvii{%
And they devised, and God devised, and God is the best of devisers.\qt@no{54}}%
\qt@newcmd\qurantrans@en@cccxlviii{%
When God said, 'Jesus, I will take thee to Me and will raise thee to Me and I will purify thee of those who believe not. I will set thy followers above the unbelievers till the Resurrection Day. Then unto Me shall you return, and I will decide between you, as to what you were at variance on.\qt@no{55}}%
\qt@newcmd\qurantrans@en@cccxlix{%
As for the unbelievers, I will chastise them with a terrible chastisement in this world and the next; they shall have no helpers.'\qt@no{56}}%
\qt@newcmd\qurantrans@en@cccl{%
But as for the believers, who do deeds of righteousness, He will pay them in full their wages: and God loves not the evildoers.\qt@no{57}}%
\qt@newcmd\qurantrans@en@cccli{%
This We recite to thee of signs and wise remembrance.\qt@no{58}}%
\qt@newcmd\qurantrans@en@ccclii{%
Truly, the likeness of Jesus, in God's sight, is as Adam's likeness; He created him of dust, then said He unto him, 'Be,' and he was.\qt@no{59}}%
\qt@newcmd\qurantrans@en@cccliii{%
The truth is of God; be not of the doubters.\qt@no{60}}%
\qt@newcmd\qurantrans@en@cccliv{%
And whoso disputes with thee concerning him, after the knowledge that has come to thee, say: 'Come now, let us call our sons and your sons, our wives and your wives, our selves and your selves, then let us humbly pray and so lay God's curse upon the ones who lie.'\qt@no{61}}%
\qt@newcmd\qurantrans@en@ccclv{%
This is the true story. There is no god but God, and assuredly God is the All-mighty, the All-wise.\qt@no{62}}%
\qt@newcmd\qurantrans@en@ccclvi{%
And if they turn their backs, assuredly God knows the workers of corruption.\qt@no{63}}%
\qt@newcmd\qurantrans@en@ccclvii{%
Say: 'People of the Book! Come now to a word common between us and you, that we serve none but God, and that we associate not aught with Him, and do not some of us take others as Lords, apart from God.' And if they turn their backs, say: 'Bear witness that we are Muslims.'\qt@no{64}}%
\qt@newcmd\qurantrans@en@ccclviii{%
People of the Book! Why do you dispute concerning Abraham? The Torah was not sent down, neither the Gospel, but after him. What, have you no reason?\qt@no{65}}%
\qt@newcmd\qurantrans@en@ccclix{%
Ha, you are the ones who dispute on what you know; why then dispute you touching a matter of which you know not anything? God knows, and you know not.\qt@no{66}}%
\qt@newcmd\qurantrans@en@ccclx{%
No; Abraham in truth was not a Jew, neither a Christian; but he was a Muslim and one pure of faith; certainly he was never of the idolaters.\qt@no{67}}%
\qt@newcmd\qurantrans@en@ccclxi{%
Surely the people standing closest to Abraham are those who followed him, and this Prophet, and those who believe; and God is the Protector of the believers.\qt@no{68}}%
\qt@newcmd\qurantrans@en@ccclxii{%
There is a party of the People of the Book yearn to make you go astray; yet none they make to stray, except themselves, but they are not aware.\qt@no{69}}%
\qt@newcmd\qurantrans@en@ccclxiii{%
People of the Book! Why do you disbelieve in God's signs, which you yourselves witness?\qt@no{70}}%
\qt@newcmd\qurantrans@en@ccclxiv{%
People of the Book! Why do you confound the truth with vanity, and conceal the truth and that wittingly?\qt@no{71}}%
\qt@newcmd\qurantrans@en@ccclxv{%
There is a party of the People of the Book say, 'Believe in what has been sent down upon those who believe at the beginning of the day, and disbelieve at the end of it; haply they will then return;\qt@no{72}}%
\qt@newcmd\qurantrans@en@ccclxvi{%
and believe not any but him who follows your religion.' Say: 'The true guidance is God's guidance -- that anyone should be given the like of what you have been given, or dispute with you before your Lord.' Say: 'Surely bounty is in the hand of God; He gives it unto whomsoever He will; and God is All-embracing, All-knowing.\qt@no{73}}%
\qt@newcmd\qurantrans@en@ccclxvii{%
He singles out for His mercy whom He will; God is of bounty abounding.'\qt@no{74}}%
\qt@newcmd\qurantrans@en@ccclxviii{%
And of the People of the Book is he who, if thou trust him with a hundredweight, will restore it thee; and of them is he who, if thou trust him with one pound, will not restore it thee, unless ever thou standest over him. That, because they say, 'There is no way over us as to the common people.' They speak falsehood against God and that wittingly.\qt@no{75}}%
\qt@newcmd\qurantrans@en@ccclxix{%
Nay, but whoso fulfils his covenant and fears God, God loves the godfearing.\qt@no{76}}%
\qt@newcmd\qurantrans@en@ccclxx{%
Those that sell God's covenant, and their oaths, for a little price, there shall be no share for them in the world to come; God shall not speak to them neither look on them on the Resurrection Day, neither will He purify them; and for them awaits a painful chastisement.\qt@no{77}}%
\qt@newcmd\qurantrans@en@ccclxxi{%
And there is a sect of them twist their tongues with the Book, that you may suppose it part of the Book, yet it is not part of the Book; and they say, 'It is from God,' yet it is not from God, and they speak falsehood against God, and that wittingly.\qt@no{78}}%
\qt@newcmd\qurantrans@en@ccclxxii{%
It belongs not to any mortal that God should give him the Book, the Judgment, the Prophethood, then he should say to men, 'Be you servants to me apart from God.' Rather, 'Be you masters in that you know the Book, and in that you study.'\qt@no{79}}%
\qt@newcmd\qurantrans@en@ccclxxiii{%
He would never order you to take the angels and the Prophets as Lords; what, would He order you to disbelieve, after you have surrendered?\qt@no{80}}%
\qt@newcmd\qurantrans@en@ccclxxiv{%
And when God took compact with the Prophets: 'That I have given you of Book and Wisdom; then there shall come to you a Messenger confirming what is with you -- you shall believe in him and you shall help him; do you agree?' He said. 'And do you take My load on you on that condition?' They said, 'We do agree.' God said, 'Bear witness so, and I shall be with you among the witnesses.'\qt@no{81}}%
\qt@newcmd\qurantrans@en@ccclxxv{%
Then whosoever turns his back after that -- they are the ungodly.\qt@no{82}}%
\qt@newcmd\qurantrans@en@ccclxxvi{%
What, do they desire another religion than God's, and to Him has surrendered whoso is in the heavens and the earth, willingly or unwillingly, and to Him they shall be returned?\qt@no{83}}%
\qt@newcmd\qurantrans@en@ccclxxvii{%
Say: 'We believe in God, and that which has been sent down on us, and sent down on Abraham and Ishmael, Isaac and Jacob, and the Tribes, and in that which was given to Moses and Jesus, and the Prophets, of their Lord; we make no division between any of them, and to Him we surrender.'\qt@no{84}}%
\qt@newcmd\qurantrans@en@ccclxxviii{%
Whoso desires another religion than Islam, it shall not be accepted of him; in the next world he shall be among the losers.\qt@no{85}}%
\qt@newcmd\qurantrans@en@ccclxxix{%
How shall God guide a people who have disbelieved after they believed, and bore witness that the Messenger is true, and the clear signs came to them? God guides not the people of the evildoers.\qt@no{86}}%
\qt@newcmd\qurantrans@en@ccclxxx{%
Those -- their recompense is that there shall rest on them the curse of God and of the angels and of men, altogether,\qt@no{87}}%
\qt@newcmd\qurantrans@en@ccclxxxi{%
therein dwelling forever; the chastisement shall not be lightened for them; no respite shall be given them.\qt@no{88}}%
\qt@newcmd\qurantrans@en@ccclxxxii{%
But those who repent thereafter, and make amends -- God is All-forgiving, All-compassionate.\qt@no{89}}%
\qt@newcmd\qurantrans@en@ccclxxxiii{%
Surely those who disbelieve after they have believed and then increase in unbelief -- their repentance shall not be accepted; those are the ones who stray.\qt@no{90}}%
\qt@newcmd\qurantrans@en@ccclxxxiv{%
Surely those who disbelieve, and die disbelieving, there shall not be accepted from any one of them the whole earth full of gold, if he would ransom himself thereby; for them awaits a painful chastisement, and they shall have no helpers.\qt@no{91}}%
\qt@newcmd\qurantrans@en@ccclxxxv{%
You will not attain piety until you expend of what you love; and whatever thing you expend, God knows of it.\qt@no{92}}%
\qt@newcmd\qurantrans@en@ccclxxxvi{%
All food was lawful to the Children of Israel save what Israel forbade for himself before the Torah was sent down. Say: 'Bring you the Torah now, and recite it, if you are truthful.'\qt@no{93}}%
\qt@newcmd\qurantrans@en@ccclxxxvii{%
Whoso forges falsehood against God after that, those are the evildoers.\qt@no{94}}%
\qt@newcmd\qurantrans@en@ccclxxxviii{%
Say: 'God has spoken the truth; therefore follow the creed of Abraham, a man of pure faith and no idolater.'\qt@no{95}}%
\qt@newcmd\qurantrans@en@ccclxxxix{%
The first House established for the people was that at Bekka, a place holy, and a guidance to all beings.\qt@no{96}}%
\qt@newcmd\qurantrans@en@cccxc{%
Therein are clear signs -- the station of Abraham, and whosoever enters it is in security. It is the duty of all men towards God to come to the House a pilgrim, if he is able to make his way there. As for the unbeliever, God is All-sufficient nor needs any being.\qt@no{97}}%
\qt@newcmd\qurantrans@en@cccxci{%
Say: 'People of the Book, why do you disbelieve in the signs of God? Surely God is witness of the things you do.'\qt@no{98}}%
\qt@newcmd\qurantrans@en@cccxcii{%
Say: 'People of the Book, why do you bar from God's way the believer, desiring to make it crooked, yourselves being witnesses? God is not heedless of the things you do.'\qt@no{99}}%
\qt@newcmd\qurantrans@en@cccxciii{%
O believers, if you obey a sect of those who have been given the Book, they will turn you, after you have believed, into unbelievers.\qt@no{100}}%
\qt@newcmd\qurantrans@en@cccxciv{%
How can you disbelieve, seeing you have God's signs recited to you, and His Messenger among you? Whosoever holds fast to God, he is guided to a straight path.\qt@no{101}}%
\qt@newcmd\qurantrans@en@cccxcv{%
O believers, fear God as He should be feared, and see you do not die, save in surrender.\qt@no{102}}%
\qt@newcmd\qurantrans@en@cccxcvi{%
And hold you fast to God's bond, together, and do not scatter; remember God's blessing upon you when you were enemies, and He brought your hearts together, so that by His blessing you became brothers. You were upon the brink of a pit of Fire, and He delivered you from it; even so God makes clear to you His signs; so haply you will be guided.\qt@no{103}}%
\qt@newcmd\qurantrans@en@cccxcvii{%
Let there be one nation of you, calling to good, and bidding to honour, and forbidding dishonour; those are the prosperers.\qt@no{104}}%
\qt@newcmd\qurantrans@en@cccxcviii{%
Be not as those who scattered and fell into variance after the clear signs came to them; those there awaits a mighty chastisement,\qt@no{105}}%
\qt@newcmd\qurantrans@en@cccxcix{%
the day when some faces are blackened, and some faces whitened. As for those whose faces are blackened -- 'Did you disbelieve after you had believed? Then taste the chastisement for that you disbelieved!'\qt@no{106}}%
\qt@newcmd\qurantrans@en@cd{%
But as for those whose faces are whitened, they shall be in God's mercy, therein dwelling forever.\qt@no{107}}%
\qt@newcmd\qurantrans@en@cdi{%
These are the signs of God We recite to thee in truth, and God desires not any injustice to living beings.\qt@no{108}}%
\qt@newcmd\qurantrans@en@cdii{%
To God belongs all that is in the heavens and in the earth, and unto Him all matters are returned.\qt@no{109}}%
\qt@newcmd\qurantrans@en@cdiii{%
You are the best nation ever brought forth to men, bidding to honour, and forbidding dishonour, and believing in God. Had the People of the Book believed, it were better for them; some of them are believers, but the most of them are ungodly.\qt@no{110}}%
\qt@newcmd\qurantrans@en@cdiv{%
They will not harm you, except a little hurt; and if they fight with you, they will turn on you their backs; then they will not be helped.\qt@no{111}}%
\qt@newcmd\qurantrans@en@cdv{%
Abasement shall be pitched on them, wherever they are come upon, except they be in a bond of God, and a bond of the people; they will be laden with the burden of God's anger, and poverty shall be pitched on them; that, because they disbelieved in God's signs, and slew the Prophets without right; that, for that they acted rebelliously and were transgressors.\qt@no{112}}%
\qt@newcmd\qurantrans@en@cdvi{%
Yet they are not all alike; some of the People of the Book are a nation upstanding, that recite God's signs in the watches of the night, bowing themselves,\qt@no{113}}%
\qt@newcmd\qurantrans@en@cdvii{%
believing in God and in the Last Day, bidding to honour and forbidding dishonour, vying one with the other in good works; those are of the righteous.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cdviii{%
And whatsoever good you do, you shall not be denied the just reward of it; and God knows the godfearing.\qt@no{115}}%
\qt@newcmd\qurantrans@en@cdix{%
As for the unbelievers, their riches shall not avail them, neither their children, against God; those are the inhabitants of the Fire, therein dwelling forever.\qt@no{116}}%
\qt@newcmd\qurantrans@en@cdx{%
The likeness of that they expend in this present life is as the likeness of a freezing blast that smites the tillage of a people who wronged themselves, and it destroyed that; God wronged them not, but themselves they wronged.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cdxi{%
O believers, take not for your intimates outside yourselves such men spare nothing to ruin you; they yearn for you to suffer Hatred has already shown itself of their mouths, and what their breasts conceal is yet greater. Now We have made clear to you the signs, if you understand.\qt@no{118}}%
\qt@newcmd\qurantrans@en@cdxii{%
Ha, there you are; you love them, and they love you not; you believe in the Book, all of it, and when they meet you they say, 'We believe,' but when they go privily, they bite at you their fingers, enraged. Say: 'Die in your rage; God knows the thoughts in the breasts.'\qt@no{119}}%
\qt@newcmd\qurantrans@en@cdxiii{%
If you are visited by good fortune, it vexes them; but if you are smitten by evil, they rejoice at it. Yet if you are patient and godfearing, their guile will hurt you nothing; God encompasses the things they do.\qt@no{120}}%
\qt@newcmd\qurantrans@en@cdxiv{%
When thou wentest forth at dawn from thy people to lodge the believers in their pitches for the battle -- God is All-hearing, All-knowing --\qt@no{121}}%
\qt@newcmd\qurantrans@en@cdxv{%
when two parties of you were about to lose heart, though God was their Protector -- and in God let the believers put all their trust --\qt@no{122}}%
\qt@newcmd\qurantrans@en@cdxvi{%
and God most surely helped you at Badr, when you were utterly abject. So fear God, and haply you Will be thankful.\qt@no{123}}%
\qt@newcmd\qurantrans@en@cdxvii{%
When thou saidst to the believers, 'Is it not enough for you that your Lord should reinforce you with three thousand angels sent down upon you?\qt@no{124}}%
\qt@newcmd\qurantrans@en@cdxviii{%
Yea; if you are patient and godfearing, and the foe come against you instantly, your Lord will reinforce you with five thousand swooping angels.'\qt@no{125}}%
\qt@newcmd\qurantrans@en@cdxix{%
God wrought this not, save as good tiding to you, and that your hearts might be at rest; help comes only from God the All-mighty, the All-wise;\qt@no{126}}%
\qt@newcmd\qurantrans@en@cdxx{%
and that He might cut off a part of the unbelievers or frustrate them, so that they turned in their tracks, disappointed.\qt@no{127}}%
\qt@newcmd\qurantrans@en@cdxxi{%
No part of the matter is thine, whether He turns towards them again, or chastises them; for they are evildoers.\qt@no{128}}%
\qt@newcmd\qurantrans@en@cdxxii{%
To God belongs all that is in the heavens and earth; He forgives whom He will, and chastises whom He will; God is All-forgiving, All-compassionate.\qt@no{129}}%
\qt@newcmd\qurantrans@en@cdxxiii{%
O believers, devour not usury, doubled and redoubled, and fear you God; haply so you will prosper.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cdxxiv{%
And fear the Fire prepared for the unbelievers,\qt@no{131}}%
\qt@newcmd\qurantrans@en@cdxxv{%
and obey God and the Messenger; haply so you will find mercy.\qt@no{132}}%
\qt@newcmd\qurantrans@en@cdxxvi{%
And vie with one another, hastening to forgiveness from your Lord, and to a garden whose breadth is as the heavens and earth, prepared for the godfearing\qt@no{133}}%
\qt@newcmd\qurantrans@en@cdxxvii{%
who expend in prosperity and adversity in almsgiving, and restrain their rage, and pardon the offences of their fellowmen; and God loves the good-doers;\qt@no{134}}%
\qt@newcmd\qurantrans@en@cdxxviii{%
who, when they commit an indecency or wrong themselves, remember God, and pray forgiveness for their sins -- and who shall forgive sins but God? -- and do not persevere in the things they did and that wittingly.\qt@no{135}}%
\qt@newcmd\qurantrans@en@cdxxix{%
Those -- their recompense is forgiveness from their Lord, and gardens beneath which rivers flow, therein dwelling forever; and how excellent is the wage of those who labour!\qt@no{136}}%
\qt@newcmd\qurantrans@en@cdxxx{%
Divers institutions have passed away before you; journey in the land, and behold how was the end of those that cried lies.\qt@no{137}}%
\qt@newcmd\qurantrans@en@cdxxxi{%
This is an exposition for mankind, and a guidance, and an admonition for such as are godfearing.\qt@no{138}}%
\qt@newcmd\qurantrans@en@cdxxxii{%
Faint not, neither sorrow; you shall be the upper ones if you are believers.\qt@no{139}}%
\qt@newcmd\qurantrans@en@cdxxxiii{%
If a wound touches you, a like wound already has touched the heathen; such days We deal out in turn among men, and that God may know who are the believers, and that He may take witnesses from among you; and God loves not the evildoers;\qt@no{140}}%
\qt@newcmd\qurantrans@en@cdxxxiv{%
and that God may prove the believers, and blot out the unbelievers.\qt@no{141}}%
\qt@newcmd\qurantrans@en@cdxxxv{%
Or did you suppose you should enter Paradise without God know who of you have struggled and who are patient?\qt@no{142}}%
\qt@newcmd\qurantrans@en@cdxxxvi{%
You were longing for death before you met it; now you have seen it, while you were beholding.\qt@no{143}}%
\qt@newcmd\qurantrans@en@cdxxxvii{%
Muhammad is naught but a Messenger; Messengers have passed away before him. Why, if he should die or is slain, will you turn about on your heels? If any man should turn about on his heels, he will not harm God in any way; and God will recompense the thankful.\qt@no{144}}%
\qt@newcmd\qurantrans@en@cdxxxviii{%
It is not given to any soul to die, save by the leave of God, at an appointed time. Whoso desires the reward of this world, We will give him of this; and whoso desires the reward of the other world, We will give him of that; and We will recompense the thankful.\qt@no{145}}%
\qt@newcmd\qurantrans@en@cdxxxix{%
Many a Prophet there has been, with whom thousands manifold have fought, and they fainted not for what smote them in God's way, neither weakened, nor did they humble themselves; and God loves the patient.\qt@no{146}}%
\qt@newcmd\qurantrans@en@cdxl{%
Nothing else they said but, 'Lord, forgive us our sins, and that we exceeded in our affair, and make firm our feet, and help us against the people of the unbelievers.'\qt@no{147}}%
\qt@newcmd\qurantrans@en@cdxli{%
And God gave them the reward of this world and the fairest reward of the world to come; and God loves the good-doers.\qt@no{148}}%
\qt@newcmd\qurantrans@en@cdxlii{%
O believers, if you obey the unbelievers they will turn you upon your heels, and you will turn about, losers.\qt@no{149}}%
\qt@newcmd\qurantrans@en@cdxliii{%
No; but God is your Protector, and He is the best of helpers.\qt@no{150}}%
\qt@newcmd\qurantrans@en@cdxliv{%
We will cast into the hearts of the unbelievers terror, for that they have associated with God that for which He sent down never authority; their lodging shall be the Fire; evil is the lodging of the evildoers.\qt@no{151}}%
\qt@newcmd\qurantrans@en@cdxlv{%
God has been true in His promise towards you when you blasted them by His leave; until you lost heart, and quarrelled about the matter, and were rebellious, after He had shown you that you longed for. Some of you there are that desire this world, and some of you there are desire the next world. Then He turned you from them, that He might try you; and He has pardoned you; and God is bounteous to the believers.\qt@no{152}}%
\qt@newcmd\qurantrans@en@cdxlvi{%
When you were going up, not twisting about for anyone, and the Messenger was calling you in your rear; so He rewarded you with grief on grief that you might not sorrow for what escaped you neither for what smote you; and God is aware of the things you do.\qt@no{153}}%
\qt@newcmd\qurantrans@en@cdxlvii{%
Then He sent down upon you, after grief, security -- a slumber overcoming a party of you; and a party themselves had grieved, thinking of God thoughts that were not true such as the pagans thought, saying, 'Have we any part whatever in the affair?' Say: 'The affair belongs to God entirely.' They were concealing in their hearts that they show not to thee, saying, 'Ah, if we had had a part in the affair, never would we have been slain here.' Say: 'Even if you had been in your houses, those for whom slaying was appointed would have sallied forth unto their last couches'; and that God might try what was in your breasts, and that He might prove what was in your hearts; and God knows the thoughts in the breasts.\qt@no{154}}%
\qt@newcmd\qurantrans@en@cdxlviii{%
Those of you who turned away the day the two hosts encountered -- Satan made them slip for somewhat they had earned; but God has pardoned them; God is All-forgiving, All-clement.\qt@no{155}}%
\qt@newcmd\qurantrans@en@cdxlix{%
O believers, be not as the unbelievers who say to their brothers, when they journey in the land, or are upon expeditions, 'If they had been with us, they would not have died and not been slain' -- that God may make that an anguish in their hearts. For God gives life, and He makes to die; and God sees the things you do.\qt@no{156}}%
\qt@newcmd\qurantrans@en@cdl{%
If you are slain or die in God's way, forgiveness and mercy from God are a better thing than that you amass;\qt@no{157}}%
\qt@newcmd\qurantrans@en@cdli{%
surely if you die or are slain, it is unto God you shall be mustered.\qt@no{158}}%
\qt@newcmd\qurantrans@en@cdlii{%
It was by some mercy of God that thou wast gentle to them; hadst thou been harsh and hard of heart, they would have scattered from about thee. So pardon them, and pray forgiveness for them, and take counsel with them in the affair; and when thou art resolved, put thy trust in God; surely God loves those who put their trust.\qt@no{159}}%
\qt@newcmd\qurantrans@en@cdliii{%
If God helps you, none can overcome you; but if He forsakes you, who then can help you after Him? Therefore in God let the believers put all their trust.\qt@no{160}}%
\qt@newcmd\qurantrans@en@cdliv{%
It is not for a Prophet to be fraudulent; whoso defrauds shall bring the fruits of his fraud on the Day of Resurrection; then every soul shall be paid in full what it has earned, and they shall not be wronged.\qt@no{161}}%
\qt@newcmd\qurantrans@en@cdlv{%
What, is he who follows God's good pleasure like him who is laden with the burden of God's anger, whose refuge is Gehenna? An evil homecoming!\qt@no{162}}%
\qt@newcmd\qurantrans@en@cdlvi{%
They are in ranks with God; and God sees the things they do.\qt@no{163}}%
\qt@newcmd\qurantrans@en@cdlvii{%
Truly God was gracious to the believers when He raised up among them a Messenger from themselves, to recite to them His signs and to purify them, and to teach them the Book and the Wisdom, though before they were in manifest error.\qt@no{164}}%
\qt@newcmd\qurantrans@en@cdlviii{%
Why, when an affliction visited you, and you had visited twice over the like of it, did you say, 'How is this?' Say: 'This is from your own selves; surely God is powerful over everything.'\qt@no{165}}%
\qt@newcmd\qurantrans@en@cdlix{%
And what visited you, the day the two hosts encountered, was by God's leave, and that He might know the believers;\qt@no{166}}%
\qt@newcmd\qurantrans@en@cdlx{%
and that He might also know the hypocrites when it was said of them, 'Come now, fight in the way of God, or repel!' They said, 'If only we knew how to fight, we would follow you.' They that day were nearer to unbelief than to belief, saying with their mouths that which never was in their hearts; and God knows very well the things they hide;\qt@no{167}}%
\qt@newcmd\qurantrans@en@cdlxi{%
who said of their brothers (and they themselves held back), 'Had they obeyed us, they would not have been slain.' Say: 'Then avert death from yourselves, if you speak truly.'\qt@no{168}}%
\qt@newcmd\qurantrans@en@cdlxii{%
Count not those who were slain in God's way as dead, but rather living with their Lord, by Him provided,\qt@no{169}}%
\qt@newcmd\qurantrans@en@cdlxiii{%
rejoicing in the bounty that God has given them, and joyful in those who remain behind and have not joined them, because no fear shall be on them, neither shall they sorrow,\qt@no{170}}%
\qt@newcmd\qurantrans@en@cdlxiv{%
joyful in blessing and bounty from God, and that God leaves not to waste the wage of the believers.\qt@no{171}}%
\qt@newcmd\qurantrans@en@cdlxv{%
And those who answered God and the Messenger after the wound had smitten them - to all those of them who did good and feared God, shall be a mighty wage;\qt@no{172}}%
\qt@newcmd\qurantrans@en@cdlxvi{%
those to whom the people said, 'The people have gathered against you, therefore fear them', but it increased them in faith, and they said, 'God is sufficient for us; an excellent Guardian is He.'\qt@no{173}}%
\qt@newcmd\qurantrans@en@cdlxvii{%
So they returned with blessing and bounty from God, untouched by evil; they followed the good pleasure of God; and God is of bounty abounding.\qt@no{174}}%
\qt@newcmd\qurantrans@en@cdlxviii{%
That is Satan frightening his friends, therefore do not fear them; but fear you Me, if you are believers.\qt@no{175}}%
\qt@newcmd\qurantrans@en@cdlxix{%
Let them not grieve thee that vie with one another in unbelief; they will nothing hurt God; God desires not to appoint for them a portion in the world to come, and there awaits them a mighty chastisement.\qt@no{176}}%
\qt@newcmd\qurantrans@en@cdlxx{%
Those who buy unbelief at the price of faith, they will nothing hurt God; and there awaits them a painful chastisement.\qt@no{177}}%
\qt@newcmd\qurantrans@en@cdlxxi{%
And let not the unbelievers suppose that the indulgence We grant them is better for them; We grant them indulgence only that they may increase in sin; and there awaits them a humbling chastisement.\qt@no{178}}%
\qt@newcmd\qurantrans@en@cdlxxii{%
God will not leave the believers in the state in which you are, till He shall distinguish the corrupt from the good, and God will not inform you of the Unseen; but God chooses out of His Messengers whom He will. Believe you then in God and His Messengers; and if you believe and are godfearing, there shall be for you a mighty wage.\qt@no{179}}%
\qt@newcmd\qurantrans@en@cdlxxiii{%
But as for those who are niggardly with the bounty God has given them, let them not suppose it is better for them; nay, it is worse for them; that they were niggardly with they shall have hung about their necks on the Resurrection Day; and to God belongs the inheritance of the heavens and earth; and God is aware of the things you do.\qt@no{180}}%
\qt@newcmd\qurantrans@en@cdlxxiv{%
God has heard the saying of those who said, 'Surely God is poor, and we are rich.' We shall write down what they have said, and their slaying the Prophets without right, and We shall say, 'Taste the chastisement of the burning --\qt@no{181}}%
\qt@newcmd\qurantrans@en@cdlxxv{%
that, for what your hands have forwarded, and for that God is never unjust unto His servants.'\qt@no{182}}%
\qt@newcmd\qurantrans@en@cdlxxvi{%
Those same men said, 'God has made covenant with us, that we believe not any Messenger until he brings to us a sacrifice devoured by fire.' Say: 'Messengers have come to you before me bearing clear signs, and that you spoke of; why therefore did you slay them, if you speak truly?'\qt@no{183}}%
\qt@newcmd\qurantrans@en@cdlxxvii{%
But if they cry lies to thee, lies were cried to Messengers before thee, who came bearing clear signs, and the Psalms, and the Book Illuminating.\qt@no{184}}%
\qt@newcmd\qurantrans@en@cdlxxviii{%
Every soul shall taste of death; you shall surely be paid in full your wages on the Day of Resurrection. Whosoever is removed from the Fire and admitted to Paradise, shall win the triumph. The present life is but the joy of delusion.\qt@no{185}}%
\qt@newcmd\qurantrans@en@cdlxxix{%
You shall surely be tried in your possessions and your selves, and you shall hear from those who were given the Book before you, and from those who are idolaters, much hurt; but if you are patient and godfearing -- surely that is true constancy.\qt@no{186}}%
\qt@newcmd\qurantrans@en@cdlxxx{%
And when God took compact with those who had been given the Book: 'You shall make it clear unto the people, and not conceal it.' But they rejected it behind their backs and sold it for a small price -- how evil was that their selling!\qt@no{187}}%
\qt@newcmd\qurantrans@en@cdlxxxi{%
Reckon not that those who rejoice in what they have brought, and love to be praised for what they have not done -- do not reckon them secure from chastisement; for them awaits a painful chastisement.\qt@no{188}}%
\qt@newcmd\qurantrans@en@cdlxxxii{%
To God belongs the Kingdom of the heavens and of the earth; and God is powerful over everything.\qt@no{189}}%
\qt@newcmd\qurantrans@en@cdlxxxiii{%
Surely in the creation of the heavens and earth and in the alternation of night and day there are signs for men possessed of minds\qt@no{190}}%
\qt@newcmd\qurantrans@en@cdlxxxiv{%
who remember God, standing and sitting and on their sides, and reflect upon the creation of the heavens and the earth: 'Our Lord, Thou hast not created this for vanity. Glory be to Thee! Guard us against the chastisement of the Fire.\qt@no{191}}%
\qt@newcmd\qurantrans@en@cdlxxxv{%
Our Lord, whomsoever Thou admittest into the Fire, Thou wilt have abased; and the evildoers shall have no helpers.\qt@no{192}}%
\qt@newcmd\qurantrans@en@cdlxxxvi{%
Our Lord, we have heard a caller calling us to belief, saying, ``Believe you in your Lord!" And we believe. Our Lord, forgive Thou us our sins and acquit us of our evil deeds, and take us to Thee with the pious.\qt@no{193}}%
\qt@newcmd\qurantrans@en@cdlxxxvii{%
Our Lord, give us what Thou hast promised us by Thy Messengers, and abase us not on the Day of Resurrection; Thou wilt not fail the tryst.'\qt@no{194}}%
\qt@newcmd\qurantrans@en@cdlxxxviii{%
And their Lord answers them: 'I waste not the labour of any that labours among you, be you male or female -- the one of you is as the other. And those who emigrated, and were expelled from their habitations, those who suffered hurt in My way, and fought, and were slain -- them I shall surely acquit of their evil deeds, and I shall admit them to gardens underneath which rivers flow.' A reward from God! And God with Him is the fairest reward.\qt@no{195}}%
\qt@newcmd\qurantrans@en@cdlxxxix{%
Let it not delude thee, that the unbelievers go to and fro in the land;\qt@no{196}}%
\qt@newcmd\qurantrans@en@cdxc{%
a little enjoyment, then their refuge is Gehenna -- an evil cradling!\qt@no{197}}%
\qt@newcmd\qurantrans@en@cdxci{%
But those who fear their Lord - for them shall be gardens underneath which rivers flow, therein dwelling forever -- a hospitality God Himself offers; and that which is with God is better for the pious.\qt@no{198}}%
\qt@newcmd\qurantrans@en@cdxcii{%
And some there are of the People of the Book who believe in God, and what has been sent down unto you, and what has been sent down unto them, men humble to God, not selling the signs of God for a small price; those -- their wage is with their Lord; God is swift at the reckoning.\qt@no{199}}%
\qt@newcmd\qurantrans@en@cdxciii{%
O believers, be patient, and vie you in patience; be steadfast; fear God; haply so you will prosper.\qt@no{200}}%
\qt@newcmd\qurantrans@en@cdxciv{%
\basmalahen Mankind, fear your Lord, who created you of a single soul, and from it created its mate, and from the pair of them scattered abroad many men and women; and fear God by whom you demand one of another, and the wombs; surely God ever watches over you.\qt@no{1}}%
\qt@newcmd\qurantrans@en@cdxcv{%
Give the orphans their property, and do not exchange the corrupt for the good; and devour not their property with your property; surely that is a great crime.\qt@no{2}}%
\qt@newcmd\qurantrans@en@cdxcvi{%
If you fear that you will not act justly towards the orphans, marry such women as seem good to you, two, three, four; but if you fear you will not be equitable, then only one, or what your right hands own; so it is likelier you will not be partial.\qt@no{3}}%
\qt@newcmd\qurantrans@en@cdxcvii{%
And give the women their dowries as a gift spontaneous; but if they are pleased to offer you any of it, consume it with wholesome appetite.\qt@no{4}}%
\qt@newcmd\qurantrans@en@cdxcviii{%
But do not give to fools their property that God has assigned to you to manage; provide for them and clothe them out of it, and speak to them honourable words.\qt@no{5}}%
\qt@newcmd\qurantrans@en@cdxcix{%
Test well the orphans, until they reach the age of marrying; then, if you perceive in them right judgment, deliver to them their property; consume it not wastefully and hastily ere they are grown. If any man is rich, let him be abstinent; if poor, let him consume in reason. And when you deliver to them their property, take witnesses over them; God suffices for a reckoner.\qt@no{6}}%
\qt@newcmd\qurantrans@en@d{%
To the men a share of what parents and kinsmen leave, and to the women a share of what parents and kinsmen leave, whether it be little or much, a share apportioned;\qt@no{7}}%
\qt@newcmd\qurantrans@en@di{%
and when the division is attended by kinsmen and orphans and the poor, make provision for them out of it, and speak to them honourable words.\qt@no{8}}%
\qt@newcmd\qurantrans@en@dii{%
And let those fear who, if they left behind them weak seed, would be afraid on their account, and let them fear God, and speak words hitting the mark.\qt@no{9}}%
\qt@newcmd\qurantrans@en@diii{%
Those who devour the property of orphans unjustly, devour Fire in their bellies, and shall assuredly roast in a Blaze.\qt@no{10}}%
\qt@newcmd\qurantrans@en@div{%
God charges you, concerning your children: to the male the like of the portion of two females, and if they be women above two, then for them two-thirds of what he leaves, but if she be one then to her a half; and to his parents to each one of the two the sixth of what he leaves, if he has children; but if he has no children, and his heirs are his parents, a third to his mother, or, if he has brothers, to his mother a sixth, after any bequest he may bequeath, or any debt. Your fathers and your sons -- you know not which out of them is nearer in profit to you. So God apportions; surely God is All-knowing, All-wise.\qt@no{11}}%
\qt@newcmd\qurantrans@en@dv{%
And for you a half of what your wives leave, if they have no children; but if they have children, then for you of what they leave a fourth, after any bequest they may bequeath, or any debt. And for them a fourth of what you leave, if you have no children; but if you have children, then for them of what you leave an eighth, after any bequest you may bequeath, or any debt. If a man or a woman have no heir direct, but have a brother or a sister, to each of the two a sixth; but if they are more numerous than that, they share equally a third, after any bequest he may bequeath, or any debt not prejudicial; a charge from God. God is All-knowing, All-clement.\qt@no{12}}%
\qt@newcmd\qurantrans@en@dvi{%
Those are God's bounds. Whoso obeys God and His Messenger, He will admit him to gardens underneath which rivers flow, therein dwelling forever; that is the mighty triumph.\qt@no{13}}%
\qt@newcmd\qurantrans@en@dvii{%
But whoso disobeys God, and His Messenger, and transgresses His bounds, him He will admit to a Fire, therein dwelling forever, and for him there awaits a humbling chastisement.\qt@no{14}}%
\qt@newcmd\qurantrans@en@dviii{%
Such of your women as commit indecency, call four of you to witness against them; and if they witness, then detain them in their houses until death takes them or God appoints for them a way.\qt@no{15}}%
\qt@newcmd\qurantrans@en@dix{%
And when two of you commit indecency, punish them both; but if they repent and make amends, then suffer them to be; God turns, and is All-compassionate.\qt@no{16}}%
\qt@newcmd\qurantrans@en@dx{%
God shall turn only towards those who do evil in ignorance, then shortly repent; God will return towards those; God is All-knowing, All-wise.\qt@no{17}}%
\qt@newcmd\qurantrans@en@dxi{%
But God shall not turn towards those who do evil deeds until, when one of them is visited by death, he says, 'Indeed now I repent,' neither to those who die disbelieving; for them We have prepared a painful chastisement.\qt@no{18}}%
\qt@newcmd\qurantrans@en@dxii{%
O believers, it is not lawful for you to inherit women against their will; neither debar them, that you may go off with part of what you have given them, except when they commit a flagrant indecency Consort with them honourably; or if you are averse to them, it is possible you may be averse to a thing, and God set in it much good.\qt@no{19}}%
\qt@newcmd\qurantrans@en@dxiii{%
And if you desire to exchange a wife in place of another, and you have given to one a hundredweight, take of it nothing. What, will you take it by way of calumny and manifest sin?\qt@no{20}}%
\qt@newcmd\qurantrans@en@dxiv{%
How shall you take it, when each of you has been privily with the other, and they have taken from you a solemn compact?\qt@no{21}}%
\qt@newcmd\qurantrans@en@dxv{%
And do not marry women that your fathers married, unless it be a thing of the past; surely that is indecent and hateful; an evil way.\qt@no{22}}%
\qt@newcmd\qurantrans@en@dxvi{%
Forbidden to you are your mothers and daughters, your sisters, your aunts paternal and maternal, your brother's daughters, your sister's daughters, your mothers who have given suck to you, your suckling sisters, your wives' mothers, your stepdaughters who are in your care being born of your wives you have been in to -- but if you have not yet been in to them it is no fault in you - and the spouses of your sons who are of your loins, and that you should take to you two sisters together, unless it be a thing of the past; God is All-forgiving, All-compassionate;\qt@no{23}}%
\qt@newcmd\qurantrans@en@dxvii{%
and wedded women, save what your right hands own. So God prescribes for you. Lawful for you, beyond all that, is that you may seek, using your wealth, in wedlock and not in licence. Such wives as you enjoy thereby, give them their wages apportionate; it is no fault in you in your agreeing together, after the due apportionate. God is All-knowing, All-wise.\qt@no{24}}%
\qt@newcmd\qurantrans@en@dxviii{%
Any one of you who has not the affluence to be able to marry believing freewomen in wedlock, let him take believing handmaids that your right hands own; God knows very well your faith; the one of you is as the other. So marry them, with their people's leave, and give them their wages honourably as women in wedlock, not as in licence or taking lovers. But when they are in wedlock, if they commit indecency, they shall be liable to half the chastisement of freewomen. That provision is for those of you who fear fornication; yet it is better for you to be patient. God is All-forgiving, All-compassionate.\qt@no{25}}%
\qt@newcmd\qurantrans@en@dxix{%
God desires to make clear to you, and to guide you in the institutions of those before you, and to turn towards you; God is All-knowing, All-wise;\qt@no{26}}%
\qt@newcmd\qurantrans@en@dxx{%
and God desires to turn towards you, but those who follow their lusts desire you to swerve away mightily.\qt@no{27}}%
\qt@newcmd\qurantrans@en@dxxi{%
God desires to lighten things for you, for man was created a weakling.\qt@no{28}}%
\qt@newcmd\qurantrans@en@dxxii{%
O believers, consume not your goods between you in vanity, except there be trading, by your agreeing together. And kill not one another. Surely God is compassionate to you.\qt@no{29}}%
\qt@newcmd\qurantrans@en@dxxiii{%
But whosoever does that in transgression and wrongfully, him We shall certainly roast at a Fire; and that for God is an easy matter.\qt@no{30}}%
\qt@newcmd\qurantrans@en@dxxiv{%
If you avoid the heinous sins that are forbidden you, We will acquit you of your evil deeds, and admit you by the gate of honour.\qt@no{31}}%
\qt@newcmd\qurantrans@en@dxxv{%
Do not covet that whereby God in bounty has preferred one of you above another. To the men a share from what they have earned, and to the women a share from what they have earned. And ask God of His bounty; God knows everything.\qt@no{32}}%
\qt@newcmd\qurantrans@en@dxxvi{%
To everyone We have appointed heirs of that which parents and kinsmen leave, and those with whom you have sworn compact. So give to them their share; God is witness over everything.\qt@no{33}}%
\qt@newcmd\qurantrans@en@dxxvii{%
Men are the managers of the affairs of women for that God has preferred in bounty one of them over another, and for that they have expended of their property. Righteous women are therefore obedient, guarding the secret for God's guarding. And those you fear may be rebellious admonish; banish them to their couches, and beat them. If they then obey you, look not for any way against them; God is All-high, All-great.\qt@no{34}}%
\qt@newcmd\qurantrans@en@dxxviii{%
And if you fear a breach between the two, bring forth an arbiter from his people and from her people an arbiter, if they desire to set things right; God will compose their differences; surely God is All-knowing, All-aware.\qt@no{35}}%
\qt@newcmd\qurantrans@en@dxxix{%
Serve God, and associate naught with Him. Be kind to parents, and the near kinsman, and to orphans, and to the needy, and to the neighbour who is of kin, and to the neighbour who is a stranger, and to the companion at your side, and to the traveller, and to that your right hands own. Surely God loves not the proud and boastful\qt@no{36}}%
\qt@newcmd\qurantrans@en@dxxx{%
such as are niggardly, and bid other men to be niggardly, and themselves conceal the bounty that God has given them. We have prepared for the unbelievers a humbling chastisement,\qt@no{37}}%
\qt@newcmd\qurantrans@en@dxxxi{%
and such as expend of their substance to show off to men, and believe not in God and the Last Day. Whosoever has Satan for a comrade, an evil comrade is he.\qt@no{38}}%
\qt@newcmd\qurantrans@en@dxxxii{%
Why, what would it harm them, if they believed in God and the Last Day, and expended of that God has provided them? God knows them.\qt@no{39}}%
\qt@newcmd\qurantrans@en@dxxxiii{%
Surely God shall not wrong so much as the weight of an ant; and if it be a good deed He will double it, and give from Himself a mighty wage.\qt@no{40}}%
\qt@newcmd\qurantrans@en@dxxxiv{%
How then shall it be, when We bring forward from every nation a witness, and bring thee to witness against those?\qt@no{41}}%
\qt@newcmd\qurantrans@en@dxxxv{%
Upon that day the unbelievers, those who have disobeyed the Messenger, will wish that the earth might be levelled with them; and they will not conceal from God one tiding.\qt@no{42}}%
\qt@newcmd\qurantrans@en@dxxxvi{%
O believers, draw not near to prayer when you are drunken until you know what you are saying, or defiled -- unless you are traversing a way -- until you have washed yourselves; but if you are sick, or on a journey, or if any of you comes from the privy, or you have touched women, and you can find no water, then have recourse to wholesome dust and wipe your faces and your hands; God is All-pardoning, All-forgiving.\qt@no{43}}%
\qt@newcmd\qurantrans@en@dxxxvii{%
Hast thou not regarded those who were given a share of the Book purchasing error, and desiring that you should also err from the way?\qt@no{44}}%
\qt@newcmd\qurantrans@en@dxxxviii{%
God knows well your enemies; God suffices as a protector, God suffices as a helper.\qt@no{45}}%
\qt@newcmd\qurantrans@en@dxxxix{%
Some of the Jews pervert words from their meanings saying, 'We have heard and we disobey' and 'Hear, and be thou not given to hear' and 'Observe us,' twisting with their tongues and traducing religion. If they had said, 'We have heard and obey' and 'Hear' and 'Regard us,' it would have been better for them, and more upright; but God has cursed them for their unbelief so they believe not except a few.\qt@no{46}}%
\qt@newcmd\qurantrans@en@dxl{%
You who have been given the Book, believe in what We have sent down, confirming what is with you, before We obliterate faces, and turn them upon their backs, or curse them as We cursed the Sabbath-men, and God's command is done.\qt@no{47}}%
\qt@newcmd\qurantrans@en@dxli{%
God forgives not that aught should be with Him associated; less than that He forgives to whomsoever He will. Whoso associates with God anything, has indeed forged a mighty sin.\qt@no{48}}%
\qt@newcmd\qurantrans@en@dxlii{%
Hast thou not regarded those who purify themselves? Nay; only God purifies whom He will; and they shall not be wronged a single date-thread.\qt@no{49}}%
\qt@newcmd\qurantrans@en@dxliii{%
Consider how they forge falsehood against God; and that suffices for a manifest sin;\qt@no{50}}%
\qt@newcmd\qurantrans@en@dxliv{%
Hast thou not regarded those who were given a share of the Book believing in demons and idols, and saying to the unbelievers, 'These are more rightly guided on the way than the believers'?\qt@no{51}}%
\qt@newcmd\qurantrans@en@dxlv{%
Those are they whom God has cursed; he whom God has cursed, thou wilt not find for him any helper.\qt@no{52}}%
\qt@newcmd\qurantrans@en@dxlvi{%
Or have they a share in the Kingdom? If that is so, they do not give the people a single date-spot.\qt@no{53}}%
\qt@newcmd\qurantrans@en@dxlvii{%
Or are they jealous of the people for the bounty that God has given them? Yet We gave the people of Abraham the Book and the Wisdom, and We gave them a mighty kingdom.\qt@no{54}}%
\qt@newcmd\qurantrans@en@dxlviii{%
And some of them there are that believe, and some of them that bar from it; Gehenna suffices for a Blaze!\qt@no{55}}%
\qt@newcmd\qurantrans@en@dxlix{%
Surely those who disbelieve in Our signs -- We shall certainly roast them at a Fire; as often as their skins are wholly burned, We shall give them in exchange other skins, that they may taste the chastisement. Surely God is All-mighty, All-wise.\qt@no{56}}%
\qt@newcmd\qurantrans@en@dl{%
And those that believe, and do deeds of righteousness, them We shall admit to gardens underneath which rivers flow, therein dwelling forever and ever; therein for them shall be spouses purified, and We shall admit them to a shelter of plenteous shade.\qt@no{57}}%
\qt@newcmd\qurantrans@en@dli{%
God commands you to deliver trusts back to their owners; and when you judge between the people, that you judge with justice. Good is the admonition God gives you; God is All-hearing, All-seeing.\qt@no{58}}%
\qt@newcmd\qurantrans@en@dlii{%
O believers, obey God, and obey the Messenger and those in authority among you. If you should quarrel on anything, refer it to God and the Messenger, if you believe in God and the Last Day; that is better, and fairer in the issue.\qt@no{59}}%
\qt@newcmd\qurantrans@en@dliii{%
Hast thou not regarded those who assert that they believe in what has been sent down to thee, and what was sent down before thee, desiring to take their disputes to idols, yet they have been commanded to disbelieve in them? But Satan desires to lead them astray into far error.\qt@no{60}}%
\qt@newcmd\qurantrans@en@dliv{%
And when it is said to them, 'Come now to what God has sent down, and the Messenger,' then thou seest the hypocrites barring the way to thee.\qt@no{61}}%
\qt@newcmd\qurantrans@en@dlv{%
How shall it be, when they are visited by an affliction for what their own hands have forwarded, then they come to thee swearing by God, 'We sought only kindness and conciliation'?\qt@no{62}}%
\qt@newcmd\qurantrans@en@dlvi{%
Those -- God knows what is in their hearts; so turn away from them, and admonish them, and say to them penetrating words about themselves.\qt@no{63}}%
\qt@newcmd\qurantrans@en@dlvii{%
We sent not ever any Messenger, but that he should he obeyed, by the leave of God. If; when they wronged themselves, they had come to thee, and prayed forgiveness of God, and the Messenger had prayed forgiveness for them, they would have found God turns, All-compassionate.\qt@no{64}}%
\qt@newcmd\qurantrans@en@dlviii{%
But no, by thy Lord! they will not believe till they make thee the judge regarding the disagreement between them, then they shall find in themselves no impediment touching thy verdict, but shall surrender in full submission.\qt@no{65}}%
\qt@newcmd\qurantrans@en@dlix{%
But had We prescribed for them, saying, 'Slay yourselves' or 'Leave your habitations,' they would not have done it, save a few of them; yet if they had done as they were admonished it would have been better for them, and stronger confirming them,\qt@no{66}}%
\qt@newcmd\qurantrans@en@dlx{%
and then We surely would have given them from Us a mighty wage,\qt@no{67}}%
\qt@newcmd\qurantrans@en@dlxi{%
and guided them on a straight path.\qt@no{68}}%
\qt@newcmd\qurantrans@en@dlxii{%
Whosoever obeys God, and the Messenger -- they are with those whom God has blessed, Prophets, just men, martyrs, the righteous; good companions they!\qt@no{69}}%
\qt@newcmd\qurantrans@en@dlxiii{%
That is the bounty from God; God suffices as One who knows.\qt@no{70}}%
\qt@newcmd\qurantrans@en@dlxiv{%
O believers, take your precautions; then move forward in companies, or move forward all together.\qt@no{71}}%
\qt@newcmd\qurantrans@en@dlxv{%
Some of you there are that are dilatory; then, if an affliction visits you, he says, 'God has blessed me, in that I was not a martyr with them.'\qt@no{72}}%
\qt@newcmd\qurantrans@en@dlxvi{%
But if a bounty from God visits you, he will surely say, as if there had never been any affection between you and him, 'Would that I had been with them, to attain a mighty triumph!'\qt@no{73}}%
\qt@newcmd\qurantrans@en@dlxvii{%
So let them fight in the way of God who sell the present life for the world to come; and whosoever fights in the way of God and is slain, or conquers, We shall bring him a mighty wage.\qt@no{74}}%
\qt@newcmd\qurantrans@en@dlxviii{%
How is it with you, that you do not fight in the way of God, and for the men, women, and children who, being abased, say, 'Our Lord, bring us forth from this city whose people are evildoers, and appoint t us a protector from Thee, and appoint to us from Thee a helper'?\qt@no{75}}%
\qt@newcmd\qurantrans@en@dlxix{%
The believers fight in the way of God, and the unbelievers fight in the idols' way. Fight you therefore against the friends of Satan; surely the guile of Satan is ever feeble.\qt@no{76}}%
\qt@newcmd\qurantrans@en@dlxx{%
Hast thou not regarded those to whom it was said, 'Restrain your hands, and perform the prayer, and pay the alms'? Then, as soon as fighting is prescribed for them, there is a party of them fearing the people as they would fear God, or with a greater fear, and they say, 'Our Lord, why hast thou prescribed fighting for us? Why not defer us to a near term?' Say: 'The enjoyment of this world is little; the world to come is better for him who fears God; you shall not be wronged a single date-thread.'\qt@no{77}}%
\qt@newcmd\qurantrans@en@dlxxi{%
Wherever you may be, death will overtake you, though you should be in raised-up towers. And if a good thing visits them, they say, 'This is from God'; but if an evil thing visits them, they say, 'This is from thee.' Say: 'Everything is from God.' How is it with this people? They scarcely understand any tiding.\qt@no{78}}%
\qt@newcmd\qurantrans@en@dlxxii{%
Whatever good visits thee, it is of God; whatever evil visits thee is of thyself. And We have sent thee to men a Messenger; God suffices for a witness.\qt@no{79}}%
\qt@newcmd\qurantrans@en@dlxxiii{%
Whosoever obeys the Messenger, thereby obeys God; and whosoever turns his back - We have not sent thee to be a watcher over them.\qt@no{80}}%
\qt@newcmd\qurantrans@en@dlxxiv{%
They say, 'Obedience'; but when they sally forth from thee, a party of them meditate all night on other than what thou sayest. God writes down their meditations; so turn away from them, and put thy trust in God; God suffices for a guardian.\qt@no{81}}%
\qt@newcmd\qurantrans@en@dlxxv{%
What, do they not ponder the Koran? If it had been from other than God surely they would have found in it much inconsistency.\qt@no{82}}%
\qt@newcmd\qurantrans@en@dlxxvi{%
When there comes to them a matter, be it of security or fear, they broadcast it; if they had referred it to the Messenger and to those in authority among them, those of them whose task it is to investigate would have known the matter. And but for the bounty of God to you, and His mercy, you would surely have followed Satan, except a few.\qt@no{83}}%
\qt@newcmd\qurantrans@en@dlxxvii{%
So do thou fight in the way of God; thou art charged only with thyself. And urge on the believers; haply God will restrain the unbelievers' might; God is stronger in might, more terrible in punishing.\qt@no{84}}%
\qt@newcmd\qurantrans@en@dlxxviii{%
Whoso intercedes with a good intercession shall receive a share of it; whosoever intercedes with a bad intercession, he shall receive the like of it; God has power over everything.\qt@no{85}}%
\qt@newcmd\qurantrans@en@dlxxix{%
And when you are greeted with a greeting greet with a fairer than it, or return it; surely God keeps a watchful count over everything.\qt@no{86}}%
\qt@newcmd\qurantrans@en@dlxxx{%
God -- there is no god but He. He will surely gather you to the Resurrection Day, no doubt of it. And who is truer in tidings than God?\qt@no{87}}%
\qt@newcmd\qurantrans@en@dlxxxi{%
How is it with you, that you are two parties touching the hypocrites, and God has overthrown them for what they earned? What, do you desire to guide him whom God has led astray? Whom God leads astray, thou wilt not find for him a way.\qt@no{88}}%
\qt@newcmd\qurantrans@en@dlxxxii{%
They wish that you should disbelieve as they disbelieve, and then you would be equal; therefore take not to yourselves friends of them, until they emigrate in the way of God; then, if they turn their backs, take them, and slay them wherever you find them; take not to yourselves any one of them as friend or helper\qt@no{89}}%
\qt@newcmd\qurantrans@en@dlxxxiii{%
except those that betake themselves to a people who are joined with you by a compact, or come to you with breasts constricted from fighting with you or fighting their people. Had God willed, He would have given them authority over you, and then certainly they would have fought you. If they withdraw from you, and do not fight you, and offer you peace, then God assigns not any way to you against them.\qt@no{90}}%
\qt@newcmd\qurantrans@en@dlxxxiv{%
You will find others desiring to be secure from you, and secure from their people, yet whenever they are returned to temptation, they are overthrown in it. If they withdraw not from you, and offer you peace, and restrain their hands, take them, and slay them wherever you come on them; against them We have given you a clear authority.\qt@no{91}}%
\qt@newcmd\qurantrans@en@dlxxxv{%
It belongs not to a believer to slay a believer, except it be by error. If any slays a believer by error, then let him set free a believing slave, and bloodwit is to be paid to his family unless they forgo it as a freewill offering. If he belong to a people at enmity with you and is a believer, let the slayer set free a believing slave. If he belong to a people joined with you by a compact, then bloodwit is to be paid to his family and the slayer shall set free a believing slave. But if he finds not the means, let him fast two successive months -- God's turning; God is All-knowing, All-wise.\qt@no{92}}%
\qt@newcmd\qurantrans@en@dlxxxvi{%
And whoso slays a believer wilfully, his recompense is Gehenna, therein dwelling forever, and God will be wroth with him and will curse him, and prepare for him a mighty chastisement.\qt@no{93}}%
\qt@newcmd\qurantrans@en@dlxxxvii{%
O believers, when you are journeying in the path of God, be discriminating, and do not say to him who offers you a greeting, 'Thou art not a believer,' seeking the chance goods of the present life. With God are spoils abundant. So you were aforetime; but God has been gracious to you. So be discriminating; surely God is aware of the things you do.\qt@no{94}}%
\qt@newcmd\qurantrans@en@dlxxxviii{%
Such believers as sit at home -- unless they have an injury -- are not the equals of those who struggle in the path of God with their possessions and their selves. God has preferred in rank those who struggle with their possessions and their selves over the ones who sit at home; yet to each God has promised the reward most fair; and God has preferred those who struggle over the ones who sit at home for the bounty of a mighty wage,\qt@no{95}}%
\qt@newcmd\qurantrans@en@dlxxxix{%
in ranks standing before Him, forgiveness and mercy; surely God is All-forgiving, All-compassionate.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dxc{%
And those the angels take, while still they are wronging themselves -- the angels will say, 'In what circumstances were you?' They will say, 'We were abased in the earth.' The angels will say, 'But was not God's earth wide, so that you might have emigrated in it?' Such men, their refuge shall be Gehenna -- an evil homecoming! --\qt@no{97}}%
\qt@newcmd\qurantrans@en@dxci{%
except the men, women, and children who, being abased, can devise nothing and are not guided to a way;\qt@no{98}}%
\qt@newcmd\qurantrans@en@dxcii{%
haply them God will yet pardon, for God is All-pardoning, All-forgiving.\qt@no{99}}%
\qt@newcmd\qurantrans@en@dxciii{%
Whoso emigrates in the way of God will find in the earth many refuges and plenty; whoso goes forth from his house an emigrant to God and His Messenger, and then death overtakes him, his wage shall have fallen on God; surely God is All-forgiving, All-compassionate.\qt@no{100}}%
\qt@newcmd\qurantrans@en@dxciv{%
And when you are journeying in the land there is no fault in you that you shorten the prayer, if you fear the unbelievers may afflict you; the unbelievers are for you a manifest foe.\qt@no{101}}%
\qt@newcmd\qurantrans@en@dxcv{%
When thou art amongst them, and performest for them the prayer, let a party of them stand with thee, and let them take their weapons. When they bow themselves, let them be behind you; and let another party who have not prayed come and pray with thee, taking their precautions and their weapons. The unbelievers wish that you should be heedless of your weapons and your baggage, then they would wheel on you all at once. There is no fault in you, if rain molests you, or you are sick, to lay aside your weapons; but take your precautions. God has prepared for the unbelievers a humbling chastisement.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dxcvi{%
When you have performed the prayer, remember God, standing and sitting and on your sides. Then, when you are secure, perform the prayer; surely the prayer is a timed prescription for the believers.\qt@no{103}}%
\qt@newcmd\qurantrans@en@dxcvii{%
Faint not in seeking the heathen; if you are suffering, they are also suffering as you are suffering, and you are hoping from God for that for which they cannot hope; God is All-knowing, All-wise.\qt@no{104}}%
\qt@newcmd\qurantrans@en@dxcviii{%
Surely We have sent down to thee the Book with the truth, so that thou mayest judge between the people by that God has shown thee. So be not an advocate for the traitors;\qt@no{105}}%
\qt@newcmd\qurantrans@en@dxcix{%
and pray forgiveness of God; surely God is All-forgiving, All-compassionate.\qt@no{106}}%
\qt@newcmd\qurantrans@en@dc{%
And do not dispute on behalf of those who betray themselves; surely God loves not the guilty traitor.\qt@no{107}}%
\qt@newcmd\qurantrans@en@dci{%
They hide themselves from men, but hide not themselves from God; for He is with them while they meditate at night discourse unpleasing to Him; God encompasses the things they do.\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcii{%
Ha, there you are; you have disputed on their behalf in the present life; but who will dispute with God on their behalf on the Resurrection Day, or who will be a guardian for them?\qt@no{109}}%
\qt@newcmd\qurantrans@en@dciii{%
Whosoever does evil, or wrongs himself; and then prays God's forgiveness, he shall find God is All-forgiving, All-compassionate.\qt@no{110}}%
\qt@newcmd\qurantrans@en@dciv{%
And whosoever earns a sin, earns it against himself only; and God is ever All-knowing, All-wise.\qt@no{111}}%
\qt@newcmd\qurantrans@en@dcv{%
And whosoever earns a fault or a sin and then casts it upon the innocent, thereby has laid upon himself calumny and manifest sin.\qt@no{112}}%
\qt@newcmd\qurantrans@en@dcvi{%
But for God's bounty to thee and His mercy a party of them purposed to lead thee astray; but they lead only themselves astray; they do not hurt thee in anything. God has sent down on thee the Book and the Wisdom, and He has taught thee that thou knewest not; God's' bounty to thee is ever great.\qt@no{113}}%
\qt@newcmd\qurantrans@en@dcvii{%
No good is there in much of their conspiring, except for him who bids to freewill offering, or honour, or setting things right between the people. Whoso does that, seeking God's good pleasure, We shall surely give him a mighty wage.\qt@no{114}}%
\qt@newcmd\qurantrans@en@dcviii{%
But whoso makes a breach with the Messenger after the guidance has become clear to him and follows a way other than the believers', him We shall turn over to what he has turned to and We shall roast him in Gehenna - an evil homecoming!\qt@no{115}}%
\qt@newcmd\qurantrans@en@dcix{%
God forgives not that aught should be with Him associated; less than that He forgives to whomsoever He will. Whoso associates with God anything, has gone astray into far error.\qt@no{116}}%
\qt@newcmd\qurantrans@en@dcx{%
In stead of Him, they pray not except to female beings; they pray not except to a rebel Satan accursed by God.\qt@no{117}}%
\qt@newcmd\qurantrans@en@dcxi{%
He said, 'Assuredly I will take unto myself a portion appointed of Thy servants,\qt@no{118}}%
\qt@newcmd\qurantrans@en@dcxii{%
and I will lead them astray, and fill them with fancies and I will command them and they will cut off the cattle's ears; I will command them and they will alter God's creation.' Whoso takes Satan to him for a friend, instead of God, has surely suffered a manifest loss.\qt@no{119}}%
\qt@newcmd\qurantrans@en@dcxiii{%
He promises them and fills them with fancies, but there is nothing Satan promises them except delusion.\qt@no{120}}%
\qt@newcmd\qurantrans@en@dcxiv{%
Such men -- their refuge shall be Gehenna, and they shall find no asylum from it.\qt@no{121}}%
\qt@newcmd\qurantrans@en@dcxv{%
But those that believe, and do deeds of righteousness, them We shall admit to gardens underneath which rivers flow, therein dwelling for ever and ever; God's promise in truth; and who is truer in speech than God?\qt@no{122}}%
\qt@newcmd\qurantrans@en@dcxvi{%
It is not your fancies, nor the fancies of the People of the Book. Whosoever does evil shall be recompensed for it, and will not find for him, apart from God, a friend or helper.\qt@no{123}}%
\qt@newcmd\qurantrans@en@dcxvii{%
And whosoever does deeds of righteousness, be it male or female, believing - they shall enter Paradise, and not be wronged a single date-spot.\qt@no{124}}%
\qt@newcmd\qurantrans@en@dcxviii{%
And who is there that has a fairer religion than he who submits his will to God being a good-doer, and who follows the creed of Abraham, a man of pure faith? And God took Abraham for a friend.\qt@no{125}}%
\qt@newcmd\qurantrans@en@dcxix{%
To God belongs all that is in the heavens and in the earth, and God encompasses everything.\qt@no{126}}%
\qt@newcmd\qurantrans@en@dcxx{%
They will ask thee for a pronouncement concerning women. Say: 'God pronounces to you concerning them, and what is recited to you in the Book concerning the orphan women to whom you give not what is prescribed for them, and yet desire to marry them, and the oppressed children, and that you secure justice for orphans. Whatever good you do, God knows of it.'\qt@no{127}}%
\qt@newcmd\qurantrans@en@dcxxi{%
If a woman fear rebelliousness or aversion in her husband, there is no fault in them if the couple set things right between them; right settlement is better; and souls are very prone to avarice. If you do good and are godfearing, surely God is aware of the things you do.\qt@no{128}}%
\qt@newcmd\qurantrans@en@dcxxii{%
You will not be able to be equitable between your wives, be you ever so eager; yet do not be altogether partial so that you leave her as it were suspended. If you set things right, and are godfearing, God is All-forgiving, All-compassionate.\qt@no{129}}%
\qt@newcmd\qurantrans@en@dcxxiii{%
But if they separate, God will enrich each of them of His plenty; God is All-embracing, All-wise.\qt@no{130}}%
\qt@newcmd\qurantrans@en@dcxxiv{%
To God belongs all that is in the heavens and in the earth. We have charged those who were given the Book before you, and you, 'Fear God.' If you disbelieve, to God belongs all that is in the heavens and in the earth; God is All-sufficient, All-laudable.\qt@no{131}}%
\qt@newcmd\qurantrans@en@dcxxv{%
To God belongs all that is in the heavens and in the earth; God suffices for a guardian.\qt@no{132}}%
\qt@newcmd\qurantrans@en@dcxxvi{%
If He will, He can put you away, O men, and bring others; surely God is powerful over that.\qt@no{133}}%
\qt@newcmd\qurantrans@en@dcxxvii{%
Whoso desires the reward of this world, with God is the reward of this world and of the world to come; God is All-hearing, All-seeing.\qt@no{134}}%
\qt@newcmd\qurantrans@en@dcxxviii{%
O believers, be you securers of justice, witnesses for God, even though it be against yourselves, or your parents and kinsmen, whether the man be rich or poor; God stands closest to either. Then follow not caprice, so as to swerve; for if you twist or turn, God is aware of the things you do.\qt@no{135}}%
\qt@newcmd\qurantrans@en@dcxxix{%
O believers, believe in God and His Messenger and the Book He has sent down on His Messenger and the Book which He sent down before. Whoso disbelieves in God and His angels and His Books, and His Messengers, and the Last Day, has surely gone astray into far error.\qt@no{136}}%
\qt@newcmd\qurantrans@en@dcxxx{%
Those who believe, and then disbelieve, and then believe, and then disbelieve, and then increase in unbelief-God is not likely to forgive them, neither to guide them on any way.\qt@no{137}}%
\qt@newcmd\qurantrans@en@dcxxxi{%
Give thou good tidings to the hypocrites that for them awaits a painful chastisement.\qt@no{138}}%
\qt@newcmd\qurantrans@en@dcxxxii{%
Those who take unbelievers for their friends instead of believers -- do they seek glory in them? But glory altogether belongs to God.\qt@no{139}}%
\qt@newcmd\qurantrans@en@dcxxxiii{%
He has sent down upon you in the Book: 'When you hear God's signs being disbelieved and made mock of, do not sit with them until they plunge into some other talk, or else you will surely be like to them.' God will gather the hypocrites and the unbelievers all in Gehenna.\qt@no{140}}%
\qt@newcmd\qurantrans@en@dcxxxiv{%
Those who wait upon you and, if a victory comes to you from God, say, 'Were we not with you?' but if the unbelievers get a share, they say, 'Did we not gain the mastery over you, and did we not defend you from the believers?' God will judge between you on the Resurrection Day, and God will not grant the unbelievers any way over the believers.\qt@no{141}}%
\qt@newcmd\qurantrans@en@dcxxxv{%
The hypocrites seek to trick God, but God is tricking them. When they stand up to pray they stand up lazily, showing off to the people and not remembering God save a little;\qt@no{142}}%
\qt@newcmd\qurantrans@en@dcxxxvi{%
wavering all the time -- not to these, not to those; and whom God leads astray, thou wilt not find for him a way.\qt@no{143}}%
\qt@newcmd\qurantrans@en@dcxxxvii{%
O believers, take not the unbelievers as friends instead of the believers; or do you desire to give God over you a clear authority?\qt@no{144}}%
\qt@newcmd\qurantrans@en@dcxxxviii{%
Surely the hypocrites will be in the lowest reach of the Fire; thou wilt not find for them any helper;\qt@no{145}}%
\qt@newcmd\qurantrans@en@dcxxxix{%
save such as repent, and make amends, and hold fast to God, and make their religion sincerely God's; those are with the believers, and God will certainly give the believers a mighty wage.\qt@no{146}}%
\qt@newcmd\qurantrans@en@dcxl{%
What would God do with chastising you if you are thankful, and believe? God is All-thankful, All-knowing.\qt@no{147}}%
\qt@newcmd\qurantrans@en@dcxli{%
God likes not the shouting of evil words unless a man has been wronged; God is All-hearing, All-knowing.\qt@no{148}}%
\qt@newcmd\qurantrans@en@dcxlii{%
If you do good openly or in secret or pardon an evil, surely God is All-pardoning, All-powerful.\qt@no{149}}%
\qt@newcmd\qurantrans@en@dcxliii{%
Those who disbelieve in God and His Messengers and desire to make division between God and His Messengers, and say, 'We believe in part, and disbelieve in part,' desiring to take between this and that a way --\qt@no{150}}%
\qt@newcmd\qurantrans@en@dcxliv{%
those in truth are the unbelievers; and We have prepared for the unbelievers a humbling chastisement.\qt@no{151}}%
\qt@newcmd\qurantrans@en@dcxlv{%
And those who believe in God and His Messengers and make no division between any of them, those -- We shall surely give them their wages; God is All-forgiving, All-compassionate.\qt@no{152}}%
\qt@newcmd\qurantrans@en@dcxlvi{%
The People of the Book will ask thee to bring down upon them a Book from heaven; and they asked Moses for greater than that, for they said, 'Show us God openly.' And the thunderbolt took them for their evildoing. Then they took to themselves the Calf, after the clear signs had come to them; yet We pardoned them that, and We bestowed upon Moses a clear authority.\qt@no{153}}%
\qt@newcmd\qurantrans@en@dcxlvii{%
And We raised above them the Mount, taking compact with them; and We said to them, 'Enter in at the gate, prostrating'; and We said to them, 'Transgress not the Sabbath'; and We took from them a solemn compact.\qt@no{154}}%
\qt@newcmd\qurantrans@en@dcxlviii{%
So, for their breaking the compact, and disbelieving in the signs of God, and slaying the Prophets without right, and for their saying, 'Our hearts are uncircumcised' -- nay, but God sealed them for their unbelief, so they believe not, except a few --\qt@no{155}}%
\qt@newcmd\qurantrans@en@dcxlix{%
and for their unbelief, and their uttering against Mary a mighty calumny,\qt@no{156}}%
\qt@newcmd\qurantrans@en@dcl{%
and for their saying, 'We slew the Messiah, Jesus son of Mary, the Messenger of God' -- yet they did not slay him, neither crucified him, only a likeness of that was shown to them. Those who are at variance concerning him surely are in doubt regarding him; they have no knowledge of him, except the following of surmise; and they slew him not of a certainty -- no indeed;\qt@no{157}}%
\qt@newcmd\qurantrans@en@dcli{%
God raised him up to Him; God is All-mighty, All-wise.\qt@no{158}}%
\qt@newcmd\qurantrans@en@dclii{%
There is not one of the People of the Book but will assuredly believe in him before his death, and on the Resurrection Day he will be a witness against them.\qt@no{159}}%
\qt@newcmd\qurantrans@en@dcliii{%
And for the evildoing of those of Jewry, We have forbidden them certain good things that were permitted to them, and for their barring from God's way many,\qt@no{160}}%
\qt@newcmd\qurantrans@en@dcliv{%
and for their taking usury, that they were prohibited, and consuming the wealth of the people in vanity; and We have prepared for the unbelievers among them a painful chastisement.\qt@no{161}}%
\qt@newcmd\qurantrans@en@dclv{%
But those of them that are firmly rooted in knowledge, and the believers believing in what has been sent down to thee, and what was sent down before thee, that perform the prayer and pay the alms, and those who believe in God and the Last Day - them We shall surely give a mighty wage.\qt@no{162}}%
\qt@newcmd\qurantrans@en@dclvi{%
We have revealed to thee as We revealed to Noah, and the Prophets after him, and We revealed to Abraham, Ishmael, Isaac, Jacob, and the Tribes, Jesus and Job, Jonah and Aaron and Solomon, and We gave to David Psalms,\qt@no{163}}%
\qt@newcmd\qurantrans@en@dclvii{%
and Messengers We have already told thee of before, and Messengers We have not told thee of; and unto Moses God spoke directly --\qt@no{164}}%
\qt@newcmd\qurantrans@en@dclviii{%
Messengers bearing good tidings, and warning, so that mankind might have no argument against God, after the Messengers; God is All-mighty, All-wise.\qt@no{165}}%
\qt@newcmd\qurantrans@en@dclix{%
But God bears witness to that He has sent down to thee; He has sent it down with His knowledge; and the angels also bear witness; and God suffices for a witness.\qt@no{166}}%
\qt@newcmd\qurantrans@en@dclx{%
Surely those who disbelieve, and bar from the way of God, have gone astray into far error.\qt@no{167}}%
\qt@newcmd\qurantrans@en@dclxi{%
Surely the unbelievers, who have done evil, God would not forgive them, neither guide them on any road\qt@no{168}}%
\qt@newcmd\qurantrans@en@dclxii{%
but the road to Gehenna, therein dwelling forever and ever; and that for God is an easy matter.\qt@no{169}}%
\qt@newcmd\qurantrans@en@dclxiii{%
O men, the Messenger has now come to you with the truth from your Lord; so believe; better is it for you. And if you disbelieve, to God belongs all that is in the heavens and in the earth; and God is All-knowing, All-wise.\qt@no{170}}%
\qt@newcmd\qurantrans@en@dclxiv{%
People of the Book, go not beyond the bounds in your religion, and say not as to God but the truth. The Messiah, Jesus son of Mary, was only the Messenger of God, and His Word that He committed to Mary, and a Spirit from Him. So believe in God and His Messengers, and say not, 'Three.' Refrain; better is it for you. God is only One God. Glory be to Him -- That He should have a son! To Him belongs all that is in the heavens and in the earth; God suffices for a guardian.\qt@no{171}}%
\qt@newcmd\qurantrans@en@dclxv{%
The Messiah will not disdain to be a servant of God, neither the angels who are near stationed to Him. Whosoever disdains to serve Him, and waxes proud, He will assuredly muster them to Him, all of them.\qt@no{172}}%
\qt@newcmd\qurantrans@en@dclxvi{%
As for the believers, who do deeds of righteousness, He will pay them in full their wages, and He will give them more, of His bounty; and as for them who disdain, and wax proud, them He will chastise with a painful chastisement, and they shall not find for them, apart from God, a friend or helper.\qt@no{173}}%
\qt@newcmd\qurantrans@en@dclxvii{%
O men, a proof has now come to you from your Lord; We have sent down to you a manifest light.\qt@no{174}}%
\qt@newcmd\qurantrans@en@dclxviii{%
As for those who believe in God, and hold fast to Him, He will surely admit them to mercy from Him, and bounty, and will guide them to Him on a straight path.\qt@no{175}}%
\qt@newcmd\qurantrans@en@dclxix{%
They will ask thee for a pronouncement. Say: 'God pronounces to you concerning the indirect heirs. If a man perishes having no children, but he has a sister, she shall receive a half of what he leaves, and he is her heir if she has no children. If there be two sisters, they shall receive two-thirds of what he leaves; if there be brothers and sisters, the male shall receive the portion of two females. God makes clear to you, lest you go astray; God has knowledge of everything.\qt@no{176}}%
\qt@newcmd\qurantrans@en@dclxx{%
\basmalahen O believers, fulfil your bonds. Permitted to you is the beast of the flocks, except that which is now recited to you, so that you deem not game permitted to be hunted when you are in pilgrim sanctity. God decrees whatsoever He desires.\qt@no{1}}%
\qt@newcmd\qurantrans@en@dclxxi{%
O believers, profane not God's waymarks nor the holy month, neither the offering, nor the necklaces, nor those repairing to the Holy House seeking from their Lord bounty and good pleasure. But when you have quit your pilgrim sanctity, then hunt for game. Let not detestation for a people who barred you from the Holy Mosque move you to commit aggression. Help one another to piety and godfearing; do not help each other to sin and enmity. And fear God; surely God is terrible in retribution.\qt@no{2}}%
\qt@newcmd\qurantrans@en@dclxxii{%
Forbidden to you are carrion, blood, the flesh of swine, what has been hallowed to other than God, the beast strangled; the beast beaten down, the beast fallen to death, the beast gored, and that devoured by beasts of prey - excepting that you have sacrificed duly -- as also things sacrificed to idols, and partition by the divining arrows; that is ungodliness. Today the unbelievers have despaired of your religion; therefore fear them not, but fear you Me. Today I have perfected your religion for you, and I have completed My blessing upon you, and I have approved Islam for your religion. But whosoever is constrained in emptiness and not inclining purposely to sin -- God is All-forgiving, All-compassionate.\qt@no{3}}%
\qt@newcmd\qurantrans@en@dclxxiii{%
They will question thee what is permitted them. Say: 'The good things are permitted you; and such hunting creatures as you teach, training them as hounds, and teaching them as God has taught you -- eat what they seize for you, and mention God's Name over it. Fear God; God is swift at the reckoning.'\qt@no{4}}%
\qt@newcmd\qurantrans@en@dclxxiv{%
Today the good things are permitted you, and the food of those who were given the Book is permitted to you, and permitted to them is your food; Likewise believing women in wedlock, and in wedlock women of them who were given the Book before you if you give them their wages, in wedlock and not in licence, or as taking lovers. Whoso disbelieves in the faith, his work has failed, and in the world to come he shall be among the losers.\qt@no{5}}%
\qt@newcmd\qurantrans@en@dclxxv{%
O believers, when you stand up to pray wash your faces, and your hands up to the elbows, and wipe your heads, and your feet up to the ankles. If you are defiled, purify yourselves; but if you are sick or on a journey, or if any of you comes from the privy, or you have touched women, and you can find no water, then have recourse to wholesome dust and wipe your faces and your hands with it. God does not desire to make any impediment for you; but He desires to purify you, and that He may complete His blessing upon you; haply you will be thankful.\qt@no{6}}%
\qt@newcmd\qurantrans@en@dclxxvi{%
And remember God's blessing upon you, and His compact which He made with you when you said, 'We have heard and we obey. And fear you God; surely God knows the thoughts in the breasts.\qt@no{7}}%
\qt@newcmd\qurantrans@en@dclxxvii{%
O believers, be you securers of justice, witnesses for God. Let not detestation for a people move you not to be equitable; be equitable -- that is nearer to godfearing. And fear God; surely God is aware of the things you do.\qt@no{8}}%
\qt@newcmd\qurantrans@en@dclxxviii{%
God has promised those that believe, and do deeds of righteousness; they shall have; forgiveness and a mighty wage.\qt@no{9}}%
\qt@newcmd\qurantrans@en@dclxxix{%
And the unbelievers, who cried lies to Our signs -- they shall be the inhabitants of Hell.\qt@no{10}}%
\qt@newcmd\qurantrans@en@dclxxx{%
O believers, remember God's blessing upon you, when a certain people purposed to stretch against you their hands, and He restrained their hands from you; and fear God; and in God let the believers put all their trust.\qt@no{11}}%
\qt@newcmd\qurantrans@en@dclxxxi{%
God took compact with the Children of Israel; and We raised up from among them twelve chieftains. And God said, 'I am with you. Surely, if you perform the prayer, and pay the alms, and believe in My Messengers and succour them, and lend to God a good loan, I will acquit you of your evil deeds, and I will admit you to gardens underneath which rivers flow. So whosoever of you thereafter disbelieves, surely he has gone astray from the right way.\qt@no{12}}%
\qt@newcmd\qurantrans@en@dclxxxii{%
So for their breaking their compact We cursed them and made their hearts hard, they perverting words from their meanings; and they have forgotten a portion of that they were reminded of; and thou wilt never cease to light upon some act of treachery on their part, except a few of them. Yet pardon them, and forgive; surely God loves the good-doers.\qt@no{13}}%
\qt@newcmd\qurantrans@en@dclxxxiii{%
And with those who say 'We are Christians' We took compact; and they have forgotten a portion of that they were reminded of. So We have stirred up among them enmity and hatred, till the Day of Resurrection; and God will assuredly tell them of the things they wrought.\qt@no{14}}%
\qt@newcmd\qurantrans@en@dclxxxiv{%
People of the Book, now there has come to you Our Messenger, making clear to you many things you have been concealing of the Book, and effacing many things. There has come to you from God a light, and a Book Manifest\qt@no{15}}%
\qt@newcmd\qurantrans@en@dclxxxv{%
whereby God guides whosoever follows His good pleasure in the ways of peace, and brings them forth from the shadows into the light by His leave; and He guides them to a straight path.\qt@no{16}}%
\qt@newcmd\qurantrans@en@dclxxxvi{%
They are unbelievers who say, 'God is the Messiah, Mary's son.' Say: 'Who then shall overrule God in any way if He desires to destroy the Messiah, Mary's son, and his mother, and all those who are on earth?' For to God belongs the kingdom of the heavens and of the earth, and all that is between them, creating what He will. God is powerful over everything.\qt@no{17}}%
\qt@newcmd\qurantrans@en@dclxxxvii{%
Say the Jews and Christians, 'We are the sons of God, and His beloved ones.' Say: 'Why then does He chastise you for your sins? No; you are mortals, of His creating; He forgives whom He will, and He chastises whom He will.' For to God belongs the kingdom of the heavens and of the earth, and all that is between them; to Him is the homecoming.\qt@no{18}}%
\qt@newcmd\qurantrans@en@dclxxxviii{%
People of the Book, now there has come to you Our Messenger, making things clear to you, upon an interval between the Messengers lest you should say, 'There has not come to us any bearer of good tidings, neither any warner. Indeed, there has come to you a bearer of good tidings and a warner; God is powerful over everything.\qt@no{19}}%
\qt@newcmd\qurantrans@en@dclxxxix{%
And when Moses said to his people, 'O my people, remember God's blessing upon you, when He appointed among you Prophets, and appointed you kings, and gave you such as He had not given to any being.\qt@no{20}}%
\qt@newcmd\qurantrans@en@dcxc{%
O my people, enter the Holy Land which God has prescribed for you, and turn not back in your traces, to turn about losers.'\qt@no{21}}%
\qt@newcmd\qurantrans@en@dcxci{%
They said, 'Moses, there are people in. it very arrogant; we will not enter it until they depart from it; if they depart from it then we will enter.'\qt@no{22}}%
\qt@newcmd\qurantrans@en@dcxcii{%
Said two men of those that feared God whom God had blessed, 'Enter against them the gate! When you enter it, you will be victors. Put you all your trust in God, if you are believers.'\qt@no{23}}%
\qt@newcmd\qurantrans@en@dcxciii{%
They said, 'Moses, we will never enter it so long as they are in it. Go forth, thou and thy Lord, and do battle; we will be sitting here.'\qt@no{24}}%
\qt@newcmd\qurantrans@en@dcxciv{%
He said, 'O my Lord, I rule no one except myself and my brother. So do Thou divide between us and the people of the ungodly.'\qt@no{25}}%
\qt@newcmd\qurantrans@en@dcxcv{%
Said He, 'Then it shall be forbidden them for forty years, while they are wandering in the earth; so grieve not for the people of the ungodly.'\qt@no{26}}%
\qt@newcmd\qurantrans@en@dcxcvi{%
And recite thou to them the story of the two sons of Adam truthfully, when they offered a sacrifice, and it was accepted of one of them, and not accepted of the other. 'I will surely slay thee,' said one. 'God accepts only of the godfearing,' said the other.\qt@no{27}}%
\qt@newcmd\qurantrans@en@dcxcvii{%
'Yet if thou stretchest out thy hand against me, to slay me, I will not stretch out my hand against thee, to slay thee; I fear God, the Lord of all Being.\qt@no{28}}%
\qt@newcmd\qurantrans@en@dcxcviii{%
I desire that thou shouldest be laden with my sin and thy sin, and so become an inhabitant of the Fire; that is the recompense of the evildoers.'\qt@no{29}}%
\qt@newcmd\qurantrans@en@dcxcix{%
Then his soul prompted him to slay his brother, and he slew him, and became one of the losers.\qt@no{30}}%
\qt@newcmd\qurantrans@en@dcc{%
Then God sent forth a raven, scratching into the earth, to show him how he might conceal the vile body of his brother. He said, 'Woe is me! Am I unable to be as this raven, and so conceal my brother's vile body?' And he became one of the remorseful.\qt@no{31}}%
\qt@newcmd\qurantrans@en@dcci{%
Therefore We prescribed for the Children of Israel that whoso slays a soul not to retaliate for a soul slain, nor for corruption done in the land, shall be as if he had slain mankind altogether; and whoso gives life to a soul, shall be as if he ha given life to mankind altogether. Our Messengers have already come to them with the clear signs; then many of them thereafter commit excesses in the earth.\qt@no{32}}%
\qt@newcmd\qurantrans@en@dccii{%
This is the recompense of those who fight against God and His Messenger, and hasten about the earth, to do corruption there: they shall be slaughtered, or crucified, or their hands and feet shall alternately be struck off; or they shall be banished from the land. That is a degradation for them in this world; and in the world to come awaits them a mighty chastisement,\qt@no{33}}%
\qt@newcmd\qurantrans@en@dcciii{%
except for such as repent, before you have power over them. So know you that God is All-forgiving, All-compassionate.\qt@no{34}}%
\qt@newcmd\qurantrans@en@dcciv{%
O believers, fear God, and seek the means to come to Him, and struggle in His way; haply you will prosper.\qt@no{35}}%
\qt@newcmd\qurantrans@en@dccv{%
The unbelievers, though they possessed all that is in the earth, and the like of it with it, to ransom themselves from the chastisement of the Day of Resurrection thereby, it would not be accepted of them; for them awaits a painful chastisement.\qt@no{36}}%
\qt@newcmd\qurantrans@en@dccvi{%
They will desire to come forth from the Fire, but they will not come forth from it; for them awaits a lasting chastisement.\qt@no{37}}%
\qt@newcmd\qurantrans@en@dccvii{%
And the thief, male and female: cut off the hands of both, as a recompense for what they have earned, and a punishment exemplary from God; God is All-mighty, All-wise.\qt@no{38}}%
\qt@newcmd\qurantrans@en@dccviii{%
But whoso repents, after his evildoing, and makes amends, God will turn towards him; God is All-forgiving, All-compassionate.\qt@no{39}}%
\qt@newcmd\qurantrans@en@dccix{%
Knowest thou not that to God belongs the kingdom of the heavens and the earth? He chastises whom He will, and forgives whom He will; and God is powerful over everything.\qt@no{40}}%
\qt@newcmd\qurantrans@en@dccx{%
O Messenger, let them not grieve thee that vie with one another in unbelief, such men as say with their mouths 'We believe' but their hearts believe not; and the Jews who listen to falsehood, listen to other folk, who have not come to thee, perverting words from their meanings, saying, 'If you are given this, then take it; if you are not given it, beware!' Whomsoever God desires to try, thou canst not avail him anything with God. Those are they whose hearts God desired not to purify; for them is degradation in this world; and in the world to come awaits them a mighty chastisement;\qt@no{41}}%
\qt@newcmd\qurantrans@en@dccxi{%
who listen to falsehood, and consume the unlawful. If they come to thee, judge thou between them, or turn away from them; if thou turnest away from them, they will hurt thee nothing; and if thou judgest, judge justly between them; God loves the just.\qt@no{42}}%
\qt@newcmd\qurantrans@en@dccxii{%
Yet how will they make thee their judge seeing they have the Torah, wherein is God's judgment, then thereafter turn their backs? They are not believers.\qt@no{43}}%
\qt@newcmd\qurantrans@en@dccxiii{%
Surely We sent down the Torah, wherein is guidance and light; thereby the Prophets who had surrendered themselves gave judgment for those of Jewry, as did the masters and the rabbis, following such portion of God's Book as they were given to keep and were witnesses to. So fear not men, but fear you Me; and sell not My signs for a little price. Whoso judges not according to what God has sent down - they are the unbelievers.\qt@no{44}}%
\qt@newcmd\qurantrans@en@dccxiv{%
And therein We prescribed for them: 'A life for a life, an eye for an eye, a nose for a nose, an ear for an ear, a tooth for a tooth, and for wounds retaliation'; but whosoever forgoes it as a freewill offering, that shall be for him an expiation. Whoso judges not according to what God has sent down -- they are the evildoers.\qt@no{45}}%
\qt@newcmd\qurantrans@en@dccxv{%
And We sent, following in their footsteps, Jesus son of Mary, confirming the Torah before him and We gave to him the Gospel, wherein is guidance and light, and confirming the Torah before it, as a guidance and an admonition unto the godfearing.\qt@no{46}}%
\qt@newcmd\qurantrans@en@dccxvi{%
So let the People of the Gospel judge according to what God has sent down therein. Whosoever judges not according to what God has sent down -- they are the ungodly.\qt@no{47}}%
\qt@newcmd\qurantrans@en@dccxvii{%
And We have sent down to thee the Book with the truth, confirming the Book that was before it, and assuring it. So judge between them according to what God has sent down, and do not follow their caprices, to forsake the truth that has come to thee. To every one of you We have appointed a right way and an open road. If God had willed, He would have made you one nation; but that He may try you in what has come to you. So be you forward in good works; unto God shall you return, all together; and He will tell you of that whereon you were at variance.\qt@no{48}}%
\qt@newcmd\qurantrans@en@dccxviii{%
And judge between them according to what God has sent down, and do not follow their caprices, and beware of them lest they tempt thee away from any of what God has sent down to thee. But if they turn their backs, know that God desires only to smite them for some sin they have committed; surely, many men are ungodly.\qt@no{49}}%
\qt@newcmd\qurantrans@en@dccxix{%
Is it the judgment of pagandom then that they are seeking? Yet who is fairer in judgment than God, for a people having sure faith?\qt@no{50}}%
\qt@newcmd\qurantrans@en@dccxx{%
O believers, take not Jews and Christians as friends; they are friends of each other. Whoso of you makes them his friends is one of them. God guides not the people of the evildoers.\qt@no{51}}%
\qt@newcmd\qurantrans@en@dccxxi{%
Yet thou seest those in whose hearts is sickness vying with one another to come to them, saying, 'We fear lest a turn of fortune should smite us.' But it may be that God will bring the victory, or some commandment from Him, and then they will find themselves, for that they kept secret within them, remorseful,\qt@no{52}}%
\qt@newcmd\qurantrans@en@dccxxii{%
and the believers will say, 'What, are these the ones who swore by God most earnest oaths that they were with you? Their works have failed now they are losers.'\qt@no{53}}%
\qt@newcmd\qurantrans@en@dccxxiii{%
O believers, whosoever of you turns from his religion, God will assuredly bring a people He loves, and who love Him, humble towards the believers, disdainful towards the unbelievers, men who struggle in the path of God, not fearing the reproach of any reproacher. That is God's bounty; He gives it unto whom He will; and God is All-embracing, All-knowing.\qt@no{54}}%
\qt@newcmd\qurantrans@en@dccxxiv{%
Your friend is only God, and His Messenger, and the believers who perform the prayer and pay the alms, and bow them down.\qt@no{55}}%
\qt@newcmd\qurantrans@en@dccxxv{%
Whoso makes God his friend, and His Messenger, and the believers -- the party of God, they are the victors.\qt@no{56}}%
\qt@newcmd\qurantrans@en@dccxxvi{%
O believers, take not as your friends those of them, who were given the Book before you, and the unbelievers, who take your religion in mockery and as a sport -- and fear God, if you are believers --\qt@no{57}}%
\qt@newcmd\qurantrans@en@dccxxvii{%
and when you call to prayer, take it in mockery and as a sport; that is because they are a people who have no understanding.\qt@no{58}}%
\qt@newcmd\qurantrans@en@dccxxviii{%
Say: 'People of the Book, do you blame us for any other cause than that we believe in God, and what has been sent down to us, and what was sent down before, and that most of you are ungodly?'\qt@no{59}}%
\qt@newcmd\qurantrans@en@dccxxix{%
Say: 'Shall I tell you of a recompense with God, worse than that? Whomsoever God has cursed, and with whom He is wroth, and made some of them apes and swine, and worshippers of idols -- they are worse situated, and have gone further astray from the right way.\qt@no{60}}%
\qt@newcmd\qurantrans@en@dccxxx{%
When they come to you, they say, 'We believe'; but they have entered in unbelief, and so they have departed in it; God knows very well what they were hiding.\qt@no{61}}%
\qt@newcmd\qurantrans@en@dccxxxi{%
Thou seest many of them vying in sin and enmity, and how they consume the unlawful; evil is the thing they have been doing.\qt@no{62}}%
\qt@newcmd\qurantrans@en@dccxxxii{%
Why do the masters and the rabbis not forbid them to utter sin, and consume the unlawful? Evil is the thing they have been working.\qt@no{63}}%
\qt@newcmd\qurantrans@en@dccxxxiii{%
The Jews have said, 'God's hand is fettered.' Fettered are their hands, and they are cursed for what they have said. Nay, but His hands are outspread; He expends how He will. And what has been sent down to thee from thy Lord will surely increase many of them in insolence and unbelief; and We have cast between them enmity and hatred, till the Day of Resurrection. As often as they light a fire for war, God will extinguish it. They hasten about the earth, to do corruption there; and God loves not the workers of corruption.\qt@no{64}}%
\qt@newcmd\qurantrans@en@dccxxxiv{%
But had the People of the Book believed and been godfearing, We would have acquitted them of their evil deeds, and admitted them to Gardens of Bliss.\qt@no{65}}%
\qt@newcmd\qurantrans@en@dccxxxv{%
Had they performed the Torah and the Gospel, and what was sent down to them from their Lord, they would have. eaten both what was above them, and what was beneath their feet. Some of them are a just nation; but many of them -- evil are the things they do.\qt@no{66}}%
\qt@newcmd\qurantrans@en@dccxxxvi{%
O Messenger, deliver that which has been sent down to thee from thy Lord; for if thou dost not, thou wilt not have delivered His Message. God will protect thee from men. God guides not the people of the unbelievers.\qt@no{67}}%
\qt@newcmd\qurantrans@en@dccxxxvii{%
Say: 'People of the Book, you do not stand on anything, until you perform the Torah and the Gospel, and what was sent down to you from your Lord.' And what has been sent down to thee from thy Lord will surely increase many of them in insolence and unbelief; so grieve not for the people of the unbelievers.\qt@no{68}}%
\qt@newcmd\qurantrans@en@dccxxxviii{%
Surely they that believe, and those of Jewry, and the Sabaeans, and those Christians, whosoever believes in God and the Last Day, and works righteousness -- no fear shall be on them, neither shall they sorrow.\qt@no{69}}%
\qt@newcmd\qurantrans@en@dccxxxix{%
And We took compact with the Children of Israel, and We sent Messengers to them. Whensoever there came to them a Messenger with that their souls had not desire for, some they cried lies to, and some they slew.\qt@no{70}}%
\qt@newcmd\qurantrans@en@dccxl{%
And they supposed there should be no trial; but blind they were, and deaf. Then God turned towards them; then again blind they were, many of them, and deaf; and God sees the things they do.\qt@no{71}}%
\qt@newcmd\qurantrans@en@dccxli{%
They are unbelievers who say, 'God is the Messiah, Mary's son.' For the Messiah said, 'Children of Israel, serve God, my Lord and your Lord. Verily whoso associates with God anything, God shall prohibit him entrance to Paradise, and his refuge shall be the Fire; and wrongdoers shall have no helpers.'\qt@no{72}}%
\qt@newcmd\qurantrans@en@dccxlii{%
They are unbelievers who say, 'God is the Third of Three. No god is there but One God. If they refrain not from what they say, there shall afflict those of them that disbelieve a painful chastisement.\qt@no{73}}%
\qt@newcmd\qurantrans@en@dccxliii{%
Will they not turn to God and pray His forgiveness? God is All-forgiving, All-compassionate.\qt@no{74}}%
\qt@newcmd\qurantrans@en@dccxliv{%
The Messiah, son of Mary, was only a Messenger; Messengers before him passed away; his mother was a just woman; they both ate food. Behold, how We make clear the signs to them; then behold, how they perverted are!\qt@no{75}}%
\qt@newcmd\qurantrans@en@dccxlv{%
Say: 'Do you serve, apart from God, that which cannot hurt or profit you? God is the All-hearing, the All-knowing.'\qt@no{76}}%
\qt@newcmd\qurantrans@en@dccxlvi{%
Say: 'People of the Book, go not beyond the bounds in your religion, other than the truth, and follow not the caprices of a people who went astray before, and led astray many, and now again have gone astray from the right way.'\qt@no{77}}%
\qt@newcmd\qurantrans@en@dccxlvii{%
Cursed were the unbelievers of the Children of Israel by the tongue of David, and Jesus, Mary's son; that, for their rebelling and their transgression.\qt@no{78}}%
\qt@newcmd\qurantrans@en@dccxlviii{%
They forbade not one another any dishonour that they committed; surely evil were the things they did.\qt@no{79}}%
\qt@newcmd\qurantrans@en@dccxlix{%
Thou seest many of them making unbelievers their friends. Evil is that they have forwarded to their account, that God is angered against them, and in the chastisement they shall dwell forever.\qt@no{80}}%
\qt@newcmd\qurantrans@en@dccl{%
Yet had they believed in God and the Prophet and what has been sent down to him, they would not have taken them as friends; but many of them are ungodly.\qt@no{81}}%
\qt@newcmd\qurantrans@en@dccli{%
Thou wilt surely find the most hostile of men to the believers are the Jews and the idolaters; and thou wilt surely find the nearest of them in love to the believers are those who say 'We are Christians'; that, because some of them are priests and monks, and they wax not proud;\qt@no{82}}%
\qt@newcmd\qurantrans@en@dcclii{%
and when they hear what has been sent down to the Messenger, thou seest their eyes overflow with tears because of the truth they recognize. They say, 'Our Lord, we believe; so do Thou write us down among the witnesses.\qt@no{83}}%
\qt@newcmd\qurantrans@en@dccliii{%
Why should we not believe in God and the truth that has come to us, and be eager that our Lord should admit us with the righteous people?'\qt@no{84}}%
\qt@newcmd\qurantrans@en@dccliv{%
And God rewards them for what they say with gardens underneath which rivers flow, therein dwelling forever; that is the recompense of the good-doers.\qt@no{85}}%
\qt@newcmd\qurantrans@en@dcclv{%
But those who disbelieve, and cry lies to Our signs -- they are the inhabitants of Hell.\qt@no{86}}%
\qt@newcmd\qurantrans@en@dcclvi{%
O believers, forbid not such good things as God has permitted you; and transgress not; God loves not transgressors.\qt@no{87}}%
\qt@newcmd\qurantrans@en@dcclvii{%
Eat of what God has provided you lawful and good; and fear God, in whom you are believers.\qt@no{88}}%
\qt@newcmd\qurantrans@en@dcclviii{%
God will not take you to task for a slip in your oaths; but He will take you to task for such bonds as you have made by oaths, whereof the expiation is to feed ten poor persons with the average of the food you serve to your families, or to clothe them, or to set free a slave; or if any finds not the means, let him fast for three days. That is the expiation of your oaths when you have sworn; but keep your oaths. So God makes clear to you His signs; haply you will be thankful.\qt@no{89}}%
\qt@newcmd\qurantrans@en@dcclix{%
O believers, wine and arrow-shuffling, idols and divining-arrows are an abomination, some of Satan's work; so avoid it; haply So you will prosper.\qt@no{90}}%
\qt@newcmd\qurantrans@en@dcclx{%
Satan only desires to precipitate enmity and hatred between you in regard to wine and arrow-shuffling, and to bar you from the remembrance of God, and from prayer. Will you then desist?\qt@no{91}}%
\qt@newcmd\qurantrans@en@dcclxi{%
And obey God and obey the Messenger, and beware; but if you turn your backs, then know that it is only for Our Messenger to deliver the Message Manifest.\qt@no{92}}%
\qt@newcmd\qurantrans@en@dcclxii{%
There is no fault in those who believe and do deeds of righteousness what they may eat, if they are godfearing, and believe, and do deeds of righteousness, and then are godfearing and believe, and then are godfearing and do good; God loves the good-doers.\qt@no{93}}%
\qt@newcmd\qurantrans@en@dcclxiii{%
O believers, God will surely try you with something of the game that your hands and lances attain, that God may know who fears Him in the Unseen. Whoso thereafter commits transgression, there awaits him a painful chastisement.\qt@no{94}}%
\qt@newcmd\qurantrans@en@dcclxiv{%
O believers, slay not the game while you are in pilgrim sanctity; whosoever of you slays it wilfully, there shall be recompense -- the like of what he has slain, in flocks as shall be judged by two men of equity among you, an offering to reach the Kaaba; or expiation -- food for poor persons or the equivalent of that in fasting, so that he may taste the mischief of his action. God has pardoned what is past; but whoever offends again, God will take vengeance on him, God is All-mighty, Vengeful.\qt@no{95}}%
\qt@newcmd\qurantrans@en@dcclxv{%
Permitted to you is the game of the sea and the food of it, as a provision for you and for the journeyers; but forbidden to you is the game of the land, so long as you remain in pilgrim sanctity; and fear God, unto whom you shall be mustered.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dcclxvi{%
God has appointed the Kaaba, the Holy House, as an establishment for men, and the holy month; the offering, and the necklaces -- that, that you may know that God knows all that is in the heavens and in the earth; and that God has knowledge of everything.\qt@no{97}}%
\qt@newcmd\qurantrans@en@dcclxvii{%
Know God is terrible in retribution, and God is All-forgiving, All-compassionate.\qt@no{98}}%
\qt@newcmd\qurantrans@en@dcclxviii{%
It is only for the Messenger to deliver the Message; and God knows what you reveal and what you hide.\qt@no{99}}%
\qt@newcmd\qurantrans@en@dcclxix{%
Say: 'The corrupt and the good are not equal, though the abundance of the corrupt please thee.' So fear God, O men possessed of minds; haply so you will prosper.\qt@no{100}}%
\qt@newcmd\qurantrans@en@dcclxx{%
O believers, question not concerning things which, if they were revealed to you, would vex you; yet if you question concerning them when the Koran is being sent down, they will be revealed to you. God has effaced those things; for God is All-forgiving, All-clement.\qt@no{101}}%
\qt@newcmd\qurantrans@en@dcclxxi{%
A people before you questioned concerning them, then disbelieved in them.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dcclxxii{%
God has not appointed cattle dedicated to idols, such as Bahira, Sa'iba, Wasila, Hami; but the unbelievers forge against God falsehood, and most of them have no understanding.\qt@no{103}}%
\qt@newcmd\qurantrans@en@dcclxxiii{%
And when it is said to them, 'Come now to what God has sent down, and the Messenger, they say, 'Enough for us is what we found our fathers doing.' What, even if their fathers had knowledge of naught and were not guided?\qt@no{104}}%
\qt@newcmd\qurantrans@en@dcclxxiv{%
O believers, look after your own souls. He who is astray cannot hurt you, if you are rightly guided. Unto God shall you return, all together, and He will tell you what you were doing.\qt@no{105}}%
\qt@newcmd\qurantrans@en@dcclxxv{%
O believers, the testimony between you when any of you is visited by death, at the bequeathing, shall be two men of equity among you; or two others from another folk, if you are journeying in the land and the affliction of death befalls you. Them you shall detain after the prayer, and they shall swear by God, if you are doubtful, 'We will not sell it for a price, even though it were a near kinsman, nor will we hide the testimony of God, for then we would surely be among the sinful'\qt@no{106}}%
\qt@newcmd\qurantrans@en@dcclxxvi{%
But if it be discovered that both of them have merited the accusation of any sin, then two others shall stand in their place, these being the nearest of those most concerned, and they shall swear by God, 'Our testimony is truer than their testimony, and we have not transgressed, for then we would assuredly be among the evildoers.'\qt@no{107}}%
\qt@newcmd\qurantrans@en@dcclxxvii{%
So it is likelier that they will bear testimony in proper form, or else they will be afraid that after their oaths, oaths may be rebutted. Fear God, and hearken; God guides not the people of the ungodly.\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcclxxviii{%
The day when God shall gather the Messengers, and say, 'What answer were you given?' They shall say, 'We have no knowledge; Thou art the Knower of the things unseen.\qt@no{109}}%
\qt@newcmd\qurantrans@en@dcclxxix{%
When God said, 'Jesus Son of Mary, remember My blessing upon thee and upon thy mother, when I confirmed thee with the Holy Spirit, to speak to men in the cradle, and of age; and when I taught thee the Book, the Wisdom, the Torah, the Gospel; and when thou createst out of clay, by My leave, as the likeness of a bird, and thou breathest into it, and it is a bird, by My leave; and thou healest the blind and the leper by My leave, and thou bringest the dead forth by My leave; and when restrained from thee the Children of Israel when thou camest unto them with the clear signs, and the unbelievers among them said, ``This is nothing but sorcery manifest."\qt@no{110}}%
\qt@newcmd\qurantrans@en@dcclxxx{%
And when I inspired the Apostles: ``Believe in Me and My Messenger"; they said, ``We believe; witness Thou our submission."'\qt@no{111}}%
\qt@newcmd\qurantrans@en@dcclxxxi{%
And when the Apostles said, 'O Jesus son of Mary, is thy Lord able to send down on us a Table out of heaven?' He said, 'Fear you God, if you are believers.\qt@no{112}}%
\qt@newcmd\qurantrans@en@dcclxxxii{%
They said, 'We desire that we should eat of it and our hearts be at rest; and that we may know that thou hast spoken true to us, and that we may be among its witnesses.'\qt@no{113}}%
\qt@newcmd\qurantrans@en@dcclxxxiii{%
Said Jesus son of Mary, 'O God, our Lord, send down upon us a Table out of heaven, that shall be for us a festival, the first and last of us, and a sign from Thee. And provide for us; Thou art the best of providers.'\qt@no{114}}%
\qt@newcmd\qurantrans@en@dcclxxxiv{%
God said, 'Verily I do send it down on you; whoso of you hereafter disbelieves, verily I shall chastise him with a chastisement wherewith I chastise no other being.'\qt@no{115}}%
\qt@newcmd\qurantrans@en@dcclxxxv{%
And when God said, 'O Jesus son of Mary, didst thou say unto men, ``Take me and my mother as gods, apart from God"?' He said, 'To Thee be glory! It is not mine to say what I have no right to. If I indeed said it, Thou knowest it, knowing what is within my soul, and I know not what is within Thy soul; Thou knowest the things unseen\qt@no{116}}%
\qt@newcmd\qurantrans@en@dcclxxxvi{%
I only said to them what Thou didst command me: ``Serve God, my Lord and your Lord." And I was a witness over them, while I remained among them; but when Thou didst take me to Thyself, Thou wast Thyself the watcher over them; Thou Thyself art witness of everything.\qt@no{117}}%
\qt@newcmd\qurantrans@en@dcclxxxvii{%
If Thou chastisest them, they are Thy servants; if Thou forgivest them, Thou art the All-mighty, the All-wise.'\qt@no{118}}%
\qt@newcmd\qurantrans@en@dcclxxxviii{%
God said, 'This is the day the truthful shall be profited by their truthfulness. For them await gardens underneath which rivers flow, therein dwelling forever and ever; God being well-pleased with them and they well-pleased with Him; that is the mighty triumph.'\qt@no{119}}%
\qt@newcmd\qurantrans@en@dcclxxxix{%
To God belongs the kingdom of the heavens and of the earth, and all that is in them, and He is powerful over everything.\qt@no{120}}%
\qt@newcmd\qurantrans@en@dccxc{%
\basmalahen Praise belongs to God who created the heavens and the earth and appointed the shadows and light; then the unbelievers ascribe equals to their Lord.\qt@no{1}}%
\qt@newcmd\qurantrans@en@dccxci{%
It is He who created you of clay, then determined a term and a term is stated with Him; yet thereafter you doubt.\qt@no{2}}%
\qt@newcmd\qurantrans@en@dccxcii{%
He is God in the heavens and the earth; He knows your secrets, and what you publish, and He knows what you are earning.\qt@no{3}}%
\qt@newcmd\qurantrans@en@dccxciii{%
Not a sign of their Lord comes to them, but they turn away from it.\qt@no{4}}%
\qt@newcmd\qurantrans@en@dccxciv{%
They cried lies to the truth when it came to them, but there shall come to them news of that they were mocking.\qt@no{5}}%
\qt@newcmd\qurantrans@en@dccxcv{%
Have they not regarded how We destroyed before them many a generation We established in the earth, as We never established you, and how We loosed heaven upon them in torrents, and made the rivers to flow beneath them? Then We destroyed them because of their sins, and raised up after them another generation;\qt@no{6}}%
\qt@newcmd\qurantrans@en@dccxcvi{%
Had We sent down on thee a Book on parchment and so they touched it with their hands, yet the unbelievers would have said, 'This is naught but manifest sorcery.'\qt@no{7}}%
\qt@newcmd\qurantrans@en@dccxcvii{%
'Why has an angel not been sent down on him?' they say; yet had We sent down an angel, the matter would have been determined, and then no respite would be given them.\qt@no{8}}%
\qt@newcmd\qurantrans@en@dccxcviii{%
And had We made him an angel, yet assuredly We would have made him a man, and confused for them the thing which they themselves are confusing.\qt@no{9}}%
\qt@newcmd\qurantrans@en@dccxcix{%
Messengers indeed were mocked at before thee; but those that scoffed at them were encompassed by that they mocked at.\qt@no{10}}%
\qt@newcmd\qurantrans@en@dccc{%
Say: 'Journey in the land, then behold how was the end of them that cried lies.'\qt@no{11}}%
\qt@newcmd\qurantrans@en@dccci{%
Say: 'To whom belongs what is in the heavens and in the earth?' Say: 'It is God's. He has prescribed for Himself mercy. He will surely gather you to the Resurrection Day, of which is no doubt. Those who have lost their souls, they do not believe.\qt@no{12}}%
\qt@newcmd\qurantrans@en@dcccii{%
And to Him belongs whatsoever inhabits the night and the day; and He is the All-hearing, the All-knowing.'\qt@no{13}}%
\qt@newcmd\qurantrans@en@dccciii{%
Say: 'Shall I take to myself as protector other than God, the Originator of the heavens and of the earth, He. who feeds and is not fed?' Say: 'I have been commanded to be the first of them that surrender: ``Be not thou of the idolaters."'\qt@no{14}}%
\qt@newcmd\qurantrans@en@dccciv{%
Say: 'Indeed I fear, if I should rebel against thy Lord, the chastisement of a dreadful day.'\qt@no{15}}%
\qt@newcmd\qurantrans@en@dcccv{%
From whomsoever it is averted on that day, He will have mercy on him; that is the manifest triumph.\qt@no{16}}%
\qt@newcmd\qurantrans@en@dcccvi{%
And if God visits thee with affliction none can remove it but He; and if He visits thee with good, He is powerful over everything.\qt@no{17}}%
\qt@newcmd\qurantrans@en@dcccvii{%
He is Omnipotent over His servants, and He is the All-wise, the All-aware. Say: 'What thing is greatest in testimony?'\qt@no{18}}%
\qt@newcmd\qurantrans@en@dcccviii{%
Say: 'God is witness between me and you, and this Koran has been revealed to me that I may warn you thereby, and whomsoever it may reach. Do you indeed testify that there are other gods with God?' Say: 'I do not testify.' Say: 'He is only One God, and I am quit of that you associate.'\qt@no{19}}%
\qt@newcmd\qurantrans@en@dcccix{%
Those to whom We have given the Book recognize it as they recognize their sons. Those who have lost their own souls, they do not believe.\qt@no{20}}%
\qt@newcmd\qurantrans@en@dcccx{%
And who does greater evil than he who forges against God a lie, or cries lies to His signs? They shall not prosper, the evildoers.\qt@no{21}}%
\qt@newcmd\qurantrans@en@dcccxi{%
And on the day when We shall muster them all together, then We shall say unto those who associated other gods with God, 'Where are your associates whom you were asserting?\qt@no{22}}%
\qt@newcmd\qurantrans@en@dcccxii{%
Then they shall have no proving, but to say, 'By God our Lord, we never associated other gods with Thee.'\qt@no{23}}%
\qt@newcmd\qurantrans@en@dcccxiii{%
Behold how they lie against themselves, and how that which they were forging has gone astray from them!\qt@no{24}}%
\qt@newcmd\qurantrans@en@dcccxiv{%
And some of them there are that listen to thee, and We lay veils upon their hearts lest they understand it, and in their ears heaviness; and if they see any sign whatever, they do not believe in it, so that when they come to thee they dispute with thee, the unbelievers saying, 'This is naught but the fairy-tales of the ancient ones.'\qt@no{25}}%
\qt@newcmd\qurantrans@en@dcccxv{%
And they forbid it, and keep afar from it, and it is only themselves they destroy, but they are not aware.\qt@no{26}}%
\qt@newcmd\qurantrans@en@dcccxvi{%
If thou couldst see when they are stationed before the Fire, and they say, 'Would that we might be returned, and then not cry lies to the signs of our Lord, but that we might be among the believers!'\qt@no{27}}%
\qt@newcmd\qurantrans@en@dcccxvii{%
No; that which they were concealing before has now appeared to them; and even if they were returned, they would again commit the very thing they were prohibited; they are truly liars.\qt@no{28}}%
\qt@newcmd\qurantrans@en@dcccxviii{%
And they say, 'There is only our present life; we shall not be raised.'\qt@no{29}}%
\qt@newcmd\qurantrans@en@dcccxix{%
If thou couldst see when they are stationed before their Lord! He will say, 'Is not this the truth?' They will say, 'Yes indeed, by our Lord!' He will say, 'Then taste the chastisement for your unbelief.\qt@no{30}}%
\qt@newcmd\qurantrans@en@dcccxx{%
Lost indeed are they that cried lies to the encounter with God, so that when the Hour comes to them suddenly they shall say, 'Alas for us, that we neglected it!' On their backs they shall be bearing their loads; O how evil the loads they bear!\qt@no{31}}%
\qt@newcmd\qurantrans@en@dcccxxi{%
The present life is naught but a sport and a diversion; surely the Last Abode is better for those that are godfearing. What, do you not understand?\qt@no{32}}%
\qt@newcmd\qurantrans@en@dcccxxii{%
We know indeed that it grieves thee the things they say; yet it is not thee they cry lies to, but the evildoers - it is the signs of God that they deny.\qt@no{33}}%
\qt@newcmd\qurantrans@en@dcccxxiii{%
Messengers indeed were cried lies to before thee, yet they endured patiently that they were cried lies to, and were hurt, until Our help came unto them. No man can change the words of God; and there has already come to thee some tiding of the Envoys.\qt@no{34}}%
\qt@newcmd\qurantrans@en@dcccxxiv{%
And if their turning away is distressful for thee, why, if thou canst seek out a hole in the earth, or a ladder in heaven, to bring them some sign but had God willed, He would have gathered them to the guidance; so be not thou one of the ignorant.\qt@no{35}}%
\qt@newcmd\qurantrans@en@dcccxxv{%
Answer only will those who hear; as for the dead, God will raise them up, then unto Him they will be returned.\qt@no{36}}%
\qt@newcmd\qurantrans@en@dcccxxvi{%
They also say, 'Why has no sign been sent down upon him from his Lord?' Say: 'Surely God is able to send down a sign, but most of them know not.'\qt@no{37}}%
\qt@newcmd\qurantrans@en@dcccxxvii{%
No creature is there crawling on the earth, no bird flying with its wings, but they are nations like unto yourselves. We have neglected nothing in the Book; then to their Lord they shall be mustered.\qt@no{38}}%
\qt@newcmd\qurantrans@en@dcccxxviii{%
And those who cry lies to Our signs are deaf and dumb, dwelling in the shadows. Whomsoever God will, He leads astray, and whomsoever He will, He sets him on a straight path.\qt@no{39}}%
\qt@newcmd\qurantrans@en@dcccxxix{%
Say: 'What think you? If God's chastisement comes upon you, or the Hour comes upon you, will you call upon any other than God if you speak truly?'\qt@no{40}}%
\qt@newcmd\qurantrans@en@dcccxxx{%
No; upon Him you will call, and He will remove that for which you call upon Him if He Will, and you will forget that you associate with Him.\qt@no{41}}%
\qt@newcmd\qurantrans@en@dcccxxxi{%
Indeed We sent to nations before thee, and We seized them with misery and hardship that haply they might be humble;\qt@no{42}}%
\qt@newcmd\qurantrans@en@dcccxxxii{%
if only, when Our might came upon them, they had been humble! But their hearts were hard, and Satan decked out fair to them what they were doing.\qt@no{43}}%
\qt@newcmd\qurantrans@en@dcccxxxiii{%
So, when they forgot what they were reminded of; We opened unto them the gates of everything until; when they rejoiced in what they were given, We seized them suddenly, and behold, they were sore confounded.\qt@no{44}}%
\qt@newcmd\qurantrans@en@dcccxxxiv{%
So the last remnant of the people who did evil was cut off. Praise belongs to God the Lord of all Being.\qt@no{45}}%
\qt@newcmd\qurantrans@en@dcccxxxv{%
Say: 'What think you? If God seizes your hearing and sight, and sets a seal upon your hearts, who is a god other than God to give it back to you?' Behold how We turn about the signs! Yet thereafter they are turning away.\qt@no{46}}%
\qt@newcmd\qurantrans@en@dcccxxxvi{%
Say: 'What think you? If God's chastisement comes upon you, suddenly or openly, shall any be destroyed, except the people of the evildoers?'\qt@no{47}}%
\qt@newcmd\qurantrans@en@dcccxxxvii{%
We do not send the Envoys, except good tidings to bear, and warning; whoever believes and makes amends -- no fear shall be on them, neither shall they sorrow.\qt@no{48}}%
\qt@newcmd\qurantrans@en@dcccxxxviii{%
But those who cry lies to Our signs, them the chastisement shall visit, for that they were ungodly.\qt@no{49}}%
\qt@newcmd\qurantrans@en@dcccxxxix{%
Say: 'I do not say to you, ``I possess the treasuries of God"; I know not the Unseen. And I say not to you, ``I am an angel"; I only follow what is revealed to me. Say: 'Are the blind and the seeing man equal? Will you not reflect?'\qt@no{50}}%
\qt@newcmd\qurantrans@en@dcccxl{%
And warn therewith those who fear they shall be mustered to their Lord; they have, apart from God, no protector and no intercessor; haply they will be godfearing.\qt@no{51}}%
\qt@newcmd\qurantrans@en@dcccxli{%
And do not drive away those who call upon their Lord at morning and evening desiring His countenance; nothing of their account falls upon thee, and nothing of thy account falls upon them, that thou shouldst drive them away, and so become one of the evildoers.\qt@no{52}}%
\qt@newcmd\qurantrans@en@dcccxlii{%
Even so We have tried some of them by others that they may say, Are these the ones God has been gracious to among us?' Knows not God very well the thankful?\qt@no{53}}%
\qt@newcmd\qurantrans@en@dcccxliii{%
And when those who believe in Our signs come to thee, say, 'Peace be upon you. Your Lord has prescribed for Himself mercy. Whosoever of you does evil in ignorance, and thereafter repents and makes amends, He is All-forgiving, All-compassionate.'\qt@no{54}}%
\qt@newcmd\qurantrans@en@dcccxliv{%
Thus We distinguish Our signs, that the sinners' way may be manifest.\qt@no{55}}%
\qt@newcmd\qurantrans@en@dcccxlv{%
Say: 'I am forbidden to serve those you call on apart from God.' Say: 'I do not follow your caprices, or else I had gone astray, and would not be of the right-guided.'\qt@no{56}}%
\qt@newcmd\qurantrans@en@dcccxlvi{%
Say: 'I stand upon a clear sign from my Lord, and you have cried lies to it. Not with me is that you seek to hasten; the judgment is God's alone. He relates the truth, and He is the Best of deciders.'\qt@no{57}}%
\qt@newcmd\qurantrans@en@dcccxlvii{%
Say: 'If what you seek to hasten were with me, the matter between you and me would be decided; and God knows very well the evildoers.'\qt@no{58}}%
\qt@newcmd\qurantrans@en@dcccxlviii{%
With Him are the keys of the Unseen; none knows them but He. He knows what is in land and sea; not a leaf falls, but He knows it. Not a grain in the earth's shadows, not a thing, fresh or withered, but it is in a Book Manifest.\qt@no{59}}%
\qt@newcmd\qurantrans@en@dcccxlix{%
It is He who recalls you by night, and He knows what you work by day; then He raises you up therein, that a stated term may be determined; then unto Him shall you return, then He will tell you of what you have been doing.\qt@no{60}}%
\qt@newcmd\qurantrans@en@dcccl{%
He is the Omnipotent over His servants. He sends recorders over you till, when any one of you is visited by death, Our messengers take him and they neglect not.\qt@no{61}}%
\qt@newcmd\qurantrans@en@dcccli{%
Then they are restored to God their Protector, the True. Surely His is the judgment; He is the swiftest of reckoners.\qt@no{62}}%
\qt@newcmd\qurantrans@en@dccclii{%
Say: 'Who delivers you from the shadows of land and sea? You call upon Him humbly and secretly, ``Truly, if Thou deliverest from these, we shall be among the thankful."\qt@no{63}}%
\qt@newcmd\qurantrans@en@dcccliii{%
Say: 'God delivers you from them and from every distress; then you assign Him associates.'\qt@no{64}}%
\qt@newcmd\qurantrans@en@dcccliv{%
Say: 'He is able to send forth upon you chastisement, from above you or from under your feet, or to confuse you in sects and to make you taste the violence of one another.' Behold how We turn about the signs; haply they will understand.\qt@no{65}}%
\qt@newcmd\qurantrans@en@dccclv{%
Thy people have cried it lies; yet it is the truth. Say: 'I am not a guardian over you.\qt@no{66}}%
\qt@newcmd\qurantrans@en@dccclvi{%
Every tiding has its time appointed; you will surely know.'\qt@no{67}}%
\qt@newcmd\qurantrans@en@dccclvii{%
When thou seest those who plunge into Our signs, turn away from them until they plunge into some other talk; or if Satan should make thee forget, do not sit, after the reminding, with the people of the evildoers.\qt@no{68}}%
\qt@newcmd\qurantrans@en@dccclviii{%
Nothing of their account falls upon those that are godfearing; but a reminding; haply they will be godfearing.\qt@no{69}}%
\qt@newcmd\qurantrans@en@dccclix{%
Leave alone those who take their religion for a sport and a diversion, and whom the present life has deluded. Remind hereby, lest a soul should be given up to destruction for what it has earned; apart from God, it has no protector and no intercessor; though it offer any equivalent, it shall not be taken from it. Those are they who are given up to destruction for what they have earned; for them awaits a draught of boiling water and a painful chastisement, for that they were unbelievers.\qt@no{70}}%
\qt@newcmd\qurantrans@en@dccclx{%
Say: 'Shall we call, apart from God, on that which neither profits nor hurts us, and shall we be turned back on our heels after that God has guided us? -- Like one lured to bewilderment in the earth by Satans, though he has friends who call him to guidance, ``Come to us!" Say: 'God's guidance is the true guidance, and we are commanded to surrender to the Lord of all Being,\qt@no{71}}%
\qt@newcmd\qurantrans@en@dccclxi{%
and: ``Perform the prayer, and fear Him; it is unto Him you shall be mustered."\qt@no{72}}%
\qt@newcmd\qurantrans@en@dccclxii{%
It is He who created the heavens and the earth in truth; and the day He says 'Be', and it is; His saying is true, and His is the Kingdom the day the Trumpet is blown; He is Knower of the Unseen and the visible; He is the All-wise, the All-aware.\qt@no{73}}%
\qt@newcmd\qurantrans@en@dccclxiii{%
And when Abraham said to his father Azar, 'Takest thou idols for gods? I see thee, and thy people, in manifest error.'\qt@no{74}}%
\qt@newcmd\qurantrans@en@dccclxiv{%
So We were showing Abraham the kingdom of the heavens and earth, that he might be of those having sure faith.\qt@no{75}}%
\qt@newcmd\qurantrans@en@dccclxv{%
When night outspread over him he saw a star and said, 'This is my Lord.' But when it set he said, 'I love not the setters.'\qt@no{76}}%
\qt@newcmd\qurantrans@en@dccclxvi{%
When he saw the moon rising, he said, 'This is my Lord.' But when it set he said, 'If my Lord does not guide me I shall surely be of the people gone astray.'\qt@no{77}}%
\qt@newcmd\qurantrans@en@dccclxvii{%
When he saw the sun rising, he said, 'This is my Lord; this is greater!' But when it set he said, 'O my people, surely I am quit of that you associate.\qt@no{78}}%
\qt@newcmd\qurantrans@en@dccclxviii{%
I have turned my face to Him who originated the heavens and the earth, a man of pure faith; I am not of the idolaters.'\qt@no{79}}%
\qt@newcmd\qurantrans@en@dccclxix{%
His people disputed with him. He said, 'Do you dispute with me concerning God, and He has guided me? I fear not what you associate with Him, except my Lord will aught. My Lord embraces all things in His knowledge; will you not remember?\qt@no{80}}%
\qt@newcmd\qurantrans@en@dccclxx{%
How should I fear what you have associated, seeing you fear not that you have associated with God that whereon He has not sent down on you any authority?' Which of the two parties has better title to security, if you have any knowledge?\qt@no{81}}%
\qt@newcmd\qurantrans@en@dccclxxi{%
Those who believe, and have not confounded their belief with evildoing -- to them belongs the true security; they are rightly guided.\qt@no{82}}%
\qt@newcmd\qurantrans@en@dccclxxii{%
That is Our argument, which We bestowed upon Abraham as against his people. We raise up in degrees whom We will; surely thy Lord is All-wise, All-knowing.\qt@no{83}}%
\qt@newcmd\qurantrans@en@dccclxxiii{%
And We gave to him Isaac and Jacob -- each one We guided, And Noah We guided before; and of his seed David and Solomon, Job and Joseph, Moses and Aaron -- even so We recompense the good-doers --\qt@no{84}}%
\qt@newcmd\qurantrans@en@dccclxxiv{%
Zachariah and John, Jesus and Elias; each was of the righteous;\qt@no{85}}%
\qt@newcmd\qurantrans@en@dccclxxv{%
Ishmael and Elisha, Jonah and Lot-each one We preferred above all beings;\qt@no{86}}%
\qt@newcmd\qurantrans@en@dccclxxvi{%
and of their fathers, and of their seed, and of their brethren; and We elected them, and We guided them to a straight path.\qt@no{87}}%
\qt@newcmd\qurantrans@en@dccclxxvii{%
That is God's guidance; He guides by it whom He will of His servants; had they been idolaters, it would have failed them, the things they did.\qt@no{88}}%
\qt@newcmd\qurantrans@en@dccclxxviii{%
Those are they to whom We gave the Book, the Judgment, the Prophethood; so if these disbelieve in it, We have already entrusted it to a people who do not disbelieve in it.\qt@no{89}}%
\qt@newcmd\qurantrans@en@dccclxxix{%
Those are they whom God has guided; so follow their guidance. Say: 'I ask of you no wage for it; it is but a reminder unto all beings.'\qt@no{90}}%
\qt@newcmd\qurantrans@en@dccclxxx{%
They measured not God with His true measure when they said, 'God has not sent down aught on any mortal.' Say: 'Who sent down the Book that Moses brought as a light and a guidance to men? You put it into parchments, revealing them, and hiding much; and you were taught that you knew not, you and your fathers.' Say: 'God.' Then leave them alone, playing their game of plunging.\qt@no{91}}%
\qt@newcmd\qurantrans@en@dccclxxxi{%
This is a Book We have sent down, blessed and confirming that which was before it, and for thee to warn the Mother of Cities and those about her; and those who believe in the world to come believe in it, and watch over their prayers.\qt@no{92}}%
\qt@newcmd\qurantrans@en@dccclxxxii{%
And who does greater evil than he who forges against God a lie, or says,, 'To me it has been revealed', when naught has been revealed to him, or he who says, 'I will send down the like of what God has sent down'? If thou couldst only see when the evildoers are in the agonies of death, and the angels are stretching out their hands: 'Give up your souls! Today you shall be recompensed with the chastisement of humiliation for what you said untruly about God, waxing proud against His signs.'\qt@no{93}}%
\qt@newcmd\qurantrans@en@dccclxxxiii{%
'Now you have come to Us one by one, as We created you upon the first time, and you have left what We conferred on you behind your backs. We do not see with you your intercessors, those you asserted to be associates in you; the bond between you is now broken; that which you ever asserted has now gone astray from you.\qt@no{94}}%
\qt@newcmd\qurantrans@en@dccclxxxiv{%
It is God who splits the grain and the date-stone, brings forth the living from the dead; He brings forth the dead too from the living. So that then is God; then how are you perverted?\qt@no{95}}%
\qt@newcmd\qurantrans@en@dccclxxxv{%
He splits the sky into dawn, and has made the night for a repose, and the sun and moon for a reckoning. That is the ordaining of the All-mighty, the All-knowing.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dccclxxxvi{%
It is He who has appointed for you the stars, that by them you might be guided in the shadows of land and sea. We have distinguished the signs for a people who know.\qt@no{97}}%
\qt@newcmd\qurantrans@en@dccclxxxvii{%
It is He who produced you from one living soul, and then a lodging-place, and then a repository. We have distinguished the signs for a people who understand.\qt@no{98}}%
\qt@newcmd\qurantrans@en@dccclxxxviii{%
It is He who sent down out of heaven water, and thereby We have brought forth the shoot of every plant, and then We have brought forth the green leaf of it, bringing forth from it close-compounded grain, and out of the palm-tree, from the spathe of it, dates thick-lustered, ready to the hand, and gardens of vines, olives, pomegranates, like each to each, and each unlike to each. Look upon their fruits when they fructify and ripen! Surely, in all this are signs for a people who do believe.\qt@no{99}}%
\qt@newcmd\qurantrans@en@dccclxxxix{%
Yet they ascribe to God, as associates, the jinn, though He created them; and they impute to Him sons and daughters without any knowledge. Glory be to Him! High be He exalted above what they describe!\qt@no{100}}%
\qt@newcmd\qurantrans@en@dcccxc{%
The Creator of the heavens and the earth -- how should He have a son, seeing that He has no consort, and He created all things, and He has knowledge of everything?\qt@no{101}}%
\qt@newcmd\qurantrans@en@dcccxci{%
That then is God your Lord; there is no god but He, the Creator of everything. So serve Him, for He is Guardian over everything.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dcccxcii{%
The eyes attain Him not, but He attains the eyes; He is the All-subtle, the All-aware.\qt@no{103}}%
\qt@newcmd\qurantrans@en@dcccxciii{%
Clear proofs have come to you from your Lord. Whoso sees clearly, it is to his own gain, and whoso is blind, it is to his own loss; I am not a watcher over you.\qt@no{104}}%
\qt@newcmd\qurantrans@en@dcccxciv{%
So We turn about the signs, that they may say, 'Thou hast studied'; and that We may make it clear to a people having knowledge.\qt@no{105}}%
\qt@newcmd\qurantrans@en@dcccxcv{%
Follow thou what has been revealed to thee from thy Lord; there is no god but He; and turn thou away from the idolaters.\qt@no{106}}%
\qt@newcmd\qurantrans@en@dcccxcvi{%
Had God willed, they were not idolaters; and We have not appointed thee a watcher over them, neither art thou their guardian.\qt@no{107}}%
\qt@newcmd\qurantrans@en@dcccxcvii{%
Abuse not those to whom they pray, apart from God, or they will abuse God in revenge without knowledge. So We have decked out fair to every nation their deeds; then to their Lord they shall return, and He will tell them what they have been doing.\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcccxcviii{%
They have sworn by God the most earnest oaths if a sign comes to them they will believe in it. Say: 'Signs are only with God.' What will make you realize that, when it comes, they will not believe?\qt@no{109}}%
\qt@newcmd\qurantrans@en@dcccxcix{%
We shall turn about their hearts and their eyes, even as they believed not in it the first time; and We shall leave them in their insolence wandering blindly.\qt@no{110}}%
\qt@newcmd\qurantrans@en@cm{%
Though We had sent down the angels to them, and the dead had spoken with them, had We mustered against them every thing, face to face, yet they would not have been the ones to believe, unless God willed; but most of them are ignorant.\qt@no{111}}%
\qt@newcmd\qurantrans@en@cmi{%
So We have appointed to every Prophet an enemy -- Satans of men and jinn, revealing tawdry speech to each other, all as a delusion; yet, had thy Lord willed, they would never have done it. So leave them to their forging,\qt@no{112}}%
\qt@newcmd\qurantrans@en@cmii{%
and that the hearts of those who believe not in the world to come may incline to it, and that they may be well-pleased with it, and that they may gain what they are gaining.\qt@no{113}}%
\qt@newcmd\qurantrans@en@cmiii{%
What, shall I seek after any judge but God? For it is He who sent down to you the Book well-distinguished; and those whom We have given the Book know it is sent down from thy Lord with the truth; so be not thou of the doubters.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cmiv{%
Perfect are the words of thy Lord in truthfulness and justice; no man can change His words; He is the All-hearing, the All-knowing.\qt@no{115}}%
\qt@newcmd\qurantrans@en@cmv{%
If thou obeyest the most part of those on earth they will lead thee astray from the path of God; they follow only surmise, merely conjecturing.\qt@no{116}}%
\qt@newcmd\qurantrans@en@cmvi{%
Thy Lord knows very well who goes astray from His path; He knows very well the right-guided.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cmvii{%
Eat of that over which God's Name has been mentioned, if you believe in His signs.\qt@no{118}}%
\qt@newcmd\qurantrans@en@cmviii{%
How is it with you, that you do not eat of that over which God's Name has been mentioned, seeing that He has distinguished for you that He has forbidden you, unless you are constrained to it? But surely, many lead astray by their caprices, without any knowledge; thy Lord knows very well the transgressors.\qt@no{119}}%
\qt@newcmd\qurantrans@en@cmix{%
Forsake the outward sin, and the inward surely the earners of sin shall be recompensed for what they have earned.\qt@no{120}}%
\qt@newcmd\qurantrans@en@cmx{%
And eat not of that over which God's Name has not been mentioned; it is ungodliness. The Satans inspire their friends to dispute with you; if you obey them, you are idolaters.\qt@no{121}}%
\qt@newcmd\qurantrans@en@cmxi{%
Why, is he who was dead, and We gave him life, and appointed for him a light to walk by among the people as one whose likeness is in the shadows, and comes not forth from them? So it is decked out fair to the unbelievers the things they have done.\qt@no{122}}%
\qt@newcmd\qurantrans@en@cmxii{%
And even so We appointed in every city great ones among its sinners, to devise there; but they devised only against themselves, and they were not aware.\qt@no{123}}%
\qt@newcmd\qurantrans@en@cmxiii{%
And when a sign came to them, they said, 'We will not believe until we are given the like of what God's Messengers were given.' God knows very well where to place His Message; and humiliation in God's sight shall befall the sinners, and a terrible chastisement, for what they devised.\qt@no{124}}%
\qt@newcmd\qurantrans@en@cmxiv{%
Whomsoever God desires to guide, He expands his breast to Islam; whomsoever He desires to lead astray, He makes his breast narrow, tight, as if he were climbing to heaven. So God lays abomination upon those who believe not.\qt@no{125}}%
\qt@newcmd\qurantrans@en@cmxv{%
This is the path of thy Lord; straight; We have distinguished the signs to a people who remember.\qt@no{126}}%
\qt@newcmd\qurantrans@en@cmxvi{%
Theirs is the abode of peace with their Lord, and He is their Protector for that they were doing.\qt@no{127}}%
\qt@newcmd\qurantrans@en@cmxvii{%
On the day when He shall muster them all together: 'Company of jinn, you have made much of mankind.' Then their friends among mankind will say, 'Our Lord, we have profited each of the other, and we have reached the term determined by Thee for us. He will say: 'The Fire is your lodging, therein to dwell forever' - except as God will; surely thy Lord is All-wise, All-knowing.\qt@no{128}}%
\qt@newcmd\qurantrans@en@cmxviii{%
So We make the evildoers friends of each other for what they have earned.\qt@no{129}}%
\qt@newcmd\qurantrans@en@cmxix{%
'Company of jinn and mankind, did not Messengers come to you from among you, relating to you My signs and warning you of the encounter of this your day?' They shall say, 'We bear witness against ourselves.' They were deluded by the present life, and they bear witness against themselves that they were unbelievers.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cmxx{%
That is because thy Lord would never destroy the cities unjustly, while their inhabitants were heedless.\qt@no{131}}%
\qt@newcmd\qurantrans@en@cmxxi{%
All have degrees according to what they have done; thy Lord is not heedless of the things they do.\qt@no{132}}%
\qt@newcmd\qurantrans@en@cmxxii{%
Thy Lord is All-sufficient, Merciful. If He will, He can put you away, and leave after you, to succeed you, what He will, as He produced you from the seed of another people.\qt@no{133}}%
\qt@newcmd\qurantrans@en@cmxxiii{%
The thing you are promised, that will surely come; you cannot frustrate it.\qt@no{134}}%
\qt@newcmd\qurantrans@en@cmxxiv{%
Say: 'O my people, act according to your station; I am acting. And assuredly you will know who shall possess the Abode Ultimate. Surely the evildoers will not prosper.'\qt@no{135}}%
\qt@newcmd\qurantrans@en@cmxxv{%
They appoint to God, of the tillage and cattle that He multiplied, a portion, saying, 'This is for God' -- so they assert -- 'and this is for our associates.' So what is for their associates reaches not God; and what is for God reaches their associates. Evil is their judgment!\qt@no{136}}%
\qt@newcmd\qurantrans@en@cmxxvi{%
Thus those associates of theirs have decked out fair to many idolaters to slay their children, to destroy them, and to confuse their religion for them. Had God willed, they would not have done so; so leave them to their forging.\qt@no{137}}%
\qt@newcmd\qurantrans@en@cmxxvii{%
They say, 'These are cattle and tillage sacrosanct; none shall eat them, but whom we will'-- so they assert -- 'and cattle whose backs have been forbidden, and cattle over which they mention not the Name of God.' All that they say, forging against God; He will assuredly recompense them for what they were forging.\qt@no{138}}%
\qt@newcmd\qurantrans@en@cmxxviii{%
And they say, 'What is within the bellies of these cattle is reserved for our males and forbidden to our spouses; but if it be dead, then they all shall be partners in it.' He will assuredly recompense them for their describing; surely He is All-wise, All-knowing.\qt@no{139}}%
\qt@newcmd\qurantrans@en@cmxxix{%
Losers are they who slay their children in folly, without knowledge, and have forbidden what God has provided them, forging against God; they have gone astray, and are not right-guided.\qt@no{140}}%
\qt@newcmd\qurantrans@en@cmxxx{%
It is He who produces gardens trellised, and untrellised, palm-trees, and crops diverse in produce, olives, pomegranates, like each to each, and each unlike to each. Eat of their fruits when they fructify, and pay the due thereof on the day of its harvest; and be not prodigal; God loves not the prodigal.\qt@no{141}}%
\qt@newcmd\qurantrans@en@cmxxxi{%
And of the cattle, for burthen and for slaughter, eat of what God has provided you; and follow not the steps of Satan; he is a manifest foe to you.\qt@no{142}}%
\qt@newcmd\qurantrans@en@cmxxxii{%
Eight couples: two of sheep, of goats two. Say: 'Is it the two males He has forbidden or the two females? Or what the wombs of the two females contain? Tell me with knowledge, if you speak truly.'\qt@no{143}}%
\qt@newcmd\qurantrans@en@cmxxxiii{%
Of camels two, of oxen two. Say: 'Is it the two males He has forbidden or the two females? Or what the wombs of the two females contain? Or were you witnesses when God charged you with this? Then who does greater evil than he who forges against God a lie, in order that he may lead mankind astray without any knowledge? Surely God guides not the people of the evildoers.'\qt@no{144}}%
\qt@newcmd\qurantrans@en@cmxxxiv{%
Say: 'I do not find, in what is revealed to me, aught forbidden to him who eats thereof except it be carrion, or blood outpoured, or the flesh of swine -- that is an abomination -- or an ungodly thing that has been hallowed to other than God; yet whoso is constrained, not desiring nor transgressing, surely thy Lord is All-forgiving, All-compassionate.'\qt@no{145}}%
\qt@newcmd\qurantrans@en@cmxxxv{%
And to those of Jewry We have forbidden every beast with claws; and of oxen and sheep We have forbidden them the fat of them, save what their backs carry, or their entrails, or what is mingled with bone; that We recompensed them for their insolence; surely We speak truly.\qt@no{146}}%
\qt@newcmd\qurantrans@en@cmxxxvi{%
So, if they cry thee lies, say: 'Your Lord is of mercy all-embracing, and His might will never be turned back from the people of the sinners.'\qt@no{147}}%
\qt@newcmd\qurantrans@en@cmxxxvii{%
The idolaters will say, 'Had God willed, we would not have been idolaters, neither our fathers, nor would we have forbidden aught.' Even so the people before them cried lies until they tasted Our might. Say: 'Have you any knowledge, for you to bring forth for us? You follow only surmise, merely conjecturing.'\qt@no{148}}%
\qt@newcmd\qurantrans@en@cmxxxviii{%
Say: 'To God belongs the argument conclusive; for had He willed, He would have guided you all.'\qt@no{149}}%
\qt@newcmd\qurantrans@en@cmxxxix{%
Say: 'Produce your witnesses, those who testify God has forbidden this.' Then if they testify, bear not witness with them; and do not thou follow the caprices of those who cried lies to Our signs, and who believe not in the world to come, and ascribe equals to their Lord.\qt@no{150}}%
\qt@newcmd\qurantrans@en@cmxl{%
Say: 'Come, I will recite what your Lord has forbidden you: that you associate not anything with Him, and to be good to your parents, and not to slay your children because of poverty; We will provide you and them and that you approach not any indecency outward or inward, and that you slay not the soul God has forbidden, except by right. That then He has charged you with; haply you will understand.\qt@no{151}}%
\qt@newcmd\qurantrans@en@cmxli{%
And that you approach not the property of the orphan, save in the fairer manner, until he is of age. And fill up the measure and the balance with justice. We charge not any soul save to its capacity. And when you speak, be just, even if it should be to a near kinsman. And fulfil God's covenant. That then He has charged you with; haply you will remember.\qt@no{152}}%
\qt@newcmd\qurantrans@en@cmxlii{%
And that this is My path, straight; so do you follow it, and follow not divers paths lest they scatter you from His path. That then He has charged you with; haply you will be godfearing.'\qt@no{153}}%
\qt@newcmd\qurantrans@en@cmxliii{%
Then We gave Moses the Book, complete for him who does good, and distinguishing every thing, and as a guidance and a mercy; haply they would believe in the encounter with their Lord.\qt@no{154}}%
\qt@newcmd\qurantrans@en@cmxliv{%
This is a Book We have sent down, blessed; so follow it, and be godfearing; haply so you will find mercy;\qt@no{155}}%
\qt@newcmd\qurantrans@en@cmxlv{%
lest you should say, 'The Book was sent down only upon two parties before us, and we have indeed been heedless of their study';\qt@no{156}}%
\qt@newcmd\qurantrans@en@cmxlvi{%
or lest you say, 'If the Book had been sent down upon us, we had surely been more rightly guided than they.' Yet indeed a clear sign has come to you from your Lord, and a guidance and a mercy; and who does greater evil than he who cries lies to God's signs, and turns away from them? We shall surely recompense those who turn away from Our signs with an evil chastisement for their turning away.\qt@no{157}}%
\qt@newcmd\qurantrans@en@cmxlvii{%
What, do they look for the angels to come to them, nothing less, or that thy Lord should come, or that one of thy Lord's signs should come? On the day that one of thy Lord's signs comes it shall not profit a soul to believe that never believed before, or earned some good in his belief. Say: 'Watch and wait; We too are waiting.'\qt@no{158}}%
\qt@newcmd\qurantrans@en@cmxlviii{%
Those who have made divisions in their religion and become sects, thou art not of them in anything; their affair is unto God, then He will tell them what they have been doing.\qt@no{159}}%
\qt@newcmd\qurantrans@en@cmxlix{%
Whoso brings a good deed shall have ten the like of it; and whoso brings an evil deed shall only be recompensed the like of it; they shall not be wronged.\qt@no{160}}%
\qt@newcmd\qurantrans@en@cml{%
Say: 'As for me, my Lord has guided me to a straight path, a right religion, the creed of Abraham, a man of pure faith; he was no idolater.'\qt@no{161}}%
\qt@newcmd\qurantrans@en@cmli{%
Say: 'My prayer, my ritual sacrifice, my living, my dying -- all belongs to God, the Lord of all Being.\qt@no{162}}%
\qt@newcmd\qurantrans@en@cmlii{%
No associate has He. Even so I have been commanded, and I am the first of those that surrender.'\qt@no{163}}%
\qt@newcmd\qurantrans@en@cmliii{%
Say: 'Shall I seek after a Lord other than God, who is the Lord of all things?' Every soul earns only to its own account, no soul laden bears the load of another. Then to your Lord shall you return, and He will tell you of that whereon you were at variance.\qt@no{164}}%
\qt@newcmd\qurantrans@en@cmliv{%
It is He who has appointed you viceroys in the earth, and has raised some of you in rank above others, that He may try you in what He has given you. Surely thy Lord is swift in retribution; and surely He is All-forgiving, All-compassionate.\qt@no{165}}%
\qt@newcmd\qurantrans@en@cmlv{%
\basmalahen Alif Lam Mim Sad\qt@no{1}}%
\qt@newcmd\qurantrans@en@cmlvi{%
A Book sent down to thee -- so let there be no impediment in thy breast because of it -- to warn thereby, and as a reminder to believers:\qt@no{2}}%
\qt@newcmd\qurantrans@en@cmlvii{%
Follow what has been sent down to you from your Lord, and follow no friends other than He; little do you remember.\qt@no{3}}%
\qt@newcmd\qurantrans@en@cmlviii{%
How many a city We have destroyed! Our might came upon it at night, or while they took their ease in the noontide,\qt@no{4}}%
\qt@newcmd\qurantrans@en@cmlix{%
and they but cried, when Our might came upon there, 'We were evildoers.';\qt@no{5}}%
\qt@newcmd\qurantrans@en@cmlx{%
So We shall question those unto whom a Message was sent, and We shall question the Envoys,\qt@no{6}}%
\qt@newcmd\qurantrans@en@cmlxi{%
and We shall relate to them with knowledge; assuredly We were not absent.\qt@no{7}}%
\qt@newcmd\qurantrans@en@cmlxii{%
The weighing that day is true; he whose scales are heavy -- they are the prosperers,\qt@no{8}}%
\qt@newcmd\qurantrans@en@cmlxiii{%
and he whose scales are light -- they have lost their soul for wronging Our signs.\qt@no{9}}%
\qt@newcmd\qurantrans@en@cmlxiv{%
We have established you in the earth and there appointed for you livelihood; little thanks you show.\qt@no{10}}%
\qt@newcmd\qurantrans@en@cmlxv{%
We created you, then We shaped you, then We said to the angels: 'Bow yourselves to Adam'; so they bowed themselves, save Iblis -- he was not of those that bowed themselves.\qt@no{11}}%
\qt@newcmd\qurantrans@en@cmlxvi{%
Said He, 'What prevented thee to bow thyself, when I commanded thee?' Said he, 'I am better than he; Thou createdst me of fire, and him Thou createdst of clay.'\qt@no{12}}%
\qt@newcmd\qurantrans@en@cmlxvii{%
Said He, 'Get thee down out of it; it is not for thee to wax proud here, so go thou forth; surely thou art among the humbled.'\qt@no{13}}%
\qt@newcmd\qurantrans@en@cmlxviii{%
Said he, 'Respite me till the day they shall be raised.'\qt@no{14}}%
\qt@newcmd\qurantrans@en@cmlxix{%
Said He, 'Thou art among the ones that are respited.'\qt@no{15}}%
\qt@newcmd\qurantrans@en@cmlxx{%
Said he, 'Now, for Thy perverting me, I shall surely sit in ambush for them on Thy straight path;\qt@no{16}}%
\qt@newcmd\qurantrans@en@cmlxxi{%
then I shall come on them from before them and from behind them, from their right hands and their left hands; Thou wilt not find most of them thankful.'\qt@no{17}}%
\qt@newcmd\qurantrans@en@cmlxxii{%
Said He, 'Go thou forth from it, despised and banished. Those of them that follow thee -- I shall assuredly fill Gehenna with all of you.'\qt@no{18}}%
\qt@newcmd\qurantrans@en@cmlxxiii{%
'O Adam, inherit, thou and thy wife, the Garden, and eat of where you will, but come not nigh this tree, lest you be of the evildoers.'\qt@no{19}}%
\qt@newcmd\qurantrans@en@cmlxxiv{%
Then Satan whispered to them, to reveal to them that which was hidden from them of their shameful parts. He said, 'Your Lord has only prohibited you from this tree lest you become angels, or lest you become immortals.'\qt@no{20}}%
\qt@newcmd\qurantrans@en@cmlxxv{%
And he swore to them, 'Truly, I am for you a sincere adviser.'\qt@no{21}}%
\qt@newcmd\qurantrans@en@cmlxxvi{%
So he led them on by delusion; and when they tasted the tree, their shameful parts revealed to them, so they took to stitching upon themselves leaves of the Garden. And their Lord called to them, 'Did not I prohibit you from this tree, and say to you, ``Verily Satan is for you a manifest foe"?'\qt@no{22}}%
\qt@newcmd\qurantrans@en@cmlxxvii{%
They said, 'Lord, we have wronged ourselves, and if Thou dost not forgive us, and have mercy upon us, we shall surely be among the lost.'\qt@no{23}}%
\qt@newcmd\qurantrans@en@cmlxxviii{%
Said He, 'Get you down, each of you an enemy to each. In the earth a sojourn shall be yours, and enjoyment for a time.'\qt@no{24}}%
\qt@newcmd\qurantrans@en@cmlxxix{%
Said He, 'Therein you shall live, and therein you shall die, and from there you shall be brought forth.'\qt@no{25}}%
\qt@newcmd\qurantrans@en@cmlxxx{%
Children of Adam! We have sent down on you a garment to cover your shameful parts, and feathers; and the garment of godfearing -- that is better; that is one of God's signs; haply they will remember.\qt@no{26}}%
\qt@newcmd\qurantrans@en@cmlxxxi{%
Children of Adam! Let not Satan tempt you as he brought your parents out of the Garden, stripping them of their garments to show them their shameful parts. Surely he sees you, he and his tribe, from where you see them not. We have made the Satans the friends of those who do not believe.\qt@no{27}}%
\qt@newcmd\qurantrans@en@cmlxxxii{%
And whenever they commit an indecency they say, 'We found our fathers practising it, and God has commanded us to do it.' Say: 'God does not command indecency; what, do you say concerning God such things as you know not?'\qt@no{28}}%
\qt@newcmd\qurantrans@en@cmlxxxiii{%
Say: 'My Lord has commanded justice. Set your faces in every place of worship and call on Him, making your religion sincerely His. As He originated you so you will return;\qt@no{29}}%
\qt@newcmd\qurantrans@en@cmlxxxiv{%
a part He guided, and a part justly disposed to error -- they have taken Satans for friends instead of God, and think them guided.'\qt@no{30}}%
\qt@newcmd\qurantrans@en@cmlxxxv{%
Children of Adam! Take your adornment at every place of worship; and eat and drink, but be you not prodigal; He loves not the prodigal.\qt@no{31}}%
\qt@newcmd\qurantrans@en@cmlxxxvi{%
Say: 'Who has forbidden the ornament of God which He brought forth for His servants, and the good things of His providing?' Say: 'These, on the Day of Resurrection, shall be exclusively for those who believed in this present life. So We distinguish the signs for a people who know.'\qt@no{32}}%
\qt@newcmd\qurantrans@en@cmlxxxvii{%
Say: 'My Lord has only forbidden indecencies, the inward and the outward, and sin, and unjust insolence, and that you associate with God that for which He sent down never authority, and that you say concerning God such as you know not.\qt@no{33}}%
\qt@newcmd\qurantrans@en@cmlxxxviii{%
To every nation a term; when their term comes they shall not put it back by a single hour nor put it forward.\qt@no{34}}%
\qt@newcmd\qurantrans@en@cmlxxxix{%
Children of Adam! If there should come to you Messengers from among you, relating to you My signs, then whosoever is godfearing and makes amends -- no fear shall be on them, neither shall they sorrow.\qt@no{35}}%
\qt@newcmd\qurantrans@en@cmxc{%
And those that cry lies to Our signs, and wax proud against them -- those shall be the inhabitants of the Fire, therein dwelling forever.\qt@no{36}}%
\qt@newcmd\qurantrans@en@cmxci{%
And who does greater evil than he who forges against God a lie, or cries lies to His signs? Those - their portion of the Book shall reach them; till, when Our messengers come to them, to take them away, they say, 'Where is that you were calling on, beside God?' They will say, 'They have gone astray from us, and they will bear witness against themselves that they were unbelievers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@cmxcii{%
He will say, 'Enter among nations that passed away before you, jinn and mankind, into the Fire.' Whenever any nation enters, it curses its sister-nation; till, when they have all successively come there, the last of them shall say to the first of them, 'O our Lord, these led us astray; so give them a double chastisement of the Fire.' He will say, 'Unto each a double, but you know not.\qt@no{38}}%
\qt@newcmd\qurantrans@en@cmxciii{%
The first of them shall say to the last of them, 'You have no superiority over us, then; so taste the chastisement for what you have been earning.'\qt@no{39}}%
\qt@newcmd\qurantrans@en@cmxciv{%
Those that cry lies to Our signs and wax proud against them the gates of heaven shall not be opened to them, nor shall they enter Paradise until the camel passes through the eye of the needle. Even so We recompense the sinners;\qt@no{40}}%
\qt@newcmd\qurantrans@en@cmxcv{%
Gehenna shall be their cradle, above them coverings. Even so We recompense the evildoers.\qt@no{41}}%
\qt@newcmd\qurantrans@en@cmxcvi{%
And those who believe, and do deeds of righteousness -- We charge not any soul, save according to its capacity; those are the inhabitants of Paradise, therein dwelling forever;\qt@no{42}}%
\qt@newcmd\qurantrans@en@cmxcvii{%
We shall strip away all rancour that is in their breasts; and underneath them rivers flowing; and they will say, 'Praise belongs to God, who guided us unto this; had God not guided us, we had surely never been guided. Indeed, our Lord's Messengers came with the truth.' And it will be proclaimed: 'This is your Paradise; you have been given it as your inheritance for what you did.'\qt@no{43}}%
\qt@newcmd\qurantrans@en@cmxcviii{%
The inhabitants of Paradise will call to the inhabitants of the Fire: 'We have found that. which our Lord promised us true; have you found what your Lord promised you true?' 'Yes,' they will say. And then a herald shall proclaim between them: 'God's curse is on the evildoers\qt@no{44}}%
\qt@newcmd\qurantrans@en@cmxcix{%
who bar from God's way, desiring to make it crooked, disbelieving in the world to come.\qt@no{45}}%
\qt@newcmd\qurantrans@en@m{%
And between them is a veil, and on the Ramparts are men knowing each by their mark, who shall call to the inhabitants of Paradise: 'Peace be upon you! They have not entered it, for all their eagerness.'\qt@no{46}}%
\qt@newcmd\qurantrans@en@mi{%
And when their eyes are turned towards the inhabitants of the Fire they shall say, 'Our Lord, do not Thou assign us with the people of the evildoers.'\qt@no{47}}%
\qt@newcmd\qurantrans@en@mii{%
And the dwellers on the Battlements shall call to certain men they know by their sign: 'Your amassing has not availed you, neither your waxing proud.\qt@no{48}}%
\qt@newcmd\qurantrans@en@miii{%
Are these the ones that you swore God would never reach with mercy?' 'Enter Paradise; no fear upon you, nor shall you sorrow.\qt@no{49}}%
\qt@newcmd\qurantrans@en@miv{%
The inhabitants of the Fire shall call to the inhabitants of Paradise: 'Pour on us water, or of that God has provided you!' They will say: 'God has forbidden them to the unbelievers\qt@no{50}}%
\qt@newcmd\qurantrans@en@mv{%
who have taken their religion as a diversion and a sport, and whom the present life has deluded.' -- Therefore today We forget them as they forgot the encounter of this their day, and that they denied Our signs.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mvi{%
And We have brought to them a Book that We have well distinguished, resting on knowledge, a guidance and a mercy unto a people that believe.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mvii{%
Do they look for aught else but its interpretation? The day its interpretation comes, those who before forgot it shall say, 'Indeed, our Lord's Messengers came with the truth. Have we then any intercessors to intercede for us, or shall we be returned, to do other than that we have done?' They have indeed lost their souls, and that which they were forging has gone astray from them.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mviii{%
Surely your Lord is God, who created the heavens and the earth in six days -- then sat Himself upon the Throne, covering the day with the night it pursues urgently -- and the sun, and the moon, and the stars subservient, by His command. Verily, His are the creation and the command. Blessed be God, the Lord of all Being.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mix{%
Call on your Lord, humbly and secretly; He loves not transgressors.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mx{%
Do not corruption in the land, after it has been set, right; and call on Him fearfully, eagerly -- surely the mercy of God is nigh to the good-doers;\qt@no{56}}%
\qt@newcmd\qurantrans@en@mxi{%
It is He who looses the winds, bearing good tidings before His mercy, till, when they are charged with heavy clouds, We drive it to a dead land and therewith send down water, and bring forth, therewith all the fruits. Even so We shall bring forth the dead; haply you will remember.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mxii{%
And the good land -- its vegetation comes forth by the leave of its Lord, and the corrupt -- it comes forth but scantily. Even so We turn about the signs for a people that are thankful.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mxiii{%
And We sent Noah to his people; and he said, 'O my people, serve God! You have no god other' than He; truly, I fear for you the chastisement of a dreadful day.'\qt@no{59}}%
\qt@newcmd\qurantrans@en@mxiv{%
Said the Council of his people, 'We see thee in manifest error.'\qt@no{60}}%
\qt@newcmd\qurantrans@en@mxv{%
Said he, 'My people, there is no error in me; but I am a Messenger from the Lord of all Being.'\qt@no{61}}%
\qt@newcmd\qurantrans@en@mxvi{%
I deliver to you the Messages of my Lord, and I advise you sincerely; for I know from God that you know not.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mxvii{%
What, do you wonder that a reminder from your Lord should come to you by the lips of a man from among you? That he may warn you, and you be godfearing, haply to find mercy.'\qt@no{63}}%
\qt@newcmd\qurantrans@en@mxviii{%
But they cried him lies; so We delivered him, and those with him, in the Ark, and We drowned those who cried lies to Our signs; assuredly they were a blind people.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mxix{%
And to Ad their brother Hood; he said, 'O my people, serve God! You have no god other than He; will you not be godfearing?'\qt@no{65}}%
\qt@newcmd\qurantrans@en@mxx{%
Said the Council of the unbelievers of his people, 'We see thee in folly, and we think that thou art one of the liars.'\qt@no{66}}%
\qt@newcmd\qurantrans@en@mxxi{%
Said he, 'My people, there is no folly in me; but I am a Messenger from the Lord of all Being.'\qt@no{67}}%
\qt@newcmd\qurantrans@en@mxxii{%
I deliver to you the Messages of my Lord; I am your adviser sincere, faithful.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mxxiii{%
What, do you wonder that a reminder from your Lord should come to you by the lips of a man from among you? That he may warn you; and remember when He appointed you as successors after the people of Noah, and increased you in stature broadly; remember God's bounties; haply you will prosper.'\qt@no{69}}%
\qt@newcmd\qurantrans@en@mxxiv{%
They said, 'Why, hast thou come to us that we may serve God alone, and forsake that our fathers served? Then bring us that thou promisest us, if thou speakest truly.'\qt@no{70}}%
\qt@newcmd\qurantrans@en@mxxv{%
Said he, 'Anger and wrath from your Lord have fallen upon you. What, do you dispute with me regarding names you have named, you and your fathers, touching which God has sent down never authority? Then watch and wait; I shall be with you watching and waiting.'\qt@no{71}}%
\qt@newcmd\qurantrans@en@mxxvi{%
So We delivered him, and those with him, by a mercy from Us; and We cut off the last remnant of those who cried lies to Our signs and were not believers.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mxxvii{%
And to Thamood their brother Salih; he said, 'O my people, serve God! You have no god other than He; there has now come to you a clear sign from your Lord -- this is the She-camel of God, to be a sign for you. Leave her that she may eat in God's earth, and do not touch her with evil, lest you be seized by a painful chastisement.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mxxviii{%
And remember when He appointed you successors after Ad, and lodged you in the land, taking to yourselves castles of its plains, and hewing its mountains into houses. Remember God's bounties, and do not mischief in the earth, working corruption.'\qt@no{74}}%
\qt@newcmd\qurantrans@en@mxxix{%
Said the Council of those of his people who waxed proud to those that were abased, to those of them who believed, 'Do you know that Salih is an Envoy from his Lord?' They said, 'In the Message he has been sent with we are believers.'\qt@no{75}}%
\qt@newcmd\qurantrans@en@mxxx{%
Said the ones who waxed proud, 'As for us, we are unbelievers in the thing in which you believe.'\qt@no{76}}%
\qt@newcmd\qurantrans@en@mxxxi{%
So they hamstrung the She-camel and turned in disdain from the commandment of their Lord, saying, 'O Salih, bring us that thou promisest us, if thou art an Envoy.'\qt@no{77}}%
\qt@newcmd\qurantrans@en@mxxxii{%
So the earthquake seized them, and morning found them in their habitation fallen prostrate.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mxxxiii{%
So he turned his back on them, and said, 'O my people, I have delivered to you the Message of my Lord, and advised you sincerely; but you do not love sincere advisers.'\qt@no{79}}%
\qt@newcmd\qurantrans@en@mxxxiv{%
And Lot, when he said to his people, 'What, do you commit such indecency as never any being in all the world committed before you?\qt@no{80}}%
\qt@newcmd\qurantrans@en@mxxxv{%
See, you approach men lustfully instead of women; no, you are a people that do exceed.'\qt@no{81}}%
\qt@newcmd\qurantrans@en@mxxxvi{%
And the only answer of his people was that they said, 'Expel them from your city; surely they are folk that keep themselves clean!'\qt@no{82}}%
\qt@newcmd\qurantrans@en@mxxxvii{%
So We delivered him and his family, except his wife; she was one of those that tarried.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mxxxviii{%
And We rained down upon them a rain; so behold thou, how was the end of the sinners!\qt@no{84}}%
\qt@newcmd\qurantrans@en@mxxxix{%
And to Midian their brother Shuaib; he said, 'O my people, serve God! You have no god other than He; there has now come to you a clear sign from your Lord. So fill up the measure and the balance, and diminish not the goods of the people; and do not corruption in the land, after it has been set right; that is better for you, if you are believers.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mxl{%
And do not sit in every path, threatening and barring from God's way those who believe in Him, desiring to make it crooked. And remember when you were few, and He multiplied you; and behold, how was the end of the workers of corruption.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mxli{%
And if there is a party of you who believe in the Message I have been sent with, and a party who believe not, be patient till God shall judge between us; He is the best of judges.'\qt@no{87}}%
\qt@newcmd\qurantrans@en@mxlii{%
Said the Council of those of his people who waxed proud, 'We will surely expel thee, O Shuaib, and those who believe with thee, from our city, unless you return into our creed.' He said, 'What, even though we detest it?\qt@no{88}}%
\qt@newcmd\qurantrans@en@mxliii{%
We should have forged against God a lie if we returned into your creed; after God delivered us from it. It is not for us to return into it, unless God our Lord so will. Our Lord embraces all things in His knowledge. In God we have put our trust. Our Lord, give true deliverance between us and our people; Thou art the best of deliverers.'\qt@no{89}}%
\qt@newcmd\qurantrans@en@mxliv{%
Said the Council of those of his people who disbelieved, 'Now, if you follow Shuaib, assuredly in that case you will be losers.'\qt@no{90}}%
\qt@newcmd\qurantrans@en@mxlv{%
So the earthquake seized them, and morning found them in their habitation fallen prostrate,\qt@no{91}}%
\qt@newcmd\qurantrans@en@mxlvi{%
those who cried lies to Shuaib, as if never they dwelt there; those who cried lies to Shuaib, they were the losers.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mxlvii{%
So he turned his back on them, and said, 'O my people, I have delivered to you the Messages of my Lord, and advised you sincerely; how should I grieve for a people of unbelievers?'\qt@no{93}}%
\qt@newcmd\qurantrans@en@mxlviii{%
We have sent no Prophet to any city but that We seized its people with misery and hardship, that haply they might be humble;\qt@no{94}}%
\qt@newcmd\qurantrans@en@mxlix{%
then We gave them in the place of evil good, till they multiplied, and said, 'Hardship and happiness visited our fathers.' So We seized them suddenly, unawares.\qt@no{95}}%
\qt@newcmd\qurantrans@en@ml{%
Yet had the peoples of the cities believed and been godfearing, We would have opened upon them blessings from heaven and earth; but they cried lies, and so We seized them for what they earned.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mli{%
Do the people of the cities feel secure Our might shall not come upon them at night while they are sleeping?\qt@no{97}}%
\qt@newcmd\qurantrans@en@mlii{%
Do the people of the cities feel secure Our might shall not come upon them in daylight while they are playing?\qt@no{98}}%
\qt@newcmd\qurantrans@en@mliii{%
Do they feel secure against God's devising? None feels secure against God's devising but the people of the lost.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mliv{%
Is it not a guidance to those who inherit the earth after those who inhabited it that, did We will, We would smite them because of their sins, sealing their hearts so they do not hear?\qt@no{100}}%
\qt@newcmd\qurantrans@en@mlv{%
Those cities We relate to thee tidings of; their Messengers came to them with the clear signs, but they were not the ones to believe in that they had cried lies before; so God seals the hearts of the unbelievers.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mlvi{%
We found no covenant in the most part of them; indeed, We found the most part of them ungodly.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mlvii{%
Then We sent, after them, Moses with Our signs to Pharaoh and his Council, but they did them wrong; so behold thou, how was the end of the workers of corruption!\qt@no{103}}%
\qt@newcmd\qurantrans@en@mlviii{%
Moses said, 'Pharaoh, I am a Messenger from the Lord of all Being,\qt@no{104}}%
\qt@newcmd\qurantrans@en@mlix{%
worthy to say nothing regarding God except the truth. I have brought a clear sign to you from your Lord; so send forth with me the Children of Israel.'\qt@no{105}}%
\qt@newcmd\qurantrans@en@mlx{%
Said he, 'If thou hast brought a sign, produce it, if thou speakest truly.'\qt@no{106}}%
\qt@newcmd\qurantrans@en@mlxi{%
So he cast his staff; and behold, it was a serpent manifest.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mlxii{%
And he drew forth his hand, and lo, it was white to the beholders.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mlxiii{%
Said the Council of the people of Pharaoh, 'Surely this man is a cunning sorcerer\qt@no{109}}%
\qt@newcmd\qurantrans@en@mlxiv{%
who desires to expel you from your land; what do you command?'\qt@no{110}}%
\qt@newcmd\qurantrans@en@mlxv{%
They said, 'Put him and his brother off a while, and send among the cities musterers,\qt@no{111}}%
\qt@newcmd\qurantrans@en@mlxvi{%
to bring thee every cunning sorcerer.'\qt@no{112}}%
\qt@newcmd\qurantrans@en@mlxvii{%
And the sorcerers came to Pharaoh, saying, 'We shall surely have a wage, if we should be the victors?'\qt@no{113}}%
\qt@newcmd\qurantrans@en@mlxviii{%
He said, 'Yes, indeed; and you shall be among the near-stationed.'\qt@no{114}}%
\qt@newcmd\qurantrans@en@mlxix{%
They said, 'Moses, wilt thou cast, or shall we be the casters?'\qt@no{115}}%
\qt@newcmd\qurantrans@en@mlxx{%
He said, 'You cast.' And when they cast they put a Spell upon the people's eyes, and called forth fear of them, and produced a mighty sorcery.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mlxxi{%
And We revealed to Moses: 'Cast thy staff!' And lo, it forthwith swallowed up their lying invention.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mlxxii{%
So the truth came to pass, and false was proved what they were doing.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mlxxiii{%
So they were vanquished there, and they turned about, humbled.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mlxxiv{%
And the sorcerers were cast down, bowing themselves.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mlxxv{%
They said, 'We believe in the Lord of all Being,\qt@no{121}}%
\qt@newcmd\qurantrans@en@mlxxvi{%
the Lord of Moses and Aaron.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mlxxvii{%
Said Pharaoh, 'You have believed in Him before I gave you leave. Surely this is a device you have devised in the city that you may expel its people from it. Now you shall know!\qt@no{123}}%
\qt@newcmd\qurantrans@en@mlxxviii{%
I shall assuredly cut off alternately your hands and feet, then I shall crucify you all together.'\qt@no{124}}%
\qt@newcmd\qurantrans@en@mlxxix{%
They said, 'Surely unto our Lord we are turning.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mlxxx{%
Thou takest vengeance upon us only because we have believed in the signs of our Lord when they came to us. Our Lord, pour out upon us patience, and gather us unto Thee surrendering.'\qt@no{126}}%
\qt@newcmd\qurantrans@en@mlxxxi{%
Then said the Council of the people of Pharaoh, 'Wilt thou leave Moses and his people to work corruption in the land, and leave thee and thy gods?' Said he, 'We shall slaughter their sons and spare their women; surely we are triumphant over them!'\qt@no{127}}%
\qt@newcmd\qurantrans@en@mlxxxii{%
Said Moses to his people, 'Pray for succour to God, and be patient; surely the earth is God's and He bequeaths it to whom He will among His servants. The issue ultimate is to the godfearing.'\qt@no{128}}%
\qt@newcmd\qurantrans@en@mlxxxiii{%
They said, 'We have been hurt before thou camest to us, and after thou camest to us.' He said, 'Perchance your Lord will destroy your enemy, and will make you successors in the land, so that He may behold how you shall do.'\qt@no{129}}%
\qt@newcmd\qurantrans@en@mlxxxiv{%
Then seized We Pharaoh's people with years of dearth, and scarcity of fruits, that haply they might remember.\qt@no{130}}%
\qt@newcmd\qurantrans@en@mlxxxv{%
So, when good came to them, they said, 'This belongs to us'; but if any evil smote them, they would augur ill by Moses and those with him. Why, surely their ill augury was with God; but the most of them knew not.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mlxxxvi{%
And they said, 'Whatsoever sign thou bringest to us, to cast a spell upon us, we will not believe thee.'\qt@no{132}}%
\qt@newcmd\qurantrans@en@mlxxxvii{%
So We let loose upon them the flood and the locusts, the lice and the frogs, the blood, distinct signs; but they waxed proud and were a sinful people.\qt@no{133}}%
\qt@newcmd\qurantrans@en@mlxxxviii{%
And when the wrath fell upon them, they said, 'Moses, pray to thy Lord for us by the covenant He has made with thee. If thou removest from us the wrath, surely we will believe thee, and send forth with thee the Children of Israel.'\qt@no{134}}%
\qt@newcmd\qurantrans@en@mlxxxix{%
But when We removed from them the wrath unto a term that they should come to, lo, they broke their troth.\qt@no{135}}%
\qt@newcmd\qurantrans@en@mxc{%
So We took vengeance on them, and drowned them in the sea, for that they cried lies to Our signs and heeded them not.\qt@no{136}}%
\qt@newcmd\qurantrans@en@mxci{%
And We bequeathed upon the people that were abased all the east and the west of the land We had blessed; and perfectly was fulfilled the most fair word of thy Lord upon the Children of Israel, for that they endured patiently; and We destroyed utterly the works of Pharaoh and his people, and what they had been building.\qt@no{137}}%
\qt@newcmd\qurantrans@en@mxcii{%
And We brought the Children of Israel over the sea, and they came upon a people cleaving to idols they had. They said, 'Moses, make for us a god, as they have gods.' Said he, 'You are surely a people who are ignorant.\qt@no{138}}%
\qt@newcmd\qurantrans@en@mxciii{%
Surely this they are engaged upon shall be shattered, and void is what they have been doing.'\qt@no{139}}%
\qt@newcmd\qurantrans@en@mxciv{%
He said, 'What, shall I seek a god for you other than God, who has preferred you above all beings?'\qt@no{140}}%
\qt@newcmd\qurantrans@en@mxcv{%
And when We delivered you from the folk of Pharaoh who were visiting you with evil chastisement, slaying your sons, and sparing your women -- and in that was a grievous trial from your Lord.\qt@no{141}}%
\qt@newcmd\qurantrans@en@mxcvi{%
And We appointed with Moses thirty nights and We completed them with ten, so the appointed time of his Lord was forty nights; and Moses said to his brother Aaron, 'Be my successor among my people, and put things right, and do not follow the way of the workers of corruption.'\qt@no{142}}%
\qt@newcmd\qurantrans@en@mxcvii{%
And when Moses came to Our appointed time and his Lord spoke with him, he said, 'Oh my Lord, show me, that I may behold Thee!' Said He, 'Thou shalt not see Me; but behold the mountain -- if it stays fast in its place, then thou shalt see Me.' And when his Lord revealed Him to the mountain He made it crumble to dust; and Moses fell down swooning. So when he awoke, he said, 'Glory be to Thee! I repent to Thee; I am the first of the believers.'\qt@no{143}}%
\qt@newcmd\qurantrans@en@mxcviii{%
Said He, 'Moses, I have chosen thee above all men for My Messages and My Utterance; take what I have given thee, and be of the thankful.'\qt@no{144}}%
\qt@newcmd\qurantrans@en@mxcix{%
And We wrote for him on the Tablets of everything an admonition, and a distinguishing of everything: 'So take it forcefully, and command thy people to take the fairest of it. I shall show you the habitation of the ungodly.\qt@no{145}}%
\qt@newcmd\qurantrans@en@mc{%
I shall turn from My signs those who wax proud in the earth unjustly; though they see every sign, they will not believe in it, and though they see the way of rectitude they will not take it for a way, and though they see the way of error, they will take it for a way. That, because they have cried lies to Our signs and heeded them not.'\qt@no{146}}%
\qt@newcmd\qurantrans@en@mci{%
Those who cry lies to Our signs, and the encounter in the world to come -- their works have failed; shall they be recompensed, except according to the things they have done?\qt@no{147}}%
\qt@newcmd\qurantrans@en@mcii{%
And the people of Moses took to them, after him, of their ornaments a Calf -- a mere body that lowed. Did they not see it spoke not to them, neither guided them upon any way? Yet they took it to them, and were evildoers.\qt@no{148}}%
\qt@newcmd\qurantrans@en@mciii{%
And when they smote their hands, and saw that they had gone astray, they said, 'If our Lord has not mercy on us, and forgives us not, surely we shall be of the lost.'\qt@no{149}}%
\qt@newcmd\qurantrans@en@mciv{%
And when Moses returned to his people, angry and sorrowful, he said, 'Evilly have you done in my place, after me; what, have you outstripped your Lord's commandment?' And he cast down the Tablets, and laid hold of his brother's head, dragging him to him. He said, 'Son of my mother, surely the people have abased me, and well nigh slain me. Make not my enemies to gloat over me, and put me not among the people of the evildoers.\qt@no{150}}%
\qt@newcmd\qurantrans@en@mcv{%
He said, 'O my Lord, forgive me and my brother and enter us into Thy mercy; Thou art the most merciful of the merciful.'\qt@no{151}}%
\qt@newcmd\qurantrans@en@mcvi{%
'Surely those who took to themselves the Calf -- anger shall overtake them from their Lord, and abasement in this present life; so We recompense those who are forgers.\qt@no{152}}%
\qt@newcmd\qurantrans@en@mcvii{%
And those who do evil deeds, then repent thereafter and believe, surely thereafter thy Lord is All-forgiving, All-compassionate.'\qt@no{153}}%
\qt@newcmd\qurantrans@en@mcviii{%
And when Moses' anger abated in him, he took the Tablets and in the inscription of them was guidance, and mercy unto all those who hold their Lord in awe.\qt@no{154}}%
\qt@newcmd\qurantrans@en@mcix{%
And Moses chose of his people seventy men for Our appointed time; and when the earthquake seized them, he said, 'My Lord, hadst Thou willed Thou wouldst have destroyed them before, and me. Wilt Thou destroy us for what the foolish ones of us have done? It is only Thy trial, whereby Thou leadest astray whom Thou wilt, and guidest whom Thou wilt. Thou art our Protector; so forgive us, and have mercy on us, for Thou art the best of forgivers.\qt@no{155}}%
\qt@newcmd\qurantrans@en@mcx{%
And prescribe for us in this world good, and in the world to come; we have repented unto Thee.' Said He, 'My chastisement -- I smite with it whom I will; and My mercy embraces all things, and I shall prescribe it for those who are godfearing and pay the alms, and those who indeed believe in Our signs,\qt@no{156}}%
\qt@newcmd\qurantrans@en@mcxi{%
those who follow the Messenger, 'the Prophet of the common folk, whom they find written down with them in the Torah and the Gospel, bidding them to honour, and forbidding them dishonour, making lawful for them the good things and making unlawful for them the corrupt things, and relieving them of their loads, and the fetters that were upon them. Those who believe in him and succour him and help him, and follow the light that has been sent down with him -- they are the prosperers.'\qt@no{157}}%
\qt@newcmd\qurantrans@en@mcxii{%
Say: 'O mankind, I am the Messenger of God to you all, of Him to whom belongs the kingdom of the heavens and of the earth. There is no god but He. He gives life, and makes to die. Believe then in God, and in His Messenger, the Prophet of the common folk, who believes in God and His words, and follow him; haply so you will be guided.'\qt@no{158}}%
\qt@newcmd\qurantrans@en@mcxiii{%
Of the people of Moses there is a nation who guide by the truth, and by it act with justice.\qt@no{159}}%
\qt@newcmd\qurantrans@en@mcxiv{%
And We cut them up into twelve tribes, nations. And We revealed to Moses, when his people asked him for water: 'Strike with thy staff the rock'; and there gushed forth from it twelve fountains all the people knew now their drinking-place. And We outspread the cloud to overshadow them, and We sent down manna and quails upon them: 'Eat of the good things wherewith We have supplied you.' And they worked no wrong upon Us, but themselves they wronged.\qt@no{160}}%
\qt@newcmd\qurantrans@en@mcxv{%
And when it was said to them, 'Dwell in this township and eat of it wherever you will; and say, Unburdening; and enter in at the gate, prostrating; We will forgive you your transgressions, and increase the good-doers.'\qt@no{161}}%
\qt@newcmd\qurantrans@en@mcxvi{%
Then the evildoers of them substituted a saying other than that which had been said to them; so We sent down upon them wrath out of heaven for their evildoing.\qt@no{162}}%
\qt@newcmd\qurantrans@en@mcxvii{%
And question them concerning the township which was bordering the sea, when they transgressed the Sabbath, when their fish came to them on the day of their Sabbath, swimming shorewards, but on the day they kept not Sabbath, they came not unto them. Even so We were trying them for their ungodliness.\qt@no{163}}%
\qt@newcmd\qurantrans@en@mcxviii{%
And when a certain nation of them said, 'Why do you admonish a people God is about to destroy or to chastise with a terrible chastisement?' They said, 'As an excuse to your Lord; and haply they will be godfearing.'\qt@no{164}}%
\qt@newcmd\qurantrans@en@mcxix{%
So, when they forgot that they were reminded of; We delivered those who were forbidding wickedness, and We seized the evildoers with evil chastisement for their ungodliness.\qt@no{165}}%
\qt@newcmd\qurantrans@en@mcxx{%
And when they turned in disdain from that forbidding We said to them, 'Be you apes, miserably slinking!'\qt@no{166}}%
\qt@newcmd\qurantrans@en@mcxxi{%
And when Thy Lord proclaimed He would send forth against them, unto the Day of Resurrection, those who should visit them with evil chastisement. Surely thy Lord is swift in retribution; surely He is All-forgiving, All-compassionate.\qt@no{167}}%
\qt@newcmd\qurantrans@en@mcxxii{%
And We cut them up into nations in the earth, some of them righteous, and some of them otherwise; and We tried them with good things and evil, that haply they should return.\qt@no{168}}%
\qt@newcmd\qurantrans@en@mcxxiii{%
And there succeeded after them a succession who inherited the Book, taking the chance goods of this lower world, and saying, 'It will be forgiven us'; and if chance goods the like of them come to them, they will take them. Has not the compact of the Book been taken touching them, that they should say concerning God nothing but the truth? And they have studied what is in it; and the Last Abode is better for those who are godfearing. Do you not understand?\qt@no{169}}%
\qt@newcmd\qurantrans@en@mcxxiv{%
And those who hold fast to the Book, and perform the prayer -- surely We leave not to waste the wage of those who set aright.\qt@no{170}}%
\qt@newcmd\qurantrans@en@mcxxv{%
And when We shook the mountain above them as if it were a canopy, and they supposed it was about to fall on them: 'Take forcefully what We have given you, and remember what is in it; haply you will be godfearing.'\qt@no{171}}%
\qt@newcmd\qurantrans@en@mcxxvi{%
And when thy Lord took from the Children of Adam, from their loins, their seed, and made them testify touching themselves, 'Am I not your Lord?' They said, 'Yes, we testify'-- lest you should say on the Day of Resurrection, 'As for us, we were heedless of this,'\qt@no{172}}%
\qt@newcmd\qurantrans@en@mcxxvii{%
or lest you say, 'Our fathers were idolaters aforetime, and we were seed after them. What, wilt Thou then destroy us for the deeds of the vain-doers?'\qt@no{173}}%
\qt@newcmd\qurantrans@en@mcxxviii{%
So We distinguish the signs; and haply they will return.\qt@no{174}}%
\qt@newcmd\qurantrans@en@mcxxix{%
And recite to them the tiding of him to whom We gave Our signs, but he cast them off; and Satan followed after him, and he became one of the perverts.\qt@no{175}}%
\qt@newcmd\qurantrans@en@mcxxx{%
And had We willed, We would have raised him up thereby; but he inclined towards the earth and followed his lust. So the likeness of him is as the likeness of a dog; if thou attackest it it lolls its tongue out, or if thou leavest it, it lolls its tongue out. That is that people's likeness who cried lies to Our signs. So relate the story; haply they will reflect.\qt@no{176}}%
\qt@newcmd\qurantrans@en@mcxxxi{%
An evil likeness is the likeness of the people who cried lies to Our signs, and themselves were wronging.\qt@no{177}}%
\qt@newcmd\qurantrans@en@mcxxxii{%
Whomsoever God guides, he is rightly guided; and whom He leads astray -- they are the losers.\qt@no{178}}%
\qt@newcmd\qurantrans@en@mcxxxiii{%
We have created for Gehenna many jinn and men: they have hearts, but understand not with them; they have eyes, but perceive not with them; they have ears, but they hear not with them. They are like cattle; nay, rather they are further astray. Those -- they are the heedless.\qt@no{179}}%
\qt@newcmd\qurantrans@en@mcxxxiv{%
To God belong the Names Most Beautiful; so call Him by them, and leave those who blaspheme His Names -- they shall assuredly be recompensed for the things they did.\qt@no{180}}%
\qt@newcmd\qurantrans@en@mcxxxv{%
Of those We created are a nation who guide by the truth, and by it act with justice.\qt@no{181}}%
\qt@newcmd\qurantrans@en@mcxxxvi{%
And those who cry lies to Our signs We will draw them on little by little whence they know not;\qt@no{182}}%
\qt@newcmd\qurantrans@en@mcxxxvii{%
and I respite them -- assuredly My guile is sure.\qt@no{183}}%
\qt@newcmd\qurantrans@en@mcxxxviii{%
Have they not reflected? No madness is in their comrade; he is naught but a plain warner.\qt@no{184}}%
\qt@newcmd\qurantrans@en@mcxxxix{%
Or have they not considered the dominion of the heaven and of the earth, and what things God has created, and that it may be their term is already nigh? In what manner of discourse then will they after this believe?\qt@no{185}}%
\qt@newcmd\qurantrans@en@mcxl{%
Whomsoever God leads astray, no guide he has; He leaves them in their insolence blindly wandering.\qt@no{186}}%
\qt@newcmd\qurantrans@en@mcxli{%
They will question thee concerning the Hour, when it shall berth. Say: 'The knowledge of it is only with my Lord; none shall reveal it at its proper time, but He. Heavy is it in the heavens and the earth; it will not come on you but suddenly!' They will question thee, as though thou art well-informed of it. Say: 'The knowledge of it is only with God, but most men know not.'\qt@no{187}}%
\qt@newcmd\qurantrans@en@mcxlii{%
Say: 'I have no power to profit for myself; or hurt, but as God will. Had I knowledge of the Unseen I would have acquired much good, and evil would not have touched me. I am only a warner, and a bearer of good tidings, to a people believing.'\qt@no{188}}%
\qt@newcmd\qurantrans@en@mcxliii{%
It is He who created you out of one living soul, and made of him his spouse that he might rest in her. Then, when he covered her, she bore a light burden and passed by with it; but when it became heavy they cried to God their Lord, 'If Thou givest us a righteous son, we indeed shall be of the thankful.'\qt@no{189}}%
\qt@newcmd\qurantrans@en@mcxliv{%
Thereafter, when He gave them a righteous son, they assigned Him associates in that He had given them; but God is high exalted above that they associate.\qt@no{190}}%
\qt@newcmd\qurantrans@en@mcxlv{%
What, do they associate that which creates nothing and themselves are created,\qt@no{191}}%
\qt@newcmd\qurantrans@en@mcxlvi{%
and that have no power to help them, neither they help themselves?\qt@no{192}}%
\qt@newcmd\qurantrans@en@mcxlvii{%
If you call them to guidance they will not follow you; equal it is to you whether you call them, or whether you are silent.\qt@no{193}}%
\qt@newcmd\qurantrans@en@mcxlviii{%
Those on whom you call apart from God, are servants the likes of you; call them and let them answer you, if you speak truly.\qt@no{194}}%
\qt@newcmd\qurantrans@en@mcxlix{%
What, have they feet wherewith they walk, or have they hands wherewith they lay hold, or have they eyes wherewith they see, or have they ears wherewith they give ear? Say: 'Call you then to your associates; then try your guile on me, and give me no respite.\qt@no{195}}%
\qt@newcmd\qurantrans@en@mcl{%
My Protector is God who sent down the Book, and He takes into His protection the righteous.\qt@no{196}}%
\qt@newcmd\qurantrans@en@mcli{%
And those on whom you call, apart from God, have no power to help you, neither they help themselves.'\qt@no{197}}%
\qt@newcmd\qurantrans@en@mclii{%
If you call them to the guidance they do not hear; and thou seest them looking at thee, unperceiving.\qt@no{198}}%
\qt@newcmd\qurantrans@en@mcliii{%
Take the abundance, and bid to what is honourable, and turn away from the ignorant.\qt@no{199}}%
\qt@newcmd\qurantrans@en@mcliv{%
If a provocation from Satan should provoke thee, seek refuge in God; He is All-hearing, All-seeing.\qt@no{200}}%
\qt@newcmd\qurantrans@en@mclv{%
The godfearing, when a visitation of Satan troubles them, remember, and then see clearly;\qt@no{201}}%
\qt@newcmd\qurantrans@en@mclvi{%
and their brothers they lead on into error, then they stop not short.\qt@no{202}}%
\qt@newcmd\qurantrans@en@mclvii{%
And when thou bringest them not a sign, they say, 'Why hast thou not chosen one?' Say: 'I follow only what is revealed to me from my Lord; this is clear testimony from your Lord, guidance, and mercy for a people of believers.'\qt@no{203}}%
\qt@newcmd\qurantrans@en@mclviii{%
And when the Koran is recited, give you ear to it and be silent; haply so you will find mercy.\qt@no{204}}%
\qt@newcmd\qurantrans@en@mclix{%
Remember thy Lord in thy soul, humbly and fearfully, not loud of voice, at morn and eventide. Be not thou among the heedless.\qt@no{205}}%
\qt@newcmd\qurantrans@en@mclx{%
Surely those who are with thy Lord wax not too proud to serve Him; they chant His praise, and to Him they bow.\qt@no{206}}%
\qt@newcmd\qurantrans@en@mclxi{%
\basmalahen They will question thee concerning the spoils. Say: 'The spoils belong to God and the Messenger; so fear you God, and set things right between you, and obey you God and His Messenger, if you are believers.'\qt@no{1}}%
\qt@newcmd\qurantrans@en@mclxii{%
Those only are believers who, when God is mentioned, their hearts quake, and when His signs are recited to them, it increases them in faith, and in their Lord they put their trust,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mclxiii{%
those who perform the prayer, and expend of what We have provided them,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mclxiv{%
those in truth are the believers; they have degrees with their Lord, and forgiveness, and generous provision.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mclxv{%
As thy Lord brought thee forth from thy house with the truth, and a part of the believers were averse to it,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mclxvi{%
disputing with thee concerning the truth after it had become clear, as though they were being driven into death with their eyes wide open.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mclxvii{%
And when God promised you one of the two parties should be yours, and you were wishing that the one not accoutred should be yours; but God was desiring to verify the truth by His words, and to cut off the unbelievers to the last remnant,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mclxviii{%
and that He might verify the truth and prove untrue the untrue, though the sinners were averse to it.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mclxix{%
When you were calling upon your Lord for succour, and He answered you, 'I shall reinforce you with a thousand angels riding behind you.'\qt@no{9}}%
\qt@newcmd\qurantrans@en@mclxx{%
God wrought this not, save as good tidings and that your hearts thereby might be at rest; help comes only from God; surely God is All-mighty, All-wise.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mclxxi{%
When He was causing slumber to overcome you as a security from Him, and sending down on you water from heaven, to purify you thereby, and to put away from you the defilement of Satan, and to strengthen your hearts, and to confirm your feet.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mclxxii{%
When thy Lord was revealing to the angels, 'I am with you; so confirm the believers. I shall cast into the unbelievers' hearts terror; so smite above the necks, and smite every finger of them!'\qt@no{12}}%
\qt@newcmd\qurantrans@en@mclxxiii{%
That, because they had made a breach with God and with His Messenger; and whosoever makes a breach with God and with His Messenger, surely God is terrible in retribution.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mclxxiv{%
That for you; therefore taste it; and that the chastisement of the Fire is for the unbelievers.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mclxxv{%
O believers, when you encounter the unbelievers marching to battle, turn not your backs to them.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mclxxvi{%
Whoso turns his back that day to them, unless withdrawing to fight again or removing to join another host, he is laden with the burden of God's anger, and his refuge is Gehenna -- an evil homecoming!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mclxxvii{%
You did not slay them, but God slew them; and when thou threwest, it was not thyself that threw, but God threw, and that He might confer on the believers a fair benefit; surely God is All-hearing, All-knowing.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mclxxviii{%
That for you; and that God weakens the unbelievers' guile.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mclxxix{%
If victory you are seeking, victory has already come upon you; and if you give over, it is better for you. But if you return, We shall return, and your host will avail you nothing though it be numerous; and that God is with the believers.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mclxxx{%
O believers, obey God and His Messenger, and do not turn away from Him, even as you are listening;\qt@no{20}}%
\qt@newcmd\qurantrans@en@mclxxxi{%
and be not as those who say, 'We hear,' and they hear not.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mclxxxii{%
Surely the worst of beasts in God's sight are those that are deaf and dumb and do not understand.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mclxxxiii{%
If God had known of any good in them He would have made them hear; and if He had made them hear, they would have turned away, swerving aside.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mclxxxiv{%
O believers, respond to God and the Messenger when He calls you unto that which will give you life; and know that God stands between a man and his heart, and that to Him you shall be mustered.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mclxxxv{%
And fear a trial which shall surely not smite in particular the evildoers among you; and know that God is terrible in retribution.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mclxxxvi{%
And remember when you were few and abased in the land, and were fearful that the people would snatch you away; but He gave you refuge, and confirmed you with His help, and provided you with the good things, that haply you might be thankful.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mclxxxvii{%
O believers, betray not God and the Messenger, and betray not your trusts and that wittingly;\qt@no{27}}%
\qt@newcmd\qurantrans@en@mclxxxviii{%
and know that your wealth and your children are a trial, and that with God is a mighty wage.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mclxxxix{%
O believers, if you fear God, He will assign you a salvation, and acquit you of your evil deeds, and forgive you; and God is of bounty abounding.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcxc{%
And when the unbelievers were devising against thee, to confine thee, or slay thee, or to expel thee, and were devising, and God was devising; and God is the best of devisers.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcxci{%
And When Our signs were being recited to them, they said, 'We have already heard; if we wished, we could say the like of this; this is naught but the fairy-tales of the ancients.'\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcxcii{%
And when they said, 'O God, if this be indeed the truth from Thee, then rain down upon us stones out of heaven, or bring us a painful chastisement.'\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcxciii{%
But God would never chastise them, with thee among them; God would never chastise them as they begged forgiveness.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcxciv{%
But what have they now, that God should not chastise them, when they are barring from the Holy Mosque, not being its protectors? Its only protectors are the godfearing; but most of them know not.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcxcv{%
And their prayer at the House is nothing but a whistling and a clapping of hands -- therefore taste you now the chastisement for your unbelief!\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcxcvi{%
The unbelievers expend their wealth to bar from God's way, and still they will expend it, till it is an anguish for them, then be overthrown, and the unbelievers will be mustered into Gehenna,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcxcvii{%
that God may distinguish the corrupt from the good, and place the corrupt one upon another, and so heap them up all together, and put them in Gehenna; those are the losers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcxcviii{%
Say to the unbelievers, if they give over He will forgive them what is past; but if they return, the wont of the ancients is already gone!\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcxcix{%
Fight them, till there is no persecution and the religion is God's entirely; then if they give over, surely God sees the things they do;\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcc{%
but if they turn away, know that God is your Protector -- an excellent Protector, an excellent Helper!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcci{%
Know that, whatever booty you take, the fifth of it is God's, and the Messenger's, and the near kinsman's, and the orphans', and for the needy, and the traveller, if you believe in God and that We sent down upon Our servant on the day of salvation,. the day the two hosts encountered; and God is powerful over everything;\qt@no{41}}%
\qt@newcmd\qurantrans@en@mccii{%
when you were on the nearer bank, and they were on the farther bank, and the cavalcade was below you; and had you made tryst together, you would have surely failed the tryst; but that God might determine a matter that was done, that whosoever perished might perish by a clear sign, and by a clear sign he might live who lived; and surely God is All-hearing, All-knowing.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcciii{%
When God showed thee them in thy dream as few; and had He shown them as many you would have lost heart, and quarrelled about the matter; but God saved; He knows the thoughts in the breasts.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcciv{%
When God showed you them in your eyes as few, when you encountered, and made you few in their eyes, that God might determine a matter that was done; and unto God all matters are returned.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mccv{%
O believers, whensoever you encounter a host, then stand firm, and remember God frequently; haply so you will prosper.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mccvi{%
And obey God, and His Messenger, and do not quarrel together, and so lose heart, and your power depart; and be patient; surely God is with the patient.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mccvii{%
Be not as those who went forth from their habitations swaggering boastfully to show off to men, and barring from God's way; and God encompasses the things they do.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mccviii{%
And when Satan decked out their deeds fair to them, and said, 'Today no man shall overcome you, for I shall be your neighbour.' But when the two hosts sighted each other, he withdrew upon his heels, saying, 'I am quit of you; for I see what you do not see. I fear God; and God is terrible in retribution.'\qt@no{48}}%
\qt@newcmd\qurantrans@en@mccix{%
When the hypocrites, and those in whose hearts was sickness, said, 'Their religion has deluded them'; but whosoever puts his trust in God, surely God is All-mighty, All-wise.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mccx{%
If thou couldst only see when the angels take the unbelievers, beating their faces and their backs: 'Taste the chastisement of the burning --\qt@no{50}}%
\qt@newcmd\qurantrans@en@mccxi{%
that, for what your hands have forwarded, and for that God is never unjust unto His servants.'\qt@no{51}}%
\qt@newcmd\qurantrans@en@mccxii{%
Like Pharaoh's folk, and the people before him, who disbelieved in God's signs; God seized them because of their sins; God is strong, terrible in retribution.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mccxiii{%
That is because God would never change His favour that He conferred on a people until they changed what was within themselves; and that God is All-hearing, All-knowing.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mccxiv{%
Like Pharaoh's folk, and the people before him, who cried lies to the signs of their Lord, so We destroyed them because of their sins, and We drowned the folk of Pharaoh; and all were evildoers.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mccxv{%
Surely the worst of beasts in God's sight are the unbelievers, who will not believe,\qt@no{55}}%
\qt@newcmd\qurantrans@en@mccxvi{%
those of them with whom thou hast made compact then they break their compact every time, not being godfearing.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mccxvii{%
So, if thou comest upon them anywhere in the war, deal with them in such wise as to scatter the ones behind them; haply they will remember.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mccxviii{%
And if thou fearest treachery any way at the hands of a people, dissolve it with them equally; surely God loves not the treacherous.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mccxix{%
And thou art not to suppose that they who disbelieve have outstripped Me; they cannot frustrate My will.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mccxx{%
Make ready for them whatever force and strings of horses you can, to terrify thereby the enemy of God and your enemy, and others besides them that you know not; God knows them. And whatsoever you expend in the way of God shall be repaid you in full; you will not be wronged.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mccxxi{%
And if they incline to peace, do thou incline to it; and put thy trust in God; He is the All-hearing, the All-knowing.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mccxxii{%
And if they desire to trick thee, God is sufficient for thee; He has confirmed thee with His help, and with the believers,\qt@no{62}}%
\qt@newcmd\qurantrans@en@mccxxiii{%
and brought their hearts together. Hadst thou expended all that is in the earth, thou couldst not have brought their hearts together; but God brought their hearts together; surely He is All-mighty, All-wise.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mccxxiv{%
O Prophet, God suffices thee, and the believers who follow thee.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mccxxv{%
O Prophet, urge on the believers to fight. If there be twenty of you, patient men, they will overcome two hundred; if there be a hundred of you, they will overcome a thousand unbelievers, for they are a people who understand not.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mccxxvi{%
Now God has lightened it for you, knowing that there is weakness in you. If there be a hundred of you, patient men, they will overcome two hundred; if there be of you a thousand, they will overcome two thousand by the leave of God; God is with the patient.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mccxxvii{%
It is not for any Prophet to have prisoners until he make wide slaughter in the land. You desire the chance goods of the present world, and God desires the world to come; and God is All-mighty, All-wise.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mccxxviii{%
Had it not been for a prior prescription from God, there had afflicted you, for what you took, a mighty chastisement.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mccxxix{%
Eat of what you have taken as booty, such as is lawful and good; and fear you God; surely God is All-forgiving, All-compassionate.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mccxxx{%
O Prophet, say to the prisoners in your hands: 'If God knows of any good in your hearts He will give you better than what has been taken from you, and He will forgive you; surely God is All-forgiving, All-compassionate.'\qt@no{70}}%
\qt@newcmd\qurantrans@en@mccxxxi{%
And if they desire treachery against thee, they have tricked God before; but He has given thee power over them; and God is All-knowing, All-wise.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mccxxxii{%
Those who believe, and have emigrated and struggled with their possessions and their selves in the way of God, and those who have given refuge and help -- those are friends one of another. And those who believe, but have not emigrated -- you have no duty of friendship towards them till they emigrate; yet if they ask you for help, for religion's sake, it is your duty to help them, except against a people between whom and you there is a compact; and God sees the things you do.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mccxxxiii{%
As for the unbelievers, they are friends one of another. Unless you do this, there will be persecution in the land and great corruption.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mccxxxiv{%
And those who believe, and have emigrated and struggled in the way of God. those who have given refuge and help those in truth are the believers, and theirs shall be forgiveness and generous provision.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mccxxxv{%
And those who have believed afterwards and emigrated, and struggled with you -- they belong to you; but those related by blood are nearer to one another in the Book of God; surely God has knowledge of everything.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mccxxxvi{%
\basmalahen An acquittal, from God and His Messenger, unto the idolaters with whom you made covenant:\qt@no{1}}%
\qt@newcmd\qurantrans@en@mccxxxvii{%
'Journey freely in the land for four months; and know that you cannot frustrate the will of God, and that God degrades the unbelievers.'\qt@no{2}}%
\qt@newcmd\qurantrans@en@mccxxxviii{%
A proclamation, from God and His Messenger, unto mankind on the day of the Greater Pilgrimage: 'God is quit, and His Messenger, of the idolaters. So if you repent, that will be better for you; but if you turn your backs; know that you cannot frustrate the will of God. And give thou good tidings to the unbelievers of a painful chastisement;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mccxxxix{%
excepting those of the idolaters with whom you made covenant, then they failed. you naught neither lent support to any man against you. With them fulfil your covenant till their term; surely God loves the godfearing.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mccxl{%
Then, when the sacred months are drawn away, slay the idolaters wherever you find them, and take them, and confine them, and lie in wait for them at every place of ambush. But if they repent, and perform the prayer, and pay the alms, then let them go their way; God is All-forgiving, All-compassionate.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mccxli{%
And if any of the idolaters seeks of thee protection, grant him protection till he hears the words of God; then do thou convey him to his place of security -- that, because they are a people who do not know.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mccxlii{%
How should the idolaters have a covenant with God and His Messenger? -- excepting those with whom you made covenant at the Holy Mosque; so long as they go straight with you, do you go straight with them; surely God loves the godfearing.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mccxliii{%
How? If they get the better of you, they will not observe towards you any bond or treaty, giving you satisfaction with their mouths but in their hearts refusing; and the most of them are ungodly.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mccxliv{%
They have sold the signs of God for a small price, and have barred from His way; truly evil is that they have been doing,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mccxlv{%
observing neither bond nor treaty towards a believer; they are the transgressors.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mccxlvi{%
Yet if they repent, and perform the prayer, and pay the alms, then they are your brothers in religion; and We distinguish the signs for a people who know.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mccxlvii{%
But if they break their oaths after their covenant and thrust at your religion, then fight the leaders of unbelief; they have no sacred oaths; haply they will give over.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mccxlviii{%
Will you not fight a people who broke their oaths and purposed to expel the Messenger, beginning the first time against you? Are you afraid of them? You would do better to be afraid of God, if you are believers.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mccxlix{%
Fight them, and God will chastise them at your hands and degrade them, and He will help you against them, and bring healing to the breasts of a people who believe,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mccl{%
and He will remove the rage within their hearts; and God turns towards whomsoever He will; God is All-knowing, All-wise\qt@no{15}}%
\qt@newcmd\qurantrans@en@mccli{%
Or did you suppose you would be left in peace, and God knows not as yet those of you who have struggled, and taken not -- apart from God and His Messenger and the believers -- any intimate? God is aware of what you do.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcclii{%
It is not for the idolaters to inhabit God's places of worship, witnessing against themselves unbelief; those -- their works have failed them, and in the Fire they shall dwell forever.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mccliii{%
Only he shall inhabit God's places of worship who believes in God and the Last Day, and performs the prayer, and pays the alms, and fears none but God alone; it may be that those will be among the guided.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mccliv{%
Do you reckon the giving of water to pilgrims and the inhabiting of the Holy Mosque as the same as one who believes in God and the Last Day and struggles in the way of God? Not equal are they in God's sight; and God guides not the people of the evildoers.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcclv{%
Those who believe, and have emigrated, and have struggled in the way of God with their possessions and their selves are mightier in rank with God; and those -- they are the triumphant;\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcclvi{%
their Lord gives them good tidings of mercy from Him and good pleasure; for them await gardens wherein is lasting bliss,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcclvii{%
therein to dwell forever and ever; surely with God is a mighty wage.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcclviii{%
O believers, take not your fathers and brothers to be your friends, if they prefer unbelief to belief; whosoever of you takes them for friends, those -- they are the evildoers.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcclix{%
Say: 'If your fathers, your sons, your brothers, your wives, your clan, your possessions that you have gained, commerce you fear may slacken, dwellings you love -- if these are dearer to you than God and His Messenger, and to struggle in His way, then wait till God brings His command; God guides not the people of the ungodly.'\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcclx{%
God has already helped you on many fields, and on the day of Hunain, when your multitude was pleasing to you, but it availed you naught, and the land for all its breadth was strait for you, and you turned about, retreating.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcclxi{%
Then God sent down upon His Messenger His Shechina, and upon the believers, and He sent down legions you did not see, and He chastised the unbelievers; and that is the recompense of the unbelievers;\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcclxii{%
then God thereafter turns towards whom He will; God is All-forgiving, All-compassionate.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcclxiii{%
O believers, the idolaters are indeed unclean; so let them not come near the Holy Mosque after this year of theirs. If you fear poverty, God shall surely enrich you of His bounty, if He will; God is All-knowing; All-wise.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcclxiv{%
Fight those who believe not in God and the Last Day and do not forbid what God and His Messenger have forbidden -- such men as practise not the religion of truth, being of those who have been given the Book -- until they pay the tribute out of hand and have been humbled.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcclxv{%
The Jews say, 'Ezra is the Son of God'; the Christians say, 'The Messiah is the Son of God.' That is the utterance of their mouths, conforming with the unbelievers before them. God assail them! How they are perverted!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcclxvi{%
They have taken their rabbis and their monks as lords apart from God, and the Messiah, Mary's son -- and they were commanded to serve but One God; there is no god but He; glory be to Him, above that they associate --\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcclxvii{%
desiring to extinguish with their mouths God's light; and God refuses but to perfect His light, though the unbelievers be averse.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcclxviii{%
It is He who has sent His Messenger with the guidance and the religion of truth, that He may uplift it above every religion, though the unbelievers be averse.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcclxix{%
O believers, many of the rabbis and monks indeed consume the goods of the people in vanity and bar from God's way. Those who treasure up gold and silver, and do not expend them in the way of God -- give them the good tidings of a painful chastisement,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcclxx{%
the day they shall be heated in the fire of Gehenna and therewith their foreheads and their sides and their backs shall be branded: 'This is the thing you have treasured up for yourselves; therefore taste you now what you were treasuring!'\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcclxxi{%
The number of the months, with God, is twelve in the Book of God, the day that He created the heavens and the earth; four of them are sacred. That is the right religion. So wrong not each other during them. And fight the unbelievers totally even as they fight you totally and know that God is with the godfearing.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcclxxii{%
The month postponed is an increase of unbelief whereby the unbelievers go astray; one year they make it profane, and hallow it another, to agree with the number that God has hallowed, and so profane what God has hallowed. Decked out fair to them are their evil deeds; and God guides not the people of the unbelievers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcclxxiii{%
O believers, what is amiss with you, that when it is said to you, 'Go forth in the way of God,' you sink down heavily to the ground? Are you so content with this present life, rather than the world to come? Yet the enjoyment of this present life, compared with the world to come, is a little thing.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcclxxiv{%
If you go not forth, He will chastise you with a painful chastisement, and instead of you He will substitute another people; and you will not hurt Him anything, for God is powerful over everything.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcclxxv{%
If you do not help him, yet God has helped him already, when the unbelievers drove him forth the second of two, when the two were in the Cave, when he said to his companion, 'Sorrow not; surely God is with us.' Then God sent down on him His Shechina, and confirmed him with legions you did not see; and He made the word of the unbelievers the lowest; and God's word is the uppermost; God is All-mighty, All-wise.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcclxxvi{%
Go forth, light and heavy! Struggle in God's way with your possessions and your selves; that is better for you, did you know.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcclxxvii{%
Were it a gain near at hand, and an easy journey, they would have followed thee; but the distance was too far for them. Still they will swear by God, 'Had we been able, we would have gone out with you,' so destroying their souls; and God knows that they are truly liars.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcclxxviii{%
God pardon thee! Why gavest thou them leave, till it was clear to thee which of them spoke the truth, and thou knewest the liars?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcclxxix{%
Those who believe in God and the Last Day ask not leave of thee, that they may struggle with their possessions and their selves; and God knows the godfearing.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcclxxx{%
They only ask leave of thee who believe not in God and the Last Day, those whose hearts are filled with doubt, so that in their doubt they go this way and that.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcclxxxi{%
If they had desired to go forth, they would have made some preparation for it; but God was averse that they should be aroused, so He made them pause, and it was said to them, 'Tarry you with the tarriers.'\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcclxxxii{%
Had they gone forth among you, they would only have increased you in trouble, and run to and fro in your midst, seeking to stir up sedition between you; and some of you would listen to them; and God knows the evildoers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcclxxxiii{%
They sought to stir up sedition already before, and turned things upside down for thee, until the truth came, and God's command appeared, though they were averse.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcclxxxiv{%
Some of them there are that say, 'Give me leave and do not tempt me.' Have not such men fallen into temptation? And surely Gehenna encompasses the unbelievers.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcclxxxv{%
If good fortune befalls thee, it vexes them; but if thou art visited by an affliction, they say, 'We took our dispositions before', and turn away, rejoicing.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcclxxxvi{%
Say: 'Naught shall visit us but what God has prescribed for us; He is our Protector; in God let the believers put all their trust.'\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcclxxxvii{%
Say: 'Are you awaiting for aught to come to us but one of the two rewards most fair? We are awaiting in your case too, for God to visit you with chastisement. from Him, or at our hands; so await; we are awaiting with you.'\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcclxxxviii{%
Say: 'Expend willingly, or unwillingly, it shall not be accepted from you; you are surely a people ungodly.'\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcclxxxix{%
And naught prevents that their expendings should be accepted from them, but that they believe not in God and His Messenger, and perform not the prayer save lazily, and that they expend not without they are averse.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mccxc{%
So let not their possessions or their children please thee; God only desires thereby to chastise them in this present life, and that their souls should depart while they are unbelievers.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mccxci{%
They swear by God that they belong with you, but they are not of you they are a people that are afraid.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mccxcii{%
If they could find a shelter, or some caverns, or any place to creep into, they would turn about and bolt away to it.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mccxciii{%
Some of them find fault with thee touching the freewill offerings; if they are given a share of them they are well-pleased, but if they are given none then they are angry.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mccxciv{%
O were they well-pleased with what God and His Messenger have brought them, saying, 'Enough for us is God; God will bring us of His bounty, and His Messenger; to God we humbly turn.'\qt@no{59}}%
\qt@newcmd\qurantrans@en@mccxcv{%
The freewill offerings are for the poor and needy, those who work to collect them, those whose hearts are brought together, the ransoming of slaves, debtors, in God's way, and the traveller; so God ordains; God is All-knowing, All-wise.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mccxcvi{%
And some of them hurt the Prophet, saying, 'He is an ear!' Say: 'An ear of good for you; he believes in God, and believes the believers, and he is a mercy to the believers among you. Those who hurt God's Messenger -- for them awaits a painful chastisement.'\qt@no{61}}%
\qt@newcmd\qurantrans@en@mccxcvii{%
They swear to you by God, to please you; but God and His Messenger -- more right is it they should please Him, if they are believers.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mccxcviii{%
Do they not know that whosoever opposes God and His Messenger -- for him awaits the fire of Gehenna, therein to dwell forever? That is the mighty degradation.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mccxcix{%
The hypocrites are afraid, lest a sura should be sent down against them, telling thee what is in their hearts. Say: 'Mock on; God will bring forth what you fear.'\qt@no{64}}%
\qt@newcmd\qurantrans@en@mccc{%
And if thou questionest them, then assuredly they will say, 'We were only plunging and playing.' Say: 'What, then were you mocking God, and His signs, and His Messenger?\qt@no{65}}%
\qt@newcmd\qurantrans@en@mccci{%
Make no excuses. You have disbelieved after your believing. If We forgive one party of you, We will chastise another party for that they were sinners.'\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcccii{%
The hypocrites, the men and the women, are as one another; they bid to dishonour, and forbid honour; they keep their hands shut; they have forgotten God, and He has forgotten them. The hypocrites -- they are the ungodly.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mccciii{%
God has promised the hypocrites, men and women, and the unbelievers, the fire of Gehenna, therein to dwell foreover. That is enough for them; God has cursed them; and there awaits them Like a lasting chastisement.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mccciv{%
those before you, who were stronger than you in might, and more abundant in wealth and children; they took enjoyment in their share; so do you take enjoyment in your share, as those before you took enjoyment in their share. You have plunged as they plunged. Those -- their works have failed in this world and in the world to come; those -- they are the losers.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcccv{%
Has there not come to you the tidings of those who were before you -- the people of Noah, Ad, Thamood, the people of Abraham, the men of Midian and the subverted cities? Their Messengers came to them with the clear signs God would not wrong them, but themselves they wronged.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcccvi{%
And the believers, the men and the women, are friends one of the other; they bid to honour, and forbid dishonour; they perform the prayer, and pay the alms, and they obey God and His Messenger. Those -- upon them God will have mercy; God is All-mighty, All-wise.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcccvii{%
God has promised the believers, men and women, gardens underneath which rivers flow, forever therein to dwell, and goodly dwelling-places in the Gardens of Eden; and greater, God's good pleasure; that is the mighty triumph.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcccviii{%
O Prophet, struggle with the unbelievers and hypocrites, and be thou harsh with them; their refuge is Gehenna -- an evil homecoming!\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcccix{%
They swear by God that they said nothing, but they indeed said the word of unbelief and disbelieved, after they had surrendered. They purposed what they never attained to, and they took revenge only that God enriched them, and His Messenger, of His bounty. So if they repent it will be better for them; if they turn away, God will chastise them with a painful chastisement in this world and the next; on the earth they have no protector or helper.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcccx{%
And some of them have made covenant with God: 'If He gives us of His bounty, we will make offerings and be of the righteous.'\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcccxi{%
Nevertheless, when He gave them of His bounty they were niggardly of it, and turned away, swerving aside.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcccxii{%
So as a consequence He put hypocrisy into their hearts, until the day they meet Him, for that they failed God in that they promised Him and they were liars.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcccxiii{%
Did they not know that God knows their secret and what they conspire together, and that God knows the things unseen?\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcccxiv{%
Those who find fault with the believers who volunteer their freewill offerings, and those who find nothing but their endeavour they deride -- God derides them; for them awaits a painful chastisement.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcccxv{%
Ask pardon for them, or ask not pardon for them; if thou askest pardon for them seventy times, God will not pardon them; that, because they disbelieved in God and His Messenger; God guides not the people of the ungodly.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcccxvi{%
Those who were left behind rejoiced in tarrying behind the Messenger of God, and were averse to struggle with their possessions and their selves in the way of God. They said, 'Go not forth in the heat.' Say: 'Gehenna's fire is hotter, did they but understand.'\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcccxvii{%
Therefore let them laugh little, and weep much, in recompense for what they have been earning.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcccxviii{%
So, if God returns thee to a party of them and they ask leave of thee to go forth, say: 'You shall not go forth with me ever, and you shall not fight with me any enemy. You were well-pleased to tarry the first time, so now tarry with those behind.'\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcccxix{%
And pray thou never over any one of them when he is dead, nor stand over his grave; they disbelieved in God and His Messenger, and died while they were ungodly.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcccxx{%
And let not their possessions and their children please thee; God only desires thereby to chastise them in this present world, and that their souls should depart while they are unbelievers.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcccxxi{%
And when a sura is sent down, saying, 'Believe in God, and struggle with His Messenger,' the affluent among them ask leave of thee, saying, 'Let us be with the tarriers.'\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcccxxii{%
They are well-pleased to be with those behind, and a seal has been set upon their hearts, so the they understand not.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcccxxiii{%
But Messenger, and the believers with him, have struggled with their possessions and their selves, and those -- for them await the good things; those -- they are the prosperers.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcccxxiv{%
God has prepared for them gardens underneath which rivers flow, therein to dwell forever; that is the mighty triumph.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcccxxv{%
And the Bedouins came with their excuses, asking for leave; those who lied to God and His Messenger tarried; there shall befall the unbelievers of them a painful chastisement.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcccxxvi{%
There is no fault in the weak and the sick and those who find nothing to expend, if they are true to God and to His Messenger. There is no way against the good-doers -- God is All-forgiving, All-compassionate --\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcccxxvii{%
neither against those who, when they came to thee, for thee to mount them, thou saidst to them, 'I find not whereon to mount you'; they turned away, their eyes overflowing with tears of sorrow, because they found nothing to expend.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcccxxviii{%
The way is open only against those who ask leave of thee, being rich; they are well-pleased to be with those behind; God has set a seal on their hearts, so they know not.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcccxxix{%
They will excuse themselves to you, when you return to them. Say: 'Do not excuse yourselves; we will not believe you. God has already told us tidings of you. God will surely see your work, and His Messenger, then you will be returned to Him who knows the unseen and the visible, and He will tell you what you were doing.'\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcccxxx{%
They will swear to you by God, when you turn back to them, that you may turn aside from them. So turn aside from them, for they are an abomination, and their refuge is Gehenna -- a recompense for what they have been earning.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcccxxxi{%
They will swear to you, that you may be well-pleased with them; but if you are well-pleased with them, God will surely not be well-pleased with the people of the ungodly.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcccxxxii{%
The Bedouins are more stubborn in unbelief and hypocrisy, and apter not to know the bounds of what God has sent down on His Messenger; and God is All-knowing, All-wise.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcccxxxiii{%
Some of the Bedouins take what they expend for a fine, and await the turns of fortune to go against you. Theirs shall be the evil turn; God is All-hearing, All-knowing.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcccxxxiv{%
And some of the Bedouins believe in God and the Last Day, and take what they expend for offerings bringing them near to God, and the prayers of the Messenger. Surely they are an offering for them, and God will admit them into His mercy; God is All-forgiving, All-compassionate.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcccxxxv{%
And the Outstrippers, the first of the Emigrants and the Helpers, and those who followed them in good-doing -- God will be well-pleased with them and they are well-pleased with Him; and He has prepared for them gardens underneath which rivers flow, therein to dwell forever and ever; that is the mighty triumph.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mcccxxxvi{%
And some of the Bedouins who dwell around you are hypocrites; and some of the people of the City are grown bold in hypocrisy. Thou knowest them not; but We know them, and We shall chastise them twice, then they will be returned to a mighty chastisement.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mcccxxxvii{%
And other have confessed their sins; they have mixed a righteous deed with another evil. It may be that God will turn towards them; God is All-forgiving, All-compassionate.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mcccxxxviii{%
Take of their wealth a freewill offering, to purify them and to cleanse them thereby, and pray for them; thy prayers are a comfort for them; God is All-hearing, All-knowing.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mcccxxxix{%
Do they not know that God is He who accepts repentance from His servants, and takes the freewill offerings, and that God -- He turns, and is All-compassionate?\qt@no{104}}%
\qt@newcmd\qurantrans@en@mcccxl{%
Say: 'Work; and God will surely see your work, and His Messenger, and the believers, and you will be returned to Him who knows the unseen and the visible, and He will tell you what you were doing.'\qt@no{105}}%
\qt@newcmd\qurantrans@en@mcccxli{%
And others are deferred to God's commandment, whether He chastises them, or turns towards them; God is All-knowing, All-wise.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mcccxlii{%
And those who have taken a mosque in opposition and unbelief, and to divide the believers, and as a place of ambush for those who fought God and His Messenger aforetime -- they will swear 'We desired nothing but good'; and God testifies they are truly liars.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mcccxliii{%
Stand there never. A mosque that was founded upon godfearing from the first day is worthier for thee to stand in; therein are men who love to cleanse themselves; and God loves those who cleanse themselves.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mcccxliv{%
Why, is he better who founded his building upon the fear of God and His good pleasure, or he who founded his building upon the brink of a crumbling bank that has tumbled with him into the fire of Gehenna? And God guides not the people of the evildoers.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mcccxlv{%
The buildings they have built will not cease to be a point of doubt within their hearts, unless it be that their hearts are cut into pieces; God is All-knowing, All-wise.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mcccxlvi{%
God has bought from the believers their selves and their possessions against the gift of Paradise; they fight in the way of God; they kill, and are killed; that is a promise binding upon God in the Torah, and the Gospel, and the Koran; and who fulfils his covenant truer than God? So rejoice in the bargain you have made with Him; that is the mighty triumph.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mcccxlvii{%
Those who repent, those who serve, those who pray, those whojourney, those who bow, those who prostrate themselves, those who bid to honour and forbid dishonour, those who keep God's hounds -- and give thou good tidings to the believers.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mcccxlviii{%
It is not for the Prophet and the believers to ask pardon for the idolaters, even though they be near kinsmen, after that it has become clear to them that they will be the inhabitants of Hell.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mcccxlix{%
Abraham asked not pardon for his father except because of a promise he had made to him; and when it became clear to him that he was an enemy of God, he declared himself quit of him; Abraham was compassionate, clement.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mcccl{%
God would never lead a people astray after that He has guided them, until He makes clear to them as to what they should be godfearing; surely God knows everything.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mcccli{%
Surely to God belongs the kingdom of the heavens and of the earth; He gives life, and makes to die; and you have not, apart from God, either protector or helper.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mccclii{%
God has turned towards the Prophet and the Emigrants and the Helpers who followed him in the hour of difficulty, after the hearts of a part of them well-nigh swerved aside; then He turned towards them; surely He is Gentle to them, and All-compassionate.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mcccliii{%
And to the three who were left behind, until, when the earth became strait for them, for all its breadth, and their souls became strait for them, and they thought that there was no shelter from God except in Him, then He turned towards them, that they might also turn; surely God turns, and is All-compassionate.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mcccliv{%
O believers, fear God, and be with the truthful ones.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mccclv{%
It is not for the people of the City and for the Bedouins who dwell around them to stay behind God's Messenger, and to prefer their lives to his; that is because they are smitten neither by thirst, nor fatigue, nor emptiness in the way of God, neither tread they any tread enraging the unbelievers, nor gain any gain from any enemy, but a righteous deed is thereby written to their account; God leaves not to waste the wage of the good-doers.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mccclvi{%
Nor do they expend any sum, small or great, nor do they traverse any valley, but it is written to their account, that God may recompense them the best of what they were doing.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mccclvii{%
It is not for the believers to go forth totally; but why should not a party of every section of them go forth, to become learned in religion, and to warn their people when they return to them, that haply they may beware?\qt@no{122}}%
\qt@newcmd\qurantrans@en@mccclviii{%
O believers, fight the unbelievers who are near to you; and let them find in you a harshness; and know that God is with the godfearing.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mccclix{%
Whenever a sura is sent down to thee, some of them say, 'Which of you has this increased in belief?' As for the believers, them it has increased in belief, and they are joyful.\qt@no{124}}%
\qt@newcmd\qurantrans@en@mccclx{%
But as for those in whose heart is sickness, them it has increased in abomination added to their abomination, and they have died while they were unbelievers.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mccclxi{%
Do they not see that they are tried every year once or twice? Yet still they do not repent, nor do they remember.\qt@no{126}}%
\qt@newcmd\qurantrans@en@mccclxii{%
And whenever a sura is sent down, they look one at another: 'Does anyone see you?' Then they turn away. God has turned away their hearts, for that they are a people who do not understand.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mccclxiii{%
Now there has come to you a Messenger from among yourselves; grievous to him is your suffering; anxious is he over you, gentle to the believers, compassionate.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mccclxiv{%
So if they turn their backs, say: 'God is enough for me. There is no god but He. In Him I have put my trust. He is the Lord of the Mighty Throne.'\qt@no{129}}%
\qt@newcmd\qurantrans@en@mccclxv{%
\basmalahen Alif Lam Ra. Those are the signs of the Wise Book.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mccclxvi{%
Was it a wonder to the people that We revealed to a man from among them: 'Warn the people, and give thou good tidings to the believers that they have a sure footing with their Lord'? The unbelievers say, 'This is a manifest sorcerer.'\qt@no{2}}%
\qt@newcmd\qurantrans@en@mccclxvii{%
Surely your Lord is God, who created the heavens and the earth in six days, then sat Himself upon the Throne, directing the affair. Intercessor there is none, save after His leave that then is God, your Lord; so serve Him. Will you not remember?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mccclxviii{%
To Him shall you return, all together -- God's promise, in truth. He originates creation, then He brings it back again that He may recompense those who believe and do deeds of righteousness, justly. And those who disbelieve -- for them awaits a draught of boiling water, and a painful chastisement, for their disbelieving.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mccclxix{%
It is He who made the sun a radiance, and the moon a light, and determined it by stations, that you might know the number of the years and the reckoning. God created that not save with the truth, distinguishing the signs to a people who know.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mccclxx{%
In the alternation of night and day, and what God has created in the heavens and the earth -- surely there are signs for a godfearing people.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mccclxxi{%
Surely those who look not to encounter Us and are well-pleased with the present life and are at rest in it, and those who are heedless of Our signs,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mccclxxii{%
those -- their refuge is the Fire, for that they have been earning.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mccclxxiii{%
Surely those who believe, and do deeds of righteousness, their Lord will guide them for their belief; beneath them rivers flowing in gardens of bliss;\qt@no{9}}%
\qt@newcmd\qurantrans@en@mccclxxiv{%
their cry therein, 'Glory to Thee, O God,' their greeting, 'Peace,' and their cry ends, 'Praise belongs to God, the Lord of all Being.'\qt@no{10}}%
\qt@newcmd\qurantrans@en@mccclxxv{%
If God should hasten unto men evil as they would hasten good, their term would be already decided for them. But We leave those, who look not to encounter Us, in their insolence wandering blindly.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mccclxxvi{%
When affliction visits a man, he calls Us on his side, or sitting, or standing; but when We have removed his affliction from him, he passes on, as if he never called Us to an affliction that visited him. So decked out fair to the prodigal is that they have been doing.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mccclxxvii{%
We destroyed the generations before you when they did evil, and their Messengers came to them with the clear signs, but they would not believe; so We recompense the people of the sinners.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mccclxxviii{%
Then We appointed you viceroys in the earth after them, that We might behold how you would do.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mccclxxix{%
And when Our signs are recited to them, clear signs, those who look not to encounter Us say, 'Bring a Koran other than this, or alter it.' Say: 'It is not for me to alter it of my own accord. I follow nothing, except what is revealed to me. Truly I fear, if I should rebel against my Lord, the chastisement of a dreadful day.'\qt@no{15}}%
\qt@newcmd\qurantrans@en@mccclxxx{%
Say: 'Had God willed I would not have recited it to you, neither would He have taught you it; I abode among you a lifetime before it -- will you not understand?'\qt@no{16}}%
\qt@newcmd\qurantrans@en@mccclxxxi{%
And who does greater evil than he who forges against God a lie, or cries lies to His signs? Surely the sinners do not prosper.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mccclxxxii{%
They serve, apart from God, what hurts them not neither profits them, and they say, 'These are our intercessors with God.' Say: 'Will you tell God what He knows not either in the heavens or in the earth?' Glory be to Him! High be He exalted above that they associate!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mccclxxxiii{%
Mankind were only one nation, then they fell into variance. But for a word that preceded from thy Lord, it had been decided between them already touching their differences.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mccclxxxiv{%
They say, 'Why has a sign not been sent down upon him from his Lord?' Say: 'The Unseen belongs only to God. Then watch and wait; I shall be with you watching and waiting.'\qt@no{20}}%
\qt@newcmd\qurantrans@en@mccclxxxv{%
When We let the people taste mercy after hardship has visited them, lo, they have a device concerning Our signs. Say: 'God is swifter at devising; surely Our messengers are writing down what you are devising.'\qt@no{21}}%
\qt@newcmd\qurantrans@en@mccclxxxvi{%
It is He who conveys you on the land and the sea; and when you are in the ship -- and the ships run with them with a fair breeze, and they rejoice in it, there comes upon them a strong wind, and waves come on them from every side, and they think they are encompassed; they call upon God, making their religion His sincerely: 'If Thou deliverest us from these, surely we shall be among the thankful.'\qt@no{22}}%
\qt@newcmd\qurantrans@en@mccclxxxvii{%
Nevertheless when He has delivered them behold, they are insolent in the earth, wrongfully. O men, your insolence is only against yourselves; the enjoyment of this present life, then unto Us you shall return, then We shall tell you what you were doing.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mccclxxxviii{%
The likeness of this present life is as water that We send down out of heaven, and the plants of the earth mingle with it whereof men and cattle eat, till, when the earth has taken on its glitter and has decked itself fair, and its inhabitants think they have power over it, Our command comes upon it by night or day, and We make it stubble, as though yesterday it flourished not. Even so We distinguish the signs for a people who reflect.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mccclxxxix{%
And God summons to the Abode of Peace, and He guides whomsoever He will to to a straight path;\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcccxc{%
the good-doers the reward most fair and a surplus; neither dust nor abasement shall overspread their faces. Those are the inhabitants of Paradise, therein dwelling forever.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcccxci{%
And for those who have earned evil deeds the recompense of an evil deed shall be the like of it; abasement shall overspread them, neither have they any defender from God, as if their faces were covered with strips of night shadowy. Those are the inhabitants of the Fire, therein dwelling forever.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcccxcii{%
And the day We shall muster them all, then We shall say to those who associate other gods with God: 'Get you to your place, you and your associates!' Then We shall set a space between them, and their associates will say, 'Not us you were serving.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcccxciii{%
God is a sufficient witness between us and you; assuredly we were heedless of your service.'\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcccxciv{%
There every soul shall prove its past deeds; and they shall be restored to God, their Protector, the True, and there shall go astray from them that they were forging.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcccxcv{%
Say: 'Who provides you out of heaven and earth, or who possesses hearing and sight, and who brings forth the living from the dead and brings forth the dead from the living, and who directs the affair?' They will surely say, 'God.' Then say: 'Will you not be godfearing?'\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcccxcvi{%
That then is God, your Lord, the True; what is there, after truth, but error? Then how are you turned about?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcccxcvii{%
Thus the word of thy Lord is realized against the ungodly that they believe not.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcccxcviii{%
Say: 'Is there any of your associates who originates creation, then brings it back again?' Say: 'God -- He originates creation, then brings it back again; so how are you perverted?'\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcccxcix{%
Say: 'Is there any of your associates who guides to the truth?' Say: 'God -- He guides to the truth; and which is worthier to be followed -- He who guides to the truth, or he who guides not unless he is guided? What then ails you, how you judge?'\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcd{%
And the most of them follow only surmise, and surmise avails naught against truth. Surely God knows the things they do.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcdi{%
This Koran could not have been forged apart from God; but it is a confirmation of what is before it, and a distinguishing of the Book, wherein is no doubt, from the Lord of all Being.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcdii{%
Or do they say, 'Why, he has forged it'? Say: 'Then produce a sura like it, and call on whom you can, apart from God, if you speak truly.'\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcdiii{%
No; but they have cried lies to that whereof they comprehended not the knowledge, and whose interpretation has not yet come to them. Even so those that were before them cried lies; then behold how was the end of the evildoers!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcdiv{%
And some of them believe in it, and some believe not in it. Thy Lord knows very well those who do corruption.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcdv{%
If they cry lies to thee, then do thou say: 'I have my work, and you have your work; you are quit of What I do, and I am quit of what you do.'\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcdvi{%
And some of them give ear to thee; what, wilt thou make the deaf to hear, though they understand not?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcdvii{%
And some of them look unto thee; what, wilt thou then guide the blind, though they do not see?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcdviii{%
Surely God wrongs not men anything, but themselves men wrong.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcdix{%
And the day He shall muster them, as if they had not tarried but an hour of the day, mutually recognizing one another; lost will be those who cried lies to the encounter with God, and were not guided.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcdx{%
Whether We show thee a part of that We promise them, or We call thee unto Us, to Us they shall return; then God is witness of the things they do\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcdxi{%
Every nation has its Messenger; then, when their Messenger comes, justly the issue is decided between them, and they are not wronged.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcdxii{%
They say, 'When will this promise be, if you speak truly?'\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcdxiii{%
Say: 'I have no power to profit for myself, or hurt, but as God will. To every nation a term; when their term comes they shall not put it back by a single hour nor put it forward.'\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcdxiv{%
Say: 'Have you considered? If His chastisement comes upon you by night or day, what part of it will the sinners seek to hasten?\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcdxv{%
What, when it has come to pass, will you then believe in it? Now, when already you seek to hasten it!'\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcdxvi{%
Then it will be said to the evildoers: 'Taste the chastisement of eternity! Are you recompensed for aught but that you have been earning?'\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcdxvii{%
They ask thee to tell them, 'Is it true?' Say: 'Yes, by my Lord! It is true; you cannot frustrate Him.'\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcdxviii{%
If every soul that has done evil possessed all that is in the earth, he would offer it for his ransom; and they will be secretly remorseful when they see the chastisement, and justly the issue is decided between them, and they are not wronged.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mcdxix{%
Why, surely to God belongs everything that is in the heavens and earth. Why, surely God's promise is true; but the most of them have no knowledge\qt@no{55}}%
\qt@newcmd\qurantrans@en@mcdxx{%
He gives life, and makes to die, and to Him you shall be returned.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mcdxxi{%
O men, now there has come to you an admonition from your Lord, and a healing for what is in the breasts, and a guidance, and a mercy to the believers.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mcdxxii{%
Say: 'In the bounty of God, and His mercy -- in that let them rejoice; it is better than that they amass.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mcdxxiii{%
Say: 'Have you considered the provision God has sent down for you, and you have made some of it unlawful, and some lawful?' Say: 'Has God given you leave, or do you forge against God?'\qt@no{59}}%
\qt@newcmd\qurantrans@en@mcdxxiv{%
What will they think, who forge falsehood against God; on the Day of Resurrection? God is bountiful to men; but most of them are not thankful.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mcdxxv{%
Thou art not upon any occupation, neither recitest thou any Koran of it, nor do you any work, without that We are witnesses over you when you press on it; and not so much as the weight of an ant in earth or heaven escapes from thy Lord, neither is aught smaller than that, or greater, but in a Manifest Book.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mcdxxvi{%
Surely God's friends -- no fear shall be on them, neither shall they sorrow.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mcdxxvii{%
Those who believe, and are godfearing --\qt@no{63}}%
\qt@newcmd\qurantrans@en@mcdxxviii{%
for them is good tidings in the present life and in the world to come. There is no changing the words of God; that is the mighty triumph.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mcdxxix{%
And do not let their saying grieve thee; the glory belongs altogether to God; He is the All-hearing, the All-knowing.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mcdxxx{%
Why, surely to God belongs everyone that is in the heavens and in the earth; they follow, who call upon associates, apart from God -- they follow nothing but surmise, merely conjecturing.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcdxxxi{%
It is He who made for you the night to repose in it, and the day, to see; surely in that are signs for a people who have ears.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mcdxxxii{%
They say, 'God has taken to Him a son. Glory be to Him! He is All-sufficient; to Him belongs all that is in the heavens and in the earth; you have no authority for this. What, do you say concerning God that you know not?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mcdxxxiii{%
Say: 'Those who forge against God falsehood shall not prosper.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcdxxxiv{%
Some enjoyment in this world; then unto Us they shall return; then We shall let them taste the terrible chastisement, for that they were unbelievers.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcdxxxv{%
And recite to them the story of Noah when he said to his people, 'My people, if my standing here is grievous to you and my reminding you of the signs of God, in God have I put my trust; so resolve on your affair, with your associates, then let not your affair be a worry to you, but make decision unto me, and respite me not.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcdxxxvi{%
Then if you turn your backs, I have not asked you for any wage; my wage falls only on God, and I have been commanded to be of those that surrender.'\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcdxxxvii{%
But they cried him lies; so We delivered him, and those with him, in the Ark, and We appointed them as viceroys, and We drowned those who cried lies to Our signs; then behold how was the end of them that were warned!\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcdxxxviii{%
Then We sent forth, after him, Messengers to their people, and they brought them the clear signs; but they were not men to believe in that they had cried lies to before. So We seal the hearts of the transgressors.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcdxxxix{%
Then We sent forth, after them, Moses and Aaron to Pharaoh and his Council with Our signs, but they waxed proud, and were a sinful people.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcdxl{%
So, when the truth came to them from Us, they said, 'Surely this is a manifest sorcery.'\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcdxli{%
Moses said, 'What, do you say this to the truth, when it has come to you? Is this a sorcery? But sorcerers do not prosper.'\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcdxlii{%
They said, 'Art thou come to us to turn us from that we found our fathers practising, and that the domination in the land might belong to you two? We do not believe you.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcdxliii{%
Pharaoh said, 'Bring me every cunning sorcerer.'\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcdxliv{%
Then, when the sorcerers came, Moses said to them, 'Cast you down what you will cast.'\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcdxlv{%
Then, when they had cast, Moses said, 'What you have brought is sorcery; God will assuredly bring it to naught. God sets not right the work of those who do corruption.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcdxlvi{%
God verifies the truth by His words, though sinners be averse.'\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcdxlvii{%
So none believed in Moses, save a seed of his people, for fear of Pharaoh and their Council, that they would persecute them; and Pharaoh was high in the land, and he was one of the prodigals.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcdxlviii{%
Moses said, 'O my people, if you believe in God, in Him put your trust, if you have surrendered.'\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcdxlix{%
They said, 'In God we have put our trust. Our Lord, make us not a temptation to the people of the evildoers,\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcdl{%
and deliver us by Thy mercy from the people of the unbelievers.'\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcdli{%
And We revealed to Moses and his brother, 'Take you, for your people, in Egypt certain houses; and make your houses a direction for men to pray to; and perform the prayer; and do thou give good tidings to the believers.'\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcdlii{%
Moses said, 'Our Lord, Thou hast given to Pharaoh and his Council adornment and possessions in this present life. Our Lord, let them go astray from Thy way; Our Lord, obliterate their possessions, and harden their hearts so that they do not believe, till they see the painful chastisement.'\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcdliii{%
He said, 'Your prayer is answered; so go you straight, and follow not the way of those that know not.'\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcdliv{%
And We brought the Children of Israel over the sea; and Pharaoh and his hosts followed them insolently and impetuously till, when the drowning overtook him, he said, 'I believe that there is no god but He in whom the Children of Israel believe; I am of those that surrender.'\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcdlv{%
'Now? And before thou didst rebel, being of those that did corruption.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcdlvi{%
So today We shall deliver thee with thy body, that thou mayest be a sign to those after thee. Surely many men are heedless of Our signs.'\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcdlvii{%
And We settled the Children of Israel in a sure settlement, and We provided them with good things; so they differed not until the knowledge came to them. Surely thy Lord will decide between them on the Day of Resurrection touching their differences.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcdlviii{%
So, if thou art in doubt regarding what We have sent down to thee, ask those who recite the Book before thee. The truth has come to thee from thy Lord; so be not of the doubters,\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcdlix{%
nor be of those who cry lies to God's signs so as to be of the losers.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcdlx{%
Those against whom thy Lord's word is realized will not believe,\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcdlxi{%
though every sign come to them, till they see the painful chastisement.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcdlxii{%
Why was there never a city that believed, and its belief profited it? -- Except the people of Jonah; when they believed, We removed from them the chastisement of degradation in this present life, and We gave unto them enjoyment for a time.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcdlxiii{%
And if thy Lord had willed, whoever is in the earth would have believed, all of them, all together. Wouldst thou then constrain the people, until they are believers?\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcdlxiv{%
It is not for any soul to believe save by the leave of God; and He lays abomination upon those who have no understanding.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mcdlxv{%
Say: 'Behold what is in the heavens and in the earth!' But neither signs nor warnings avail a people who do not believe.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mcdlxvi{%
So do they watch and wait for aught but the like of the days of those who passed away before them? Say: 'Then watch and wait; I shall be with you watching and waiting.'\qt@no{102}}%
\qt@newcmd\qurantrans@en@mcdlxvii{%
Then We shall deliver Our Messengers and the believers. Even so, as is Our bounden duty, We shall deliver the believers.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mcdlxviii{%
Say: 'O men, if you are in doubt regarding my religion, I serve not those you serve apart from God, but I serve God, who will gather you to Him, and I am commanded to be of the believers, and:\qt@no{104}}%
\qt@newcmd\qurantrans@en@mcdlxix{%
``Set thy face to the religion, a man of pure faith, and be thou not of the idolaters;\qt@no{105}}%
\qt@newcmd\qurantrans@en@mcdlxx{%
and do not call, apart from God, on that which neither profits nor hurts thee, for if thou dost, then thou wilt surely be of the evildoers.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mcdlxxi{%
And if God visits thee with affliction, none can remove it but He; and if He desires any good for thee, none can repel His bounty; He causes it to fall upon whomsoever He will of His servants." He is the All-forgiving, the All-compassionate.'\qt@no{107}}%
\qt@newcmd\qurantrans@en@mcdlxxii{%
Say: 'O men, the truth has come to you from your Lord. Whosoever is guided is guided only to his own gain, and whosoever goes astray, it is only to his own loss. I am not a guardian over you.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mcdlxxiii{%
And follow thou what is revealed to thee; and be thou patient until God shall judge; and He is the best of judges.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mcdlxxiv{%
\basmalahen Alif Lam Ra. A Book whose verses are set clear, and then distinguished, from One All-wise, All-aware:\qt@no{1}}%
\qt@newcmd\qurantrans@en@mcdlxxv{%
'Serve you none but God' (I am to you a warner from Him and a bearer of good tidings)\qt@no{2}}%
\qt@newcmd\qurantrans@en@mcdlxxvi{%
and: 'Ask forgiveness of your Lord, then repent to Him, and He will give you fair enjoyment unto a term stated, and He will give of His bounty to every man of grace. But if you should turn your backs I fear for you the chastisement of a mighty day;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mcdlxxvii{%
to God shall you return; He is powerful over everything.'\qt@no{4}}%
\qt@newcmd\qurantrans@en@mcdlxxviii{%
Behold, they fold their breasts, to hide them from Him; behold, when they wrap themselves in their garments He knows what they secrete and what they publish; surely He knows all the thoughts within the breasts.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mcdlxxix{%
No creature is there crawling on the earth, but its provision rests on God; He knows its lodging-place and its repository. All is in a Manifest Book.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mcdlxxx{%
And it is He who created the heavens and the earth in six days, and His Throne was upon the waters -- that He might try you, which one of you is fairer in works. And if thou sayest, 'you shall surely be raised up after death,' the unbelievers will say, 'This is naught but a manifest sorcery.'\qt@no{7}}%
\qt@newcmd\qurantrans@en@mcdlxxxi{%
And if We postpone the chastisement from them till a reckoned moment they will say 'What is detaining it?' Surely, the day it shall come to them, it shall not be turned aside from them, and they shall be encompassed by that they mocked at.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mcdlxxxii{%
And if We let a man taste mercy from Us, and then We wrest it from him, he is desperate, ungrateful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mcdlxxxiii{%
But if We let him taste prosperity after hardship that has visited him, he will say, 'The evils have gone from me'; behold, he is joyous, boastful --\qt@no{10}}%
\qt@newcmd\qurantrans@en@mcdlxxxiv{%
save such as are patient, and do deeds of righteousness; for them awaits forgiveness and a mighty wage.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mcdlxxxv{%
Perchance thou art leaving part of what is revealed to thee, and thy breast is straitened by it, because they say, 'Why has a treasure not been sent down upon him, or an angel not come with him?' Thou art only a warner; and God is a Guardian over everything.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mcdlxxxvi{%
Or do they say, 'He has forged it'? Say: 'Then bring you ten suras the like of it, forged; and call upon whom you are able, apart from God, if you speak truly.'\qt@no{13}}%
\qt@newcmd\qurantrans@en@mcdlxxxvii{%
Then, if they do not answer you, know that it has been sent down with God's knowledge, and that there is no god but He. So have you surrendered?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mcdlxxxviii{%
Whoso desires the present life and its adornment, We will pay them in full for their works therein, and they shall not be defrauded there;\qt@no{15}}%
\qt@newcmd\qurantrans@en@mcdlxxxix{%
those are they for whom in the world to come there is only the Fire; their deeds there will have failed, and void will be their works.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcdxc{%
And what of him who stands upon a clear sign from his Lord, and a witness from Him recites it, and before him is the Book of Moses for an ensample and a mercy? Those believe in it; but whosoever disbelieves in it, being one of the partisans, his promised land is the Fire. So be thou not in doubt of it; it is the truth from thy Lord, but most men do not believe.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mcdxci{%
And who does greater evil than he who forges against God a lie? Those shall be presented before their Lord, and the witnesses will say, 'Those are they who lied against their Lord.' Surely the curse of God shall rest upon the evildoers\qt@no{18}}%
\qt@newcmd\qurantrans@en@mcdxcii{%
who bar from God's way, desiring to make it crooked; they disbelieve in the world to come;\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcdxciii{%
they are unable to frustrate Him on earth and they have no protectors, apart from God. For them the chastisement shall be doubled; they could not hear, neither did they see.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcdxciv{%
Those are they that have lost their souls, and that they forged has gone astray from them;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcdxcv{%
they without doubt will be the greatest losers in the world to come.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcdxcvi{%
But those who believe, and do righteous deeds, and have humbled themselves unto their Lord -- they shall be the inhabitants of Paradise, therein dwelling forever.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcdxcvii{%
The likeness of the two parties is as the man blind and deaf, and the man who sees and hears; are they equal in likeness? Will you not remember?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcdxcviii{%
And We sent Noah to his people: 'I am for you a warner, and a bearer of good tidings:\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcdxcix{%
Serve you none but God. I fear for you the chastisement of a painful day.'\qt@no{26}}%
\qt@newcmd\qurantrans@en@md{%
Said the Council of the unbelievers of his people, 'We see thee not other than a mortal like ourselves, and we see no? any following thee but the vilest of us, inconsiderately. We do not see you have over us any superiority; no, rather we think you are liars.'\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdi{%
He said, 'O my people, what think you? If I stand upon a clear sign from my Lord, and He has given me mercy from Him, and it has been obscured for you, shall we compel you to it while you are averse to it?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdii{%
O my people, I do not ask of you wealth for this; my wage falls only upon God. I will not drive away those who believe; they shall surely meet their Lord. But I see you are an ignorant people.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdiii{%
O my people, who would help me against God, if I drive you away?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdiv{%
Will you not remember? I do not say to you, ``I possess the treasuries of God"; I know not the Unseen; and I do not say, ``I am an angel." Nor do I say to those your eyes despise, ``God will not give them any good"; God knows best what is in their hearts. 'Surely in that case I should be among the evildoers.'\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdv{%
They said, 'Noah, thou hast disputed with us and make much disputation with us. Then bring us that thou promisest us, if thou speakest truly.'\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdvi{%
He said, 'God will bring you it if He will; you cannot frustrate Him.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdvii{%
And my sincere counsel will not profit you, if I desire to counsel you sincerely, if God desires to pervert you; He is your Lord, and unto Him you shall be returned.'\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdviii{%
(Or do they say, 'He has forged it'? Say: 'If I have forged it, upon me falls my sin; and I am quit of the sins you do.')\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdix{%
And it was revealed to Noah, saying, 'None of thy people shall believe but he who has already believed; so be thou not distressed by that they may be doing.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdx{%
Make thou the Ark under Our eyes, and as We reveal; and address Me not concerning those who have done evil; they shall be drowned.'\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdxi{%
So he was making the Ark; and whenever a council of his people passed by him they scoffed at him, He said, 'If you scoff at us, we shall surely scoff at you, as you scoff\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdxii{%
and you shall know to whom will come a chastisement degrading him, and upon whom there shall alight a lasting chastisement.'\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdxiii{%
Until, when Our command came, and the Oven boiled, We said, 'Embark in it two of every kind, and thy family -- except for him against whom the word has already been spoken and whosoever believes.' And there believed not with him except a few.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdxiv{%
He said, 'Embark in it! In God's Name shall be its course and its berthing. Surely my Lord is All-forgiving, All-compassionate.'\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdxv{%
So it ran with them amid waves like mountains; and Noah called to his son, who was standing apart, 'Embark with us, my son, and be thou not with the unbelievers!'\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdxvi{%
He said, 'I will take refuge in a mountain, that shall defend me from the water.' Said he, 'Today there is no defender from God's command but for him on whom He has mercy.' And the waves came between them, and he was among the drowned.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdxvii{%
And it was said, 'Earth, swallow thy waters; and, heaven, abate!' And the waters subsided, the affair was accomplished, and the Ark settled on El-Judi, and it was said: 'Away with the people of the evildoers!'\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdxviii{%
And Noah called unto his Lord, and said, 'O my Lord, my son is of my family, and Thy promise is surely the truth. Thou art the justest of those that judge.'\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdxix{%
Said He, 'Noah, he is not of thy family; it is a deed not righteous. Do not ask of Me that whereof thou hast no knowledge. I admonish thee, lest thou shouldst be among the ignorant.'\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdxx{%
He said, 'My Lord, I take refuge with Thee, lest I should ask of Thee that whereof I have no knowledge; for if Thou forgivest me not, and hast not mercy on me, I shall be among the losers.'\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdxxi{%
It was said, 'Noah, get thee down in peace from Us, and blessings upon thee and on the nations of those with thee; and nations -- We shall give them enjoyment, then there shall visit them from Us a painful chastisement.'\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdxxii{%
(That is of the tiding's of the Unseen, that We reveal to thee; thou didst not know it, neither thy people, before this. So be patient; the issue ultimate is to the godfearing.)\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdxxiii{%
And to Ad their brother Hood; he said, 'O my people, serve God! You have no god other than He; you are but forgers.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdxxiv{%
O my people, I do not ask of you a wage for this; my wage falls only upon Him who did originate me; will you not understand?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdxxv{%
And, O my people, ask forgiveness of your Lord, then repent to Him, and He will loose heaven in torrents upon you, and He will increase you in strength unto your strength; and turn not your backs as sinners.'\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdxxvi{%
They said, 'Hood, thou hast not brought us a clear sign, and we will not leave our gods for what thou sayest; we do not believe thee.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdxxvii{%
We say nothing, but that one of our gods has smitten thee with some evil.' He said, 'I call God to witness; and witness you, that I am quit of that you associate\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdxxviii{%
apart from Him; so try your guile on me, all together, then you shall give me no respite.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdxxix{%
Truly, I have put my trust in God, my Lord and your Lord; there is no creature that crawls, but He takes it by the forelock. Surely my Lord is on a straight path.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdxxx{%
But if you turn your backs, I have delivered to you that I was sent with unto you, and my Lord will make a people other than you successors; you will not hurt Him anything. My Lord is Guardian over everything.'\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdxxxi{%
And when Our command came, We delivered Hood and those who believed with him by a mercy from Us, and delivered them from a harsh chastisement.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdxxxii{%
That was Ad; they denied the signs of their Lord, and rebelled against His Messengers, and followed the command of every froward tyrant.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdxxxiii{%
And there was sent following after them in this world a curse, and upon the Day of Resurrection: 'Surely Ad disbelieved in their Lord: so away with Ad, the people of Hood!'\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdxxxiv{%
And to Thamood their brother Salih; he said, 'O my people, serve God! You have no god other than He. It is He who produced you from the earth and has given you to live therein; so ask forgiveness of Him, then repent to Him; surely my Lord is nigh, and answers prayer.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdxxxv{%
They said, 'Salih, thou hast hitherto been a source of hope among us. What, dost thou forbid us to serve that our fathers served? Truly we are in doubt, concerning what thou callest us to, disquieting.'\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdxxxvi{%
He said, 'O my people, what think you? If I stand upon a clear sign from my Lord, and He has given me mercy from Him, who shall help me against God if I rebel against Him? You would do nothing for me, except increase my loss.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdxxxvii{%
O my people, this is the She-camel of God, to be a sign for you. Leave her that she may eat in God's earth, and touch her not with evil, lest you' be seized by a nigh chastisement.'\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdxxxviii{%
But they hamstrung her; and he said, 'Take your joy in your habitation three days -- that is a promise not to be belied.'\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdxxxix{%
And when Our command came, We delivered Salih and those who believed with him by a mercy from Us, and from the degradation of that day; thy Lord is the All-strong, the All-mighty.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdxl{%
And the evildoers were seized by the Cry, and morning found them in their habitations fallen prostrate\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdxli{%
as if they never dwelt there: 'Surely Thamood disbelieved in their Lord, so away with Thamood!'\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdxlii{%
Our messengers came to Abraham with the good tidings; they said, 'Peace!' 'Peace,' he said; and presently he brought a roasted calf.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdxliii{%
And when he saw their hands not reaching towards it, he was suspicious of them and conceived a fear of them. They said, 'Fear not; we have been sent to the people of Lot.'\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdxliv{%
And his wife was standing by; she laughed, therefore We gave her the glad tidings of Isaac, and, after Isaac, of Jacob.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdxlv{%
She said, 'Woe is me! Shall I bear, being an old woman, and this my husband is an old man? This assuredly is a strange thing.'\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdxlvi{%
They said, 'What, dost thou marvel at God's command? The mercy of God and His blessings be upon you, O people of the House! Surely He is All-laudable, All-glorious.'\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdxlvii{%
So, when the awe departed from Abraham and the good tidings came to him, he was disputing with Us concerning the people of Lot;\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdxlviii{%
Abraham was clement, compassionate, penitent.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdxlix{%
'O Abraham, turn away from this; thy Lord's command has surely come, and there is coming upon them a chastisement not to be turned back.'\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdl{%
And when Our messengers came to Lot, he was troubled on their account and distressed for them, and he said, 'This is a fierce day.'\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdli{%
And his people came to him, running towards him; and erstwhile they had been doing evil deeds. He said, 'O my people, these are my daughters; they are cleaner for you. So fear God, and do not degrade me in my guests. What, is there not one man among you of a right mind?'\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdlii{%
They said, 'Thou knowest we have no right to thy daughters, and thou well knowest what we desire.'\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdliii{%
He said, 'O would that I had power against you, or might take refuge in a strong pillar!'\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdliv{%
They said, 'Lot, we are messengers of thy Lord. They shall not reach thee; so set forth, thou with thy family, in a watch of the night, and let not any one of you turn round, excepting thy wife; surely she shall be smitten by that which smites them. Their promised time is the morning; is the morning not nigh?'\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdlv{%
So when Our command came, We turned it uppermost nethermost, and rained on it stones of baked clay, one on another,\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdlvi{%
marked with thy Lord, and never far from the evildoers.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdlvii{%
And to Midian their brother Shuaib; he said, 'O my people, serve God! You have no god other than He. And diminish not the measure and the balance. I see you are prospering; and I fear for you the chastisement of an encompassing day.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdlviii{%
O my people, fill up the measure and the balance justly, and do not diminish the goods of the people, and do not mischief in the land, working corruption.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdlix{%
God's remainder is better for you, if you are believers. And I am not a guardian over you.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdlx{%
They said, 'Shuaib, does thy prayer command thee that we should leave that our fathers served, or to do as we will with our goods? Thou art the clement one, the right-minded.'\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdlxi{%
He said, 'O my people, what think you? If I stand upon a clear sign from my Lord, and He has provided me with fair provision from Him -- and I desire not to come behind you, betaking me to that I forbid you; I desire only to set things right, so far as I am able. My succour is only with God; in Him I have put my trust, and to Him I turn, penitent.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdlxii{%
O my people, let not the breach with me move you, so that there smite you the like of what smote the people of Noah, or the people of Hood, or the people of Salih; and the people of Lot are not far away from you.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdlxiii{%
And ask forgiveness of your Lord, then repent to Him; surely my Lord is All-compassionate, All-loving.'\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdlxiv{%
They said, 'Shuaib, we do not understand much of what thou sayest. Truly we see thee weak among us; but for thy tribe we would have stoned thee; for thou art not strong against us.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdlxv{%
He said, 'O my people, is my tribe stronger against you than God? And Him -- have you taken Him as something to be thrust behind you? My Lord encompasses the things you do.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdlxvi{%
O my people, act according to your station; I am acting; and certainly you will know to whom will come the chastisement degrading him, and who is a liar. And be upon the watch; I shall be with you, watching.'\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdlxvii{%
And when Our command came, We delivered Shuaib and those who believed with him by a mercy from Us, and the evildoers were seized by the Cry, and morning found them in their habitations fallen prostrate\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdlxviii{%
as if they had never dwelt there: 'So away with Midian, even as Thamood was done away!'\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdlxix{%
And We sent Moses with Our signs, and a manifest authority,\qt@no{96}}%
\qt@newcmd\qurantrans@en@mdlxx{%
to Pharaoh and his Council; but they followed Pharaoh's command, and Pharaoh's command was not right-minded.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mdlxxi{%
He shall go before his people on the Day of Resurrection, and will have led them down to the Fire-evil the watering-place to be led down to!\qt@no{98}}%
\qt@newcmd\qurantrans@en@mdlxxii{%
And there was sent following after them in this world a curse, and upon the Day of Resurrection -- evil the offering to be offered!\qt@no{99}}%
\qt@newcmd\qurantrans@en@mdlxxiii{%
That is of the tidings of the cities We relate to thee; some of them are standing and some stubble.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mdlxxiv{%
And We wronged them not, but they wronged themselves; their gods availed them not that they called upon, apart from God, anything, when the command of thy Lord came; and they increased them not, save in destruction.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mdlxxv{%
Such is the seizing of thy Lord, when He seizes the cities that are evildoing; surely His seizing is painful, terrible.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mdlxxvi{%
Surely in that is a sign for him who fears the chastisement in the world to come; that is a day mankind are to be gathered to, a day to witness,\qt@no{103}}%
\qt@newcmd\qurantrans@en@mdlxxvii{%
and We shall not postpone it, save to a term reckoned;\qt@no{104}}%
\qt@newcmd\qurantrans@en@mdlxxviii{%
the day it comes, no soul shall speak save by His leave; some of them shall be wretched and some happy.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mdlxxix{%
As for the wretched, they shall be in the Fire, wherein there shall be for them moaning and sighing, therein dwelling forever,\qt@no{106}}%
\qt@newcmd\qurantrans@en@mdlxxx{%
so long as the heavens and earth abide, save as thy Lord will; surely thy Lord accomplishes what He desires.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mdlxxxi{%
And as for the happy, they shall be in Paradise, therein dwelling forever, so long as the heavens and earth abide, save as thy Lord will -- for a gift unbroken.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mdlxxxii{%
So be thou not in doubt concerning what these men serve; they serve only as their fathers served before; and We shall surely pay them in full their portion undiminished.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mdlxxxiii{%
And We gave Moses the Book; and there was difference regarding it, and but for a word that preceded from thy Lord, it had been decided between them; and they are in doubt of it disquieting.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mdlxxxiv{%
Surely each one of them -- thy Lord will pay them in full for their works; He is aware of the things they do.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mdlxxxv{%
So go thou straight, as thou hast been commanded, and whoso repents with thee; and be you not insolent; surely He sees the things you do.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mdlxxxvi{%
And lean not on the evildoers, so that the Fire touches you -- you have no protectors apart from God -- and then you will not be helped.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mdlxxxvii{%
And perform the prayer at the two ends of the day and nigh of the night; surely the good deeds will drive away the evil deeds. That is a remembrance unto the mindful.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mdlxxxviii{%
And be thou patient; God will not leave to waste the wage of the good-doers.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mdlxxxix{%
Or if there had been, of the generations before you, men of a remainder forbidding corruption in the earth -- except a few of those whom We delivered of them; but the evildoers followed the ease they were given to exult in and became sinners.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mdxc{%
Yet thy Lord would never destroy the cities unjustly, while as yet their people were putting things right.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mdxci{%
Had thy Lord willed, He would have made mankind one nation; but they continue in their differences\qt@no{118}}%
\qt@newcmd\qurantrans@en@mdxcii{%
excepting those on whom thy Lord has mercy. To that end He created them, and perfectly is fulfilled the word of thy Lord: 'I shall assuredly fill Gehenna with jinn and men all together.'\qt@no{119}}%
\qt@newcmd\qurantrans@en@mdxciii{%
And all that We relate to thee of the tidings of the Messengers is that whereby We strengthen thy heart; in these there has come to thee the truth and an admonition, and a reminder to the believers.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mdxciv{%
And say to the unbelievers: 'Act you according to your station; we are acting.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mdxcv{%
And watch and wait; we are also watching and waiting.'\qt@no{122}}%
\qt@newcmd\qurantrans@en@mdxcvi{%
To God belongs the Unseen in the heavens and the earth. To Him the whole matter shall be returned; so serve Him, and put thy trust in Him. Thy Lord is not heedless of the things you do.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mdxcvii{%
\basmalahen Alif Lam Ra. Those are the signs of the Manifest Book.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdxcviii{%
We have sent it down as an Arabic Koran; haply you will understand.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdxcix{%
We will relate to thee the fairest of stories in that We have revealed to thee this Koran, though before it thou wast one of the heedless.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdc{%
When Joseph said to his father, 'Father, I saw eleven stars, and the sun and the moon; I saw them bowing down before me.'\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdci{%
He said, 'O my son, relate not thy vision to thy brothers, lest they devise against thee some guile. Surely Satan is to man a manifest enemy.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcii{%
So will thy Lord choose thee, and teach thee the interpretation of tales, and perfect His blessing upon thee and upon the House of Jacob, as He perfected it formerly on thy fathers Abraham and Isaac; surely thy Lord is All-knowing, All-wise.'\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdciii{%
(In Joseph and his brethren were signs for those who ask questions.)\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdciv{%
When they said, 'Surely Joseph and his brother are dearer to our father than we, though we are a band. Surely our father is in manifest error.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcv{%
Kill you Joseph, or cast him forth into some land, that your father's face may be free for you, and thereafter you may be a righteous people.'\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcvi{%
One of them said, 'No, kill not Joseph, but cast him into the bottom of the pit and some traveller will pick him out, if you do aught.'\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcvii{%
They said, 'Father, what ails thee, that thou trustest us not with Joseph? Surely we are his sincere well-wishers.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcviii{%
Send him forth with us tomorrow, to frolic and play; surely we shall be watching over him.'\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcix{%
He said, 'It grieves me that you should go with him, and I fear the wolf may eat him, while you are heedless of him.'\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcx{%
They said, 'If the wolf eats him, and we a band, then are we losers!'\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcxi{%
So when they went with him, and agreed to put him in the bottom of the well, and We revealed to him, 'Thou shalt tell them of this their doing when they are unaware.'\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcxii{%
And they came to their father in the evening, and they were weeping.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcxiii{%
They said, 'Father, we went running races, and left Joseph behind with our things; so the wolf ate him. But thou wouldst never believe us, though we spoke truly.'\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcxiv{%
And they brought his shirt with false blood on it. He said, 'No; but your spirits tempted you to do somewhat. But come, sweet patience! And God's succour is ever there to seek against that you describe.'\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcxv{%
Then came travellers, and they sent one of them, a water-drawer, who let down his bucket. 'Good news!' he said. 'Here is a young man.' So they hid him as merchandise; but God knew what they were doing.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcxvi{%
Then they sold him for a paltry price, a handful of counted dirhams; for they set small store by him.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcxvii{%
He that bought him, being of Egypt, said to his wife, 'Give him goodly lodging, and it may be that he will profit us, or we may take him for our own son.' So We established Joseph in the land, and that We might teach him the interpretation of tales. God prevails in His purpose, but most men know not.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcxviii{%
And when he was fully grown, We gave him judgment and knowledge. Even so We recompense the good-doers.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcxix{%
Now the woman in whose house he was solicited him, and closed the doors on them. 'Come,' she said, 'take me!' 'God be my refuge,' he said. 'Surely my lord has given me a goodly lodging. Surely the evildoers do not prosper.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcxx{%
For she desired him; and he would have taken her, but that he saw the proof of his Lord. So was it, that We might turn away from him evil and abomination; he was one of Our devoted servants.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcxxi{%
They raced to the door; and she tore his shirt from behind. They encountered her master by the door. She said, 'What is the recompense of him who purposes evil against thy folk, but that he should be imprisoned, or a painful chastisement?'\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcxxii{%
Said he, 'It was she that solicited me'; and a witness of her folk bore witness, 'If his shirt has been torn from before then she has spoken truly, and he is one of the liars;\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcxxiii{%
but if it be that his shirt has been torn from behind, then she has lied, and he is one of the truthful.'\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcxxiv{%
When he saw his shirt was torn from behind he said, 'This is of your women's guile; surely your guile is great.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcxxv{%
Joseph, turn away from this; and thou, woman, ask forgiveness of thy crime; surely thou art one of the sinners.'\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcxxvi{%
Certain women that were in the city said, 'The Governor's wife has been soliciting her page; he smote her heart with love; we see her in manifest error.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcxxvii{%
When she heard their sly whispers, she sent to them, and made ready for them a repast, then she gave to each one of them a knife. 'Come forth, attend to them,' she said. And when they saw him, they so admired him that they cut their hands, saying, 'God save us! This is no mortal; he is no other but a noble angel.'\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcxxviii{%
'So now you see, she said. 'This is he you blamed me for. Yes, I solicited him, but he abstained. Yet if he will not do what I command him, he shall be imprisoned, and be one of the humbled.'\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcxxix{%
He said, 'My Lord, prison is dearer to me than that they call me to; yet if Thou turnest not from me their guile, then I shall yearn towards them, and so become one of the ignorant.'\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcxxx{%
So his Lord answered him, and He turned away from him their guile; surely He is the All-hearing, the All-knowing.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcxxxi{%
Then it seemed good to them, after they had seen the signs, that they should imprison him for a while.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcxxxii{%
And there entered the prison with him two youths. Said one of them, 'I dreamed that I was pressing grapes. Said the other, 'I dreamed that I was carrying on my head bread, that birds were eating of. Tell us its interpretation; we see that thou art of the good-doers.'\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcxxxiii{%
He said, 'No food shall come to you for your sustenance, but ere it comes to you I shall tell you its interpretation. That I shall tell you is of what God has taught me. I have forsaken the creed of a people who believe not in God and who moreover are unbelievers in the world to come.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcxxxiv{%
And I have followed the creed of my fathers, Abraham, Isaac and Jacob. Not ours is it to associate aught with God. That is of God's bounty to us, and to men; but most men are not thankful.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcxxxv{%
Say, which is better, my fellow-prisoners -- many gods at variance, or God the One, the Omnipotent?\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdcxxxvi{%
That which you serve, apart from Him, is nothing but names yourselves have named, you and your fathers; God has sent down no authority touching them. Judgment belongs only to God; He has commanded that you shall not serve any but Him. That is the right religion; but most men know not.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdcxxxvii{%
Fellow-prisoners, as for one of you, he shall pour wine for his lord; as for the other, he shall be crucified, and birds will eat of his head. The matter is decided whereon you enquire.'\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdcxxxviii{%
Then he said to the one he deemed should be saved of the two, 'Mention me in thy lord's presence.' But Satan caused him to forget to mention him to his master, so that he continued in the prison for certain years.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdcxxxix{%
And the king said, 'I saw in a dream seven fat kine, and seven lean ones devouring them; likewise seven green ears of corn, and seven withered. My counsellors, pronounce to me upon my dream, if you are expounders of dreams.'\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdcxl{%
'A hotchpotch of nightmares!' they said. 'We know nothing of the interpretation of nightmares.'\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdcxli{%
Then said the one who had been delivered, remembering after a time, 'I will myself tell you its interpretation; so send me forth.'\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdcxlii{%
'Joseph, thou true man, pronounce to us regarding seven fat kine, that seven lean ones were devouring, seven green ears of corn, and seven withered; haply I shall return to the men, haply they will know.'\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdcxliii{%
He said, 'You shall sow seven years after your wont; what you have harvested leave in the ear, excepting a little whereof you eat.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdcxliv{%
Then thereafter there shall come upon you seven hard years, that shall devour what you have laid up for them, all but a little you keep in store.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdcxlv{%
Then thereafter there shall come a year wherein the people will be succoured and press in season.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdcxlvi{%
The king said, 'Bring him to me!' And when the messenger came to him, he said, 'Return unto thy lord, and ask of him, ``What of the women who cut their hands?" Surely my Lord has knowledge of their guile.'\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdcxlvii{%
'What was your business, women,' he said, 'when you solicited Joseph?' 'God save us!' they said. 'We know no evil against him.' The Governor's wife said, 'Now the truth is at last discovered; I solicited him; he is a truthful man.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcxlviii{%
'That, so that he may know I betrayed him not secretly, and that God guides not the guile of the treacherous.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdcxlix{%
Yet I claim not that my soul was innocent -- surely the soul of man incites to evil -- except inasmuch as my Lord had mercy; truly my Lord is All-forgiving, All-compassionate.'\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdcl{%
The king said, 'Bring him to me! I would attach him to my person.' Then, when he had spoken with him, he said, 'Today thou art established firmly in our favour and in our trust.'\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdcli{%
He said, 'Set me over the land's storehouses; I am a knowing guardian.'\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdclii{%
So We established Joseph in the land, to make his dwelling there wherever he would. We visit with Our mercy whomsoever We will, and We leave not to waste the wage of the good-doers.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdcliii{%
Yet is the wage of the world to come better for those who believe, and are godfearing.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdcliv{%
And the brethren of Joseph came, and entered unto him, and he knew them, but they knew him not.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdclv{%
When he had equipped them with their equipment be said, 'Bring me a certain brother of yours from your father. Do you not see that I fill up the measure, and am the best of hosts?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdclvi{%
But if you bring him not to me, there shall be no measure for you with me, neither shall you come nigh me.'\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdclvii{%
They said, 'We will solicit him of our father; that we will do.'\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdclviii{%
He said to his pages, 'Put their merchandise in their saddlebags; haply they will recognize it when they have turned to their people; haply they will return.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdclix{%
So, when they had returned to their father, they said, 'Father, the measure was denied to us; so send with us our brother, that we may obtain the measure; surely we shall be watching over him.'\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdclx{%
He said, 'And shall I entrust him to you otherwise than as I entrusted before his brother to you? Why, God is the best guardian, and He is the most merciful of the merciful.'\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdclxi{%
And when they opened their things, they found their merchandise, restored to them. 'Father,' they said, 'what more should we desire? See, our merchandise here is restored to us. We shall get provision for our family, and we shall be watching over our brother; we shall obtain an extra camel's load -- that is an easy measure.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdclxii{%
He said, 'Never will I send him with you until you bring me a solemn pledge by God that you will surely bring him back to me unless it be that you are encompassed.' When they had brought him their solemn pledge he said, 'God shall be Guardian over what we say.'\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdclxiii{%
He also said, 'O my sons, enter not by one door; enter by separate doors. Yet I cannot avail you anything against God; judgment belongs not to any but God. In Him I have put my trust; and in Him let all put their trust who put their trust.'\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdclxiv{%
And when they entered after the manner their father commanded them, it availed them nothing against God; but it was a need in Jacob's soul that he so satisfied. Verily he was possessed of a knowledge for that We had taught him; but most men know not.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdclxv{%
And when they entered unto Joseph, he said, taking his brother into his arms, 'I am thy brother; so do not despair of that they have done.'\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdclxvi{%
Then, when he had equipped them with their equipment, he put his drinking-cup into the saddlebag of his brother. Then a herald proclaimed, 'Ho, cameleers, you are robbers!'\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdclxvii{%
They said, turning to them, 'What is it that you are missing?'\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdclxviii{%
They said, 'We are missing the king's goblet. Whoever brings it shall receive a camel's load; that I guarantee.'\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdclxix{%
'By God,' they said, 'you know well that we came not to work corruption in the land. We are not robbers.'\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdclxx{%
They said, 'And what shall be its recompense if you are liars?'\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdclxxi{%
They said, 'This shall be its recompense -- in whoever's saddlebag the goblet is found, he shall be its recompense. So we recompense the evildoers.'\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdclxxii{%
So he made beginning with their sacks, before his brother's sack, then he pulled it out of his brother's sack. So We contrived for Joseph's sake; he could not have taken his brother, according to the king's doom, except that God willed. Whomsoever We will, We raise in rank; over every man of knowledge is One who knows.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdclxxiii{%
They said, 'If he is a thief, a brother of his was a thief before.' But Joseph secreted it in his soul and disclosed it not to them, saying, 'You are in a worse case; God knows very well what you are describing.'\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdclxxiv{%
They said, 'Mighty prince, he has a father, aged and great with years; so take one of us in his place; we see that thou art one of the good-doers.'\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdclxxv{%
He said, 'God forbid that we should take any other but him in whose possession we found the goods; for if we did so, we would be evildoers.'\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdclxxvi{%
When they despaired of moving him, they conferred privily apart. Said the eldest of them, 'Do you not know how your father has taken a solemn pledge from you by God, and aforetime you failed regarding Joseph? Never will I quit this land, until my father gives me leave, or God judges in my favour; He is the best of judges.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdclxxvii{%
Return you all to your father, and say, ``Father, thy son stole; we do not testify except that we know; we were no guardians of the Unseen.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdclxxviii{%
Enquire of the city wherein we were, and the caravan in which we approached; surely we are truthful men".'\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdclxxix{%
'No!' he said 'But your spirits tempted you to do somewhat. But come, sweet patience! Haply God will bring them all to me; He is the All-knowing, the All-wise.'\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdclxxx{%
And he turned away from them, and said, 'Ah, woe is me for Joseph!' And his eyes turned white because of the sorrow that he choked within him.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdclxxxi{%
'By God,' they said, 'thou wilt never cease mentioning Joseph till thou art consumed, or among the perishing.'\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdclxxxii{%
He said, 'I make complaint of my anguish and my sorrow unto God; I know from God that you know not.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdclxxxiii{%
Depart, my sons, and search out tidings of Joseph and his brother. Do not despair of God's comfort; of God's comfort no man despairs, excepting the people of the unbelievers.'\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdclxxxiv{%
So, when they entered unto him, they said, 'O mighty prince, affliction has visited us and our people. We come with merchandise of scant worth. Fill up to us the measure, and be charitable to us; surely God recompenses the charitable.'\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdclxxxv{%
He said, 'Are you aware of what you did with Joseph and his brother, when you were ignorant?'\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdclxxxvi{%
They said, 'Why, art thou indeed Joseph?' 'I am Joseph,' he said. 'This is my brother. God has indeed been gracious unto us. Whosoever fears God, and is patient -- surely God leaves not to waste the wage of the good-doers.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdclxxxvii{%
'By God,' they said, 'God has indeed preferred thee above us, and certainly we have been sinful.'\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdclxxxviii{%
He said, 'No reproach this day shall be on you; God will forgive you; He is the most merciful of the merciful.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdclxxxix{%
Go, take this shirt, and do you cast it on my father's face, and he shall recover his sight; then bring me your family all together.'\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdcxc{%
So, when the caravan set forth, their father said, 'Surely I perceive Joseph's scent, unless you think me doting.'\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdcxci{%
They said, 'By God, thou art certainly in thy ancient error.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdcxcii{%
But when the bearer of good tidings came to him, and laid it on his face, forthwith he saw once again. He said, 'Did I not tell you I know from God that you know not?'\qt@no{96}}%
\qt@newcmd\qurantrans@en@mdcxciii{%
They said, 'Our father, ask forgiveness of our crimes for us; for certainly we have been sinful.'\qt@no{97}}%
\qt@newcmd\qurantrans@en@mdcxciv{%
He said, 'Assuredly I will ask my Lord to forgive you; He is the All-forgiving, the All-compassionate.'\qt@no{98}}%
\qt@newcmd\qurantrans@en@mdcxcv{%
So, when they entered unto Joseph, he took his father and mother into his arms saying, 'Enter you into Egypt, if God will, in security.'\qt@no{99}}%
\qt@newcmd\qurantrans@en@mdcxcvi{%
And he lifted his father and mother upon the throne; and the others fell down prostrate before him. 'See, father,' he said, 'this is the interpretation of my vision of long ago; my Lord has made it true. He was good to me when He brought me forth from the prison, and again when He brought you out of the desert, after that Satan set at variance me and my brethren. My Lord is gentle to what He will; He is the All-knowing, the All-wise.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mdcxcvii{%
O my Lord, Thou hast given me to rule, and Thou hast taught me the interpretation of tales. O Thou, the Originator of the heavens and earth, Thou art my Protector in this world and the next. O receive me to Thee in true submission, and join me with the righteous.'\qt@no{101}}%
\qt@newcmd\qurantrans@en@mdcxcviii{%
That is of the tidings of the Unseen that We reveal to thee; thou wast not with them when they agreed upon their plan, devising.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mdcxcix{%
Yet, be thou ever so eager, the most part of men believe not.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mdcc{%
Thou askest of them no wage for it; it is nothing but a reminder unto all beings.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mdcci{%
How many a sign there is in the heavens and in the earth that they pass by, turning away from it!\qt@no{105}}%
\qt@newcmd\qurantrans@en@mdccii{%
And the most part of them believe not in God, but they associate other gods with Him.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mdcciii{%
Do they feel secure that there shall come upon them no enveloping of the chastisement of God, or that the Hour shall not come upon them suddenly when they are unaware?\qt@no{107}}%
\qt@newcmd\qurantrans@en@mdcciv{%
Say: 'This is my way. I call to God with sure knowledge, I and whoever follows after me. To God be glory! And I am not among the idolaters.'\qt@no{108}}%
\qt@newcmd\qurantrans@en@mdccv{%
We sent not forth any before thee, but men We revealed to of the people living in the cities. Have they not journeyed in the land? Have they not beheld how was the end of those before them?. Surely the abode of the world to come is better for those that are godfearing. What, do you not understand?\qt@no{109}}%
\qt@newcmd\qurantrans@en@mdccvi{%
Till, when the Messengers despaired, deeming they were counted liars, Our help came to them and whosoever We willed was delivered. Our might will never be turned back from the people of the sinners.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mdccvii{%
In their stories is surely a lesson to men possessed of minds; it is not a tale forged, but a confirmation of what is before it, and a distinguishing of every thing, and a guidance, and a mercy to a people who believe.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mdccviii{%
\basmalahen Alif Lam Mim Ra. Those are the signs of the Book; and that which has been sent down to thee from thy Lord is the truth, but most men do not believe.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdccix{%
God is He who raised up the heavens without pillars you can see, then He sat Himself upon the Throne. He subjected the sun and the moon, each one running to a term stated. He directs the affair; He distinguishes the signs; haply you will have faith in the encounter with your Lord.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdccx{%
It is He who stretched out the earth and set therein firm mountains and rivers, and of every fruit He placed there two kinds, covering the day with the night. Surely in that are signs for a people who reflect.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdccxi{%
And on the earth are tracts neighbouring each to each, and gardens of vines, and fields sown, and palms in pairs, and palms single, watered with one water; and some of them We prefer in produce above others. Surely in that are signs for a people who understand.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdccxii{%
If thou wouldst wonder, surely wonderful is their saying, 'What, when we are dust shall we indeed then be raised up again in new creation?' Those are they that disbelieve in their Lord; those -- on their necks are fetters; those shall be the inhabitants of the Fire, therein dwelling forever.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdccxiii{%
They would have thee hasten the evil ere the good; yet there have passed away before them examples. Thy Lord is forgiving to men, for all their evil-doing, and thy Lord is terrible in retribution.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdccxiv{%
The unbelievers say, 'Why has a sign not been sent down upon him from his Lord?' Thou art only a warner, and a guide to every people.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdccxv{%
God knows what every female bears, and the wombs' shrinking and swelling; everything with Him has its measure --\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdccxvi{%
the Knower of the unseen and the visible, the All-great, the All-exalted:\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdccxvii{%
Alike of you is he who conceals his -- saying, and he who proclaims it, he who hides himself in the night, and he who sallies by day;\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdccxviii{%
he has attendant angels, before him and behind him, watching over him by God's command. God changes not what is in a people, until they change what is in themselves. Whensover God desires evil for a people, there is no turning it back; apart from Him, they have no protector.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdccxix{%
It is He who shows you the lightning, for fear and hope, and produces the heavy clouds;\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdccxx{%
the thunder proclaims. His praise, and the angels, in awe of Him. He looses the thunderbolts, and smites with them whomsoever He will; yet they dispute about God, who is mighty in power.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdccxxi{%
To Him is the call of truth; and those upon whom they call, apart from Him, answer them nothing, but it is as a man who stretches out his hands to water that it may reach his mouth, and it reaches it not. The prayer of the unbelievers goes only astray.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdccxxii{%
To God bow all who are in the heavens and the earth, willingly or unwillingly, as do their shadows also in the mornings and the evenings.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdccxxiii{%
Say: 'Who is the Lord of the heavens and of the earth?' Say: 'God.' Say: 'Then have you taken unto you others beside Him to be your protectors, even such as have no power to profit or hurt themselves?' Say: 'Are the blind and the seeing man equal, or are the shadows and the light equal? Or have they ascribed to God associates who created as He created, so that creation is all alike to them?' Say: 'God is the Creator of everything, and He is the One, the Omnipotent.'\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdccxxiv{%
He sends down out of heaven water, and the wadis flow each in its measure, and the torrent carries a swelling scum; and out of that over which they kindle fire, being desirous of ornament or ware, out of that rises a scum the like of it. So God strikes both the true and the false. As for the scum, it vanishes as jetsam, and what profits men abides in the earth. Even so God strikes His similitudes.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdccxxv{%
For those who answer their Lord, the reward most fair; and those who answer Him not -- if they possessed all that is in the earth and the like of it with it, they would offer it for their ransom. Those theirs shall be the evil reckoning, and their refuge shall be Gehenna -- an evil cradling!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdccxxvi{%
What, is he who knows what is sent down to thee from thy Lord is the truth, like him who is blind? Only men possessed of minds remember;\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdccxxvii{%
who fulfil God's covenant, and break not the compact,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdccxxviii{%
who join what God has commanded shall be joined, and fear their Lord, and dread the evil reckoning,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdccxxix{%
patient men, desirous of the Face of their Lord, who perform the prayer, and expend of that We have provided them, secretly and in public, and who avert evil with good -- theirs shall be the Ultimate Abode,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdccxxx{%
Gardens of Eden which they shall enter; and those who were righteous of their fathers, and their wives, and their seed, shall enter them, and the angels shall enter unto them from every gate:\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdccxxxi{%
'Peace be upon you, for that you were patient.' Fair is the Ultimate Abode.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdccxxxii{%
And those who break the covenant of God after His compact, and who snap what God has commanded to be joined, and who work corruption in the earth -- theirs shall be the curse, and theirs the Evil Abode.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdccxxxiii{%
God outspreads and straitens His provision unto whomsoever He will. They rejoice in this present life; and this present life, beside the world to come, is naught but passing enjoyment.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdccxxxiv{%
The unbelievers say, 'Why has a sign not been sent down upon him from his Lord?' Say: 'God leads astray whomsoever He will, and He guides to Him all who are penitent.'\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdccxxxv{%
Those who believe, their hearts being at rest in God's remembrance -- in God's remembrance are at rest the hearts\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdccxxxvi{%
of those who believe and do righteous deeds; theirs is blessedness and a fair resort.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdccxxxvii{%
Thus We have sent thee among a nation before which other nations have passed away, to recite to them that We have revealed to thee; and yet they disbelieve in the All-merciful. Say: 'He is my Lord -- there is no god but He. In Him I have put my trust, and to Him I turn.'\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdccxxxviii{%
If only a Koran whereby the mountains were set in motion, or the earth were cleft, or the dead were spoken to -- nay, but God's is the affair altogether. Did not the believers know that, if God had willed, He would have guided men all together? And still the unbelievers are smitten by a shattering for what they wrought, or it alights nigh their habitation, until God's promise comes; and God will not fail the tryst.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdccxxxix{%
Messengers indeed were scoffed at before thee, and I respited the unbelievers; then I seized them -- and how was my retribution?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdccxl{%
What, He who stands over every soul for what it has earned? -- And yet they ascribe to God associates. Say: 'Name them! Or will you tell Him what He knows not in the earth? Or in apparent words?' Nay; but decked out fair to the unbelievers is their devising, and they are barred from the way; and whomsoever God leads astray, no guide has he.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdccxli{%
For them is chastisement in the present life; and the chastisement of the world to come is yet more grievous; they have none to defend them from God.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdccxlii{%
The likeness of Paradise, that is promised to the godfearing: beneath it rivers flow, its produce is eternal, and its shade. That is the requital of the god-fearing; and the requital of the unbelievers is -- the Fire!\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdccxliii{%
And those to whom We have given the Book rejoice in what is sent down unto thee; and of the parties some reject some of it. Say: 'I have only been commanded to serve God, and not to associate aught with Him. To Him I call, and to Him I turn.'\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdccxliv{%
Even so We have sent it down as an Arabic judgment. And if thou dost follow their caprices, after the knowledge that has come to thee, thou shalt have no protector against God, and no defender.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdccxlv{%
And We sent Messengers before thee, and We assigned to them wives, and seed; and it was not for any Messengers to bring a sign, but by God's leave. Every term has a Book.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdccxlvi{%
God blots out, and He establishes whatsoever He will; and with Him is the Essence of the Book.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdccxlvii{%
Whether We show thee a part of that We promise them, or We call thee to Us, it is thine only to deliver the Message, and Ours the reckoning.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdccxlviii{%
Have they not seen how We come to the land diminishing it in its extremities? God judges; none repels His judgment; He is swift at the reckoning.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdccxlix{%
Those that were before them devised; but God's is the devising altogether. He knows what every soul earns. The unbelievers shall assuredly know whose will be the Ultimate Abode.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdccl{%
The unbelievers say, 'Thou art not an Envoy.' Say: 'God suffices as a witness between me and you, and whosoever possesses knowledge of the Book.'\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdccli{%
\basmalahen Alif Lam Ra. A Book We have sent down to thee that thou mayest bring forth mankind from the shadows to the light by the leave of their Lord, to the path of the All-mighty, the All-laudable,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdcclii{%
God, to whom belongs all that is in the heavens and all that is in the earth. And woe to the unbelievers for a terrible chastisement,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdccliii{%
such as prefer the present life over the world to come, and bar from God's way, desiring to make it crooked -- they are in far error.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdccliv{%
And We have sent no Messenger save with the tongue of his people, that he might make all clear to them; then God leads astray whomsoever He will, and He guides whomsoever He will; and He is the All-mighty, the All-wise.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdcclv{%
And We sent Moses with Our signs -- 'Bring forth thy people from the shadows to the light and remind thou them of the Days of God.' Surely in that are signs for every man enduring, thankful!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcclvi{%
And when Moses said to his people, 'Remember God's blessing upon you when He delivered you from the folk of Pharaoh, who were visiting you with evil chastisement, slaughtering your sons, and sparing your women -- and in that was a grievous trial from your Lord.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdcclvii{%
And when your Lord proclaimed, ``If you are thankful, surely I will increase you, but if you are thankless My chastisement is surely terrible."'\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdcclviii{%
And Moses said, 'If you are thankless, you and whoso is on earth, all together, yet assuredly God is All-sufficient, All-laudable.'\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcclix{%
Has there not come to you the tidings of those who were before you -- the people of Noah, Ad, Thamood, and of those after them whom none knows but God? Their Messengers came to them with the clear signs; but they thrust their hands into their mouths, saying, 'We certainly disbelieve in the Message you have been sent with, and we are in doubt, concerning that you call us unto, disquieting.'\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcclx{%
Their Messengers said, 'Is there any doubt regarding God, the Originator of the heavens and the earth, who calls you so that He may forgive you your sins, and defer you to a term stated?' They said, 'You are nothing but mortals, like us; you desire to bar us from that our fathers served; then bring us a manifest authority.'\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcclxi{%
Their Messengers said to them, 'We are nothing but mortals, like you; but God is gracious unto whomsoever He will of His servants. It is not for us to bring you an authority save by the leave of God; and in God let the believers put all their trust.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcclxii{%
And why should we not put our trust in God, seeing that He has guided us in our ways? We will surely endure patiently, whatever you hurt us; and in God let all put their trust who put their trust.'\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcclxiii{%
The unbelievers said to their Messengers, 'We will assuredly expel you from our land, or you will surely return into our creed.' Then did their Lord reveal unto them: 'We will surely destroy the evildoers,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcclxiv{%
and We will surely make you to dwell in the land after them -- that, for him who fears My station and fears My threat.'\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcclxv{%
They sought a judgment; then was disappointed every froward tyrant --\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcclxvi{%
beyond him Gehenna, and he is given to drink of oozing pus,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcclxvii{%
the which he gulps, and can scarce swallow, and death comes upon him from every side, yet he cannot die; and still beyond him is a harsh chastisement.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcclxviii{%
The likeness of those who disbelieve in their Lord: their works are as ashes, whereon the wind blows strong upon a tempestuous day; they have no power over that they have earned - that is the far error!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcclxix{%
Hast thou not seen that God created the heavens and the earth in truth? If He will, He can put you away and bring a new creation;\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcclxx{%
that is surely no great matter for God.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcclxxi{%
They sally forth unto God, all together; then say the weak to those who waxed proud, 'We were your followers; will you avail us against the chastisement of God anything?' They say, 'If God had guided us, we would have guided you. Alike it is for us whether we cannot endure, or whether we are patient; we have no asylum.'\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcclxxii{%
And Satan says, when the issue is decided, 'God surely promised you a true promise; and I promised you, then I failed you, for I had no authority over you, but that I called you, and you answered me. So do not blame me, but blame yourselves; I cannot aid you, neither can you aid me. I disbelieved in your associating me with God aforetime.' As for the evildoers, for them awaits a painful chastisement;\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcclxxiii{%
but as for those who believe, and do deeds of righteousness, they shall be admitted to gardens underneath which rivers flow, therein dwelling forever, by the leave of their Lord, their greeting therein: 'Peace!'\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcclxxiv{%
Hast thou not seen how God has struck a similitude? A good word is as a good tree -- its roots are firm, and its branches are in heaven;\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcclxxv{%
it gives its produce every season by the leave of its Lord. So God strikes similitudes for men; haply they will remember.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcclxxvi{%
And the likeness of a corrupt word is as a corrupt tree -- uprooted from the earth, having no stablishment.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcclxxvii{%
God confirms those who believe with the firm word, in the present life and in the world to come; and God leads astray the evildoers; and God does what He will.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcclxxviii{%
Hast thou not seen those who exchanged the bounty of God with unthankfulness, and caused their people to dwell in the abode of ruin? --\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcclxxix{%
Gehenna, wherein they are roasted; an evil stablishment!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcclxxx{%
And they set up compeers to God, that they might lead astray from His way. Say: 'Take your joy! Your homecoming shall be -- the Fire!'\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcclxxxi{%
Say to My servants who believe, that they perform the prayer, and expend of that We have provided them, secretly and in public, before a day comes wherein shall be neither bargaining nor befriending.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcclxxxii{%
It is God who created the heavens and the earth, and sent down out of heaven water wherewith He brought forth fruits to be your sustenance. And He subjected to you the ships to run upon the sea at His commandment; and He subjected to you the rivers\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcclxxxiii{%
and He subjected to you the sun and moon constant upon their courses, and He subjected to you the night and day,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcclxxxiv{%
and gave you of all you asked Him. If you count God's blessing, you will never number it; surely man is sinful, unthankful!\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcclxxxv{%
And when Abraham said, 'My Lord, make this land secure, and turn me and my sons away from serving idols;\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcclxxxvi{%
my Lord, they have led astray many men. Then whoso follows me belongs to me; and whoso rebels against me, surely Thou art All-forgiving, All-compassionate.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcclxxxvii{%
Our Lord, I have made some of my seed to dwell in a valley where is no sown land by Thy Holy House; Our Lord, let them perform the prayer, and make hearts of men yearn towards them, and provide them with fruits; haply they will be thankful.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcclxxxviii{%
Our Lord, Thou knowest what we keep secret and what we publish; from God nothing whatever is hidden in earth and heaven.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcclxxxix{%
Praise be to God, who has given me, though I am old, Ishmael and Isaac; surely my Lord hears the petition.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdccxc{%
My Lord, make me a performer of the prayer, and of my seed. Our Lord, and receive my petition.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdccxci{%
Our Lord, forgive Thou me and my parents, and the believers, upon the day when the reckoning shall come to pass.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdccxcii{%
Deem not that God is heedless of what the evildoers work; He is only deferring them to a day when eyes shall stare,\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdccxciii{%
when they shall run with necks outstretched and heads erect, their glances never returned on themselves, their hearts void.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdccxciv{%
And warn mankind of the day when the chastisement comes on them, And those who did evil shall say, 'Our Lord, defer us to a near term, and we will answer Thy call, and follow the Messengers.' 'Ah, but did you not swear aforetime there should be no removing for you?\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdccxcv{%
And you dwelt in the dwelling-places of those who wronged themselves, and it became clear to you how We did with them, and how We struck similitudes for you.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdccxcvi{%
They devised their devising, and their devising is known to God; though their devising were such as to remove mountains.'\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdccxcvii{%
So do not deem that God will fail in His promise to His Messengers; surely God is All-mighty, Vengeful.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdccxcviii{%
Upon the day the earth shall be changed to other than the earth, and the heavens and they sally forth unto God, the One, the Omnipotent.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdccxcix{%
And thou shalt see the sinners that day coupled in fetters,\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdccc{%
of pitch their shirts, their faces enveloped by the Fire,\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdccci{%
that God may recompense every soul for its earnings; surely God is swift at the reckoning.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcccii{%
This is a Message to be delivered to mankind that they may be warned by it, and that they may know that He is One God, and that all possessed of minds may remember.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdccciii{%
\basmalahen Alif Lam Ra. Those are the signs of the Book and of a manifest Koran.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdccciv{%
Perchance the unbelievers will wish that they had surrendered:\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdcccv{%
leave them to eat, and to take their joy, and to be bemused by hope; certainly they will soon know!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdcccvi{%
Never a city have We destroyed, but it had a known decree,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdcccvii{%
and no nation outstrips its term, nor do they put it back.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcccviii{%
They say: 'Thou, upon whom the Remembrance is sent down, thou art assuredly possessed!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdcccix{%
Why dost thou not bring the angels unto us, if thou speakest truly?'\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdcccx{%
We send not down the angels, save with truth;\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcccxi{%
then they would not be respited. It is We who have sent down the Remembrance, and We watch over it.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcccxii{%
Indeed, We sent Messengers before thee, among the factions of the ancients,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcccxiii{%
and not a single Messenger came to them, but they mocked at him;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcccxiv{%
even so We cause it to enter into the hearts of the sinners --\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcccxv{%
they believe not in it, though the wont of the ancients is already gone.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcccxvi{%
Though We opened to them a gate in heaven, and still they mounted through it,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcccxvii{%
yet would they say, 'Our eyes have been dazzled; nay, we are a people bewitched!'\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcccxviii{%
We have set in heaven constellations and decked them out fair to the beholders,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcccxix{%
and guarded them from every accursed Satan\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcccxx{%
excepting such as listens by stealth -- and he is pursued by a manifest flame.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcccxxi{%
And the earth -- We stretched it forth, and cast on it firm mountains, and We caused to grow therein of every thing justly weighed,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcccxxii{%
and there appointed for you livelihood, and for those you provide not for.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcccxxiii{%
Naught is there, but its treasuries are with Us, and We send it not down but in a known measure.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcccxxiv{%
And We loose the winds fertilising, and We send down out of heaven water, then We give it to you to drink, and you are not its treasurers.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcccxxv{%
It is We who give life, and make to die, and it is We who are the inheritors.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcccxxvi{%
We know the ones of you who press forward, and We know the laggards;\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcccxxvii{%
and it is thy Lord shall muster them, and He is All-wise, All-knowing.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcccxxviii{%
Surely We created man of a clay of mud moulded,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcccxxix{%
and the jinn created We before of fire flaming.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcccxxx{%
And when thy Lord said to the angels, 'See, I am creating a mortal of a clay of mud moulded.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcccxxxi{%
When I have shaped him, and breathed My spirit in him, fall you down, bowing before him!'\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcccxxxii{%
Then the angels bowed themselves all together,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcccxxxiii{%
save Iblis; he refused to be among those bowing.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcccxxxiv{%
Said He, 'What ails thee, Iblis, that thou art not among those bowing?'\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcccxxxv{%
Said he, 'I would never bow myself before a mortal whom Thou hast created of a clay of mud moulded.'\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcccxxxvi{%
Said He, 'Then go thou forth hence; thou art accursed.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcccxxxvii{%
Upon thee shall rest the curse, till the Day of Doom.'\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcccxxxviii{%
Said he, 'My Lord, respite me till the day they shall be raised.'\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcccxxxix{%
Said He, 'Thou art among the ones that are respited\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcccxl{%
unto the day of a known time.'\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcccxli{%
Said he, 'My Lord, for Thy perverting me I shall deck all fair to them in the earth, and I shall pervert them, all together,\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdcccxlii{%
excepting those Thy servants among them that are devoted.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdcccxliii{%
Said He, 'This is for Me a straight path:\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdcccxliv{%
over My servants thou shalt have no authority, except those that follow thee,\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdcccxlv{%
being perverse; Gehenna shall be their promised land all together.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdcccxlvi{%
Seven gates it has, and unto each gate a set portion of them belongs.'\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdcccxlvii{%
But the godfearing shall be amidst gardens and fountains:\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdcccxlviii{%
'Enter you them, in peace and security!'\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdcccxlix{%
We shall strip away all rancour that is in their breasts; as brothers they shall be upon couches set face to face;\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdcccl{%
no fatigue there shall smite them, neither shall they ever be driven forth from there.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdcccli{%
Tell My servants I am the All-forgiving, the All-compassionate,\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdccclii{%
and that My chastisement is the painful chastisement.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdcccliii{%
And tell them of the guests of Abraham,\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcccliv{%
when they entered unto him, saying, 'Peace!' He said, 'Behold, we are afraid of you.'\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdccclv{%
They said, 'Be not afraid; behold, we give thee good tidings of a cunning boy.'\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdccclvi{%
He said, 'What, do you give me good tidings, though old age has smitten me? Of what do you\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdccclvii{%
give me good tidings?' They said, 'We give thee good tidings of truth. Be not of those that despair.'\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdccclviii{%
He said, 'And who despairs of the mercy of his Lord, excepting those that are astray?'\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdccclix{%
He said, 'And what is your business, envoys?'\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdccclx{%
They said, 'We have been sent unto a people of sinners,\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdccclxi{%
excepting the folk of Lot; them we shall deliver\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdccclxii{%
all together, excepting his wife -- we have decreed, she shall surely be of those that tarry.'\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdccclxiii{%
So, when the envoys came to the folk of Lot,\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdccclxiv{%
he said, 'Surely you are a people unknown to me!'\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdccclxv{%
They said, 'Nay, but we have brought thee that concerning which they were doubting.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdccclxvi{%
We have come to thee with the truth, and assuredly we speak truly.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdccclxvii{%
So set forth, thou with thy family, in a watch of the night, and follow after the backs of them, and let not any one of you turn round; and depart unto the place you are commanded.'\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdccclxviii{%
And We decreed for him that commandment, that the last remnant of those should be cut off in the morning.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdccclxix{%
And the people of the city came rejoicing.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdccclxx{%
He said, 'These are my guests; put me not to shame,\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdccclxxi{%
and fear God, and do not degrade me.'\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdccclxxii{%
They said, 'Have we not forbidden thee all beings?'\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdccclxxiii{%
He said, 'These are my daughters, if you would be doing.'\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdccclxxiv{%
By thy life, they wandered blindly in their dazzlement,\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdccclxxv{%
and the Cry seized them at the sunrise,\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdccclxxvi{%
and We turned it uppermost nethermost and rained on it stones of baked clay.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdccclxxvii{%
Surely in that are signs for such as mark;\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdccclxxviii{%
surely it is on a way yet remaining;\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdccclxxix{%
surely in that is a sign for believers.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdccclxxx{%
Certainly the dwellers in the Thicket were evildoers,\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdccclxxxi{%
and We took vengeance on them. The two of them were upon a roadway manifest.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdccclxxxii{%
The dwellers in El-Hijr cried lies to the Envoys.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdccclxxxiii{%
We brought them. Our signs, and they turned away from them.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdccclxxxiv{%
They were hewing the mountains into houses, therein dwelling securely;\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdccclxxxv{%
and the Cry seized them in the morning;\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdccclxxxvi{%
that they earned did not avail them.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdccclxxxvii{%
We created not the heavens and the earth, and all that is between them, save in truth. Surely the Hour is coming; so pardon thou, with a gracious pardoning.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdccclxxxviii{%
Surely thy Lord, He is the All-creator, the All-knowing.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdccclxxxix{%
We have given thee seven of the oft-repeated, and the mighty Koran.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdcccxc{%
Stretch not thine eyes to that We have given pairs of them to enjoy; and do not sorrow for them, and lower thy wing unto the believers,\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdcccxci{%
and say, 'Surely, I am the manifest warner.'\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdcccxcii{%
So We sent it down to the partitioners,\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdcccxciii{%
who have broken the Koran into fragments.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdcccxciv{%
Now by thy Lord, We shall surely question them all together\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdcccxcv{%
concerning that they were doing.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdcccxcvi{%
So shout that thou art commanded and turn thou away from the idolaters.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdcccxcvii{%
We suffice thee against the mockers,\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdcccxcviii{%
even against those who set up with God another god. Certainly they will soon know!\qt@no{96}}%
\qt@newcmd\qurantrans@en@mdcccxcix{%
We know indeed thy breast is straitened by the things they say.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcm{%
Proclaim thy Lord's praise, and be of those that bow,\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcmi{%
and serve thy Lord, until the Certain comes to thee.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcmii{%
\basmalahen God's command comes; so seek not to hasten it. Glory be to Him! High be He exalted above that they associate with Him!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mcmiii{%
He sends down the angels with the Spirit of His command upon whomsoever He will among His servants, saying: Give you warning that there is no God but I; so fear you Me!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mcmiv{%
He created the heavens and the earth in truth; high be He exalted above that they associate With Him!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mcmv{%
He created man of a sperm-drop; and, behold, he is a manifest adversary.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mcmvi{%
And the cattle -- He created them for you; in them is warmth, and uses various, and of them you eat,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mcmvii{%
and there is beauty in them for you, when you bring them home to rest and when you drive them forth abroad to pasture;\qt@no{6}}%
\qt@newcmd\qurantrans@en@mcmviii{%
and they bear your loads unto a land that you never would reach, excepting with great distress. Surely your Lord is All-clement, All-compassionate.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mcmix{%
And horses, and mules, and asses, for you to ride, and as an adornment; and He creates what you know not.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mcmx{%
God's it is to show the way; and some do swerve from it. If He willed, He would have guided you all together.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mcmxi{%
It is He who sends down to you out of heaven water of which you have to drink, and of which trees, for you to pasture your herds,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mcmxii{%
and thereby He brings forth for you crops, and olives, and palms, and vines, and all manner of fruit. Surely in that is a sign for a people who reflect.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mcmxiii{%
And He subjected to you the night and day, and the sun and moon; and the stars are subjected by His command. Surely in that are signs for a people who understand.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mcmxiv{%
And that which He has multiplied for you in the earth of diverse hues. Surely in that is a sign for a people who remember.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mcmxv{%
It is He who subjected to you the sea, that you may eat of it fresh flesh, and bring forth out of it ornaments for you to wear; and thou mayest see the ships cleaving through it; and that you may seek of His bounty, and so haply you will be thankful.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mcmxvi{%
And He cast on the earth firm mountains, lest it shake with you, and rivers and ways; so haply you will be guided;\qt@no{15}}%
\qt@newcmd\qurantrans@en@mcmxvii{%
and waymarks; and by the stars they are guided.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcmxviii{%
Is He who creates as he who does not create? Will you not remember?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mcmxix{%
If you count God's blessing, you will never number it; surely God is All-forgiving, All-compassionate.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mcmxx{%
And God knows what you keep secret and what you publish.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcmxxi{%
And those they call upon, apart from God, created nothing, and themselves are created,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcmxxii{%
dead, not alive; and are not aware when they shall be raised.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcmxxiii{%
Your God is One God. And they who believe not in the world to come, their hearts deny, and they have waxed proud.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcmxxiv{%
Without a doubt God knows what they keep secret and what they publish; He loves not those that wax proud.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcmxxv{%
And when it is said to them, 'What has your Lord sent down?' they say, 'Fairy-tales of the ancients.'\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcmxxvi{%
That they may bear their loads complete on the Day of Resurrection, and some of the loads of those that they lead astray without any knowledge. O evil the load they bear!\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcmxxvii{%
Those that were before them contrived; then God came upon their building from the foundations, and the roof fell down on them from over them, and the chastisement came upon them from whence they were not aware.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcmxxviii{%
Then on the Day of Resurrection He will degrade them, saying, 'Where are My associates concerning which you made a breach together?' Those that were given the knowledge will say, 'Degradation today and evil are on the unbelievers,\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcmxxix{%
whom the angels take while still they are wronging themselves.' Then they will offer surrender: 'We were doing nothing evil. 'Nay; but surety God has knowledge of the things you did.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcmxxx{%
So enter the gates of Gehenna, there to dwell forever.' Evil is the lodging of those that wax proud.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcmxxxi{%
And it shall be said to the godfearing, 'What has your Lord sent down?' They will say, 'Good! For those who do good in this world good; and surely the abode of the world to come is better; excellent is the abode of the godfearing --\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcmxxxii{%
Gardens of Eden they shall enter, underneath which rivers flow, wherein they shall have all they will. So God recompenses the godfearing,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcmxxxiii{%
whom the angels take while they are goodly, saying, 'Peace be on you! Enter Paradise for that you were doing.'\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcmxxxiv{%
Do they look for aught but that the angels shall come to them, or thy Lord's command shall come? So did those before them, and God wronged them not, but themselves they wronged.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcmxxxv{%
So the evil things that they wrought. smote them, and they were encompassed by that they mocked at.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcmxxxvi{%
The idolators say, 'If God had willed we would not have served; apart from Him, anything, neither we nor our fathers, nor would we have forbidden, apart from Him, anything.' So did those before them; yet is aught for the Messengers, but to deliver the manifest Message?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcmxxxvii{%
Indeed, We sent forth among every nation a Messenger,; saying: 'Serve you God, and eschew idols.' Then some. of them God guided, and some were justly disposed to error. So journey in the land, and behold how was the end of them that cried lies.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcmxxxviii{%
Though thou art ever so eager to guide them, God guides not those whom He leads astray; they have no helpers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcmxxxix{%
have sworn by God the most earnest oaths God will never raise up him who dies; nay, it is a promise binding upon Him, but most men know not,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcmxl{%
so that He may make clear to them that whereon they were at variance, and that the unbelievers may know that they were truly liars.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcmxli{%
The only words We say to a thing, when We desire it, is that We say to it 'Be,' and it is.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcmxlii{%
And those that emigrated in God's cause after they were wronged -- We shall surely lodge them in this world in a goodly lodging, and the wage of the world to come is greater, did they but know;\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcmxliii{%
even such men as are patient, and put their trust in their Lord.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcmxliv{%
We sent not any before thee, except men to whom We revealed: 'Question the people of the Remembrance, if it should be that you do not know --\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcmxlv{%
with the clear signs, and the Psalms; and We have sent down to thee the Remembrance that thou mayest make clear to mankind what was sent down to them; and so haply they will reflect.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcmxlvi{%
Do they feel secure, those who devise evil things, that God will not cause the earth to swallow them, or that the chastisement will not come upon them, from whence they are not aware?\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcmxlvii{%
Or that He will not seize them in their going to and fro, and they will not be able to frustrate Him?\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcmxlviii{%
Or that He will not seize them, little by little destroying them? Surely thy Lord is All-clement, All-compassionate.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcmxlix{%
Have they not regarded all things that God has created casting their shadows to the right and to the left, bowing themselves before God in all lowliness?\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcml{%
To God bows everything in the heavens, and every creature crawling on the earth, and the angels. They have not waxed proud;\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcmli{%
they fear their Lord above them, and they do what they are commanded.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcmlii{%
God says: 'Take not to you two gods. He is only One God; so have awe of Me.'\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcmliii{%
To Him belongs all that is in the heavens and earth; His is the religion for ever. Then will you fear other than God?\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcmliv{%
Whatsoever blessing you have, it comes from God; then when affliction visits you it is unto Him that you groan.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcmlv{%
Then, when He removes the affliction from you, lo, a party of you assign associates to their Lord,\qt@no{54}}%
\qt@newcmd\qurantrans@en@mcmlvi{%
that they may show unthankfulness for that We have given them. So take your joy; certainly you will soon know!\qt@no{55}}%
\qt@newcmd\qurantrans@en@mcmlvii{%
And they appoint a share of that We have provided them to what they know not. By God, you shall be questioned as to that you forged.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mcmlviii{%
And they assign to God daughters; glory be to Him! -- and they have their desire;\qt@no{57}}%
\qt@newcmd\qurantrans@en@mcmlix{%
and when any of them is given the good tidings of a girl, his face is darkened and he chokes inwardly,\qt@no{58}}%
\qt@newcmd\qurantrans@en@mcmlx{%
as he hides him from the people because of the evil of the good tidings that have been given unto him, whether he shall preserve it in humiliation, or trample it; into the dust. Ah, evil is that they judge!\qt@no{59}}%
\qt@newcmd\qurantrans@en@mcmlxi{%
Those who believe not in the world to come, theirs is the evil likeness; God's is the loftiest likeness; He is the All-mighty, the All-wise.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mcmlxii{%
If God should take men to task for their evildoing, He would not leave on the earth one creature that crawls; but He is deferring them to a term stated; and when their term is come they shall not put it back by a single hour nor put it forward.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mcmlxiii{%
They assign to God that they themselves dislike; and their tongues describe falsehood, that the reward most fair shall be theirs. Without any doubt theirs shall be the Fire, and they are hastened in.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mcmlxiv{%
By God, assuredly We sent Messengers to nations before thee, but Satan decked out fair to them their deeds; he is their protector today, and there yet awaits them a painful chastisement.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mcmlxv{%
And We have not sent down upon thee the Book except that thou mayest make clear to them that whereon they were at variance, and as a guidance and as a mercy to a people who believe.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mcmlxvi{%
And it is God who sends down out of heaven water, and therewith revives the earth after it is dead. Surely in that is a sign for a people who have ears.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mcmlxvii{%
And surely in the cattle there is a lesson for you; We give you to drink of what is in their bellies, between filth and blood, pure milk, sweet to drinkers.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcmlxviii{%
And of the fruits of the palms and the vines, you take therefrom an intoxicant and a provision fair. Surely in that is a sign for a people who understand.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mcmlxix{%
And thy Lord revealed unto the bees, saying: 'Take unto yourselves, of the mountains, houses, and of the trees, and of what they are building.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mcmlxx{%
Then eat of all manner of fruit, and follow the ways of your Lord easy to go upon.' Then comes there forth out of their bellies a drink of diverse hues wherein is healing for men. Surely in that is a sign for a people who reflect.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcmlxxi{%
God created you; then He will gather you to Him; and some of you will be kept back unto the vilest state of life, that after knowing somewhat, they may know nothing; God is All-knowing, All-powerful.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcmlxxii{%
And God has preferred some of you over others in provision;, but those that were preferred shall not give over their provision to that their right hands possess, so that they may be equal therein. What, and do they deny God's blessing?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcmlxxiii{%
God has appointed for you of yourselves wives, and He has appointed for you of your wives sons and grandsons, and He has provided you of the good things. What, do they believe in vanity, and do they disbelieve in God's blessing?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcmlxxiv{%
And do they serve, apart from God, that which has no power to provide them anything from the heavens and the earth and can do nothing?\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcmlxxv{%
So strike not any similitudes for God; surely God knows, and you know not.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcmlxxvi{%
God has struck a similitude: a servant possessed by his master, having no power over anything, and one whom We have provided of Ourselves with a provision fair, and he expends of it secretly and openly. Are they equal? Praise belongs to God! Nay, most of them know not.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcmlxxvii{%
God has struck a similitude: two men, one of them dumb, having no power over anything, and he is a burden upon his master -- wherever he despatches him, he brings no good. Is he equal to him who bids to justice, and is on a straight path?\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcmlxxviii{%
To God belongs the Unseen in the heavens and in the earth. And the matter of the Hour is as a twinkling of the eye, or nearer. Surely God is powerful over everything.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcmlxxix{%
And it is God who brought you forth from your mothers' wombs, and He appointed for you hearing, and sight, and hearts, that haply so you will be thankful.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcmlxxx{%
Have they not regarded the birds, that are subjected in the air of heaven? Naught holds them but God; surely in that are signs for' a people who believe.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcmlxxxi{%
And it is God who has appointed a place of rest for you of your houses, and He has appointed for you of the skins of the cattle houses you find light on the day that you journey, and on the day you abide, and of their wool, and of their fur, and of their hair furnishing and an enjoyment for a while.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcmlxxxii{%
And it is God who has appointed for you coverings of the things He created, and He has appointed for you of the mountains refuges, and He has appointed for you shirts to protect you from the heat, and shirts to protect you from your own violence. Even so He perfects His blessing upon you, that haply you will surrender.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcmlxxxiii{%
So, if they turn their backs, thine it is only to deliver the manifest Message.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcmlxxxiv{%
They recognize the blessing of God, then they deny it, and the most of them are the unthankful.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcmlxxxv{%
And the day We shall raise up from every nation a witness, then to the unbelievers no leave shall be given, nor shall they be suffered to make amends.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcmlxxxvi{%
And when the evildoers behold the chastisement, it shall not be lightened for them, and no respite shall be given them.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcmlxxxvii{%
And when the idolaters behold their associates, they shall say, 'Our Lord, these are our associates on whom we called apart from Thee.' They will fling back at them the saying, 'Surely, you are truly liars.'\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcmlxxxviii{%
And they will offer God surrender that day, and there shall go astray from them that they were forging.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcmlxxxix{%
Those that disbelieve and bar from the way of God -- them We shall give increase of chastisement upon chastisement, for that they were doing corruption.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcmxc{%
And the day We shall raise up from every nation a witness against them from amongst them, and We shall bring thee as a witness against those. And We have sent down on thee the Book making clear everything, and as a guidance and a mercy, and as good tidings to those who surrender.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcmxci{%
Surely God bids to justice and good-doing and giving to kinsmen; and He forbids indecency, dishonour, and insolence, admonishing you, so that haply you will remember.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcmxcii{%
Fulfil God's covenant, when you make covenant, and break not the oaths after they have been confirmed, and you have made God your surety; surely God knows the things you do.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcmxciii{%
And be not as a woman who breaks her thread, after it is firmly spun, into fibres, by taking your oaths as mere mutual deceit, one nation being more numerous than another nation. God only tries you thereby; and certainly He will make clear to you upon the Day of Resurrection that whereon you were at variance.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcmxciv{%
If God had willed, He would have made you one nation; but He leads astray whom He will, and guides whom He will; and you will surely be questioned about the things you wrought.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcmxcv{%
Take not your oaths as mere mutual deceit, lest any foot should slip after it has stood firm, and you should taste evil, for that you barred from the way of God, and lest there should await you a mighty chastisement.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcmxcvi{%
And do not sell the covenant of God for a small price; surely what is with God -- that is better for you, did you but know.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcmxcvii{%
What is with you comes to an end, but what is with God abides; and surely We shall recompense those who were patient their wage, according to the best of what they did.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcmxcviii{%
And whosoever does a righteous deed, be it male or female, believing, We shall assuredly give him to live a goodly life; and We shall recompense them their wage, according to the best of what they did.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcmxcix{%
When thou recitest the Koran, seek refuge in God from the accursed Satan;\qt@no{98}}%
\qt@newcmd\qurantrans@en@mm{%
he has no authority over those who believe and trust in their Lord;\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmi{%
his authority is over those who take him for their friend and ascribe associates to God.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmii{%
And when We exchange a verse in the place of another verse and God knows very well what He is sending down -- they say, 'Thou art a mere forger!' Nay, but the most of them have no knowledge.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmiii{%
Say: 'The Holy Spirit sent it down from thy Lord in truth, and to confirm those who believe, and to be a guidance and good tidings to those who surrender.'\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmiv{%
And We know very well that they say, 'Only a mortal is teaching him.' The speech of him at whom they hint is barbarous; and this is speech Arabic, manifest.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmv{%
Those that believe not in the signs of God, God will not guide; there awaits them a painful chastisement.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmvi{%
They only forge falsehood, who believe not in the signs of God, and those -- they are the liars.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmvii{%
Whoso disbelieves in God, after he has believed -- excepting him who has been compelled, and his heart is still at rest in his belief -- but whosoever's breast is expanded in unbelief, upon them shall rest anger from God, and there awaits them a mighty chastisement;\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmviii{%
that, because they have preferred the present life over the world to come, and that God guides not the people of the unbelievers.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmix{%
Those -- God has set a seal on their hearts, and their hearing, and their eyes, and those -- they are the heedless ones;\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmx{%
without a doubt, in the world to come they will be the losers.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmxi{%
Then, surely thy Lord -- unto those who have emigrated after persecution, then struggled and were patient -- surely thy Lord thereafter is All-forgiving, All-compassionate.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmxii{%
The day that every soul shall come disputing in its own behalf; and every soul shall be paid in full for what it wrought, and they shall not be wronged.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmxiii{%
God has struck a similitude: a city that was secure, at rest, its provision coming to it easefully from every place, then it was unthankful for the blessings of God; so God let it taste the garment of hunger and of fear, for the things that they were working.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmxiv{%
There came indeed to them a Messenger from amongst them, but they cried him lies; so they were seized by the chastisement while they were evildoers.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmxv{%
So eat of what God has provided you lawful and good; and be you thankful for the blessing of God, if it be Him that you serve.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmxvi{%
These things only He has forbidden you: carrion, blood, the flesh of swine, what has been hallowed to other than God. Yet whoso is constrained, not desiring nor transgressing, God is All-forgiving, All-compassionate.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmxvii{%
And do not say, as to what your tongues falsely describe, 'This is lawful; and this is forbidden, so that you may forge against God falsehood; surely those who forge against God falsehood shall not prosper.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmxviii{%
A little enjoyment, then for them awaits a painful chastisement.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmxix{%
And those of Jewry -- We have forbidden them what We related to thee before, and We wronged them not, but they wronged themselves.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmxx{%
Then, surely thy Lord -- unto those who did evil in ignorance, then repented after that and put things right -- surely thy Lord thereafter is All-forgiving, All-compassionate.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmxxi{%
Surely, Abraham was a nation obedient unto God, a man of pure faith and no idolater,\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmxxii{%
showing thankfulness for His blessings; He chose him, and He guided him to a straight path.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmxxiii{%
And We gave him in this world good, and in the world to come he shall be among the righteous.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmxxiv{%
Then We revealed to thee: 'Follow thou the creed of Abraham, a man of pure faith and no idolater.'\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmxxv{%
The Sabbath was only appointed for those who were at variance thereon; surely thy Lord will decide between them on the Day of Resurrection, touching their differences.\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmxxvi{%
Call thou to the way of thy Lord with wisdom and good admonition, and dispute with them in the better way. Surely thy Lord knows very well those who have gone astray from His way, and He knows very well those who are guided.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmxxvii{%
And if you chastise, chastise even as you have been chastised; and yet assuredly if you are patient, better it is for those patient.\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmxxviii{%
And be patient; yet is thy patience only with the help of God. And do not sorrow for them, nor be thou straitened for what they devise.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmxxix{%
Surely God is with those who are godfearing, and those who are good-doers.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmxxx{%
\basmalahen Glory be to Him, who carried His servant by night from the Holy Mosque to the Further Mosque the precincts of which We have blessed, that We might show him some of Our signs. He is the All-hearing, the All-seeing.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmxxxi{%
And We gave Moses the Book, and made it a guidance to the Children of Israel: 'Take not unto yourselves any guardian apart from Me.'\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmxxxii{%
The seed of those We bore with Noah; he was a thankful servant.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmxxxiii{%
And We decreed for the Children of Israel in the Book: 'You shall do corruption in the earth twice, and you shall ascend exceeding high.'\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmxxxiv{%
So, when the promise of the first of these came to pass, We sent against you servants of Ours, men of great might, and they went through the habitations, and it was a promise performed.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmxxxv{%
Then We gave back to you the turn to prevail over them, and We succoured you with wealth and children, and We made you a greater host.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmxxxvi{%
'If you do good, it is your own souls you do good to, and if you do evil it is to them likewise.' Then, when the promise of the second came to pass, We sent against you Our servants to discountenance you, and to enter the Temple, as they entered it the first time, and to destroy utterly that which they ascended to.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmxxxvii{%
Perchance your Lord will have mercy upon you; but if you return, We shall return; and We have made Gehenna a prison for the unbelievers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmxxxviii{%
Surely this Koran guides to the way that is straightest and gives good tidings to the believers who do deeds of righteousness, that theirs shall be a great wage,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmxxxix{%
and that those who do not believe in the world to come -- we have prepared for them a painful chastisement.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmxl{%
Man prays for evil, as he prays for good; man is ever hasty.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmxli{%
We have appointed the night and the day as two signs; then We have blotted out the sign of the night, and made the sign of the day to see, and that you may seek bounty from your Lord, and that you may know the number of the years, and the reckoning; and everything We have distinguished very distinctly.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmxlii{%
And every man -- We have fastened to him his bird of omen upon his neck; and We shall bring forth for him, on the Day of Resurrection, a book he shall find spread wide open.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmxliii{%
'Read thy book! Thy soul suffices thee this day as a reckoner against thee.'\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmxliv{%
Whosoever is guided, is only guided to his own gain, and whosoever goes astray, it is only to his own loss; no soul laden bears the load of another. We never chastise, until We send forth a Messenger.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmxlv{%
And when We desire to destroy a city, We command its men who live at ease, and they commit ungodliness therein, then the Word is realized against it, and We destroy it utterly.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmxlvi{%
How many generations We have destroyed after Noah! Thy Lord suffices as one who is aware of and sees the sins of His servants.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmxlvii{%
Whosoever desires this hasty world, We hasten for him therein what We will unto whomsoever We desire; then We appoint for him Gehenna wherein he shall roast, condemned and rejected.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmxlviii{%
And whosoever desires the world to come and strives after it as he should, being a believer -- those, their striving shall be thanked.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmxlix{%
Each We succour, these and those, from thy Lord's gift; and thy Lord's gift is not confined.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mml{%
Behold, how We prefer some of them over others! And surely the world to come is greater in ranks, greater in preferment.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmli{%
Set not up with God another god, or thou wilt sit condemned and forsaken.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmlii{%
Thy Lord has decreed you shall not serve any but Him, and to be good to parents, whether one or both of them attains old age with thee; say not to them 'Fie' neither chide them, but speak unto them words respectful,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmliii{%
and lower to them the wing of humbleness out of mercy and say; 'My Lord, have mercy upon them, as they raised me up when I was little.'\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmliv{%
Your Lord knows very well what is in your hearts if you are righteous, for He is All-forgiving to those who are penitent.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmlv{%
And give the kinsman his right, and the needy, and the traveller; and never squander;\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmlvi{%
the squanderers are brothers of Satan, and Satan is unthankful to his Lord.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmlvii{%
But if thou turnest from them, seeking mercy from thy Lord that thou hopest for, then speak unto them gentle words.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmlviii{%
And keep not thy hand chained to thy neck, nor outspread it widespread altogether, or thou wilt sit reproached and denuded.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmlix{%
Surely thy Lord outspreads and straitens His provision unto whom He will; surely He is aware of and sees His servants.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmlx{%
And slay not your children for fear of poverty; We will provide for you and them; surely the slaying of them is a grievous sin.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmlxi{%
And approach not fornication; surely it is an indecency, and evil as a way.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmlxii{%
And slay not the soul God has forbidden, except by right. Whosoever is slain unjustly, We have appointed to his next-of-kin authority; but let him not exceed in slaying; he shall be helped.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmlxiii{%
And do not approach the property of the orphan save in the fairest manner, until he is of age. And fulfil the covenant; surely the covenant shall be questioned of.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmlxiv{%
And fill up the measure when you measure, and weigh with the straight balance; that is better and fairer in the issue.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmlxv{%
And pursue not that thou hast no knowledge of; the hearing, the sight, the heart -- all of those shall be questioned of.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmlxvi{%
And walk not in the earth exultantly; certainly thou wilt never tear the earth open, nor attain the mountains in height.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmlxvii{%
All of that -- the wickedness of it is hateful in the sight of thy Lord has revealed to thee:\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmlxviii{%
That is of the wisdom thy Lord set not up with God another god, or thou wilt be cast into Gehenna, reproached and rejected.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmlxix{%
What, has your Lord favoured you with sons and taken to Himself from the angels females? Surely it is a monstrous thing you are saying!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmlxx{%
We have turned about in this Koran, that they may remember; and it increases them only in aversion.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmlxxi{%
Say: 'If there had been other gods with Him, as they say, in that case assuredly they would have sought a way unto the Lord of the Throne.' Glory be to Him!\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmlxxii{%
High indeed be He exalted above that they say!\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmlxxiii{%
The seven heavens and the earth, and whosoever in them is, extol Him; nothing is, that does not proclaim His praise, but you do not understand their extolling. Surely He is All-clement, All-forgiving.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmlxxiv{%
When thou recitest the Koran, We place between thee, and those who do not believe in the world to come, a curtain obstructing,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmlxxv{%
and We lay veils upon their hearts lest they understand it, and in their ears heaviness. And when thou mentionest thy Lord only in the Koran, they turn in their traces in aversion.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmlxxvi{%
We know very well how they listen when they listen to thee, and when they conspire, when the evildoers say, 'You are only following a man bewitched!'\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmlxxvii{%
Behold, how they strike similitudes for thee, and go astray, and cannot find a way!\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmlxxviii{%
They say, 'What, when we are bones and broken bits, shall we really be raised up again in a new creation?'\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmlxxix{%
Say: 'Let you be stones, or iron,\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmlxxx{%
or some creation yet more monstrous in your minds!' Then they will say, 'Who will bring us back?' Say: 'He who originated you the first time.' Then they will shake their heads at thee, and they will say, 'When will it be?' Say: 'It is possible that it may be nigh,\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmlxxxi{%
on the day when He will call you, and you will answer praising Him, and you will think you have but tarried a little.'\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmlxxxii{%
And say to My servants, that they say words that are kindlier. For surely Satan provokes strife between them, and Satan is ever a manifest foe to man.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmlxxxiii{%
Your Lord knows you very well; if He will, He will have mercy on you, or, if He will, He will chastise you. We sent thee not to be a guardian over them.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmlxxxiv{%
And thy Lord knows very well all who are in the heavens and the earth; and We have preferred some Prophets over others; and We gave to David Psalms.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmlxxxv{%
Say: 'Call on those you asserted apart from Him; they have no power to remove affliction from you, or to transfer it.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmlxxxvi{%
Those they call upon are themselves seeking the means to come to their Lord, which of them shall be nearer; they hope for His mercy, and fear His chastisement. Surely thy Lord's chastisement is a thing to beware of.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmlxxxvii{%
No city is there, but We shall destroy it before the Day of Resurrection, or We shall chastise it with a terrible chastisement; that is in the Book inscribed.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmlxxxviii{%
Naught prevented Us from sending the signs but that the ancients cried lies to them; and We brought Thamood the She-camel visible, but they did her wrong. And We do not send the signs, except to frighten.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmlxxxix{%
And when We said to thee, 'Surely thy Lord encompasses men,' and We made the vision that We showed thee and the tree cursed in the Koran to be only a trial for men; and We frighten them, but it only increases them in great insolence.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmxc{%
And when We said to the angels, 'Bow yourselves to Adam'; so they bowed themselves, save Iblis; he said,, 'Shall I bow myself unto one Thou hast created of clay?'\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmxci{%
He said, 'What thinkest Thou? This whom Thou hast honoured above me -- if Thou deferrest me to the Day of Resurrection I shall assuredly master his seed, save a few.'\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmxcii{%
Said He, 'Depart! Those of them that follow thee -- surely Gehenna shall be your recompense, an ample recompense!\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmxciii{%
And startle whomsoever of them thou canst with thy voice; and rally against them thy horsemen and thy foot, and share with them in their wealth and their children, and promise them!' But Satan promises them naught, except delusion.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmxciv{%
'Surely over My servants thou shalt have no authority.' Thy Lord suffices as a guardian.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmxcv{%
Your Lord it is who drives for you the ships on the sea that you may seek His bounty; surely He is All-compassionate towards you.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmxcvi{%
And when affliction visits you upon the sea, then there go astray those on whom you call except Him; and when He delivers you to land, you turn away; man is ever unthankful.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmxcvii{%
Do you feel secure that He will not cause the shore to swallow you up, or loose against you a squall of pebbles, then you will find no guardian for you?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmxcviii{%
Or do you feel secure that He will not send you back into it a second time, and loose against you a hurricane of wind and drown you for your thanklessness, then you will find no prosecutor for you against Us?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmxcix{%
We have honoured the Children of Adam and carried them on land and sea, and provided them with good things, and preferred them greatly over many of those We created.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmc{%
On the day when We shall call all men with their record, and whoso is given his book in his right hand -- those shall read their book, and they shall not be wronged a single date-thread.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmci{%
And whosoever is blind in this world shall be blind in the world to come, and he shall be even further astray from the way.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcii{%
Indeed they were near to seducing thee from that We revealed to thee, that thou mightest forge against Us another, and then they would surely have taken thee as a friend;\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmciii{%
and had We not confirmed thee, surely thou wert near to inclining unto them a very little;\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmciv{%
then would We have let thee taste the double of life and the double of death; and then thou wouldst have found none to help thee against Us.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcv{%
Indeed they were near to startling thee from the land, to expel thee from it, and then they would have tarried after thee only a little --\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcvi{%
the wont of those We sent before thee of Our Messengers; thou wilt find no change to Our wont.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcvii{%
Perform the prayer at the sinking of the sun to the darkening of the night and the recital of dawn; surely the recital of dawn is witnessed.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcviii{%
And as for the night, keep vigil a part of it, as a work of supererogation for thee; it may be that thy Lord will raise thee up to a laudable station.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcix{%
And say: 'My Lord, lead me in with a just ingoing, and lead me out with a just outgoing; grant me authority from Thee, to help me.'\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcx{%
And say: 'The truth has come, and falsehood has vanished away; surely falsehood is ever certain to vanish.'\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcxi{%
And We send down, of the Koran, that which is a healing and a mercy to the believers; and the unbelievers it increases not, except in loss.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcxii{%
And when We bless man, he turns away, and withdraws aside; but when evil visits him, he is in despair.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcxiii{%
Say: 'Every man works according to his own manner; but your Lord knows very well what man is best guided as to the way.'\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcxiv{%
They will question thee concerning the Spirit. Say: 'The Spirit is of the bidding of my Lord. You have been given of knowledge nothing except a little.'\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcxv{%
If We willed, We could take away that We have revealed to thee, then thou wouldst find none thereover to guard thee against Us,\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcxvi{%
excepting by some mercy of thy Lord; surly His favour to thee is great.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcxvii{%
Say: 'If men and jinn banded together to produce the like of this Koran, they would never produce its like, not though they backed one another.'\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcxviii{%
We have indeed turned about for men in this Koran every manner of similitude; yet most men refuse all but unbelief.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcxix{%
They say, 'We will not believe thee till thou makest a spring to gush forth from the earth for us,\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcxx{%
or till thou possessest a garden of plants and vines, and thou makest rivers to gush forth abundantly all amongst it,\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcxxi{%
or till thou makest heaven to fall, as thou assertest, on us in fragments, or thou bringest God and the angels as a surety,\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcxxii{%
or till thou possessest a house of gold ornament, or till thou goest up into heaven; and we will not believe thy going up till thou bringest down on us a book that we may read. Say: 'Glory be to my Lord. Am I aught but a mortal, a Messenger?'\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcxxiii{%
And naught prevented men from believing when the guidance came to them, but that they said, 'Has God sent forth a mortal as Messenger?'\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcxxiv{%
Say: 'Had there been in the earth angels walking. at peace, We would have sent down upon them out of heaven an angel as Messenger.'\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcxxv{%
Say: 'God suffices as a witness between me and you; surely He is aware of and sees His servants.'\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcxxvi{%
Whomsoever God guides, he is rightly guided; and whom He leads astray -- thou wilt not find for them protectors, apart from Him. And We shall muster them on the Resurrection Day upon their faces, blind, dumb, deaf; their refuge shall be Gehenna, and whensoever it abates We shall increase for them the Blaze.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcxxvii{%
That is their recompense because they disbelieved in Our signs and said, 'What, when we are bones and broken bits, shall we really be raised up again in a new creation?'\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcxxviii{%
Have they not seen that God, who created the heavens and earth, is powerful to create the like of them? He has appointed for them a term, no doubt of it; yet the unbelievers refuse all but unbelief.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmcxxix{%
Say: 'If you possessed the treasuries of my Lord's mercy, yet would you hold back for fear of expending; and man is ever niggardly.'\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmcxxx{%
And We gave Moses nine signs, clear signs. Ask the Children of Israel when he came to them, and Pharaoh said to him, 'Moses, I think thou art bewitched.'\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmcxxxi{%
He said, 'Indeed thou knowest that none sent these down, except the Lord of the heavens and earth, as clear proofs; and, Pharaoh, I think thou art accursed.'\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmcxxxii{%
He desired to startle them from the land; and We drowned him and those with him, all together.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmcxxxiii{%
And We said to the Children of Israel after him, 'Dwell in the land; and when the promise of the world to come comes to pass, We shall bring you a rabble.'\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmcxxxiv{%
With the truth We have sent it down, and with the truth it has come down; and We have sent thee not, except good tidings to bear, and warning;\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmcxxxv{%
and a Koran We have divided, for thee to recite it to mankind at intervals, and We have sent it down successively.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmcxxxvi{%
Say: 'Believe in it, or believe not; those who were given the knowledge before it when it is recited to them, fall down upon their faces prostrating,\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmcxxxvii{%
and say, ``Glory be to our Lord! Our Lord's promise is performed."\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmcxxxviii{%
And they fall down upon their faces weeping; and it increases them in humility.'\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmcxxxix{%
Say: 'Call upon God, or call upon the Merciful; whichsoever you call upon, to Him belong the Names Most Beautiful.' And be thou not loud in thy prayer, nor hushed therein, but seek thou for a way between that.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmcxl{%
And say: 'Praise belongs to God, who has not taken to Him a son, and who has not any associate in the Kingdom, nor any protector out of humbleness.' And magnify Him with repeated magnificats.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmcxli{%
\basmalahen Praise belongs to God who has sent down upon His servant the Book and has not assigned unto it any crookedness;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcxlii{%
right, to warn of great violence from Him, and to give good tidings unto the believers, who do righteous deeds, that theirs shall be a goodly wage\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcxliii{%
therein to abide for ever,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcxliv{%
and to warn those who say, 'God has taken to Himself a son';\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcxlv{%
they have no knowledge of it, they nor their fathers; a monstrous word it is, issuing out of their mouths; they say nothing but a lie.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcxlvi{%
Yet perchance, if they believe not in this tiding, thou wilt consume thyself, following after them, of grief.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcxlvii{%
We have appointed all that is on the earth for an adornment for it, and that We may try which of them is fairest in works;\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcxlviii{%
and We shall surely make all that is on it barren dust.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcxlix{%
Or dost thou think the Men of the Cave and Er-Rakeem were among Our signs a wonder?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcl{%
When the youths took refuge in the Cave saying, 'Our lord, give us mercy from Thee, and furnish us with rectitude in our affair.'\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcli{%
Then We smote their ears many years in the Cave.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmclii{%
Afterwards. We raised them up again, that We might know which of the two parties would better calculate the while they had tarried.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcliii{%
We will relate to thee their tidings truly. They were youths who believed in their Lord, and We increased them in guidance.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcliv{%
And We strengthened their hearts, when they stood up and said, 'Our Lord is the Lord of the heavens and earth; we will not call upon any god, apart from Him, or then we had spoken outrage.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmclv{%
These our people have taken to them other gods, apart from Him. Ah, if only they would bring some clear authority regarding them! But who does greater evil than he who forges against God a lie?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmclvi{%
So, when you have gone apart from them and that they serve, excepting God, take refuge in the Cave, and your Lord will unfold to you of His mercy, and will furnish -- you with a gentle issue of your affair.'\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmclvii{%
And thou mightest have seen the sun, when it rose, inclining from their Cave towards the right, and, when it set, passing them by on the left, while they were in a broad fissure of the Cave. That was one of God's signs; whomsoever God guides, he is rightly guided, and whomsoever He leads astray, thou wilt not find for him a protector to direct.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmclviii{%
Thou wouldst have thought them awake, as they lay sleeping, while We turned them now to the right, now to the left,' and their dog 'stretching its paws on the threshold. Hadst thou observed them surely thou wouldst have turned thy back on them in flight, and been filled with terror of them.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmclix{%
And even so We raised them up again that they might question one another. One of them said, 'How long have you tarried?' They said, 'We have tarried a day, or part of a day.' They said, 'Your Lord knows very well how long you have tarried. Now send one of you forth with this silver to the city, and let him look for which of them has purest food, and bring you provision thereof; let him be courteous, and apprise no man of you.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmclx{%
If they should get knowledge of you they will stone you, or restore you to their creed, then you will not prosper ever.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmclxi{%
And even so We made them stumble upon them, that they might know that God's promise is true, and that the Hour -- there is no doubt of it. When they were contending among themselves of their affair then they said, 'Build over them a building; their Lord knows of them very well.' Said those who prevailed over their affair, 'We will raise over them a place of worship.'\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmclxii{%
(They will say, 'Three; and 'their dog was the fourth of them.' They will say, 'Five; and their dog was the sixth of them, guessing at the Unseen. They will say, 'Seven; and their dog was the eighth of them.' Say: 'My Lord knows very well their number, and none knows them, except a few.' So do not dispute with them, except in outward disputation, and ask not any of them for a pronouncement on them.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmclxiii{%
And do not say, regarding anything, 'I am going to do that tomorrow,'\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmclxiv{%
but only, 'If God will'; and mention thy Lord, when thou forgettest, and say, 'It may be that my Lord will guide me unto something nearer to rectitude than this.')\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmclxv{%
And they tarried in the Cave three hundred years, and to that they added nine more.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmclxvi{%
Say: 'God knows very well how long they tarried. To Him belongs the Unseen in the heavens and in the earth. How well He sees! How well He hears! They have no protector, apart from Him, and He associates in His government no one.'\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmclxvii{%
Recite what has been revealed to thee of the Book of thy Lord; no man can change His words. Apart from Him, thou wilt find no refuge.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmclxviii{%
And restrain thyself with those who call upon their Lord at morning and evening, desiring His countenance, and let not thine eyes turn away from them, desiring the adornment of the present life; and obey not him whose heart We have made neglectful of Our remembrance so that he follows his own lust, and his affair has become all excess.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmclxix{%
Say: 'The truth is from your Lord; so let whosoever will believe, and let whosoever will disbelieve.' Surely We have prepared for the evildoers a fire, whose pavilion encompasses them; if they call for succour, they will be succoured with water like molten copper, that shall scald their faces -- how evil a potion, and how evil a resting-place!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmclxx{%
Surely those who believe, and do deeds of righteousness -- surely We leave not to waste the wage of him who does good works;\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmclxxi{%
those -- theirs shall be Gardens of Eden, underneath which rivers flow; therein they shall be adorned with bracelets of gold, and they shall be robed in green garments of silk and brocade, therein reclining upon couches -- O, how excellent a reward! And O, how fair a resting-place!\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmclxxii{%
And strike for them a similitude: two men. To one of them We assigned two gardens of vines, and surrounded them with palm-trees, and between them We set a sown field;\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmclxxiii{%
each of the two gardens yielded its produce and failed naught in any wise; and We caused to gush amidst them a river.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmclxxiv{%
So he had fruit; and he said to his fellow, as he was conversing with him, 'I have more abundance of wealth than thou and am mightier in respect of men.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmclxxv{%
And he entered his garden, wronging himself; he said, 'I do not think that this will ever perish;\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmclxxvi{%
I do not think that the Hour is coming; and if I am indeed returned to my Lord, I shall surely find a better resort than this.'\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmclxxvii{%
Said his fellow, as he was conversing with him, 'What, disbelievest thou in Him who created thee of dust, then of a sperm-drop, then shaped thee as a man?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmclxxviii{%
But lo, He is God, my Lord, and I will not associate with my Lord any one.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmclxxix{%
Why, when thou wentest into thy garden, didst thou not say, ``As God will; there is no power except in God"? If thou seest me, that I am less than thou in wealth and children,\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmclxxx{%
yet it may be that my Lord will give me better than thy garden, and loose on it a thunderbolt out of heaven, so that in the morning it will be a slope of dust,\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmclxxxi{%
or in the morning the water of it will be sunk into the earth, so that thou wilt not be able to seek it out.'\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmclxxxii{%
And his fruit was all encompassed, and in the morning he was wringing his hands for that he had expended upon it, and it was fallen down upon its trellises, and he was saying, 'Would I had not associated with my Lord any one!'\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmclxxxiii{%
But there was no host to help him, apart from God, and he was helpless.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmclxxxiv{%
Thereover protection belongs only to God the True; He is best rewarding, best in the issue.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmclxxxv{%
And strike for them the similitude of the present life: it is as water that We send down out of heaven, and the plants of the earth mingle with it; and in the morning it is straw the winds scatter; and God is omnipotent over everything.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmclxxxvi{%
Wealth and sons are the adornment of the present world; but the abiding things, the deeds of righteousness, are better with God in reward, and better in hope.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmclxxxvii{%
And on the day We shall set the mountains in motion, and thou seest the earth coming forth, and We muster them so that We leave not so much as one of them behind;\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmclxxxviii{%
and they shall be presented before their Lord in ranks -- 'You have come to Us, as We created you upon the first time; nay, you asserted We should not appoint for you a tryst.'\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmclxxxix{%
And the Book shall be set in place; and thou wilt see the sinners fearful at what is in it, and saying, 'Alas for us! How is it with this Book, that it leaves nothing behind, small or great, but it has numbered it?' And they shall find all they wrought present, and thy Lord shall not wrong anyone.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcxc{%
And when We said to the angels, 'Bow yourselves to Adam'; so they bowed themselves, save Iblis; he was one of the jinn, and committed ungodliness against his Lord's command. What, and do you take him and his seed to be your friends, apart from Me, and they an enemy to you? How evil is that exchange for the evildoers!\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcxci{%
I made them not witnesses of the creation of the heavens and earth, neither of the creation of themselves; I would not ever take those who lead others astray to be My supporters.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcxcii{%
And on the day He shall say, 'Call on My associates whom you asserted'; and then they shall call on them, but they will not answer them, and We shall set a gulf between them.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcxciii{%
Then the evildoers will see the Fire, and think that they are about to fall into it, and will find no escape from it.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcxciv{%
We have indeed turned about for men in this Koran every manner of similitude; man is the most disputatious of things.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcxcv{%
And naught prevented men from believing when the guidance came unto them, and seeking their Lord's forgiveness, but that the wont of the ancients should come upon them, or that the chastisement should come upon them face to face.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcxcvi{%
And We send not the Envoys, but good tidings to bear, and warning. Yet do the unbelievers dispute with falsehood, that they may rebut thereby the truth. They have taken My signs, and what they are warned of, in mockery.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcxcvii{%
And who does greater evil than he who, being reminded of the signs of his Lord, turns away from them and forgets what his hands have forwarded? Surely We have laid veils on their hearts lest they understand it, and in their ears heaviness; and though thou callest them to the guidance, yet they will not be guided ever.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcxcviii{%
But thy Lord is the All-forgiving, full of mercy. If He should take them to task for that they have earned, He would hasten for them the chastisement; but they have a tryst, from which they will find no escape.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcxcix{%
And those cities, We destroyed them when they did evil, and appointed for their destruction a tryst.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcc{%
And when Moses said to his page, 'I will not give up until I reach the meeting of the two seas, though I go on for many years.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcci{%
Then, when they reached their meeting, they forgot their fish, and it took its way into the sea, burrowing.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmccii{%
When they had passed over, he said to his page, 'Bring us our breakfast; indeed, we have encountered weariness from this our journey.'\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcciii{%
He said, 'What thinkest thou? When we took refuge in the rock, then I forgot the fish-and it was Satan himself that made me forget it so that I should not remember it -- and so it took its way into the sea in a manner marvellous.'\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcciv{%
Said he, 'This is what we were seeking!' And so they returned upon their tracks, retracing them.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmccv{%
Then they found one of Our servants unto whom We had given mercy from Us, and We had taught him knowledge proceeding from Us.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmccvi{%
Moses said to him, 'Shall I follow thee so that thou teachest me, of what thou hast been taught, right judgment.'\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmccvii{%
Said he, 'Assuredly thou wilt not be able to bear with me patiently.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmccviii{%
And how shouldst thou bear patiently that thou hast never encompassed in thy knowledge?'\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmccix{%
He said, 'Yet thou shalt find me, if God will, patient; and I shall not rebel against thee in anything.'\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmccx{%
Said he, 'Then if thou followest me, question me not on anything until I myself introduce the mention of it to thee.'\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmccxi{%
So they departed; until, when they embarked upon the ship, he made a hole in it. He said, 'What, hast thou made a hole in it so as to drown its passengers? Thou hast indeed done a grievous thing.'\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmccxii{%
Said he, 'Did I not say that thou couldst never bear with me patiently?'\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmccxiii{%
He said, 'Do not take me to task that I forgot, neither constrain me to do a thing too difficult.'\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmccxiv{%
So they departed; until, when they met a lad, he slew him. He said, 'What, hast thou slain a soul innocent, and that not to retaliate for a soul slain? Thou hast indeed done a horrible thing.'\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmccxv{%
Said he, 'Did I not say that thou couldst never bear with me patiently?'\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmccxvi{%
He said, 'If I question thee on anything after this, then keep me company no more; thou hast already experienced excuse sufficient on my part.'\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmccxvii{%
So they departed; until, when they reached the people of a city, they asked the people for food, but they refused to receive them hospitably. There they found a wall about to tumble down, and so he set it up. He said, 'If thou hadst wished, thou couldst have taken a wage for that.'\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmccxviii{%
Said he, 'This is the parting between me and thee. Now I will tell thee the interpretation of that thou couldst not bear patiently.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmccxix{%
As for the ship, it belonged to certain poor men, who toiled upon the sea; and I desired to damage it, for behind them there was a king who was seizing every ship by brutal force.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmccxx{%
As for the lad, his parents were believers; and we were afraid he would impose on them insolence and unbelief;\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmccxxi{%
so we desired that their Lord should give to them in exchange one better than he in purity, and nearer in tenderness.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmccxxii{%
As for the wall, it belonged to two orphan lads in the city, and under it was a treasure belonging to them. Their father was a righteous man; and thy Lord desired that they should come of age and then bring forth their treasure as a mercy from thy Lord. I did it not of my own bidding. This is the interpretation of that thou couldst not bear patiently.'\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmccxxiii{%
They will question thee concerning Dhool Karnain. Say: 'I will recite to you a mention of him.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmccxxiv{%
We established him in the land, and We gave him a way to everything;\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmccxxv{%
and he followed a way\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmccxxvi{%
until, when he reached the setting of the sun, he found it setting in a muddy spring, and he found nearby a people. We said, 'O Dhool Karnain, either thou shalt chastise them, or thou shalt take towards them a way of kindness.'\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmccxxvii{%
He said, 'As for the evildoer, him we shall chastise, then he shall be returned to his Lord and He shall chastise him with a horrible chastisement.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmccxxviii{%
But as for him who believes, and does righteousness, he shall receive as recompense the reward most fair, and we shall speak to him, of our command, easiness.'\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmccxxix{%
Then he followed a way\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmccxxx{%
until, when he reached the rising of the sun, he found it rising upon a people for whom We had not appointed any veil to shade them from it.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmccxxxi{%
So; and We encompassed in knowledge what was with him.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmccxxxii{%
Then he followed a way\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmccxxxiii{%
until, when he reached between the two barriers, he found this side of them a people scarcely able to understand speech.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmccxxxiv{%
They said, 'O Dhool Karnain, behold, Gog and Magog are doing corruption in the earth; so shall we assign to thee a tribute, against thy setting up a barrier between us and between them?'\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmccxxxv{%
He said, 'That wherein my Lord has established me is better; so aid me forcefully, and I will set up a rampart between you and between them.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmccxxxvi{%
Bring me ingots of iron!' Until, when he had made all level between the two cliffs, he said, 'Blow!' Until, when he had made it a fire, he said, 'Bring me, that I may pour molten brass on it.'\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmccxxxvii{%
So they were unable either to scale it or pierce it.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmccxxxviii{%
He said, 'This is a mercy from my Lord. But when the promise of my Lord comes to pass, He will make it into powder; and my Lord's promise is ever true.'\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmccxxxix{%
Upon that day We shall leave them surging on one another, and the Trumpet shall he blown, and We shall gather them together,\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmccxl{%
and upon that day We shall present Gehenna to the unbelievers\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmccxli{%
whose eyes were covered against My remembrance, and they were not able to hear.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmccxlii{%
What, do the unbelievers reckon that they may take My servants as friends, apart from Me? We have prepared Gehenna for the unbelievers' hospitality.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmccxliii{%
Say: 'Shall We tell you who will be the greatest losers in their works?\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmccxliv{%
Those whose striving goes astray in the present life, while they think that they are working good deeds.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmccxlv{%
Those are they that disbelieve in the signs of their Lord and the encounter with Him; their works have failed, and on the Day of Resurrection We shall not assign to them any weight.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmccxlvi{%
That is their recompense -- Gehenna for that they were unbelievers and took My signs and My messengers in mockery.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmccxlvii{%
But those who believe, and do deeds of righteousness -- the Gardens. of Paradise shall be their hospitality,\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmccxlviii{%
therein to dwell forever, desiring no removal out of them.'\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmccxlix{%
Say:. 'If the sea were ink for the Words of my Lord, the sea would be spent before the Words of my Lord are spent, though We brought replenishment the like of it.'\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmccl{%
Say: 'I am only a mortal the like of you; it is revealed to me that your God is One God. So let him, who hopes for the encounter with his Lord, work righteousness, and not associate with his Lord's service anyone.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmccli{%
\basmalahen Kaf Ha Ya Ain Sad\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcclii{%
The mention of thy Lord's mercy unto His servant Zachariah;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmccliii{%
when he called upon his Lord secretly\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmccliv{%
saying, 'O my Lord, behold the bones within me are feeble and my head is all aflame with hoariness. And in calling on Thee, my Lord, I have never been hitherto unprosperous.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcclv{%
And now I fear my kinsfolk after I am gone; and my wife is barren. So give me, from Thee, a kinsman\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcclvi{%
who shall be my inheritor and the inheritor of the House of Jacob; and make him, my Lord, well-pleasing.'\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcclvii{%
'O Zachariah, We give thee good tidings of a boy, whose name is John. No namesake have We given him aforetime.'\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcclviii{%
He said, 'O my Lord, how shall I have a son, seeing my wife is barren, and I have attained to the declining of old age?'\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcclix{%
Said He, 'So it shall be; thy Lord says, ``Easy is that for Me, seeing that I created thee aforetime, when thou wast nothing."'\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcclx{%
He said, 'Lord, appoint to me some sign.' Said He, 'Thy sign is that thou shall not speak to men, though being without fault, three nights.'\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcclxi{%
So he came forth unto his people from the Sanctuary, then he made signal to them, 'Give you glory at dawn and evening.'\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcclxii{%
'O John, take the Book forcefully'; and We gave him judgment, yet a little child,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcclxiii{%
and a tenderness from Us, and purity; and he was godfearing,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcclxiv{%
and cherishing his parents, not arrogant, rebellious.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcclxv{%
'Peace be upon him, the day he was born, and the day he dies, and the day he is raised up alive!'\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcclxvi{%
And mention in the Book Mary when she withdrew from her people to an eastern place,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmcclxvii{%
and she took a veil apart from them; then We sent unto her Our Spirit that presented himself to her a man without fault.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmcclxviii{%
She said, 'I take refuge in the All-merciful from thee!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmcclxix{%
If thou fearest God... He said, 'I am but a messenger come from thy Lord, to give thee a boy most pure.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmcclxx{%
She said, 'How shall I have a son whom no mortal has touched, neither have I been unchaste?'\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmcclxxi{%
He said, 'Even so thy Lord has said: ``Easy is that for Me; and that We may appoint him a sign unto men and a mercy from Us; it is a thing decreed."'\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmcclxxii{%
So she conceived him, and withdrew with him to a distant place.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmcclxxiii{%
And the birthpangs surprised her by the trunk of the palm-tree. She said, 'Would I had died ere this, and become a thing forgotten!'\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmcclxxiv{%
But the one that was below her called to her, 'Nay, do not sorrow; see, thy Lord has set below thee a rivulet.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmcclxxv{%
Shake also to thee the palm-trunk, and there shall come tumbling upon thee dates fresh and ripe.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmcclxxvi{%
Eat therefore, and drink, and be comforted; and if thou shouldst see any mortal, say, ``I have vowed to the All-merciful a fast, and today I will not speak to any man.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmcclxxvii{%
Then she brought the child to her folk carrying him; and they said, 'Mary, thou hast surely committed a monstrous thing!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmcclxxviii{%
Sister of Aaron, thy father was not a wicked man, nor was thy mother a woman unchaste.'\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmcclxxix{%
Mary pointed to the child then; but they said, 'How shall we speak to one who is still in the cradle, a little child?'\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmcclxxx{%
He said, 'Lo, I am God's servant; God has given me the Book, and made me a Prophet.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmcclxxxi{%
Blessed He has made me, wherever I may be; and He has enjoined me to pray, and to give the alms, so long as I live,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmcclxxxii{%
and likewise to cherish my mother; He has not made me arrogant, unprosperous.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmcclxxxiii{%
Peace be upon me, the day I was born, and the day I die, and the day I am raised up alive!'\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmcclxxxiv{%
That is Jesus, son of Mary, in word of truth, concerning which they are doubting.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmcclxxxv{%
It is not for God to take a son unto Him. Glory be to Him! When He decrees a thing, He but says to it 'Be,' and it is.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmcclxxxvi{%
Surely God is my Lord, and your Lord; So serve you Him. This is a straight path.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmcclxxxvii{%
But the parties have fallen into variance among themselves; then woe to those who disbelieve for the scene of a dreadful day.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmcclxxxviii{%
How well they will hear and see on the day they come to Us! But the evildoers even today are in error manifest.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmcclxxxix{%
Warn thou them of the day of anguish, when the matter shall be determined, and they yet heedless and unbelieving.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmccxc{%
Surely We shall inherit the earth and all that are upon it, and unto Us they shall be returned.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmccxci{%
And mention in the Book Abraham; surely he was a true man, a Prophet.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmccxcii{%
When he said to his father, 'Father, why worshippest thou that which neither hears nor sees, nor avails thee anything?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmccxciii{%
Father, there has come to me knowledge such as came not to thee; so follow me, and I will guide thee on a level path.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmccxciv{%
Father, serve not Satan; surely Satan is a rebel against the All-merciful.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmccxcv{%
Father, I fear that some chastisement from the All-merciful will smite thee, so that thou becomest a friend to Satan.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmccxcvi{%
Said he, 'What, art thou shrinking from my gods, Abraham? Surely, if thou givest not over, I shall stone thee; so forsake me now for some while.'\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmccxcvii{%
He said, 'Peace be upon thee! I will ask my Lord to forgive thee; surely He is ever gracious to me.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmccxcviii{%
Now I will go apart from you and that you call upon, apart from God; I will call upon my Lord, and haply I shall not be, in calling upon my Lord, unprosperous.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmccxcix{%
So, when he went apart from them and that they were serving, apart from God, We gave him Isaac and Jacob, and each We made a Prophet;\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmccc{%
and We gave them of Our mercy, and We appointed unto them a tongue of truthfulness, sublime.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmccci{%
And mention in the Book Moses; he was devoted, and he was a Messenger, a Prophet.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcccii{%
We called to him from the right side Of the Mount, and We brought him near in communion.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmccciii{%
And We gave him his brother Aaron, of Our mercy, a Prophet.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmccciv{%
And mention in the Book Ishmael; he was true to his promise, and he was a Messenger, a Prophet.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcccv{%
He bade his people to pray and to give the alms, and he was pleasing to his Lord.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcccvi{%
And mention in the Book Idris; he was a true man, a Prophet.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcccvii{%
We raised him up to a high place.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcccviii{%
These are they whom God has blessed among the Prophets of the seed of Adam, and of those We bore with Noah, and of the seed of Abraham and Israel, and of those We guided and chose. When the signs of the All-merciful were recited to them, they fell down prostrate, weeping.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcccix{%
Then there succeeded after them a succession who wasted the prayer, and followed lusts; so they shall encounter error\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcccx{%
save him who repents, and believes, and does a righteous deed; those -- they shall enter Paradise, and they shall not be wronged anything;\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcccxi{%
Gardens of Eden that the All-merciful promised His servants in the Unseen; His promise is ever performed.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcccxii{%
There they shall hear no idle talk, but only 'Peace.' There they shall have their provision at dawn and evening.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcccxiii{%
That is Paradise which We shall give as an inheritance to those of Our servants who are godfearing.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcccxiv{%
We come not down, save at the commandment of thy Lord. To Him belongs all that is before us, and all that is behind us, and all between that.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcccxv{%
And thy Lord is never forgetful, Lord He of the heavens and earth and all that is between them. So serve Him, and be thou patient in His service; knowest thou any that can be named with His Name?\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcccxvi{%
Man says, 'What, when I am dead shall I then be brought forth alive?'\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcccxvii{%
Will not man remember that We created him aforetime, when he was nothing?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcccxviii{%
Now, by thy Lord, We shall surely muster them, and the Satans, then We shall parade them about Gehenna hobbling on their knees.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcccxix{%
Then We shall pluck forth from every party whichever of them was the most hardened in disdain of the All-merciful;\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcccxx{%
then We shall know very well those most deserving to burn there.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcccxxi{%
Not one of you there is, but he shall go down to it; that for thy Lord is a thing decreed, determined.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcccxxii{%
Then We shall deliver those that were godfearing; and the evildoers We shall leave there, hobbling on their knees.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcccxxiii{%
When Our signs are recited to them as clear signs, the unbelievers say to the believers, 'Which of the two parties is better in station, fairer in assembly?'\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcccxxiv{%
And how many a generation We destroyed before them, who were fairer in furnishing and outward show!\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcccxxv{%
Say: 'Whosoever is in error, let the All-merciful prolong his term for him! Till, when they see that they were threatened, whether the chastisement, or the Hour, then they shall surely know who is worse in place, and who is weaker in hosts.'\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcccxxvi{%
And God shall increase those who were guided in guidance; and the abiding things, the deeds of righteousness, are better with thy Lord in reward, and better in return\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcccxxvii{%
Hast thou seen him who disbelieves in Our signs and says, 'Assuredly I shall be given wealth and children'?\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcccxxviii{%
What, has he observed the Unseen, or taken a covenant with the All-merciful?\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcccxxix{%
No, indeed! We shall assuredly write down all that he says, and We shall prolong for him the chastisement;\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcccxxx{%
and We shall inherit from him that he says, and he shall come to Us alone.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcccxxxi{%
And they have taken to them other gods apart from God, that they might be for them a might.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcccxxxii{%
No, indeed! They shall deny their service, and they shall be against them pitted.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcccxxxiii{%
Hast thou not seen how We sent the Satans against the unbelievers, to prick them?\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcccxxxiv{%
So hasten thou not against them; We are only numbering for them a number.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcccxxxv{%
On the day that We shall muster the godfearing to the All-merciful with pomp\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcccxxxvi{%
and drive the evildoers into Gehenna herding,\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcccxxxvii{%
having no power of intercession, save those who have taken with the All-merciful covenant.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcccxxxviii{%
And they say, 'The All-merciful has taken unto Himself a son.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcccxxxix{%
You have indeed advanced something hideous!\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcccxl{%
The heavens are wellnigh rent of it and the earth split asunder, and the mountains wellnigh fall down crashing for\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcccxli{%
that they have attributed to the All-merciful a son;\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcccxlii{%
and it behoves not the All-merciful to take a son.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcccxliii{%
None is there in the heavens and earth but he comes to the All-merciful as a servant;\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcccxliv{%
He has indeed counted them, and He has numbered them exactly.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcccxlv{%
Every one of them shall come to Him upon the Day of Resurrection, all alone.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcccxlvi{%
Surely those who believe and do deeds of righteousness -- unto them the All-merciful shall assign love.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcccxlvii{%
Now We have made it easy by thy tongue that thou mayest bear good tidings thereby to the godfearing, and warn a people stubborn.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcccxlviii{%
And how many a generation We destroyed before them! Dost thou perceive so much as one of them, or hear of them a whisper?\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcccxlix{%
\basmalahen Ta Ha\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcccl{%
We have not sent down the Koran upon thee for thee to be unprosperous,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcccli{%
but only as a reminder to him who tears,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmccclii{%
a revelation from Him who created the earth and the high heavens;\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcccliii{%
the All-compassionate sat Himself upon the Throne; to Him belongs\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcccliv{%
all that is in the heavens and the earth and all that is between them, and all that is underneath the soil.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmccclv{%
Be thou loud in thy speech, yet surely He knows the secret and that yet more hidden.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmccclvi{%
God -- there is no god but He. To Him belong the Names Most Beautiful.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmccclvii{%
Hast thou received the story of Moses?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmccclviii{%
When he saw a fire, and said to his family, 'Tarry you here; I observe a fire. Perhaps I shall bring you a brand from it, or I shall find at the fire guidance.'\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmccclix{%
When he came to it, a voice cried, 'Moses,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmccclx{%
I am thy Lord; put off thy shoes; thou art in the holy valley, Towa.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmccclxi{%
I Myself have chosen thee; therefore give thou ear to this revelation.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmccclxii{%
Verily I am God; there is no god but I; therefore serve Me, and perform the prayer of My remembrance.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmccclxiii{%
The Hour is coming; I would conceal it that every soul may be recompensed for its labours.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmccclxiv{%
Let none bar thee from it, that believes not in it but follows after his own caprice, or thou wilt perish.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmccclxv{%
What is that, Moses, thou hast in thy right hand?'\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmccclxvi{%
'Why, it is my staff,' said Moses. 'I lean upon it, and with it I beat down leaves to feed my sheep; other uses also I find in it.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmccclxvii{%
Said He, 'Cast it down, Moses!'\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmccclxviii{%
and he cast it down, and behold it was a serpent sliding.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmccclxix{%
Said He, 'Take it, and fear not; We will restore it to its first state.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmccclxx{%
Now clasp thy hand to thy arm-pit; it shall come forth white, without evil. That is a second sign.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmccclxxi{%
So We would show thee some of Our greatest signs.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmccclxxii{%
Go to Pharaoh; he has waxed insolent.'\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmccclxxiii{%
'Lord, open my breast,' said Moses,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmccclxxiv{%
'and do Thou ease for me my task.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmccclxxv{%
Unloose the knot upon my tongue, t\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmccclxxvi{%
hat they may understand my words.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmccclxxvii{%
Appoint for me of my folk a familiar,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmccclxxviii{%
Aaron, my brother;\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmccclxxix{%
by him confirm my strength,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmccclxxx{%
and associate him with me in my task.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmccclxxxi{%
So shall we glorify Thee,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmccclxxxii{%
and remember Thee abundantly.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmccclxxxiii{%
Surely Thou seest into us.'\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmccclxxxiv{%
Said He, 'Thou art granted, Moses, thy petition.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmccclxxxv{%
Already another time We favoured thee,\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmccclxxxvi{%
when We revealed what was revealed unto thy mother:\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmccclxxxvii{%
``Cast him into the ark, and cast him into the river, and let the river throw him up on the shore. An enemy of Mine and his shall take him." And I loaded on thee love from Me, and to be formed in My sight,\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmccclxxxviii{%
when thy sister went out, saying, ``Shall I point you to one to have charge of him?" So We returned thee to thy mother that she might rejoice, and not sorrow. Then thou slewest; a living soul, and We delivered thee out of grief, and We tried thee with many trials. Many years among the people of Midian thou didst sojourn, then camest hither, Moses, according to a decree.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmccclxxxix{%
I have chosen thee for My service;\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmcccxc{%
go therefore, thou and thy brother; with My signs, and neglect not to remember Me.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmcccxci{%
Go to Pharaoh, for he has waxed insolent;\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmcccxcii{%
yet speak gently to him, that haply he may be mindful, or perchance fear.'\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcccxciii{%
'O our Lord,' said Moses and Aaron, 'truly we fear he may exceed against us, or wax insolent.'\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcccxciv{%
'Fear not,' said He. 'Surely I shall be with you, hearing and seeing.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcccxcv{%
So go you both to Pharaoh, and say, ``We are the Messengers of thy Lord, so send forth with us the Children of Israel and chastise them not; we have brought thee a sign from thy Lord; and peace be upon him who follows the guidance!\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcccxcvi{%
It has been revealed to us that chastisement shall light upon him who cries lies and turns his back."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcccxcvii{%
Pharaoh said, 'Who is your Lord, Moses?'\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcccxcviii{%
He said, 'Our Lord is He who gave everything its creation, then guided it.'\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcccxcix{%
Pharaoh said, 'And what of the former generations?'\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcd{%
Said Moses, 'The knowledge of them is with my Lord, in a Book; my Lord goes not astray, nor forgets --\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcdi{%
He who appointed the earth to be a cradle for you, and therein threaded roads for you, and sent down water out of heaven, and therewith We have brought forth divers kinds of plants.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcdii{%
Do you eat, and pasture your cattle! Surely in that are signs for men possessing reason.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcdiii{%
Out of the earth We created you, and We shall restore you into it, and bring you forth from it a second time.'\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcdiv{%
So We showed Pharaoh all Our signs, but he cried lies, and refused.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcdv{%
'Hast thou come, Moses,' he said, 'to expel us out of our land\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcdvi{%
by thy sorcery? We shall assuredly bring thee sorcery the like of it; therefore appoint a tryst between us and thee, a place mutually agreeable, and we shall not fail it, neither thou.'\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcdvii{%
'Your tryst shall be upon the Feast Day.' said Moses. 'Let the people be mustered at the high noon.'\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcdviii{%
Pharaoh then withdrew, and gathered his guile. Thereafter he came again,\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcdix{%
and Moses said to them, 'O beware! Forge not a lie against God, lest He destroy you with a chastisement. Whoso forges has ever failed.'\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcdx{%
And they disputed upon their plan between them, and communed secretly\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcdxi{%
saying, 'These two men are sorcerers and their purpose is to expel you out of your land by their sorcery, and to extirpate your justest way.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcdxii{%
So gather your guile; then come in battle-line. Whoever today gains the upper hand shall surely prosper.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcdxiii{%
They said, 'Moses, either thou wilt cast, or we shall be the first to cast.'\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcdxiv{%
'No,' said Moses. 'Do you cast!' And lo, it seemed to him, by their sorcery, their ropes and their staffs were sliding;\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcdxv{%
and Moses conceived a fear within him.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcdxvi{%
We said unto him, 'Fear not; surely thou art the uppermost.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcdxvii{%
Cast down what is in thy right hand, and it shall swallow what they have fashioned; for they have fashioned only the guile of a sorcerer, and the sorcerer prospers not; wherever he goes.'\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcdxviii{%
And the sorcerers cast themselves down prostrating. 'We believe,' they said, 'in the Lord of Aaron and Moses.'\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcdxix{%
Pharaoh said, 'Have you believed him before I gave you leave? Why, he is the chief of you, the same that taught you sorcery; I shall assuredly cut off alternately your hands and feet, then I shall crucify you upon the trunks of palm-trees; you shall know of a certainty which of us is more terrible in chastisement, and more abiding.'\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcdxx{%
They said, 'We will not prefer thee over the clear signs that have come to us, nor over Him who originated us. Decide then what thou wilt decide; thou canst only decide touching this present life.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcdxxi{%
We believe in our Lord, that He may pardon us our offences, and the sorcery thou hast constrained us to practise; God is better, and more abiding.'\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcdxxii{%
Whosoever comes unto his Lord a sinner, for him awaits Gehenna wherein he shall neither die nor live.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcdxxiii{%
And whoso comes unto Him a believer having done deeds of righteousness, those -- for them await the most sublime degrees;\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcdxxiv{%
Gardens of Eden, underneath which rivers flow, therein dwelling forever; that is the recompense of the self-purified.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcdxxv{%
Also We revealed unto Moses, 'Go with My servants by night; strike for them a dry path in the sea, fearing not overtaking, neither afraid.'\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcdxxvi{%
Pharaoh followed them with his hosts, but they were overwhelmed by the sea;\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcdxxvii{%
so Pharaoh had led his people astray, and was no guide to them.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcdxxviii{%
Children of Israel, We delivered you from your enemy; and We made covenant with you upon the right side of the Mount, and sent down on you manna and quails:\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcdxxix{%
'Eat of the good things wherewith We have provided you; but exceed not therein, or My anger shall alight on you; and on whomsoever My anger alights, that man is hurled to ruin.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcdxxx{%
Yet I am All-forgiving to him who repents and believes, and does righteousness, and at last is guided.'\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcdxxxi{%
'What has sped thee far from thy people, Moses?'\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcdxxxii{%
'They are upon my tracks,' Moses said. 'I have hastened, Lord, only that I may please Thee.'\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcdxxxiii{%
Said He, 'We have tempted thy people since thou didst leave them. The Samaritan has misled them into error.'\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcdxxxiv{%
Then Moses returned very angry and sorrowful to his people, saying, 'My people, did your Lord not promise a fair promise to you? Did the time of the covenant seem so long to you, or did you desire that anger should alight on you from your Lord, so that you failed in your tryst with me?'\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcdxxxv{%
'We have not failed in our tryst with thee,' they said, 'of our volition; but we were loaded with fardels, even the ornaments of the people, and we cast them, as the Samaritan also threw them, into the fire.'\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcdxxxvi{%
(Then he brought out for them a Calf, a mere body that lowed; and they said, 'This is your god, and the god of Moses, whom he has forgotten.'\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcdxxxvii{%
What? Did they not see that thing returned no speech unto them, neither had any power to hurt or profit them?\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcdxxxviii{%
Yet Aaron had aforetime said to them, 'My people, you have been tempted by this thing, no more; surety your Lord is the All-merciful; therefore follow me, and obey my commandment!'\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcdxxxix{%
'We will not cease,' they said, 'to cleave to it, until Moses returns to us.')\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcdxl{%
Moses said, 'What prevented thee, Aaron, when thou sawest them in error,\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcdxli{%
so that thou didst not follow after me? Didst thou then disobey my commandment?'\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcdxlii{%
'Son of my mother,' Aaron said, 'take me not by the beard, or the head! I was fearful that thou wouldst say, ``Thou hast divided the Children of Israel, and thou hast not observed my word."\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcdxliii{%
Moses said, 'And thou, Samaritan, what was thy business?'\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcdxliv{%
'I beheld what they beheld not,' he said, 'and I seized a handful of dust from the messenger's track, and cast it into the thing. So my soul prompted me.'\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcdxlv{%
'Depart!' said Moses. 'It shall be thine all this life to cry ``Untouchable!" And thereafter a tryst awaits thee thou canst not fail to keep Behold thy god, to whom all the day thou wast cleaving! We will surely burn it and scatter its ashes into the sea.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcdxlvi{%
Your God is only the One God; there is no god, but He alone who in His knowledge embraces everything.'\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcdxlvii{%
So We relate to thee stories of what has gone before, and We have given thee a remembrance from Us.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmcdxlviii{%
Whosoever turns away from it, upon the Day of Resurrection He shall bear a fardel,\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmcdxlix{%
therein abiding forever; how evil upon the Day of Resurrection that burden for them!\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmcdl{%
On the day the Trumpet is blown; and We shall muster the sinners upon that day with eyes staring,\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmcdli{%
whispering one to another, 'You have tarried only ten nights.'\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmcdlii{%
We know very well what they will say, when the justest of them in the way will say, 'You have tarried only a day.'\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmcdliii{%
They will question thee concerning the mountains. Say: 'My Lord will scatter them as ashes;\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmcdliv{%
then He will leave them a level hollow\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmcdlv{%
wherein thou wilt see no crookedness neither any curving.'\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmcdlvi{%
On that day they will follow the Summoner in whom is no crookedness; voices will be hushed to the All-merciful, so that thou hearest naught but a murmuring.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmcdlvii{%
Upon that day the intercession will not profit, save for him to whom the All-merciful gives leave, and whose speech He approves.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmcdlviii{%
He knows what is before them and behind them, and they comprehend Him not in knowledge.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmcdlix{%
And faces shall be humbled unto the Living, the Eternal. He will have failed whose burden is of evildoing;\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmcdlx{%
but whosoever does deeds of righteousness, being a believer, shall fear neither wrong nor injustice.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmcdlxi{%
Even so We have sent it down as an Arabic Koran, and We have turned about in it something of threats, that haply they may be godfearing, or it may arouse in them remembrance.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmcdlxii{%
So high exalted be God, the true King! And hasten not with the Koran ere its revelation is accomplished unto thee; and say, 'O my Lord, increase me in knowledge.'\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmcdlxiii{%
And We made covenant with Adam before, but he forgot, and We found in him no constancy.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmcdlxiv{%
And when We said to the angels, 'Bow yourselves to Adam'; so they bowed themselves, save Iblis; he refused.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmcdlxv{%
Then We said, 'Adam, surely this is an enemy to thee and thy wife. So let him not expel you both from the Garden, so that thou art unprosperous.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmcdlxvi{%
It is assuredly given to thee neither to hunger therein, nor to go naked,\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmcdlxvii{%
neither to thirst therein, nor to suffer the sun.'\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmcdlxviii{%
Then Satan whispered to him saying, 'Adam, shall I point thee to the Tree of Eternity, and a Kingdom that decays not?'\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmcdlxix{%
So the two of them ate of it, and their shameful parts revealed to them, and they took to stitching upon themselves leaves of the Garden. And Adam disobeyed his Lord, and so he erred.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmcdlxx{%
Thereafter his Lord chose him, and turned again unto him, and He guided him.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmcdlxxi{%
Said He, 'Get you down, both of you together, out of it, each of you an enemy to each; but if there comes to you from Me guidance, then whosoever follows My guidance shall not go astray, neither shall he be unprosperous;\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmcdlxxii{%
but whosoever turns away from My remembrance, his shall be a life of narrowness, and on the Resurrection Day We shall raise him blind.'\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmcdlxxiii{%
He shall say, 'O my Lord, why hast thou raised me blind, and I was wont to see?'\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmcdlxxiv{%
God shall say, 'Even so it is. Our signs came unto thee, and thou didst forget them; and so today thou art forgotten.'\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmcdlxxv{%
So We recompense him who is prodigal and believes not in the signs of his Lord; and the chastisement of the world to come is more terrible and more enduring.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmcdlxxvi{%
Is it not a guidance to them, how many generations We destroyed before them in whose dwelling-places they walk? Surely in that are signs for men possessing reason.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmcdlxxvii{%
And but for a word that preceded from thy Lord, and a stated term, it had been fastened.\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmcdlxxviii{%
So be thou patient under what they say, and proclaim thy Lord's praise before the rising of the sun, and before its setting, and proclaim thy Lord's praise in the watches of the night, and at the ends of the day; haply thou wilt be well-pleasing.\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmcdlxxix{%
Stretch not thine eyes to that We have given pairs of them to enjoy - the flower of the present life, that We may try them therein and thy Lord's provision is better, and more enduring.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmcdlxxx{%
And bid thy family to pray, and be thou patient in it; We ask of thee no provision, but it is We who provide thee and the issue ultimate is to godfearing.\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmcdlxxxi{%
They say, 'Why does he not bring us a sign from his Lord?' Has there not come to them the clear sign of what is in the former scrolls?\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmcdlxxxii{%
Had We destroyed them with a chastisement aforetime, they would have said, 'Our Lord, why didst Thou not send us a Messenger, so that we might have followed Thy signs before that we were humiliated and degraded?'\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmcdlxxxiii{%
Say: 'Everyone is waiting; so wait, and assuredly you shall know who are the travellers on the even path, and who is guided.'\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmcdlxxxiv{%
\basmalahen Nigh unto men has drawn their reckoning, while they in heedlessness are yet turning away;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcdlxxxv{%
no Remembrance from their Lord comes to them lately renewed, but they listen to it yet playing,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcdlxxxvi{%
diverted their hearts. The evildoers whisper one to another, 'Is this aught but a mortal like to yourselves? What, will you take to sorcery with your eyes open?'\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcdlxxxvii{%
He says: 'My Lord knows what is said in the heavens and the earth, and He is the All-hearing, the All-knowing.'\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcdlxxxviii{%
Nay, but they say: 'A hotchpotch of nightmares! Nay, he has forged it; nay, he is a poet! Now therefore let him bring us a sign, even as the ancient ones were sent as Messengers.'\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcdlxxxix{%
Not one city that We destroyed before them believed; what then, will they not believe?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcdxc{%
And We sent none before thee, but men to whom We made revelation -- question the People of the Remembrance, if you do not know --\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcdxci{%
nor did We fashion them as bodies that ate not food, neither were they immortal;\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcdxcii{%
then We made true the promise We gave them and We delivered them, and whomsoever We would; and We destroyed the prodigal.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcdxciii{%
Now We have sent down to you a Book wherein is your Remembrance; will you not understand?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcdxciv{%
How many a city that was evildoing We have shattered, and set up after it another people!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcdxcv{%
Then, when they perceived Our might, behold, they ran headlong out of it.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcdxcvi{%
'Run not! Return you unto the luxury that you exulted in, and your dwelling-places; haply you shall be questioned.'\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcdxcvii{%
They said, 'Alas for us! We have been evildoers.'\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcdxcviii{%
So they ceased not to cry, until We made them stubble, silent and still.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcdxcix{%
We created not the heaven and the earth, and whatsoever between them is, as playing;\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmd{%
had We desired to take to Us a diversion We would have taken it to Us from Ourselves, had We done aught.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdi{%
Nay, but We hurl the truth against falsehood and it prevails over it, and behold, falsehood vanishes away. Then woe to you for that you describe!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdii{%
To Him belongs whosoever is in the heavens and the earth; and those who are with Him wax not too proud to do Him service neither grow weary,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdiii{%
glorifying Him by night and in the daytime and never failing.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdiv{%
Or have they taken gods out of the earth who raise the dead?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdv{%
Why, were there gods in earth and heaven other than God, they would surely go to ruin; so glory be to God, the Lord of the Throne, above that they describe!\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdvi{%
He shall not be questioned as to what He does, but they shall he questioned.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdvii{%
Or have they taken gods apart from Him? Say: 'Bring your proof! This is the Remembrance of him who is with me, and the Remembrance of those before me. Nay, but the most part of them know not the truth, so therefore they are turning away.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdviii{%
And We sent never a Messenger before thee except that We revealed to him, saying, 'There is no god but I; so serve Me.'\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdix{%
They say:' 'The All-merciful has taken to Him a son.' Glory be to Him! Nay, but they are honoured servants\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdx{%
that outstrip Him not in speech, and perform as He commands.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdxi{%
He knows what is before them and behind them, and they intercede not save for him with whom He is well-pleased, and they tremble in awe of Him.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdxii{%
If any of them says, 'I am a god apart from Him', such a one We recompense with Gehenna; even so We recompense the evildoers.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdxiii{%
Have not the unbelievers then beheld that the heavens and the earth were a mass all sewn up, and then We unstitched them and of water fashioned every living thing? Will they not believe?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdxiv{%
And We set in the earth firm mountains lest it should shake with them, and We set in it ravines to serve as ways, that haply so they may be guided;\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdxv{%
and We set up the heaven as a roof well-protected; yet still from Our signs they are turning away.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdxvi{%
It is He who created the night and the day, the sun and the moon, each swimming in a sky.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdxvii{%
We have not assigned to any mortal before thee to live forever; therefore, if thou diest, will they live forever?\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdxviii{%
Every soul shall taste of death; and We try you with evil and good for a testing, then unto Us you shall be returned.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdxix{%
When the unbelievers behold thee, they take thee only for mockery: 'Ha, is this the one who makes mention of your gods?' Yet they in the Remembrance of the All-merciful are unbelievers.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdxx{%
Man was created of haste. Assuredly I shall show you My signs; so demand not that I make haste.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdxxi{%
They say, 'And when shall the promise come to pass, if you speak truly?'\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdxxii{%
If the unbelievers but knew when that they shall not ward off the Fire from their faces nor from their backs, neither shall they be helped!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdxxiii{%
Nay, but it shall come upon them suddenly, dumbfounding them, and they shall not be able to repel it, nor shall they be respited.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdxxiv{%
Messengers indeed were mocked at before thee, but those that scoffed at them were encompassed by that they mocked at.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdxxv{%
Say: 'Who shall guard you by night and in the daytime from the All-merciful?' Nay, but from the Remembrance of their Lord they are turning away.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdxxvi{%
Or have they gods that shall defend them apart from Us? Why, they are not able to help themselves, nor shall they be guarded in safety from Us.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdxxvii{%
Nay, but Ourselves gave these and their fathers enjoyment of days, until their life had lasted long while upon them. What, do they not see how We come to the land, diminishing it in its extremities? Or are they the victors?\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdxxviii{%
Say: 'I warn you only by the Revelation'; but they that are deaf do not hear the call when they are warned.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdxxix{%
If but a breath of thy Lord's chastisement touched them, they would surely say, 'Alas for us! We were evildoers.'\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdxxx{%
And We shall set up the just balances for the Resurrection Day, so that not one soul shall be wronged anything; even if it be the weight of one grain of mustard-seed We shall produce it, and sufficient are We for reckoners.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdxxxi{%
We gave Moses and Aaron the Salvation and a Radiance, and a Remembrance for the godfearing\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdxxxii{%
such as fear God in the Unseen, trembling because of the Hour.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdxxxiii{%
And this is a blessed Remembrance that We have sent down; so are you now denying it?\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdxxxiv{%
We gave Abraham aforetime his rectitude -- for We knew him --\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdxxxv{%
when he said to his father and his people, 'What are these statues unto which you are cleaving?'\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdxxxvi{%
They said, 'We found our fathers serving them.'\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdxxxvii{%
He said, 'Then assuredly you and your fathers have been in manifest error.'\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdxxxviii{%
They said, 'What, hast thou come to us with the truth, or art thou one of those that play?'\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdxxxix{%
He said, 'Nay, but your Lord is the Lord of the heavens and the earth who originated them, and I am one of those that bear witness thereunto.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdxl{%
And, by God, I shall assuredly outwit your idols, after you have gone away turning your backs.'\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdxli{%
So he broke them into fragments, all but a great one they had, for haply they would return to it.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdxlii{%
They said, 'Who has. done this with our gods? Surely he is one of the evildoers.'\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdxliii{%
They said, 'We heard a young man making mention of them, and he was called Abraham.'\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdxliv{%
They said, 'Bring him before the people's eyes; haply they shall bear witness.'\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdxlv{%
They said, 'So, art thou the man who did this unto our gods, Abraham?'\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdxlvi{%
He said, 'No; it was this great one of them that did it. Question them; if they are able to speak!'\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdxlvii{%
So they returned one to another, and they said, 'Surely it is you who are the evildoers.'\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdxlviii{%
Then they were utterly put to confusion saying, 'Very well indeed thou knowest these do not speak.'\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdxlix{%
He said, 'What, and do you serve, apart from God, that which profits you nothing; neither hurts you?\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdl{%
Fie upon you and that you serve apart from God! Do you not understand?'\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdli{%
They said, 'Burn him, and help your gods, if you would do aught.'\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdlii{%
We said, 'O fire, be coolness and safety for Abraham!'\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdliii{%
They desired to outwit him; so We made them the worse losers,\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdliv{%
and We delivered him, and Lot, unto the land that We had blessed for all beings.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdlv{%
And We gave him Isaac and Jacob in superfluity, and every one made We righteous\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdlvi{%
and appointed them to be leaders guiding by Our command, and We revealed to them the doing of good deeds, and to perform the prayer, and to pay the alms, and Us they served.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdlvii{%
And Lot -- to him We gave judgment and knowledge; and we delivered him from the city that had been doing deeds of corruption; they were an evil people, truly ungodly;\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdlviii{%
and We admitted him into Our mercy; he was of the righteous.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdlix{%
And Noah -- when he called before, and We answered him, and delivered him and his people from the great distress,\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdlx{%
and We helped him against the people who cried lies to Our signs; surely they were an evil people, so We drowned them all together.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdlxi{%
And David and Solomon -- when they gave judgment concerning the tillage, when the sheep of the people strayed there, and We bore witness to their judgment;\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdlxii{%
and We made Solomon to understand it, and unto each gave We judgment and knowledge. And with David We subjected the mountains to give glory, and the birds, and We were doers.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmdlxiii{%
And We taught him the fashioning of garments for you, to fortify you against your violence; then are you thankful?\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmdlxiv{%
And to Solomon the wind, strongly blowing, that ran at his command unto the land that We had blessed; and We had knowledge of everything;\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmdlxv{%
and of the Satans some dived for him and did other work besides; and We were watching over them.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmdlxvi{%
And Job -- when he called unto his Lord, 'Behold, affliction has visited me, and Thou art the most merciful of the merciful.'\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmdlxvii{%
So We answered him, and removed the affliction that was upon him, and We gave his people, and the like of them with them, mercy from Us, and a Reminder to those who serve.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmdlxviii{%
And Ishmael, Idris, Dhul Kifl -- each was of the patient,\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmdlxix{%
and We admitted them into Our mercy; they were of the righteous.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmdlxx{%
And Dhul Nun -- when he went forth enraged and thought that We would have no power over him; then he called out in the darkness, 'There is no god but Thou. Glory be to Thee! I have done evil.'\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmdlxxi{%
So We answered him, and delivered him out of grief; even so do, We deliver the believers.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmdlxxii{%
And Zachariah -- when he called unto his Lord, 'O my Lord, leave me not solitary; though Thou art the best of inheritors.'\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmdlxxiii{%
So We answered him, and bestowed on him John, and We set his wife right for him; truly they vied with one another, hastening to good works, and called upon Us out of yearning and awe; and they were humble to Us.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmdlxxiv{%
And she who guarded her virginity, so We breathed into her of Our spirit and appointed her and her son to be a sign unto all beings.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmdlxxv{%
'Surely this community of yours is one community, and I am your Lord; so serve Me.'\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmdlxxvi{%
But they split up their affair between them; all shall return to Us.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmdlxxvii{%
And whosoever does deeds of righteousness, being a believer, no unthankfulness shall befall his endeavour; We Ourselves write it down for him.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmdlxxviii{%
There is a ban upon any city that We have destroyed; they shall not return\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmdlxxix{%
till, when Gog and Magog are unloosed, and they slide down out of every slope,\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmdlxxx{%
and nigh has drawn the true promise, and behold, the eyes of the unbelievers staring: 'Alas for us! We were heedless of this; 'nay, we were evildoers.'\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmdlxxxi{%
'Surely you, and that you were serving apart from God, are fuel for Gehenna; you shall go down to it.'\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmdlxxxii{%
If those had been gods, they would never have gone down to it; yet every one of them shall therein abide forever;'\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmdlxxxiii{%
there shall be sighing for them therein, and naught they shall hear.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmdlxxxiv{%
But as for those unto whom already the reward most fair has gone forth from Us,\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmdlxxxv{%
they shall be, kept far from it neither shall they hear any whisper of it, and they shall dwell forever in that their souls desired;\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmdlxxxvi{%
the greatest terror shall not grieve them, and the angels shall receive them: 'This is your day that you were promised.'\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmdlxxxvii{%
On the day when We shall roll up heaven as a scroll is rolled for the writings; as We originated the first creation, so We shall bring it back again -- a promise binding on Us; so We shall do.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmdlxxxviii{%
For We have written in the Psalms, after the Remembrance, 'The earth shall be the inheritance of My righteous servants.'\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmdlxxxix{%
Surely in this is a Message delivered unto a people who serve.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmdxc{%
We have not sent thee, save as a mercy unto all beings.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmdxci{%
Say: 'It is revealed unto me only that your God is One God; do you then surrender?'\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmdxcii{%
Then, if they should turn their backs, say: 'I have proclaimed to you all equally, even though I know not whether near or far is that you are promised.'\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmdxciii{%
Surely He knows what is spoken aloud and He knows what you hide.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmdxciv{%
I know not; haply it is a trial for you and an enjoyment for a time.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmdxcv{%
He said: 'My Lord, judge Thou with truth! And our Lord is the All-merciful; His succour is ever to be sought against that you describe.'\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmdxcvi{%
\basmalahen O men, fear your Lord! Surely the earthquake of the Hour is a mighty thing;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdxcvii{%
on the day when you behold it, every suckling woman shall neglect the child she has suckled, and every pregnant woman shall deposit her burden, and thou shalt see mankind drunk, yet they are not drunk, but God's chastisement is terrible.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdxcviii{%
And among men there is such a one that disputes concerning God without knowledge and follows every rebel Satan,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdxcix{%
against whom it is written down that whosoever takes him for a friend, him he leads astray, and he guides him to the chastisement of the burning.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdc{%
O men, if you are in doubt as to the Uprising, surely We created you of dust then of a sperm-drop, then of a blood clot, then of a lump of flesh, formed and unformed that We may make clear to you. And We establish in the wombs what We will, till a stated term, then We deliver you as infants, then that you may come of age; and some of you die, and some of you are kept back unto the vilest state of life, that after knowing somewhat, they may know nothing. And thou beholdest the earth blackened, then, when We send down water upon it, it quivers, and swells, and puts forth herbs of every joyous kind.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdci{%
That is because God -- He is the Truth, and brings the dead to life, and is powerful over everything,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdcii{%
and because the Hour is coming, no doubt of it, and God shall raise up whosoever is within the tombs.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdciii{%
And among men there is such a one that disputes concerning God without knowledge or guidance, or an illuminating Book,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdciv{%
turning his side to lead astray from God's way; for him is degradation in this world; and on the Resurrection Day We shall let him taste the chastisement of the burning:\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdcv{%
'That is for what thy hands have forwarded and for that God is never unjust unto His servants.'\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdcvi{%
And among men there is such a one as serves God upon the very edge -- if good befalls him he is at rest in it, but if a trial befalls him he turns completely over; he loses this world and the world to come; that is indeed the manifest loss.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdcvii{%
He calls, apart from God, upon that which hurts him not, and which neither profits him anything; that is indeed the far error.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdcviii{%
He calls upon him who is likelier to hurt him, rather than to profit him -- an evil protector indeed, he, an evil friend!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdcix{%
God shall surely admit those who believe and do righteous deeds into gardens underneath which rivers flow; surely God does that He desires.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdcx{%
Whosoever thinks God will not help him in the present world and the world to come; let him stretch up a rope to heaven, then let him sever it, and behold whether his guile does away with what enrages him.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdcxi{%
Even so We have sent it down as signs, clear signs, and for that God guides whom He desires.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcxii{%
Surely they that believe, and those of Jewry, the Sabaeans, the Christians, the Magians and the idolaters -- God shall distinguish between them on the Day of Resurrection; assuredly God is witness over everything.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcxiii{%
Hast thou not seen how to God bow all who are in the and all who are in the earth, heavens the sun and the moon, the stars and the mountains, the trees and the beasts, and many of mankind? And many merit the chastisement; and whom God abases, there is none to honour him. God does whatsoever He will.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcxiv{%
These are two disputants who have disputed concerning their Lord. As for the unbelievers, for them garments of fire shall, be cut, and there shall be poured over their heads boiling water\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcxv{%
whereby whatsoever is in their bellies and their skins shall be melted;\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcxvi{%
for them await hooked iron rods;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcxvii{%
as often as they desire in their anguish to come forth from it, they shall be restored into it, and: 'Taste the chastisement of the burning!'\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcxviii{%
God shall surely admit those who believe and do righteous deeds into gardens underneath which rivers flow; therein they shall be adorned with bracelets of gold and with pearls, and their apparel there shall be of silk;\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcxix{%
and they; shall be guided unto goodly speech, and they shall be guided unto the path of the All-laudable.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcxx{%
Those who disbelieve, and bar from God's way and the Holy Mosque that We have appointed equal unto men, alike him who cleaves to it and the tent-dweller, and whosoever purposes to violate it wrongly, We shall let him taste a painful chastisement.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcxxi{%
And when We settled for Abraham the place of the House: 'Thou shall not associate with Me anything. And do thou purify My House for those that shall go about it and those that stand, for those that bow and prostrate themselves;\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcxxii{%
and proclaim among men the Pilgrimage, and they shall come unto thee on foot and upon every lean beast, they shall come from every deep ravine\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcxxiii{%
that they may witness things profitable to them and mention God's Name on days well-known over such beasts of the flocks as He has provided them: ``So eat thereof, and feed the wretched poor."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdcxxiv{%
Let them then finish with their self-neglect and let them fulfil their vows, and go about the Ancient House.'\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcxxv{%
All that; and whosoever venerates the sacred things of God, it shall be better for him with his Lord. And permitted to you are the flocks, except that which is recited to you. And eschew the abomination of idols, and eschew the speaking of falsehood,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcxxvi{%
being men pure of faith unto God, not associating with Him anything; for whosoever associates with God anything, it is as though he has fallen from heaven and the birds snatch him away, or the wind sweeps him headlong into a place far away.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdcxxvii{%
All that; and whosoever venerates God's waymarks, that is of the godliness of the hearts.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdcxxviii{%
There are things therein profitable to you unto a stated term; thereafter their lawful place of sacrifice is by the Ancient House.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdcxxix{%
We have appointed for every nation a holy rite, that they may mention God's Name over such beasts of the flocks as He has provided them. Your God is One God, so to Him surrender. And give thou good tidings unto the humble\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcxxx{%
who, when God is mentioned, their hearts quake, and such as endure patiently whatever visits them, and who perform the prayer, and expend of what We have provided them.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcxxxi{%
And the beasts of sacrifice -- We have appointed them for you as among God's waymarks; therein is good for you. So mention God's Name over them, standing in ranks then, when their flanks collapse, eat of them and feed the beggar and the suppliant. So We have subjected them to you; haply you will be thankful.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcxxxii{%
The flesh of them shall not reach God, neither their blood, but godliness from you shall reach Him. So He has subjected them to you, that you may magnify God for that He has guided you. And give thou good tidings unto the good-doers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcxxxiii{%
Assuredly God will defend those who believe; surely God loves not any ungrateful traitor.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcxxxiv{%
Leave is given to those who fight because they were wronged -- surely God is able to help them --\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcxxxv{%
who were expelled from their habitations without right, except that they say 'Our Lord is God.' Had God not driven back the people, some by the means of others, there had been destroyed cloisters and churches, oratories and mosques, wherein God's Name is much mentioned. Assuredly God will help him who helps Him -- surely God is All-strong, All-mighty\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcxxxvi{%
who, if We establish them in the land, perform the prayer, and pay the alms, and bid to honour, and forbid dishonour; and unto God belongs the issue of all affairs.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcxxxvii{%
If they cry lies to thee, so too before them the people of Noah cried lies, and Ad and Thamood,\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcxxxviii{%
and the people of Abraham, the people of Lot,\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcxxxix{%
and the men of Midian; to Moses also they cried lies. And I respited the unbelievers, then I seized them; and how was My horror!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdcxl{%
How many a city We have destroyed in its evildoing, and now it is fallen down upon its turrets! How many a ruined well, a tall palace!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdcxli{%
What, have they not journeyed in the land so that they have hearts to understand with or ears to hear with? It is not the eyes that are blind, but blind are the hearts within the breasts.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdcxlii{%
And they demand of thee to hasten the chastisement! God will not fail His promise; and surely a day with thy Lord is as a thousand years of your counting.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdcxliii{%
How many a city I have respited in its evildoing; then I seized it, and to Me was the homecoming.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdcxliv{%
Say: 'O men, I am only for you a plain warner.'\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdcxlv{%
Those who believe, and do deeds of righteousness -- theirs shall be forgiveness and generous provision.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdcxlvi{%
And those who strive against Our signs to void them -- they shall be the inhabitants of Hell.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdcxlvii{%
We sent not ever any Messenger or Prophet before thee, but that Satan cast into his fancy, when he was fancying; but God annuls what Satan casts, then God confirms His signs -- surely God is All-knowing, All-wise --\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdcxlviii{%
that He may make what Satan casts a trial for those in whose hearts is sickness, and those whose hearts are hard; and surely the evildoers are in wide schism;\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdcxlix{%
and that they who have been given knowledge may know that it is the truth from thy Lord and believe in it, and so their hearts be humble unto Him; and assuredly God ever guides those who believe to a straight path.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdcl{%
And the unbelievers will not cease to be in doubt of it, until the Hour comes on them suddenly, or there shall come upon them the chastisement of a barren day.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdcli{%
The Kingdom upon that day shall belong to God, and He shall judge between them. As for those who believe, and do deeds of righteousness, they shall be in Gardens of Bliss.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdclii{%
But as for the unbelievers, who cried lies to Our signs; for them awaits a humbling chastisement.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdcliii{%
And those who emigrated in God's way and were slain, or died, God shall provide them with a fair provision; and surely God is the best of providers.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdcliv{%
He shall admit them by a gate that is well-pleasing to them; and surely God is All-knowing, All-clement.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdclv{%
All that; and whosoever chastises after the manner that he was chastised and then again is oppressed, assuredly God will help him; surely God is All-pardoning, All-forgiving.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdclvi{%
That is because God makes the night to enter into the day and makes the day to enter into the night; and that God is All-hearing, All-seeing.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdclvii{%
That is because God -- He is the Truth, and that they call upon apart from Him -- that is the false; and for that God is the All-high, the All-great.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdclviii{%
Hast thou not seen how that God has sent down out of heaven water, and in the morning the earth becomes green? God is All-subtle, All-aware.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdclix{%
To Him belongs all that is in the heavens and in the earth; surely God -- He is the All-sufficient, the All-laudable.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdclx{%
Hast thou not seen how that God has subjected to you all that is in the earth and the ships to run upon the sea at His commandment, and He holds back heaven lest it should fall upon the earth, save by His leave? Surely God is All-gentle to men, All-compassionate.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdclxi{%
It is He who gave you life, then He shall make you dead, then He shall give you life. Surely man is ungrateful.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdclxii{%
We have appointed for every nation a holy rite that they shall perform. Let them not therefore wrangle with thee upon the matter, and do thou summon unto thy Lord; surely thou art upon a straight guidance.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdclxiii{%
And if they should dispute with thee, do thou say, 'God knows very well what you are doing.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdclxiv{%
God shall judge between you on the Day of Resurrection touching that whereon you were at variance.'\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdclxv{%
Didst thou not know that God knows all that is in heaven and earth? Surely that is in a Book; surely that for God is an easy matter.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdclxvi{%
They serve, apart from God, that whereon He has sent down never authority and that whereof they have no knowledge; and for the evildoers there shall be no helper.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdclxvii{%
And when Our signs are recited to them, clear signs, thou recognisest in the faces of the unbelievers denial; wellnigh they rush upon those who recite to them Our signs. Say: 'Shall I tell you of something worse than that? The Fire -- God has promised it to the unbelievers -- an evil homecoming!'\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdclxviii{%
O men, a similitude is struck; so give you ear to it. Surely those upon whom you call, apart from God, shall never create a fly, though they banded together to do it; and if a fly should rob them of aught, they would never rescue it from him. Feeble indeed alike are the seeker and the sought!\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdclxix{%
They measure not God with His true measure; surely God is All-strong, All-mighty.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdclxx{%
God chooses of the angels Messengers and of mankind; surely God is All-hearing, All-seeing.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdclxxi{%
He knows whatsoever is before them and behind them, and unto God all matters are returned.'\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdclxxii{%
O men, bow you down and prostrate yourselves, and serve your Lord, and do good; haply so you shall prosper;\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdclxxiii{%
and struggle for God as is His due, for He has chosen you, and has laid on you no impediment in your religion, being the creed of your father Abraham; He named you Muslims aforetime and in this, that the Messenger might be a witness against you, and that you might be witnesses against mankind. So perform the prayer, and pay the alms, and hold you fast to God; He is your Protector -- an excellent Protector, an excellent Helper.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdclxxiv{%
\basmalahen Prosperous are the believers\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdclxxv{%
who in their prayers are humble\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdclxxvi{%
and from idle talk turn away\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdclxxvii{%
and at almsgiving are active\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdclxxviii{%
and guard their private parts\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdclxxix{%
save from their wives and what their right hands own then being not blameworthy\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdclxxx{%
(but whosoever seeks after more than that, those are the transgressors)\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdclxxxi{%
and who preserve their trusts and their covenant\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdclxxxii{%
and who observe their prayers.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdclxxxiii{%
Those are the inheritors\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdclxxxiv{%
who shall inherit Paradise therein dwelling forever.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdclxxxv{%
We created man of an extraction of clay,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdclxxxvi{%
then We set him, a drop, in a receptacle secure,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdclxxxvii{%
then We created of the drop a clot then We created of the clot a tissue then We created of the tissue bones then We garmented the bones in flesh; thereafter We produced him as another creature. So blessed be God, the fairest of creators!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdclxxxviii{%
Then after that you shall surely die,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdclxxxix{%
then on the Day of Resurrection you shall surely be raised up.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcxc{%
And We created above you seven ways, and We were not heedless of creation.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcxci{%
And We sent down out of heaven water in measure and lodged it in the earth; and We are able to take it away.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcxcii{%
Then We produced for you therewith gardens of palms and vines wherein are many fruits for you, and of them you eat,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcxciii{%
and a tree issuing from the Mount of Sinai that bears oil and seasoning for all to eat.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcxciv{%
And surely in the cattle there is a lesson for you; We give you to drink of what is in their bellies, and many uses there are in them for you, and of them you eat;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcxcv{%
and upon them, and on the ships, you are borne.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcxcvi{%
And We sent Noah to his people; and he, said, 'O my people, serve God! You have no god other than He. Will you not be godfearing?"\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcxcvii{%
Said the Council of the unbelievers of his people, 'This is naught but a mortal like yourselves, who desires to gain superiority over you. And if God willed, He would have sent down angels. We never heard of this among, our fathers, the ancients.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcxcviii{%
He is naught but a man bedevilled; so wait on him for a time.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcxcix{%
He said, 'O my Lord, help me, for that they cry me lies.'\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcc{%
Then We said to him, 'Make thou the Ark under Our eyes and as We reveal, and then, when Our command comes and the Oven boils, insert in it two of every kind and thy, family -- except for him against whom the word already has been spoken; and address Me not concerning those who have done evil; they shall be drowned.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcci{%
Then, when thou art seated in the Ark and those with thee, say, ``Praise belongs to God, who has delivered us from the people of the evildoers."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdccii{%
And say, ``'O my Lord, do Thou harbour me in a blessed harbour, for Thou art the best of harbourers."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcciii{%
Surely in that are signs, and surely We put to the test.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcciv{%
Thereafter, after them, We produced another generation,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdccv{%
and We sent amongst them a Messenger of themselves, saying, 'Serve God! You have no god other than He. Will you not be godfearing?'\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdccvi{%
Said the Council of the unbelievers of his people, who cried lies to the encounter of the world to come, and to whom We had given ease in the present' life, 'This is naught but a mortal like yourselves, who eats of what you eat and drinks of what you drink.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdccvii{%
If you obey a mortal like yourselves, then you will be losers.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdccviii{%
What, does he promise you that when you are dead, and become dust and bones, you shall be brought forth?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdccix{%
Away, away with that you are promised!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdccx{%
There is nothing but our present life; we die, and we live, and we shall not be raised up.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdccxi{%
He is naught but a man who has forged against God a lie, and we will not believe him.'\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdccxii{%
He said, 'O my Lord, help me, for that they cry me lies.'\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdccxiii{%
He said, 'In a little they will be remorseful.'\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdccxiv{%
And the Cry seized them justly, and We made them as scum; so away with the people of the evildoers!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdccxv{%
Thereafter, after them, We produced other generations;\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdccxvi{%
no nation outstrips its term, nor do they put it back.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdccxvii{%
Then sent We Our Messengers successively; whenever its Messenger came to a nation they cried him lies, so We caused some of them to follow others, and We made them as but tales; so away with a people who do not believe!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdccxviii{%
Then We sent Moses and his brother Aaron with Our signs and a manifest authority\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdccxix{%
unto Pharaoh and his Council; but they waxed proud, and they were a lofty people,\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdccxx{%
and they said, 'What, shall we believe two mortals like ourselves, whose people are our servants?'\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdccxxi{%
So they cried them lies, and they were among the destroyed.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdccxxii{%
And We gave Moses the Book, that haply they would be guided;\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdccxxiii{%
and We made Mary's son, and his mother, to be a sign, and gave them refuge upon a height, where was a hollow and a spring:\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdccxxiv{%
'O Messengers, eat of the good things and do righteousness; surely I know the things you do.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdccxxv{%
Surely this community of yours is one community, and I am your Lord; so fear Me.'\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdccxxvi{%
But they split in their affair between them into sects, each party rejoicing in what is with them.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdccxxvii{%
So leave thou them in their perplexity for a time.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdccxxviii{%
What, do they think that We succour them with of wealth and children,\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdccxxix{%
We vie in good works for them? Nay, but they are not aware.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdccxxx{%
Surely those who tremble in fear of their Lord\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdccxxxi{%
and those who believe in the signs of their Lord\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdccxxxii{%
and those who associate naught with their Lord\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdccxxxiii{%
and those who give what they give, their hearts quaking that they are returning to their Lord --\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdccxxxiv{%
those vie in good works, outracing to them.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdccxxxv{%
We charge not any soul save to its capacity, and with Us is a Book speaking truth, and they shall not be wronged.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdccxxxvi{%
Nay, but their hearts are in perplexity as to this, and they have deeds besides that that they are doing.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdccxxxvii{%
Till, when We seize with the chastisement the ones of them that live at ease, behold, they groan.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdccxxxviii{%
'Groan not today; surely you shall not be helped from Us.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdccxxxix{%
My signs were recited to you, but upon your heels you withdrew,\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdccxl{%
waxing proud against it, talking foolish talk by night.'\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdccxli{%
Have they not pondered the saying, or came there upon them that which came not upon their fathers, the ancients?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdccxlii{%
Or did they not recognise their Messenger and so denied him?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdccxliii{%
Or do they say, 'He is bedevilled'? Nay, he has brought them the truth, but most of them are averse from the truth.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdccxliv{%
Had the truth followed their caprices, the heavens and the earth and whosoever in them is had surely corrupted. Nay, We brought them their Remembrance, but from their Remembrance they turned.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdccxlv{%
Or dost thou ask them for tribute? Yet the tribute of thy Lord is better, and He is the best of providers.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdccxlvi{%
Assuredly thou art calling them to a straight path;\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdccxlvii{%
and surely they that believe not in the world to come are deviating from the path.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdccxlviii{%
Did We have mercy on them, and remove the affliction that is upon them, they would persist in their insolence wandering blindly.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdccxlix{%
We already seized them with the chastisement, yet they abased not themselves to their Lord nor were they humble;\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdccl{%
until, when We open against them a door of terrible chastisement, lo, they are sore confounded at it.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdccli{%
It is He who produced for you hearing, and eyes, and hearts; little thanks you show.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdcclii{%
It is He who scattered you in the earth, and to Him you shall be mustered.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmdccliii{%
It is He who gives life, and makes to die, and to Him belongs the alternation of night and day; what, will you not understand?\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmdccliv{%
Nay, but they said the like of what the ancients said.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmdcclv{%
They said, 'What, when we are dead and become dust and bones, shall we be indeed raised up?\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmdcclvi{%
We and our fathers have been promised this before; this is naught but the fairy-tales of the ancients.'\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmdcclvii{%
Say: 'Whose is the earth, and whoso is in it, if you have knowledge?'\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmdcclviii{%
They will say, God's.' Say: 'Will you not then remember?'\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmdcclix{%
Say: 'Who is the Lord of the seven heavens and the Lord of the mighty Throne?'\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmdcclx{%
They will say, 'God's.' Say: 'Will you not then be godfearing?'\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmdcclxi{%
Say: 'In whose hand is the dominion of everything, protecting and Himself unprotected, if you have knowledge?'\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmdcclxii{%
They will say, 'God's.' Say: 'How then are you bewitched?\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmdcclxiii{%
Nay, but We brought them the truth and they are truly liars.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmdcclxiv{%
God has not taken to Himself any son, nor is there any god with Him; for then each god would have taken off that he created and some of them would have risen up over others; glory to be God, beyond that they describe,\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmdcclxv{%
who has knowledge of the Unseen and the Visible; high exalted be He, above that they associate!\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmdcclxvi{%
Say: 'O my Lord, if Thou shouldst show me that they are promised,\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmdcclxvii{%
O my Lord, put me not among the people of the evildoers.'\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmdcclxviii{%
Assuredly, We are able to show thee that We promise them.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmdcclxix{%
Repel thou the evil with that which is fairer. We Ourselves know very well that they describe.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmdcclxx{%
And say: 'O my Lord, I take refuge in Thee from the evil suggestions of the Satans,\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmdcclxxi{%
and I take refuge in Thee, O my Lord, lest they attend me.'\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmdcclxxii{%
Till, when death comes to one of them, he says, 'My Lord, return me;\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmdcclxxiii{%
haply I shall do righteousness in that I forsook.' Nay, it is but a word he speaks; and there; behind them, is a barrier until the day that they shall be raised up.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmdcclxxiv{%
For when the Trumpet is blown, that day there shall be no kinship any more between them, neither will they question one another.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmdcclxxv{%
Then he whose scales are heavy -- they are the prosperers,\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmdcclxxvi{%
and he whose scales are light -- they have lost their souls in Gehenna dwelling forever,\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmdcclxxvii{%
the Fire smiting their faces the while they glower there.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmdcclxxviii{%
'What, were My signs not recited to you, and you cried them lies?'\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmdcclxxix{%
They shall say, 'Our Lord, our adversity prevailed over us; we were an erring people.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmdcclxxx{%
Our Lord, bring us forth out of it! Then, if we revert, we shall be evildoers indeed.'\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmdcclxxxi{%
'Slink you into it,' He shall say, 'and do not speak to Me.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmdcclxxxii{%
There is a party of My servants who said, ``Our Lord, we believe; therefore forgive us, and have mercy on us, for Thou art the best of the merciful."\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmdcclxxxiii{%
But you took them for a laughing-stock, till they made you forget My remembrance, mocking at them.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmdcclxxxiv{%
Now today I have recompensed them for their patient endurance; they are the triumphant.'\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmdcclxxxv{%
He shall say, 'How long have you tarried in the earth, by number of years?'\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmdcclxxxvi{%
They shall say, 'We have tarried a day, or part of a day; ask the numberers!'\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmdcclxxxvii{%
He shall say, 'You have tarried but a little, did you know.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmdcclxxxviii{%
What, did you think that We created you only for sport, and that you would not be returned to Us?'\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmdcclxxxix{%
Then high exalted be God, the King, the True! There is no god but He? the Lord of the noble Throne.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmdccxc{%
And whosoever calls upon another god with God, whereof he has no proof, his reckoning is with his Lord; surely the unbelievers shall not prosper.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmdccxci{%
And say: 'My Lord, forgive and have mercy, for Thou art the best of the merciful.'\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmdccxcii{%
\basmalahen A sura that We have sent down and appointed; and We have sent down in it signs, clear signs, that haply you will remember.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdccxciii{%
The fornicatress and the fornicator -- scourge each one of them a hundred stripes, and in the matter of God's religion let no tenderness for them seize you if you believe in God and the Last Day; and let a party of the believers witness their chastisement.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdccxciv{%
The fornicator shall marry none but a fornicatress or an idolatress, and the fornicatress -- none shall marry her but a fornicator or an idolator; that is forbidden to the believers.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdccxcv{%
And those who cast it up on women in wedlock, and then bring not four witnesses, scourge them with eighty stripes, and do not accept any testimony of theirs ever; those -- they are the ungodly,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdccxcvi{%
save such as repent thereafter and make amends; surely God is All-forgiving, All-compassionate.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdccxcvii{%
And those who cast it up on their wives having no witnesses except themselves, the testimony of one of them shall be to testify by God four times that he is of the truthful,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdccxcviii{%
and a fifth time, that the curse of God shall be upon him, if he should be of the liars.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdccxcix{%
It shall avert from her the chastisement if she testify by God four times that he is of the liars,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdccc{%
and a fifth time, that the wrath of God shall be upon her, if he should be of the truthful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdccci{%
But for God's bounty to you and His mercy and that God turns, and is All-wise --\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdcccii{%
Those who came with the slander are a band of you; do not reckon it evil for you; rather it is good for you. Every man of them shall have the sin that he has earned charged to him; and whosoever of them took upon himself the greater part of it, him there awaits a mighty chastisement.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdccciii{%
Why, when you heard it, did the believing men and women not of their own account think good thoughts, and say, 'This is a manifest calumny'?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdccciv{%
Why did they not bring four witnesses against it? But since they did not bring the witnesses, in God's sight they are the liars.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdcccv{%
But for God's bounty to you and His mercy in the present world and the world to come there would have visited you for your mutterings a mighty chastisement.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdcccvi{%
When you received it on your tongues, and were speaking with your mouths that whereof you had no knowledge, and reckoned it a light thing, and with God it was a mighty thing --\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdcccvii{%
And why, when you heard it, did you not say, 'It is not for us to speak about this; glory be to Thee! This is a mighty calumny'?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcccviii{%
God admonishes you, that you shall never repeat the like of it again; if you are believers.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcccix{%
God makes clear to you the signs; and God is All-knowing, All-wise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcccx{%
Those who love that indecency should be spread abroad concerning them that believe -- there awaits them a painful chastisement in the present world and the world to come; and God knows, and you know not.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcccxi{%
But for God's bounty to you and His mercy and that God is All-gentle, All-compassionate --\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcccxii{%
O believers, follow not the steps of Satan; for whosoever follows the steps of Satan, assuredly he bids to indecency and dishonour. But for God's bounty to you and His mercy not one of you would have been pure ever; but God purifies whom He will; and God is All-hearing, All-knowing.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcccxiii{%
Let not those of you who possess bounty and plenty swear off giving kinsmen and the poor and those who emigrate in the way of God; but let them pardon and forgive. Do you not wish that God should forgive you? God is All-forgiving, All-compassionate.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcccxiv{%
Surely those who cast it up on women in wedlock that are heedless but believing shall be accursed in the present world and the world to come; and there awaits them a mighty chastisement\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcccxv{%
on the day when their tongues, their hands and their feet shall testify against them touching that they were doing.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcccxvi{%
Upon that day God will pay them in full their just due, and they shall know that God is the manifest Truth.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcccxvii{%
Corrupt women for corrupt men, and corrupt men for corrupt women; good women for good men, and good men for good women -- these are declared quit of what they say; theirs shall be forgiveness and generous provision.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcccxviii{%
O believers, do not enter houses other than your houses until you first ask leave and, salute the people thereof; that is better for you; haply you will remember.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcccxix{%
And if you find not anyone therein, enter it not until leave is given to you. And if you are told, 'Return,' return; that is purer for you; and God knows the things you do.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdcccxx{%
There is no fault in you that you enter houses uninhabited wherein enjoyment is for you. God knows what you reveal and what you hide.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcccxxi{%
Say to the believers, that they cast down their eyes and guard their private parts; that is purer for them. God is aware of the things they work.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcccxxii{%
And say to the believing women, that they cast down their eyes' and guard their private parts, and reveal not their adornment save such as is outward; and let them cast their veils over their bosoms, and not reveal their adornment save to their husbands, or their fathers, or their husbands' fathers, or their sons, or their husbands' sons, or their brothers, or their brothers' sons, or their sisters' sons, or their women, or what their right hands own, or such men as attend them, not having sexual desire, or children who have not yet attained knowledge of women's private parts; nor let them stamp their feet, so that their hidden ornament may be known. And turn all together to God, O you believers; haply so you will prosper.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdcccxxiii{%
Marry the spouseless among you, and your slaves and handmaidens that are righteous; if they are poor, God will enrich them of His bounty; God is All-embracing, All-knowing.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdcccxxiv{%
And let those who find not the means to marry be abstinent till God enriches them of His bounty. Those your right hands own who seek emancipation, contract with them accordingly, if you know some good in them; and give them of the wealth of God that He has given you. And constrain not your slave-girls to prostitution, if they desire to live in chastity, that you may seek the chance goods of the present life. Whosoever constrains them, surely God, after their being constrained, is All-forgiving, All-compassionate.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdcccxxv{%
Now We have sent down to you signs making all clear, and an example of those who passed away before you, and an admonition for the godfearing.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcccxxvi{%
God is the Light of the heavens and the earth; the likeness of His Light is as a niche wherein is a lamp (the lamp in a glass, the glass as it were a glittering star) kindled from a Blessed Tree, an olive that is neither of the East nor of the West whose oil wellnigh would shine, even if no fire touched it; Light upon Light; (God guides to His Light whom He will.) (And God strikes similitudes for men, and God has knowledge of everything.)\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcccxxvii{%
in temples God has allowed to be raised up, and His Name to be commemorated therein; therein glorifying Him, in the mornings and the evenings,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcccxxviii{%
are men whom neither commerce nor trafficking diverts from the remembrance of God and to perform the prayer, and to pay the alms, fearing a day when hearts and eyes shall be turned about,\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcccxxix{%
that God may recompense them for their fairest works and give them increase of His bounty; and God provides whomsoever He will, without reckoning.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcccxxx{%
And as for the unbelievers, their works are as a mirage in a spacious plain which the man athirst supposes to be water, till, when he comes to it, he finds it is nothing; there indeed he finds God, and He pays him his account in full; (and God is swift at the reckoning.)\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcccxxxi{%
or they are as shadows upon a sea obscure covered by a billow above which is a billow above which are clouds, shadows piled one upon another; when he puts forth his hand, wellnigh he cannot see it. And to whomsoever God assigns no light, no light has he.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcccxxxii{%
Hast thou not seen how that whatsoever is in the heavens and in the earth extols God, and the birds spreading their wings? Each -- He knows its prayer and its extolling; and God knows the things they do.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcccxxxiii{%
To God belongs the Kingdom of the heavens and the earth, and to Him is the homecoming.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcccxxxiv{%
'hast thou not seen how God drives the clouds, then composes them, then converts them into a mass, then thou seest the rain issuing out of the midst of them? And He sends down out of heaven mountains, wherein is hail, so that He smites whom He will with it, and turns it aside from whom He will; wellnigh the gleam of His lightning snatches away the sight.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcccxxxv{%
God turns about the day and the night; surely in that is a lesson for those who have eyes.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdcccxxxvi{%
God has created every beast of water, and some of them go upon their bellies, and some of them go upon two feet, and some of them go upon four; God creates whatever He will; God is powerful over everything.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdcccxxxvii{%
Now We have sent down signs making all clear; God guides whomsoever He will to a straight path.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdcccxxxviii{%
They say, 'We believe in God and the Messenger, and we obey.' Then after that a party of them turn away; those -- they are not believers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdcccxxxix{%
When they are called to God and His Messenger that he may judge between them, lo, a party of them are swerving aside;\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdcccxl{%
but if they are in the right, they will come to him submissively.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdcccxli{%
What, is there sickness in their hearts, or are they in doubt, or do they fear that God may be unjust towards them and His Messenger? Nay, but those -- they are the evildoers.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdcccxlii{%
All that the believers say, when they are called to God and His Messenger, that he may judge between them, is that they say, 'We hear, and we obey'; those -- they are the prosperers.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdcccxliii{%
Whoso obeys God and His Messenger, and fears God and has awe of Him, those -- they are the triumphant.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdcccxliv{%
They have sworn by God the most earnest oaths, if thou commandest them they will go forth. Say: 'Do not swear; honourable obedience is sufficient. Surely God is aware of the things you do.'\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdcccxlv{%
Say: 'Obey God, and obey the Messenger; then, if you turn away, only upon him rests what is laid on him, and upon you rests what is laid on you. If you obey him, you will be guided. It is only for the Messenger to deliver the manifest Message.'\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdcccxlvi{%
God has promised those of you who believe and do righteous deeds that He will surely make you successors in the land, even as He made those who were before them successors, and that He will surely establish their religion for them that He has approved. for them, and will give them in exchange, after their fear, security: 'They shall serve Me, not associating with Me anything.' Whoso disbelieves after that, those - they are the ungodly.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdcccxlvii{%
Perform the prayer, and pay the alms, and obey the Messenger -- haply so you will find mercy.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdcccxlviii{%
Think not the unbelievers able to frustrate God in the earth; their refuge is the Fire -- an evil homecoming.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdcccxlix{%
O believers, let those your right hands own and those of you who have not reached puberty ask leave of you three times -- before the prayer of dawn, and when you put off your garments at the noon, and after the evening prayer -- three times of nakedness for you. There is no fault in you or them, apart from these, that you go about one to the other. So God makes clear to you the signs; and God is All-knowing, All-wise.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdcccl{%
When your children reach puberty, let them ask leave, as those before them asked leave. So God makes clear to you His signs; and God is All-knowing, All-wise.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdcccli{%
Such women as are past child- bearing and have no hope of marriage -- there is no fault in them that they put off their clothes, so be it that they flaunt no ornament; but to abstain is better for them; and God is All-hearing, All-knowing.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdccclii{%
There is no fault in the blind, and there is no fault in the lame, and there is no fault in the sick, neither in yourselves, that you eat of your houses, or your fathers' houses, or your mothers' houses, or your brothers' houses, or your sisters' houses, or the houses of your uncles or your aunts paternal, or the houses of your uncles or your aunts maternal, or that whereof you own the keys, or of your friend; there is no fault in you that you eat all together, or in groups separately. But when you enter houses, greet one another with a greeting from God, blessed and good. So God makes clear to you the signs; haply you will understand.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdcccliii{%
Those only are believers, who believe in God and His Messenger and who, when they are with him upon a common matter, go not away until they ask his leave. Surely those who ask thy leave -- those are they that believe in God and His Messenger; so, when they ask thy leave for some affair of their own, give leave to whom thou wilt of them, and ask God's forgiveness for them; surely God is All-forgiving, All-compassionate.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdcccliv{%
Make not the calling of the Messenger among yourselves like your calling one of another. God knows those of you who slip away surreptitiously; so let those who go against His command beware, lest a trial befall them, or there befall them a painful chastisement.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdccclv{%
Why, surely to God belongs whatsoever is in the heavens and the earth; He ever knows what state you are upon; and the day when they shall be returned to Him, then He will tell them of what they did; and God knows everything.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdccclvi{%
\basmalahen Blessed be He who has sent down the Salvation upon His servant, that he may be a warner to all beings;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdccclvii{%
to whom belongs the Kingdom of the heavens and the earth; and He has not taken to Him a son, and He has no associate in the Kingdom; and He created every thing, then He ordained it very exactly.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdccclviii{%
Yet they have taken to them gods, apart from Him, that create nothing and themselves are created, and have no power to hurt or profit themselves, no power of death or life or raising up.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdccclix{%
The unbelievers say, 'This is naught but a calumny he has forged, and other folk have helped him to it.' So they have committed wrong and falsehood.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdccclx{%
They say, 'Fairy-tales of the ancients that he has had written down, so that they are recited to him at the dawn and in the evening.'\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdccclxi{%
Say: 'He sent it down, who knows the secret in the heavens and earth; He is All-forgiving, All-compassionate.'\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdccclxii{%
They also say, 'What ails this Messenger that he eats food, and goes in the markets? Why has an angel not been sent down to him, to be a warner with him?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdccclxiii{%
Or why is not a treasure thrown to him, or why has he not a Garden to eat of?' The evildoers say, 'You are only following a man bewitched!'\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdccclxiv{%
Behold, how they strike similitudes for thee, and go astray, and are unable to find a way!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdccclxv{%
Blessed be He who, if He will, shall assign to them better than that -- gardens underneath which rivers flow, and he shall assign to thee palaces.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdccclxvi{%
Nay, but they cry lies to the Hour; and We have prepared for him who cries lies to the Hour a Blaze.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdccclxvii{%
When it sees them from a far place, they shall hear its bubbling and sighing.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdccclxviii{%
And when they are cast, coupled in fetters, into a narrow place of that Fire, they will call out there for destruction.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdccclxix{%
'Call not out today for one destruction, but call for many!'\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdccclxx{%
Say: 'Is that better, or the Garden of Eternity, that is promised to the godfearing, and is their recompense and homecoming?'\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdccclxxi{%
Therein they shall have what they will dwelling forever; it is a promise binding upon thy Lord, and of Him to be required.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdccclxxii{%
Upon the day when He shall muster them and that they serve, apart from God, and He shall say, 'Was it you that led these My servants astray, or did they themselves err from the way?'\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdccclxxiii{%
They shall 'Glory be to Thee! It did not behove us to take unto say, ourselves protectors apart from Thee; but Thou gavest them and their fathers enjoyment of days, until they forgot\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdccclxxiv{%
the Remembrance, and were a people corrupt.' So they cried lies touching the things you say, and you can neither turn it aside, nor find any help. Whosoever of you does evil, We shall let him taste a great chastisement.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdccclxxv{%
And We sent not before thee any Envoys, but that they ate food, and went in the markets; and We appointed some of you to be a trial for others: 'Will you endure?' Thy Lord is ever All-seeing.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdccclxxvi{%
Say those who look not to encounter Us, 'Why have the angels not been sent down on us, or why see we not our Lord?' Waxed proud they have within them, and become greatly disdainful.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdccclxxvii{%
Upon the day that they see the angels, no good tidings that day for the sinners; they shall say, 'A ban forbidden!'\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdccclxxviii{%
We shall advance upon what work they have done, and make it a scattered dust.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdccclxxix{%
The inhabitants of Paradise that day, better shall be their lodging, fairer their resting-place.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdccclxxx{%
Upon the day that heaven is split asunder with the clouds and the angels are sent down in majesty,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdccclxxxi{%
the Kingdom that day, the true Kingdom, shall belong to the All-merciful and it shall be a day harsh for the unbelievers.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdccclxxxii{%
Upon the day the evildoer shall bite his hands, saying, 'Would that I had taken a way along with the Messenger!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdccclxxxiii{%
Alas, would that I had not taken So-and-so for a friend!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdccclxxxiv{%
He indeed led me astray from the Remembrance, after it had come to me; Satan is ever a forsaker of men.'\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdccclxxxv{%
The Messenger says, 'O my Lord, behold, my people have taken this Koran as a thing to be shunned.'\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdccclxxxvi{%
Even so We have appointed to every Prophet an enemy among the sinners; but thy Lord suffices as a guide and as a helper.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdccclxxxvii{%
The unbelievers say, 'Why has the Koran not been sent down upon him all at once?' Even so, that We may strengthen thy heart thereby, and We have chanted it very distinctly.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdccclxxxviii{%
They bring not to thee any similitude but that We bring thee the truth, and better in exposition.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdccclxxxix{%
Those who shall be mustered to Gehenna upon their faces -- they shall be worse in place, and gone further astray from the way.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcccxc{%
We gave Moses the Book, and appointed with him his brother Aaron as minister\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcccxci{%
and We said, 'Go to the people who have cried lies to Our signs'; then We destroyed them utterly.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcccxcii{%
And the people of Noah, when they cried lies to the Messengers, We drowned them, and made them to be a sign to mankind; and We have prepared for the evildoers a painful chastisement.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcccxciii{%
And Ad, and Thamood, and the men of Er-Rass, and between that generations a many,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcccxciv{%
for each We struck similitudes, and each We ruined utterly.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcccxcv{%
Surely they have come by the city that was rained on by an evil rain; what, have they not seen it? Nay, but they look for no upraising.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcccxcvi{%
And when they see thee, they take thee in mockery only: 'What, is this he whom God sent forth as a Messenger?\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcccxcvii{%
Wellnigh he had led us astray from our gods, but that we kept steadfast to them.' Assuredly they shall know, when they see the chastisement, who is further astray from the way.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcccxcviii{%
Hast thou seen him who has taken his caprice to be his god? Wilt thou be a guardian over them?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcccxcix{%
Or deemest thou that most of them hear or understand? They are but as the cattle; nay, they are further astray from the way.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcm{%
Hast thou not regarded thy Lord, how He has stretched out the shadow? Had He willed, He would have made it still. Then We appointed the sun, to be a guide to it;\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcmi{%
thereafter We seize it to Ourselves, drawing it gently.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcmii{%
It is He who appointed the night for you to be a garment and sleep for a rest, and day He appointed for a rising.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcmiii{%
And it is He who has loosed the winds, bearing good tidings before His mercy; and We sent down from heaven pure water\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcmiv{%
so that We might revive a dead land, and give to drink of it, of that We created, cattle and men a many.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcmv{%
We have indeed turned it about amongst them, so that they may remember; yet most men refuse all but unbelief.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcmvi{%
If We had willed, We would have raised up in every city a warner.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcmvii{%
So obey not the unbelievers, but struggle with them thereby mightily.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcmviii{%
And it is He who let forth the two seas, this one Sweet, grateful to taste, and this salt, bitter to the tongue, and He set between them a barrier, and a ban forbidden.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcmix{%
And it is He who created of water a mortal, and made him kindred of blood and marriage; thy Lord is All-powerful.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcmx{%
And they serve, apart from God, what neither profits them nor hurts them; and the unbeliever is ever a partisan against his Lord.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcmxi{%
We have sent thee not, except good tidings to bear, and warning.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcmxii{%
Say: 'I do not ask of you a wage for this, except for him who wishes to take to his Lord a way.'\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcmxiii{%
Put thy trust in the Living God, the Undying, and proclaim His praise. Sufficiently is He aware of His servants sins\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcmxiv{%
who created the heavens and the earth, and what between them is, in six days, then sat Himself upon the Throne, the All-compassionate: ask any informed of Him!\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcmxv{%
But when they are told, 'Bow yourselves to the All-merciful,' they say, 'And what is the All-merciful? Shall we bow ourselves to what thou biddest us?' And it increases them in aversion.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcmxvi{%
Blessed be He who has set in heaven constellations, and has set among them a lamp, and an illuminating moon.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcmxvii{%
And it is He who made the night and day a succession for whom He desires to remember or He desires to be thankful.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcmxviii{%
The servants of the All-merciful are those who walk in the earth modestly and who, when the ignorant address them, say, 'Peace';\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcmxix{%
who pass the night prostrate to their Lord and standing;\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcmxx{%
who say, 'Our Lord, turn Thou from us the chastisement of Gehenna; surely its chastisement is torment most terrible;\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcmxxi{%
evil it is as a lodging-place and an abode';\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcmxxii{%
who, when they expend, are neither prodigal nor parsimonious, but between that is a just stand;\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcmxxiii{%
who call not upon another god with God, nor slay the soul God has forbidden except by right, neither fornicate, for whosoever does that shall meet the price\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcmxxiv{%
of sin-doubled shall be the chastisement for him on the Resurrection Day, and he shall dwell therein humbled,\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcmxxv{%
save him who repents, and believes, and does righteous work -- those, God will change their evil deeds into good deeds, for God is ever All-forgiving, All-compassionate;\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcmxxvi{%
and whosoever repents, and does righteousness, he truly turns to God in repentance.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcmxxvii{%
And those who bear not false witness and, when they pass by idle talk, pass by with dignity;\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcmxxviii{%
who, when they are reminded of the signs of their Lord, fall not down thereat deaf and blind;\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcmxxix{%
who say, 'Our Lord, give us refreshment of our wives and seed, and make us a model to the godfearing.'\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcmxxx{%
Those shall be recompensed with the highest heaven, for that they endured patiently, and they shall receive therein a greeting and --' Peace!'\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcmxxxi{%
Therein they shall dwell forever; fair it is as a lodging-place and an abode.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcmxxxii{%
Say: 'My Lord esteems you not at all were it not for your prayer, for you have cried lies, and it shall surely be fastened.'\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcmxxxiii{%
\basmalahen Ta Sin Mim\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcmxxxiv{%
Those are the signs of the Manifest Book.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcmxxxv{%
Perchance thou consumest thyself that they are not believers.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcmxxxvi{%
If We will, We shall send down on them out of heaven a sign, so their necks will stay humbled to it.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcmxxxvii{%
But never fresh remembrance comes to them from the All-merciful, except they turn away from it.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcmxxxviii{%
So they have cried lies; therefore assuredly tidings will come to them of that they mocked at.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcmxxxix{%
What, have they not regarded the earth, how many therein We have caused to grow of every generous kind?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcmxl{%
Surely in that is a sign, yet most of them are not believers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcmxli{%
Surely thy Lord, He is the All-mighty, the All-compassionate.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcmxlii{%
And when thy Lord called to Moses, 'Go to the people of the evildoers,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcmxliii{%
the people of Pharaoh; will they not be godfearing?'\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcmxliv{%
He said, 'My Lord, I fear they will cry me lies,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcmxlv{%
and my breast will be straitened, and my tongue will not be loosed; so send to Aaron.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcmxlvi{%
They also have a sin against me, and I fear they will slay me.'\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcmxlvii{%
Said He, 'No indeed; but go, both of you, with Our signs, and We assuredly shall be with you, listening.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcmxlviii{%
So go you to Pharaoh, and say, ``Verily, I am the Messenger of the Lord of all Being;\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmcmxlix{%
so send forth with us the Children of Israel."\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmcml{%
He said, 'Did we not raise thee amongst us as a child? Didst thou not tarry among us years of thy life?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmcmli{%
And thou didst the deed thou didst, being one of the ungrateful!'\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmcmlii{%
Said he, 'Indeed I did it then, being one of those that stray;\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmcmliii{%
so I fled from you, fearing you. But my Lord gave me Judgment and made me one of the Envoys.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmcmliv{%
That is a blessing thou reproachest me with, having enslaved the Children of Israel.'\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmcmlv{%
Pharaoh said, 'And what is the Lord of all Being?'\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmcmlvi{%
He said, 'The Lord of the heavens and earth, and what between them is, if you have faith.'\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmcmlvii{%
Said he to those about him, 'Do you not hear?'\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmcmlviii{%
He said, 'Your Lord and the Lord of your fathers, the ancients.'\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmcmlix{%
Said he, 'Surely your Messenger who was sent to you is possessed!'\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmcmlx{%
He said, 'The Lord of the East and West, and what between them is, if you have understanding,'\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmcmlxi{%
Said he, 'If thou takest a god other than me, I shall surely make thee one of the imprisoned.'\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmcmlxii{%
He said, 'What, even though I brought thee something so manifest?'\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmcmlxiii{%
Said he, 'Bring it then, if thou art of the truthful.'\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmcmlxiv{%
So he cast his staff, and behold, it was a serpent manifest.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmcmlxv{%
And he drew forth his hand, and lo, it was white to the beholders.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmcmlxvi{%
Said he to the Council about him, 'Surely this man is a cunning sorcerer\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmcmlxvii{%
who desires to expel you from your land by his sorcery; what do you command?'\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmcmlxviii{%
They said, 'Put him and his brother off a while, and send among the cities musterers,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmcmlxix{%
to bring thee every cunning sorcerer.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmcmlxx{%
So the sorcerers were assembled for the appointed time of a fixed day.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmcmlxxi{%
The people were asked, 'Will you assemble?\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmcmlxxii{%
Haply we shall follow the sorcerers if it should be they are the victors.'\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmcmlxxiii{%
Then, when the sorcerers came, they said to Pharaoh, 'Shall we indeed have a wage, if we should be the victors?'\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmcmlxxiv{%
He said, 'Yes indeed; and you shall then be among the near-stationed.'\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmcmlxxv{%
Moses said to them, 'Cast you down what you will cast.'\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmcmlxxvi{%
So they cast their ropes and their staffs, and said, 'By the might of Pharaoh we shall be the victors.'\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcmlxxvii{%
Then Moses cast his staff and lo, it forthwith swallowed up their lying invention;\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcmlxxviii{%
so the sorcerers were cast down, bowing themselves.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcmlxxix{%
They said, 'We believe in the Lord of all Being,\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcmlxxx{%
the Lord of Moses and Aaron.'\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcmlxxxi{%
Said Pharaoh, 'You have believed him before I gave you leave. Why, he is the chief of you, the same that taught you sorcery; now you shall know! I shall assuredly cut off alternately your hands and feet, then I shall crucify you all together.'\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcmlxxxii{%
They said, 'There is no harm; surely unto our Lord we are turning.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcmlxxxiii{%
We are eager that our Lord should forgive us our offences, for that we are the first of the believers.'\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcmlxxxiv{%
Also We revealed unto Moses, 'Go with My servants by night; surely you will be followed.'\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcmlxxxv{%
Then Pharaoh sent among the cities musterers:\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcmlxxxvi{%
'Behold, these are a small troop,\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcmlxxxvii{%
and indeed they are enraging us;\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcmlxxxviii{%
and we are a host on our guard.'\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcmlxxxix{%
So We expelled them from gardens and fountains,\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcmxc{%
and treasures and a noble station;\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcmxci{%
even so, and We bequeathed them upon the Children of Israel.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcmxcii{%
Then they followed them at the sunrise;\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcmxciii{%
and, when the two hosts sighted each other, the companions of Moses said, 'We are overtaken!'\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcmxciv{%
Said he, 'No indeed; surely my Lord is with me; He will guide me.'\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcmxcv{%
Then We revealed to Moses, 'Strike with thy staff the sea'; and it clave, and each part was as a mighty mount.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcmxcvi{%
And there We brought the others on,\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcmxcvii{%
and We delivered Moses and those with him all together;\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcmxcviii{%
then We drowned the others.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcmxcix{%
Surely in that is a sign, yet most of them are not believers.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmm{%
Surely thy Lord, He is the All-mighty, the All-compassionate.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmi{%
And recite to them the tiding of Abraham\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmii{%
when he said to his father and his people, 'What do you serve?'\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmiii{%
They said, 'We serve idols, and continue cleaving to them.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmiv{%
He said, 'Do they hear you when you call,\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmv{%
or do they profit you, or harm?'\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmvi{%
They said, 'Nay, but we found our fathers so doing.'\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmvii{%
He said, 'And have you considered what you have been serving,\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmviii{%
you and your fathers, the elders?\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmix{%
They are an enemy to me, except the Lord of all Being\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmx{%
who created me, and Himself guides me,\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmxi{%
and Himself gives me to eat and drink,\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmxii{%
and, whenever I am sick, heals me,\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmxiii{%
who makes me to die, then gives me life,\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmxiv{%
and who I am eager shall forgive me my offence on the Day of Doom.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmxv{%
My Lord, give me Judgment, and join me with the righteous,\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmxvi{%
and appoint me a tongue of truthfulness among the others.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmxvii{%
Make me one of the inheritors of the Garden of Bliss\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmxviii{%
and forgive my father, for he is one of those astray.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmxix{%
Degrade me not upon the day when they are raised up,\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmxx{%
the day when neither wealth nor sons shall profit\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmxxi{%
except for him who comes to God with a pure heart.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmxxii{%
And Paradise shall be brought forward for the godfearing,\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmxxiii{%
and Hell advanced for the perverse.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmxxiv{%
It shall be said to them, 'Where is that you were serving\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmxxv{%
apart from God? Do they help you or help themselves?'\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmxxvi{%
Then they shall be pitched into it, they and the perverse\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmxxvii{%
and the hosts of Iblis, all together.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmxxviii{%
They shall say, as they dispute there one with another,\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmxxix{%
'By God, we were certainly in manifest error\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmmxxx{%
when we made you equal with the Lord of all Being.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmmxxxi{%
It was naught but the sinners that led us astray;\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmmxxxii{%
so now we have no intercessors,\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmmxxxiii{%
no loyal friend.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmmxxxiv{%
O that we might return again, and be among the believers!'\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmmxxxv{%
Surely in that is a sign, yet most of them are not believers.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmmxxxvi{%
Surely thy Lord, He is the All-mighty, the All-compassionate.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmmxxxvii{%
The people of Noah cried lies to the Envoys\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmmxxxviii{%
when their brother Noah said to them, 'Will you not be godfearing?\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmmxxxix{%
I am for you a faithful Messenger,\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmmxl{%
so serve you God, and obey you me.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmmxli{%
I ask of you no wage for this; my wage falls only upon the Lord of all Being;\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmmxlii{%
so fear you God, and obey you me.'\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmmxliii{%
They said, 'Shall we believe thee, whom the vilest follow?'\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmmxliv{%
He said, 'What knowledge have I of that they have been doing?\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmmxlv{%
Their account falls only upon my Lord, were you but aware.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmmxlvi{%
I would not drive away the believers;\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmmxlvii{%
'I am naught but a plain warner.'\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmmxlviii{%
They said, 'If thou givest not over, Noah, thou shalt assuredly be one of the stoned.'\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmmxlix{%
He said, 'My Lord, my people have cried me lies,\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmml{%
so give true deliverance between me and them, and deliver me and the believers that are with me.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmmli{%
So We delivered him, and those with him, in the laden ship,\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmmlii{%
then afterwards We drowned the rest.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmmliii{%
Surely in that is a sign, yet most of them are not believers.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmmliv{%
Surely thy Lord, He is the All-mighty, the All-compassionate.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmmlv{%
Ad cried lies to the Envoys\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmmlvi{%
when their brother Hood said to them, 'Will you not be godfearing?\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmmlvii{%
I am for you a faithful Messenger,\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmmlviii{%
so fear you God, and obey you me.\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmmlix{%
I ask of you no wage for this; my wage falls only upon the Lord of all Being.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmmlx{%
What, do you build on every prominence a sign, sporting,\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmmlxi{%
and do you take to you castles, haply to dwell forever?\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmmlxii{%
When you assault, you assault like tyrants!\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmmlxiii{%
So fear you God, and obey you me;\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmmlxiv{%
and fear Him who has succoured you with what you know,\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmmlxv{%
succoured you with flocks and sons,\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmmlxvi{%
gardens and fountains.\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmmlxvii{%
'Indeed, I fear for you the chastisement of a dreadful day.'\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmmlxviii{%
They said, 'Alike it is to us, whether thou admonishest, or art not one of the admonishers;\qt@no{136}}%
\qt@newcmd\qurantrans@en@mmmlxix{%
this is nothing but the habit of the ancients,\qt@no{137}}%
\qt@newcmd\qurantrans@en@mmmlxx{%
and we shall not be chastised.'\qt@no{138}}%
\qt@newcmd\qurantrans@en@mmmlxxi{%
So they cried him lies; then We destroyed them. Surely in that is a sign, yet most of them are not believers.\qt@no{139}}%
\qt@newcmd\qurantrans@en@mmmlxxii{%
Surely thy Lord, He is the All-mighty, the All-compassionate.\qt@no{140}}%
\qt@newcmd\qurantrans@en@mmmlxxiii{%
Thamood cried lies to the Envoys\qt@no{141}}%
\qt@newcmd\qurantrans@en@mmmlxxiv{%
when their brother Salih said to them, 'Will you not be godfearing?\qt@no{142}}%
\qt@newcmd\qurantrans@en@mmmlxxv{%
I am for you a faithful Messenger,\qt@no{143}}%
\qt@newcmd\qurantrans@en@mmmlxxvi{%
so fear you God, and obey you me.'\qt@no{144}}%
\qt@newcmd\qurantrans@en@mmmlxxvii{%
'I ask of you no wage for this; my wage falls only upon the Lord of all Being.\qt@no{145}}%
\qt@newcmd\qurantrans@en@mmmlxxviii{%
Will you be left secure in this here,\qt@no{146}}%
\qt@newcmd\qurantrans@en@mmmlxxix{%
among gardens and fountains,\qt@no{147}}%
\qt@newcmd\qurantrans@en@mmmlxxx{%
sown fields, and palms with slender spathes?\qt@no{148}}%
\qt@newcmd\qurantrans@en@mmmlxxxi{%
Will you still skilfully hew houses out of the mountains?\qt@no{149}}%
\qt@newcmd\qurantrans@en@mmmlxxxii{%
So fear you God, and obey you me;\qt@no{150}}%
\qt@newcmd\qurantrans@en@mmmlxxxiii{%
and obey not the commandment of the prodigal\qt@no{151}}%
\qt@newcmd\qurantrans@en@mmmlxxxiv{%
who do corruption in the earth, and set not things aright.'\qt@no{152}}%
\qt@newcmd\qurantrans@en@mmmlxxxv{%
They said, 'Thou art merely one of those that are bewitched;\qt@no{153}}%
\qt@newcmd\qurantrans@en@mmmlxxxvi{%
thou art naught but a mortal, like us; then produce a sign, if thou art one of the truthful.'\qt@no{154}}%
\qt@newcmd\qurantrans@en@mmmlxxxvii{%
He said, 'This is a she-camel; to her a draught and to you a draught, on a day appointed,\qt@no{155}}%
\qt@newcmd\qurantrans@en@mmmlxxxviii{%
and do not touch her with malice so that there seize you the chastisement of a dreadful day.'\qt@no{156}}%
\qt@newcmd\qurantrans@en@mmmlxxxix{%
But they hamstrung her, and in the morning they were remorseful,\qt@no{157}}%
\qt@newcmd\qurantrans@en@mmmxc{%
and the chastisement seized them. Surely in that is a sign, yet most of them are not believers.\qt@no{158}}%
\qt@newcmd\qurantrans@en@mmmxci{%
Surely thy Lord, He is the All-mighty, the All-compassionate.\qt@no{159}}%
\qt@newcmd\qurantrans@en@mmmxcii{%
The people of Lot cried lies to the Envoys\qt@no{160}}%
\qt@newcmd\qurantrans@en@mmmxciii{%
when their brother Lot said to them, 'Will you not be godfearing?\qt@no{161}}%
\qt@newcmd\qurantrans@en@mmmxciv{%
I am for you a faithful Messenger,\qt@no{162}}%
\qt@newcmd\qurantrans@en@mmmxcv{%
so fear you God, and obey you me.\qt@no{163}}%
\qt@newcmd\qurantrans@en@mmmxcvi{%
I ask of you no wage for this; my wage falls only upon the Lord of all Being.\qt@no{164}}%
\qt@newcmd\qurantrans@en@mmmxcvii{%
What, do you come to male beings,\qt@no{165}}%
\qt@newcmd\qurantrans@en@mmmxcviii{%
leaving your wives that your Lord created for you? Nay, but you are a people of transgressors.\qt@no{166}}%
\qt@newcmd\qurantrans@en@mmmxcix{%
They said, 'If thou givest not over, Lot, thou shalt assuredly be one of the expelled.'\qt@no{167}}%
\qt@newcmd\qurantrans@en@mmmc{%
He said, 'Truly I am a detester of what you do.\qt@no{168}}%
\qt@newcmd\qurantrans@en@mmmci{%
My Lord, deliver me and my people from that they do.'\qt@no{169}}%
\qt@newcmd\qurantrans@en@mmmcii{%
So We delivered him and his people all together,\qt@no{170}}%
\qt@newcmd\qurantrans@en@mmmciii{%
save an old woman among those that tarried;\qt@no{171}}%
\qt@newcmd\qurantrans@en@mmmciv{%
then We destroyed the others,\qt@no{172}}%
\qt@newcmd\qurantrans@en@mmmcv{%
and We rained on them a rain; and evil is the rain of them that are warned.\qt@no{173}}%
\qt@newcmd\qurantrans@en@mmmcvi{%
Surely in that is a sign, yet most of them are not believers.\qt@no{174}}%
\qt@newcmd\qurantrans@en@mmmcvii{%
Surely thy Lord, He is the All-mighty, the All-compassionate.\qt@no{175}}%
\qt@newcmd\qurantrans@en@mmmcviii{%
The men of the Thicket cried lies to the Envoys\qt@no{176}}%
\qt@newcmd\qurantrans@en@mmmcix{%
when Shuaib said to them, 'Will you not be godfearing?\qt@no{177}}%
\qt@newcmd\qurantrans@en@mmmcx{%
I am for you a faithful Messenger, so fear you God, and obey you me.\qt@no{178}}%
\qt@newcmd\qurantrans@en@mmmcxi{%
I ask of you no wage for this;\qt@no{179}}%
\qt@newcmd\qurantrans@en@mmmcxii{%
my wage falls only upon the Lord of all Being.\qt@no{180}}%
\qt@newcmd\qurantrans@en@mmmcxiii{%
Fill up the measure, and be not cheaters,\qt@no{181}}%
\qt@newcmd\qurantrans@en@mmmcxiv{%
and weigh with the straight balance,\qt@no{182}}%
\qt@newcmd\qurantrans@en@mmmcxv{%
and diminish not the goods of the people, and do not mischief in the earth, working corruption.\qt@no{183}}%
\qt@newcmd\qurantrans@en@mmmcxvi{%
Fear Him who created you, and the generations of the ancients.'\qt@no{184}}%
\qt@newcmd\qurantrans@en@mmmcxvii{%
They said, 'Thou art merely one of those that are bewitched;\qt@no{185}}%
\qt@newcmd\qurantrans@en@mmmcxviii{%
thou art naught but a mortal, like us; indeed, we think that thou art one of the liars.\qt@no{186}}%
\qt@newcmd\qurantrans@en@mmmcxix{%
Then drop down on us lumps from heaven, if thou art one of the truthful.'\qt@no{187}}%
\qt@newcmd\qurantrans@en@mmmcxx{%
He said, 'My Lord knows very well what you are doing.'\qt@no{188}}%
\qt@newcmd\qurantrans@en@mmmcxxi{%
But they cried him lies; then there seized them the chastisement of the Day of Shadow; assuredly it was the chastisement of a dreadful day.\qt@no{189}}%
\qt@newcmd\qurantrans@en@mmmcxxii{%
Surely in that is a sign, yet most of them are not believers.\qt@no{190}}%
\qt@newcmd\qurantrans@en@mmmcxxiii{%
Surely thy Lord, He is the All-mighty, the All-compassionate.\qt@no{191}}%
\qt@newcmd\qurantrans@en@mmmcxxiv{%
Truly it is the revelation of the Lord of all Being,\qt@no{192}}%
\qt@newcmd\qurantrans@en@mmmcxxv{%
brought down by the Faithful Spirit\qt@no{193}}%
\qt@newcmd\qurantrans@en@mmmcxxvi{%
upon thy heart, that thou mayest be one of the warners,\qt@no{194}}%
\qt@newcmd\qurantrans@en@mmmcxxvii{%
in a clear, Arabic tongue.\qt@no{195}}%
\qt@newcmd\qurantrans@en@mmmcxxviii{%
Truly it is in the Scriptures of the ancients.\qt@no{196}}%
\qt@newcmd\qurantrans@en@mmmcxxix{%
Was it not a sign for them, that it is known to the learned of the Children of Israel?\qt@no{197}}%
\qt@newcmd\qurantrans@en@mmmcxxx{%
If We had sent it down on a barbarian\qt@no{198}}%
\qt@newcmd\qurantrans@en@mmmcxxxi{%
and he had recited it to them, they would not have believed in it.\qt@no{199}}%
\qt@newcmd\qurantrans@en@mmmcxxxii{%
Even so We have caused it to enter into the hearts of the sinners,\qt@no{200}}%
\qt@newcmd\qurantrans@en@mmmcxxxiii{%
who will not believe in it, until they see the painful chastisement\qt@no{201}}%
\qt@newcmd\qurantrans@en@mmmcxxxiv{%
so that it will come upon them suddenly, while they are not aware,\qt@no{202}}%
\qt@newcmd\qurantrans@en@mmmcxxxv{%
and they will say, 'Shall we be respited?'\qt@no{203}}%
\qt@newcmd\qurantrans@en@mmmcxxxvi{%
What, do they seek to hasten Our chastisement?\qt@no{204}}%
\qt@newcmd\qurantrans@en@mmmcxxxvii{%
What thinkest thou? If We give them enjoyment of days for many years,\qt@no{205}}%
\qt@newcmd\qurantrans@en@mmmcxxxviii{%
then there comes on them that they were promised,\qt@no{206}}%
\qt@newcmd\qurantrans@en@mmmcxxxix{%
what will it then avail them, the enjoyment of days they were given?\qt@no{207}}%
\qt@newcmd\qurantrans@en@mmmcxl{%
Never a city We destroyed, but it had warners\qt@no{208}}%
\qt@newcmd\qurantrans@en@mmmcxli{%
for a reminder; and never did We wrong.\qt@no{209}}%
\qt@newcmd\qurantrans@en@mmmcxlii{%
Not by the Satans has it been brought down;\qt@no{210}}%
\qt@newcmd\qurantrans@en@mmmcxliii{%
it behoves them not, neither are they able.\qt@no{211}}%
\qt@newcmd\qurantrans@en@mmmcxliv{%
Truly, they are expelled from hearing.\qt@no{212}}%
\qt@newcmd\qurantrans@en@mmmcxlv{%
So call thou not upon another god with God, lest thou shouldst be one of those that are chastised.\qt@no{213}}%
\qt@newcmd\qurantrans@en@mmmcxlvi{%
And warn thy clan, thy nearest kin.\qt@no{214}}%
\qt@newcmd\qurantrans@en@mmmcxlvii{%
Lower thy wing to those who follow thee, being believers;\qt@no{215}}%
\qt@newcmd\qurantrans@en@mmmcxlviii{%
then, if they disobey thee, say, 'I am quit of that you do.'\qt@no{216}}%
\qt@newcmd\qurantrans@en@mmmcxlix{%
Put thy trust in the All-mighty, the All-compassionate\qt@no{217}}%
\qt@newcmd\qurantrans@en@mmmcl{%
who sees thee when thou standest\qt@no{218}}%
\qt@newcmd\qurantrans@en@mmmcli{%
and when thou turnest about among those who bow.\qt@no{219}}%
\qt@newcmd\qurantrans@en@mmmclii{%
Surely He is the All-hearing, the All-knowing.\qt@no{220}}%
\qt@newcmd\qurantrans@en@mmmcliii{%
Shall I tell you on whom the Satans come down?\qt@no{221}}%
\qt@newcmd\qurantrans@en@mmmcliv{%
They come down on every guilty impostor.\qt@no{222}}%
\qt@newcmd\qurantrans@en@mmmclv{%
They give ear, but most of them are liars.\qt@no{223}}%
\qt@newcmd\qurantrans@en@mmmclvi{%
And the poets -- the perverse follow them;\qt@no{224}}%
\qt@newcmd\qurantrans@en@mmmclvii{%
hast thou not seen how they wander in every valley\qt@no{225}}%
\qt@newcmd\qurantrans@en@mmmclviii{%
and how they say that which they do not?\qt@no{226}}%
\qt@newcmd\qurantrans@en@mmmclix{%
Save those that believe, and do righteous deeds, and remember God oft, and help themselves after being wronged; and those who do wrong shall surely know by what overturning they will he overturned.\qt@no{227}}%
\qt@newcmd\qurantrans@en@mmmclx{%
\basmalahen Ta Sin. Those are the signs of the Koran and a Manifest Book,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmclxi{%
a guidance, and good tidings unto the believers\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmclxii{%
who perform the prayer, and pay the alms, and have sure faith in the Hereafter.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmclxiii{%
Those who believe not in the Hereafter, We have decked out fair for them their works, and they wander blindly;\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmclxiv{%
those are they whom an evil chastisement awaits, and they will be the greatest losers in the Hereafter.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmclxv{%
Thou receivest the Koran from One All-wise, All-knowing.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmclxvi{%
When Moses said to his people 'I observe a fire, and will bring you news of it, or I will bring you a flaming brand, that haply you shall warm yourselves.'\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmclxvii{%
So, when he came to it, he was called: 'Blessed is he who is in the fire, and he who is about it. Glory be to God, the Lord of all Being!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmclxviii{%
Moses, behold, it is I, God, the All-mighty, the All-wise.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmclxix{%
Cast down thy staff.' And when he saw it quivering like a serpent he turned about, retreating, and turned not back. 'Moses, fear not; surely the Envoys do not fear in My presence,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmclxx{%
save him who has done evil, then; after evil, has changed into good; All-forgiving am I, All-compassionate.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmclxxi{%
Thrust thy hand in thy bosom and it will come forth white without evil-among nine signs to Pharaoh and his people; they are an ungodly people.'\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmclxxii{%
But when Our signs came to them visibly, they said, 'This is a manifest sorcery';\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmclxxiii{%
and they denied them, though their souls acknowledged them, wrongfully and out of pride. Behold, how was the end of the workers of corruption!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmclxxiv{%
And We gave David and Solomon knowledge and they said, 'Praise belongs to God who has preferred us over many of His believing servants.'\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmclxxv{%
And Solomon was David's heir, and he said, 'Men, we have been taught the speech of the birds, and we have been given of everything; surely this is indeed the manifest bounty.'\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmclxxvi{%
And his hosts were mustered to Solomon, jinn, men and birds, duly disposed;\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmclxxvii{%
till, when they came on the Valley of Ants, an ant said, 'Ants, enter your dwelling-places, lest Solomon and his hosts crush you, being unaware!'\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmclxxviii{%
But he smiled, laughing at its words, and he said, 'My Lord, dispose me that I may be thankful for Thy blessing wherewith Thou hast blessed me and my father and mother, and that I may do righteousness well-pleasing to Thee; and do Thou admit me, by Thy mercy, amongst Thy righteous servants.'\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmclxxix{%
And he reviewed the birds; then he said, 'How is it with me, that I do not see the hoopoe? Or is he among the absent?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmclxxx{%
Assuredly I will chastise him with a terrible chastisement, or I will slaughter him, or he bring me a clear authority.'\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmclxxxi{%
But he tarried not long, and said, 'I have comprehended that which thou hast not comprehended, and I have come from Sheba to thee with a sure tiding.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmclxxxii{%
I found a woman ruling over them, and she has been given of everything, and she possesses a mighty throne.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmclxxxiii{%
I found her and her people prostrating to the sun, apart from God; Satan has decked out fair their deeds to them and he has barred them from the way, and therefore they are not guided,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmclxxxiv{%
so that they prostrate not themselves to God, who brings forth what is hidden in the heavens and earth; and He knows what you conceal and what you publish.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmclxxxv{%
God: there is no god but He, the Lord of the Mighty Throne.'\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmclxxxvi{%
Said he, 'Now We will see whether thou hast spoken truly, or whether thou art amongst those that lie.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmclxxxvii{%
Take this letter of mine, and cast it unto them, then turn back from them and see what they shall return '\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmclxxxviii{%
She said, 'O Council, see, a letter honourable has been cast unto me.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmclxxxix{%
It is from Solomon, and it is ``In the Name of God, the Merciful, the Compassionate.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcxc{%
Rise not up against me, but come to me in surrender." '\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcxci{%
She said, 'O Council, pronounce to me concerning my affair; I am not used to decide an affair until you bear me witness.'\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcxcii{%
They said, 'We possess force and we possess great might. The affair rests with thee; so consider what thou wilt command.'\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcxciii{%
She said, 'Kings, when they enter a city, disorder it and make the mighty ones of its inhabitants abased. Even so they too will do.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcxciv{%
Now I will send them a present, and see what the envoys bring back.'\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcxcv{%
But when he came to Solomon he said, 'What, would you succour me with wealth, and what God gave me is better than what He has given you? Nay, but instead you rejoice in your gift!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcxcvi{%
Return thou to them; we shall assuredly come against them with hosts they have not power to resist, and we shall expel them from there, abased and utterly humbled.'\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmcxcvii{%
He said, 'O Council, which one of you will bring me her throne, before they come to me in surrender?'\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmcxcviii{%
An efreet of the jinns said, 'I will bring it to thee, before thou risest from thy place; I have strength for it\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmcxcix{%
and I am trusty.' Said he who possessed knowledge of the Book, 'I will bring it to thee, before ever thy glance returns to thee.' Then, when he saw it settled before him, he said, 'This is of my Lord's bounty that He may try me, whether I am thankful or ungrateful. Whosoever gives thanks gives thanks only for his own soul's good, and whosoever is ungrateful -- my Lord is surely All-sufficient, All-generous.'\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmcc{%
He said, 'Disguise her throne for her, and we shall behold whether she is guided or if she is of those that are not guided.'\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmcci{%
So, when she came, it was said, 'Is thy throne like this?' She said, 'It seems the same.' 'And we were given the knowledge before her, and we were in surrender,\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccii{%
but that she served, apart from God, barred her, for she was of a people of unbelievers.'\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmcciii{%
It was said to her, 'Enter the pavilion.' But when she saw it, she supposed it was a spreading water, and she bared her legs. He said, 'It is a pavilion smoothed of crystal. She said, 'My Lord, indeed I have wronged myself, and I surrender with Solomon to God, the Lord of all Being.'\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmcciv{%
And We sent to Thamood their brother Salih: 'Serve you God!' And behold, they were two parties, that were disputing one with another.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccv{%
He said, 'O my people, why do you seek to hasten evil before good? Why do you not ask forgiveness of God? Haply so you will find mercy.'\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccvi{%
They said, 'We augur ill of thee and of those that are with thee.' He said, 'Your augury is with God; nay, but you are a people being proved.'\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccvii{%
Now in the city there were nine persons who did corruption in the land, and put not things right;\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccviii{%
they said, 'Swear you, one to another, by God, ``We will attack him and his family by night, then we will tell his protector, We were not witnesses of the destruction of his family; and assuredly we are truthful men."'\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmccix{%
And they devised a device, and We likewise devised a device, while they were not aware;\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmccx{%
and behold, how was the end of their device! For We destroyed them and their people all together.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmccxi{%
Those are their houses, all fallen down because of the evil they committed; surely in that is a sign for a people who have knowledge.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmccxii{%
And We delivered those who believed and were godfearing.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmccxiii{%
And Lot, when he said to his people, 'What, do you commit indecency with your eyes open?\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmccxiv{%
What, do you approach men lustfully instead of women? No, you are a people that are ignorant.'\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmccxv{%
And the only answer of his people was that they said, 'Expel the folk of Lot from your city; they are men that keep themselves clean!'\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmccxvi{%
So We delivered him and his family, except his wife; We decreed she should be of those that tarried.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmccxvii{%
And We rained on them a rain; and evil indeed is the rain of them that are warned.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmccxviii{%
Say: 'Praise belongs to God, and peace be on His servants whom He has chosen.' What, is God better, or that they associate?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmccxix{%
He who created the heavens and earth, and sent down for you out of heaven water; and We caused to grow therewith gardens full of loveliness whose trees you could never grow. Is there a god with God? Nay, but they are a people who assign to Him equals!\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmccxx{%
He who made the earth a fixed place and set amidst it rivers and appointed for it firm mountains and placed a partition between the two seas. Is there a god with God? Nay, but the most of them have no knowledge.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmccxxi{%
He who answers the constrained, when he calls unto Him, and removes the evil and appoints you to be successors in the earth. Is there a god with God? Little indeed do you remember.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmccxxii{%
He who guides you in the shadows of the land and the sea and looses the winds, bearing good tidings before His mercy. Is there a god with God? High exalted be God, above that which they associate!\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmccxxiii{%
Who originates creation, then brings it back again, and provides you out of heaven and earth. Is there a god with God? Say: 'Produce your proof, if you speak truly.'\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmccxxiv{%
Say: 'None knows the Unseen in the heavens and earth except God. And they are not aware when they shall be raised;\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmccxxv{%
nay, but their knowledge fails as to the Hereafter; nay, they are in doubt of it; nay, they are blind to it.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmccxxvi{%
The unbelievers say, 'What, when we are dust, and our fathers, shall we indeed be brought forth?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmccxxvii{%
We have been promised this, and our fathers before; this is naught but the fairy-tales of the ancients.'\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmccxxviii{%
Say: 'Journey in the land, then behold how was the end of the sinners.'\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmccxxix{%
Do not sorrow for them, nor be thou straitened for what they devise.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmccxxx{%
They say, 'When shall this promise come to pass, if you speak the truth?'\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmccxxxi{%
Say: 'It may be that riding behind you already is some part of that you seek to hasten on.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmccxxxii{%
Surely thy Lord is bountiful to men; but most of them are not thankful.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmccxxxiii{%
Surely thy Lord knows what their hearts conceal, and what they publish.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmccxxxiv{%
And not a thing is there hidden in heaven and earth but it is in a Manifest Book.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmccxxxv{%
Surely this Koran relates to the Children of Israel most of that concerning which they are at variance;\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmccxxxvi{%
it is a guidance, and a mercy unto the believers.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmccxxxvii{%
Surely thy Lord will decide between them by His Judgment; He is the All-mighty, the All-knowing.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmccxxxviii{%
So put thy trust in God; thou art upon the manifest truth.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmccxxxix{%
Thou shalt not make the dead to hear, neither shalt thou make the deaf to hear the call when they turn about, retreating.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmccxl{%
Thou shalt not guide the blind out of their error neither shalt thou make any to hear, save such as believe in Our signs, and so surrender.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmccxli{%
When the Word falls on them, We shall bring forth for them out of the earth a beast that shall speak unto them: 'Mankind had no faith in Our signs.'\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmccxlii{%
Upon the day when We shall muster out of every nation a troop of those that cried lies to Our signs, duly disposed,\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmccxliii{%
till, when they are come, He shall say, 'Did you cry lies to My signs, not comprehending them in knowledge, or what have you been doing?'\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmccxliv{%
And the Word shall fall upon them because of the evil they committed, while they speak naught.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmccxlv{%
Have they not seen how We made the night for them, to repose in it, and the day, to see? Surely in that is a sign for a people who are believers.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmccxlvi{%
On the day the Trumpet is blown, and terrified is whosoever is in the heavens and earth, excepting whom God wills, and every one shall come to Him, all utterly abject;\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmccxlvii{%
and thou shalt see the mountains, that thou supposest fixed, passing by like clouds -- God's handiwork, who has created everything very well. He is aware of the things you do.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmccxlviii{%
Whosoever comes with a good deed, he shall have better than it; and they shall be secure from terror that day.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmccxlix{%
And whosoever comes with an evil deed, their faces shall be thrust into the Fire: 'Are you recompensed but for what you did?'\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmccl{%
I have only been commanded to serve the Lord of this territory which He has made sacred; to Him belongs everything. And I have been commanded to be of those that surrender,\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmccli{%
and to recite the Koran. So whosoever is guided, is only guided to his own gain; and whosoever goes astray, say: 'I am naught but a warner.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmcclii{%
And say: 'Praise belongs to God. He shall show you His signs and you will recognise them. Thy Lord is not heedless of the things you do.'\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmccliii{%
\basmalahen Ta Sin Mim\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmccliv{%
Those are the signs of the Manifest Book.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcclv{%
We will recite to thee something of the tiding of Moses and Pharaoh truthfully, for a people who believe.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcclvi{%
Now Pharaoh had exalted himself in the land and had divided its inhabitants into sects, abasing one party of them, slaughtering their sons, and sparing their women; for he was of the workers of corruption.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcclvii{%
Yet We desired to be gracious to those that were abased in the land, and to make them leaders, and to make them the inheritors,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcclviii{%
and to establish them in the land, and to show Pharaoh and Ha man, and their hosts, what they were dreading from them.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcclix{%
So We revealed to Moses' mother, 'Suckle him, then, when thou fearest for him, cast him into the sea, and do not fear, neither sorrow, for We shall return him to thee, and shall appoint him one of the Envoys.'\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcclx{%
So then the folk of Pharaoh picked him out to be an enemy and a sorrow to them; certainly Pharaoh and Haman, and their hosts, were of the sinners.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcclxi{%
Said Pharaoh's wife, 'He will be a comfort to me and thee. Slay him not; perchance he will profit us, or we will take him for a son.' And they were not aware.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcclxii{%
On the morrow the heart of Moses" mother became empty, and she wellnigh disclosed him had We not strengthened her heart, that she might be among the believers;\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcclxiii{%
and she said to his sister, 'Follow him,' and she perceived him from afar, even while they were not aware.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcclxiv{%
Now We had forbidden to him aforetime to be suckled by any foster-mother; therefore she said, 'Shall I direct you to the people of a household who will take charge of him for you and look after him?'\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcclxv{%
So We returned him to his mother, that she might be comforted and not sorrow, and that she might know that the promise of God is true; but most of them do not know.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcclxvi{%
And when he was fully grown and in the perfection of his strength, We gave him judgment and knowledge; even so do We recompense the good-doers.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcclxvii{%
And he entered the city, at a time when its people were unheeding, and found there two men fighting; the one was of his own party, and the other was of his enemies. Then the one that was of his party cried to him to aid him against the other that was of his enemies; so Moses struck him, and despatched him, and said, 'This is of Satan's doing; he is surely an enemy misleading, manifest.'\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcclxviii{%
He said, 'My Lord, I have wronged myself. Forgive me!' So God forgave him, for He is the All-forgiving, the All-compassionate.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcclxix{%
He said, 'My Lord, forasmuch as Thou hast blessed me, I will never be a partisan of the sinners.'\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcclxx{%
Now in the morning he was in the city, fearful and vigilant; and behold, the man who had sought his, succour on the day before cried out to him again. Moses said to him, 'Clearly thou art, a quarreller.'\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcclxxi{%
But when he would have assaulted the man who was an enemy to them both, the man said, 'Moses, dost thou' desire to slay me, even as thou slewest a living 'soul yesterday? Thou only desirest to be a tyrant in the land; thou desirest not to be of them that put things right.'\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcclxxii{%
Then came a man from the furthest part of the city, running; he said, 'Moses, the Council are conspiring to slay thee. Depart; I am one of thy sincere advisers.'\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcclxxiii{%
So he departed therefrom, fearful and vigilant; he said, 'My Lord, deliver me from the people of the evildoers.'\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcclxxiv{%
And when he turned his face towards Midian he said, 'It may be that my Lord will guide me\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcclxxv{%
On the right way. And when he came to the waters of Midian he found a company of the people there drawing water, and he found, apart from them, two women holding back their flocks. He said, 'What is your business?' They said, 'We may not draw water until the shepherds drive off; and our father is passing old.'\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcclxxvi{%
So he drew water for them; then he turned away to the shade, and he said, 'O my Lord, surely I have need of whatever good Thou shalt have sent down upon me.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcclxxvii{%
Then came one of the two women to him, walking modestly, and said, 'My father invites thee, that he may recompense thee with the wage of thy drawing water for us.' So when he came to him and had related to him the story, he said, 'Be not afraid; thou hast escaped from the people of the evildoers.'\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcclxxviii{%
Said one of the two women, 'Father, hire him; surely the best man thou canst hire is the one strong and trusty.'\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcclxxix{%
He said, 'I desire to marry thee to one of these my two daughters, on condition that thou hirest thyself to me for eight years. If thou completest ten, that shall be of thy own accord; I do not desire to' press hard 'upon thee. Thou shalt assuredly find me, if God wills, one of the righteous.'\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcclxxx{%
Said he, 'So let it be between me and thee. Whichever of the two' terms I fulfil, it shall be no Injustice to me; and God is guardian of what we say.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcclxxxi{%
So when Moses had accomplished the term and departed with his household, he observed on the side of the Mount a fire. He said to his household, 'Tarry you here; I observe a fire. Perhaps I shall bring you news of it, or a faggot from the fire, that haply you shall warm yourselves.'\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcclxxxii{%
When he came to it, a voice cried from the right of the watercourse, in the sacred hollow, coming from the tree: 'Moses, I am God, the Lord of all Being.'\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcclxxxiii{%
'Cast down thy staff.' And when he saw it quivering like a serpent, he turned about retreating, and turned not back. 'Moses, come forward, and fear not; for surely thou art in security.'\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcclxxxiv{%
Insert thy hand into thy bosom, and it will come forth white without evil; and press to thee thy arm, that thou be not afraid. So these shall be two proofs from thy Lord to Pharaoh and his Council; for surely they are an ungodly people.'\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcclxxxv{%
Said he, 'My Lord, I have indeed slain a living soul among them, and I fear that they will slay me.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcclxxxvi{%
Moreover my brother Aaron is more eloquent than I. Send him with me as a helper and to confirm I speak truly, for' I fear they will cry me lies.'\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcclxxxvii{%
Said He, 'We will strengthen thy arm by means of thy brother, and We shall appoint. to you an authority, so that they shall not reach you because of Our signs; you, and whoso follows you, shall be the victors.'\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcclxxxviii{%
So when Moses came to them with Our signs, clear signs, they said, 'This is nothing but a forged sorcery. We never heard of this among our fathers, the ancients.'\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcclxxxix{%
But Moses said, 'My Lord knows very well who comes with the guidance from Him, and shall possess the Ultimate Abode; surely the evildoers will not prosper.'\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmccxc{%
And Pharaoh said, 'Council, I know not that you have any god but me. Kindle me, Haman, a fire upon the clay, and make me a tower, that I may mount up to Moses' god; for I think that he is one of the liars.'\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmccxci{%
And he waxed proud in the land, he and his hosts, wrongfully; and they thought they should not be returned to Us.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmccxcii{%
Therefore We seized him and his hosts, and cast their into the sea; so behold how was the end of the evildoers!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmccxciii{%
And We appointed them leaders, calling to the Fire; and on the Day of Resurrection they shall not be helped;\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmccxciv{%
and We pursued them in this world with a curse, and on the Day of Resurrection they shall be among the spurned.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccxcv{%
And We gave Moses the Book, after that We had destroyed the former generations, to be examples and a guidance and a mercy, that haply so they might remember.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmccxcvi{%
Thou wast not upon the western side when We decreed to Moses the commandment, nor wast thou of those witnessing;\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmccxcvii{%
but We raised up generations, and long their lives continued. Neither wast thou a dweller among the Midianites, reciting to them Our signs; but We were sending Messengers.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccxcviii{%
Thou wast not upon the side of the Mount when We called; but for a mercy from thy Lord, that thou mayest warn a people to whom no warner came before thee, and that haply they may remember.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccxcix{%
Else, did an affliction visit them for that their own hands have forwarded then they might say, 'Our Lord, why didst Thou not send a Messenger to us that we might follow Thy signs and so be among the believers?'\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccc{%
Yet when the truth came to them 'from Ourselves, they said, 'Why has he not been given the like' of that Moses was given?' But they, did they not disbelieve also in what Moses was given aforetime? They said, 'A pair of sorceries mutually supporting each other.' They said, 'We disbelieve both.'\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccci{%
Say: 'Bring a Book from God that gives better guidance than these, and follow it, if you speak truly.'\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcccii{%
Then if they do not answer thee, know that they are only following their caprices; and who is further astray than he who follows his caprice without guidance from God? Surely God guides not the people of the evildoers.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmccciii{%
Now We have brought them the Word; haply they may remember.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmccciv{%
Those to whom We gave the Book before this believe in it\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcccv{%
and, when it is recited to them, they say, 'We believe in it; surely it is the truth from our Lord. Indeed, even before' it we had surrendered.'\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcccvi{%
These shall be given their wage twice over for that they patiently endured, and avert evil with good, and expend of that We have provided them.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcccvii{%
When they hear idle talk, they turn away from it and say, 'We have our deeds, and you your deeds. Peace be upon your We desire not the ignorant.'\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcccviii{%
Thou guidest not whom thou likest, but God guides whom He wills, and knows very well those that are guided.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcccix{%
They say, 'Should we follow the guidance with thee, we shall be snatched from our land.' Have We not established for them a sanctuary secure, to which are collected the fruits of everything, as a provision from Us? But most of them know not.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcccx{%
How many a city We have destroyed that flourished in insolent ease! Those are their dwelling-places, undwelt in after them, except a little; Ourselves are the inheritors.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcccxi{%
Yet thy Lord never destroyed the cities until He sent in their mother-city a Messenger, to recite Our signs unto them; and We never destroyed the cities, save that their inhabitants were evildoers.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcccxii{%
Whatever thing you have been given is the enjoyment of the present life and its adornment; and what is with God is better and more enduring.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcccxiii{%
Will you not understand? What, is he to whom We have promised a fair promise, and he receives it, like him to whom We have given the enjoyment of the present life, then he on the Resurrection Day shall be of those that are arraigned?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmcccxiv{%
Upon the day when He shall call to them, and He shall say, 'Where now are My associates whom you were asserting?'\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmcccxv{%
Those against whom the Word is realized they shall say, 'Our Lord, those whom we perverted, we perverted them even as we ourselves erred. We declare our innocence unto Thee; it was not us that they were serving.'\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmcccxvi{%
It shall be said, 'Call you now upon your associates!' And they will call upon them, but they shall not answer them, and they shall see the chastisement-ah, if they had been guided!\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmcccxvii{%
Upon the day when He shall call to them, and He shall say, 'What answer gave you to the Envoys?'\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmcccxviii{%
Upon that day the tidings will be darkened for them, nor will they ask each other.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmcccxix{%
But as for him who repents, and believes, and works righteousness, haply he shall be among the prosperers.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmcccxx{%
Thy Lord creates whatsoever He will and He chooses; they have not the choice. Glory be to God! High be He exalted above that they associate!\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmcccxxi{%
And thy Lord knows what their breasts conceal and what they publish.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmcccxxii{%
And He is God; there is no god but He. His is the praise in the former as in the latter; His too is the Judgment, and unto Him you shall be returned.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmcccxxiii{%
Say: 'What think you? If God should make the night unceasing over you, until the Day of Resurrection, what god other than God shall bring you illumination? Will you not hear?'\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmcccxxiv{%
Say: 'What think you? If God should make the day unceasing over you, until the Day of Resurrection, what god other than God shall bring you night to repose in? Will you not see?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmcccxxv{%
Of His mercy He has appointed for you night and day, for you to repose in and seek after His bounty, that haply you will be thankful.'\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmcccxxvi{%
Upon the day when He shall call. to them, and He shall say, 'Where now are My associates whom you were asserting?'\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmcccxxvii{%
And We shall draw out from every nation a witness, and say, 'Produce your proof!' Then will they know that Truth is God's, and there shall go astray from them that they were forging.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmcccxxviii{%
Now Korah was of the people of Moses; he became insolent to them, for We had given him treasures such that the very keys of them were too heavy a burden for a company of men endowed with strength. When his people said to him, 'Do not exult; God loves not those that exult;\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmcccxxix{%
but seek, amidst that which God has given thee, the Last Abode, and forget not thy portion of the present world; and do good, as God has been good to thee.' And seek not to work corruption in the earth; surely God loves not the workers of corruption.'\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmcccxxx{%
He said, 'What I have been given is only because of a knowledge that is in me.' What, did he not know that God bad destroyed before him generations of men stronger than he ill might, and more numerous in multitude? And yet the sinners shall not be questioned concerning their sins.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmcccxxxi{%
So he went forth unto his people in his adornment. Those who desired the present life said, 'Would that we possessed the like of that Korah has been given! Surely he is a man of mighty fortune.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmcccxxxii{%
But those to whom knowledge had been given said, 'Woe upon you! The reward of God is better for him who believes, and works righteousness; and none shall receive it except the steadfast.'\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmcccxxxiii{%
So We made the earth to swallow him and his dwelling and there was no host to help him, apart from God, and he was helpless;\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmcccxxxiv{%
and in the morning those who had longed to be in his place the day before were saying, 'Ah, God outspreads and straitens His provision to whomsoever He will of His servants. Had God not been gracious to us, He would have made us to be swallowed too. Ah, the unbelievers do not prosper,\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmcccxxxv{%
That is the Last Abode; We appoint it for those who desire not exorbitance in the earth, nor corruption. The issue ultimate is to the godfearing.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmcccxxxvi{%
Whoso brings a good deed shall have better than it; and whoso brings an evil deed those who have done evil deeds shall only be recompensed for that they were doing.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmcccxxxvii{%
He who imposed 'the Recitation upon thee. shall surely restore thee to a place of homing. Say: 'My Lord' knows very well who comes with guidance, and who is in manifest error.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmcccxxxviii{%
Thou didst not hope that the Book should be cast unto thee, except it be as a mercy from thy Lord; so be thou not a partisan of the unbelievers.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmcccxxxix{%
Let them not bar thee from the signs of God, after that they have been sent down to thee. And call upon thy Lord, and be thou' not of the idolaters.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmcccxl{%
And call not upon another god with God; there is no god but He. All things perish, except His Face. His is the Judgment, and unto Him you shall be returned.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmcccxli{%
\basmalahen Alif Lam Mim\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcccxlii{%
Do the people reckon that they will be left to say 'We believe,' and will not be tried?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcccxliii{%
We certainly tried those that were before them, and assuredly God knows those who speak truly, and assuredly He knows the liars.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcccxliv{%
Or do they reckon, those who do evil deeds, that they will outstrip Us? Ill they judge!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcccxlv{%
Whoso looks to encounter God, God's term is coming; He is the All-hearing, the All-knowing.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcccxlvi{%
Whosoever struggles, struggles only to his own gain; surely God is All-sufficient nor needs any being.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcccxlvii{%
And those who believe, and do righteous deeds, We shall surely acquit them of their evil deeds, and shall recompense them the best of what they were doing.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcccxlviii{%
We have charged man, that he be kind to his parents; but if they strive with thee to make thee associate with Me that whereof thou hast no knowledge, then do not obey them; unto Me you shall return, and I shall tell you what you were doing.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcccxlix{%
And those who believe, and do righteous deeds assuredly We shall admit them among the righteous.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcccl{%
Some men there are who say, 'We believe in God,' but when such a man is hurt in God's cause, he makes the persecution of men as it were God's chastisement; then if help comes from thy Lord, he will say 'We were with you.' What, does not God know very well what is in the breasts of all beings?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcccli{%
God surely knows the believers, and He knows the hypocrites.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmccclii{%
The unbelievers say to the believers, 'Follow our path, and let us carry your offences'; yet they cannot carry anything, even of their own offences; they are truly liars.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcccliii{%
They shall certainly carry their loads, and other loads along with their loads, and upon the Day of Resurrection they shall surely be questioned concerning that they were forging.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcccliv{%
Indeed, We sent Noah to his people, and he tarried among them a thousand years, all but fifty; so the Flood seized them, while they were evildoers.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmccclv{%
Yet We delivered him, and those who were in the ship, and appointed it for a sign unto all beings.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmccclvi{%
And Abraham, when he said to his people, 'Serve God, and fear Him; that is better for you, did you know.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmccclvii{%
You only serve, apart from God, idols and you create a calumny; those you serve, apart from God, have no power to provide for you. So seek after your provision with God, and serve Him, and be thankful to Him; unto Him you shall be returned.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmccclviii{%
'But if you cry me lies, nations cried lies before you; and it is only for the Messenger to deliver the Manifest Message.'\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmccclix{%
(Have they not seen how God originates creation, then brings it back again? Surely that is an easy matter for God.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmccclx{%
Say: Journey in the land, then behold how He originated creation; then God causes the second growth to grow; God is powerful over everything,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmccclxi{%
chastising whom He will, and having mercy on whomsoever He will, and unto Him you shall be turned.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmccclxii{%
You are not able to frustrate Him either in the earth or in heaven; and you have not, apart from God, either protector or helper.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmccclxiii{%
And those who disbelieve in God's signs and the encounter with Him -- they despair of My mercy, and there awaits them a painful chastisement.)\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmccclxiv{%
But the only answer of his people was that they said, 'Slay him, or burn him!' Then God delivered him from the fire; surely in that are signs for a people who believe.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmccclxv{%
And he said, 'You have only taken to yourselves idols, apart from God, as a mark of mutual love between you in the present life; then upon the Day of Resurrection you will deny one another, and you will curse one another, and your refuge will be the Fire, and you will have no helpers.'\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmccclxvi{%
But Lot believed him; and he said, 'I will flee to my Lord; He is the All-mighty, the All-wise.'\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmccclxvii{%
And We gave him Isaac and Jacob, and We appointed the Prophecy and the Book to be among his seed; We gave him his wage in this world, and in the world to come he shall be among the righteous.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmccclxviii{%
And Lot, when he said to his people 'Surely you commit such indecency as never any being in all the world committed before you.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmccclxix{%
What, do you approach men, and cut the way, and commit in your assembly dishonour?' But the only answer of his people was that they said, 'Then bring us the chastisement of God, if thou speakest truly.'\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmccclxx{%
He said, 'My Lord, help me against the people that work corruption.'\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmccclxxi{%
And when Our messengers came to Abraham with the good tidings, they said, 'We shall destroy the people of this city, for its people are evildoers.'\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmccclxxii{%
He said, 'Lot is in it.' They said, 'We know very well who is in it; assuredly We shall deliver him and his family, except his wife; she has become of those that tarry.'\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmccclxxiii{%
When that Our messengers came to Lot he was troubled on their account and distressed for them; but they said, 'Fear not, neither sorrow, for surely we shall deliver thee and thy family, except thy wife; she has become of those that tarry.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmccclxxiv{%
We shall send down upon the people of this city wrath out of heaven for their ungodliness.'\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmccclxxv{%
And indeed, We have left thereof a sign, a clear sign? unto a people who understand.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmccclxxvi{%
And to Midian their brother Shuaib; he said, 'O my people, serve God, and look you for the Last Day; and do not mischief in the land, working corruption.'\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmccclxxvii{%
But they cried lies to him; so the earthquake seized them, and morning found them in their habitation fallen prostrate.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmccclxxviii{%
And Ad, and Thamood -- it has become clear to you from their dwelling-places; and Satan decked out fair to them their works, and barred them from the way, though they saw clearly.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmccclxxix{%
And Korah, and Pharaoh, and Haman; Moses came to them with the clear signs, but they waxed proud in the earth, yet they outstripped Us not.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmccclxxx{%
Each We seized for his sin; and of them against some We loosed a squall of pebbles and some were seized by the Cry, and some We made the earth to swallow, and some We drowned; God would never wrong them, but they wronged themselves.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmccclxxxi{%
The likeness of those who have taken to them protectors, apart from God, is as the likeness of the spider that takes to itself a house; and surely the frailest of houses is the house of the spider, did they but know.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmccclxxxii{%
God knows whatever thing they call upon apart from Him; He is the All-mighty, the All-wise.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccclxxxiii{%
And those similitudes -- We strike them for the people, but none understands them save those who know.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmccclxxxiv{%
God created the heavens and the earth with the truth; surely in that is a sign to the believers.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmccclxxxv{%
Recite what has been revealed to thee of the Book, and perform the prayer; prayer forbids indecency and dishonour. God's remembrance is greater; and God knows the things you work.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccclxxxvi{%
Dispute not with the People of the Book save in the fairer manner, except for those of them that do wrong; and say, 'We believe in what has been sent down to us, and what has been sent down to you; our God and your God is One, and to Him we have surrendered.'\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccclxxxvii{%
Even so We have sent down to thee the Book. Those to whom We have given the Book believe in it; and some of these believe in it; and none denies Our signs but the unbelievers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccclxxxviii{%
Not before this didst thou recite any Book, or inscribe it with thy right hand, for then those who follow falsehood would have doubted.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccclxxxix{%
Nay; rather it is signs, clear signs in the breasts of those who have been given knowledge; and none denies Our signs but the evildoers.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcccxc{%
They say, 'Why have signs not been gent down upon him from his Lord?' Say: 'The signs are only with God, and I am only a plain warner.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmcccxci{%
What, is it not sufficient for them that We have sent down upon thee the Book that is recited to them? Surely in that is a mercy, and a reminder to a people who believe.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmcccxcii{%
Say: 'God suffices as a witness between me and you.' He knows whatsoever is in the heavens and earth. Those who believe in vanity and disbelieve in God -- those, they are the losers.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcccxciii{%
And they demand of thee to hasten the chastisement! But for a stated term the chastisement would have come upon them; but it shall come upon them suddenly, when they are not aware.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcccxciv{%
They demand of thee to hasten the chastisement! Lo, Gehenna encompasses the unbelievers.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcccxcv{%
Upon the day the chastisement shall overwhelm them from above them and from under their feet, and He shall say, 'Taste now what you were doing!'\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcccxcvi{%
O My servants who believe, surely My earth is wide; therefore Me do you serve!\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcccxcvii{%
Every soul shall taste of death; then unto Us you shall be returned.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcccxcviii{%
And those who believe, and do righteous deeds, We shall surely lodge them in lofty chambers of paradise, underneath which rivers flow, therein dwelling forever; and excellent is the wage of those who labour,\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcccxcix{%
such men as are patient, and put their trust in their Lord.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcd{%
How many a beast that bears not its own provision, but God provides for it and you! He is the All-hearer, the All-knower.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcdi{%
If thou askest them, 'Who created the heavens and the earth and subjected the sun and the moon?' they will say, 'God.' How then are they perverted?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmcdii{%
God outspreads and straitens His provision to whomsoever He will of His servants; God has knowledge of everything.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmcdiii{%
If thou askest them, 'Who sends down out of heaven water, and therewith revives the earth after it is dead?' they will say, 'God.' Say: 'Praise belongs to God.' Nay, but most of them have no understanding.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmcdiv{%
This present life is naught but a diversion and a sport; surely the Last Abode is Life, did they but know.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmcdv{%
When they embark in the ships, they call on God, making their religion sincerely His; but when He has delivered them to the land, they associate others with Him,\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmcdvi{%
that they may be ungrateful for what We have given them, and take their enjoyment; they will soon know!\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmcdvii{%
Have they not seen that We have appointed a sanctuary secure, while all about them the people are snatched away? What, do they believe in vanity, and do they disbelieve in God's blessing?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmcdviii{%
And who does greater evil than he who forges against God a lie, or cries lies to the truth when it comes to him? What, is there not in Gehenna a lodging for the unbelievers?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmcdix{%
But those who struggle in Our cause, surely We shall guide them in Our ways; and God is with the good-doers.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmcdx{%
\basmalahen Alif Lam Mim\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcdxi{%
The Greeks have been vanquished\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcdxii{%
in the nearer part of the land; and, after their vanquishing, they shall be the victors\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcdxiii{%
in a few years. To God belongs the Command before and after, and on that day the believers shall rejoice\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcdxiv{%
in God's help; God helps whomsoever He will; and He is the All-mighty, the All-compassionate.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcdxv{%
The promise of God! God fails not His promise, but most men do not know it.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcdxvi{%
They know an outward part of the present life, but of the Hereafter they are heedless.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcdxvii{%
What, have they not considered within themselves? God created not the heavens and the earth, and what between them is, save with the truth and a stated term; yet most men disbelieve in the encounter with their Lord.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcdxviii{%
What, have they not journeyed in the land and beheld how was the end of those before them? They were stronger than themselves in might, and they ploughed up the earth and cultivated it more than they themselves have cultivated it; and their Messengers came to them with the clear signs; and God would never wrong them, but themselves they wronged.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcdxix{%
Then the end of those that did evil was evil, for that they cried lies to the signs of God and mocked at them.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcdxx{%
God originates creation, then brings it back again, then unto Him you shall be returned.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcdxxi{%
Upon the day when the Hour is come, the sinners shall be confounded\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcdxxii{%
no intercessors shall they have amongst their associates, and they shall disbelieve in their associates.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcdxxiii{%
Upon the day when the Hour is come, that day they shall be divided;\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcdxxiv{%
as for those who believed, and did deeds of righteousness, they shall walk with joy in a green meadow,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcdxxv{%
but as for those who disbelieved, and cried lies to Our signs and the encounter of the Hereafter, they shall be arraigned into the chastisement.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcdxxvi{%
So glory be to God both in your evening hour and in your morning hour.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcdxxvii{%
His is the praise in the heavens and earth, alike at the setting sun and in your noontide hour.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcdxxviii{%
He brings forth the living from the dead, and brings forth the dead from the living, and He revives the earth after it is dead; even so you shall be brought forth.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcdxxix{%
And of His signs is that He created you of dust; then lo, you are mortals, all scattered abroad.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcdxxx{%
And of His signs is that He created for you, of yourselves, spouses, that you might repose in them, and He has set between you love and mercy. Surely in that are signs for a people who consider.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcdxxxi{%
And of His signs is the creation of the heavens and earth and the variety of your tongues and hues. Surely in that are signs for all living beings.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcdxxxii{%
And of His signs is your slumbering by night and day, and your seeking after His bounty. Surely in that are signs for a people who hear.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcdxxxiii{%
And of His signs He shows you lightning, for fear and hope, and that He sends down out of heaven water and He revives the earth after it is dead. Surely in that are signs for a people who understand.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcdxxxiv{%
And of His signs is that the heaven and earth stand firm by His command; then, when He calls you once and suddenly, out of the earth, lo you shall come forth.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcdxxxv{%
To Him belongs whosoever is in the heavens and the earth; all obey His will.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcdxxxvi{%
And it is He who originates creation, then brings it back again, and it is very easy for Him. His is the loftiest likeness in the heavens and the earth; He is the All-mighty, the All-wise.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcdxxxvii{%
He has struck for you a similitude from yourselves; do you have, among that your right hands own, associates in what We have provided for you so that you are equal in regard to it, you fearing them as you fear each other? So We distinguish the signs for a people who understand.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcdxxxviii{%
Nay, but the evildoers follow their own caprices, without knowledge; so who shall guide those whom God has led astray? They have no helpers.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcdxxxix{%
So set thy face to the religion, a man of pure faith -- God's original upon which He originated mankind. There is no changing God's creation. That is the right religion; but most men know it not --\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcdxl{%
turning to Him. And fear you Him, and perform the prayer, and be not of the idolaters,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcdxli{%
even of those who have divided up their religion, and become sects, each several party rejoicing in what is theirs.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcdxlii{%
When some affliction visits mankind, they call unto their Lord, turning to Him; then, when He lets them taste mercy from Him, lo, a party of them assign associates to their Lord,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcdxliii{%
that they may be ungrateful for what We have given them. 'Take your enjoyment; certainly you will soon know.'\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcdxliv{%
Or have We sent down any authority upon them, such as speaks of that they associate with Him?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcdxlv{%
And when We let men taste mercy, they rejoice in it; but if some evil befalls them for that their own hands have forwarded, behold, they despair.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcdxlvi{%
Have they not seen that God outspreads and straitens His provision to whom He will? Surely in that are signs for a people who believe.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmcdxlvii{%
And give the kinsman his right, and the needy, and the traveller; that is better for those who desire God's Face; those they are the prosperers.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmcdxlviii{%
And what you give in usury, that it may increase upon the people's wealth, increases not with God; but what you give in alms, desiring God's Face, those -- they receive recompense manifold.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmcdxlix{%
God is He that created you, then He provided for you, then He shall make you dead, then He shall give you life; is there any of your associates does aught of that? Glory be to Him! High be He exalted above that they associate!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmcdl{%
Corruption has appeared in the land and sea, for that men's own hands have earned, that He may let them taste some part of that which they have done, that haply so they may return.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmcdli{%
Say: 'Journey in the land, then behold how was the end of those that were before; most of them were idolaters.'\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmcdlii{%
So set thy face to the true religion before there comes a day from God that cannot be turned back; on that day they shall be sundered apart.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmcdliii{%
Whoso disbelieves, his unbelief shall be charged against him; and whosoever does righteousness for themselves they are making provision,\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmcdliv{%
that He may recompense those who believe and do righteous deeds of His bounty; He loves not the unbelievers.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmcdlv{%
And of His signs is that He looses the winds, bearing good tidings and that He may let you taste of His mercy, and that the ships may run at His commandment, and that you may seek His bounty; haply so you will be thankful.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmcdlvi{%
Indeed, We sent before thee Messengers unto their people, and they brought them the clear signs; then We took vengeance upon those who sinned; and it was ever a duty incumbent upon Us, to help the believers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmcdlvii{%
God is He that looses the winds, that stir up clouds; and He spreads them in heaven how He will, and shatters them; then thou seest the rain issuing out of the midst of them, and when He smites with it whomsoever of His servants He will, lo, they rejoice,\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmcdlviii{%
although before it was sent down on them before that they had been in despair.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcdlix{%
So behold the marks of God's mercy, how He quickens the earth after it was dead; surely He is the quickener of the dead, and He is powerful over everything.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmcdlx{%
But if We loose a wind, and they see it growing yellow, they remain after that unbelievers.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmcdlxi{%
Thou shalt not make the dead to hear, neither shalt thou make the deaf to hear the call when they turn about, retreating.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcdlxii{%
Thou shalt not guide the blind out of their error neither shalt thou make any to hear except for such as believe in Our signs, and so surrender.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcdlxiii{%
God is He that created you of weakness, then He appointed after weakness strength, then after strength He appointed weakness and grey hairs; He creates what He will, and He is the All-knowing, the All-powerful.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcdlxiv{%
Upon the day when the Hour is come, the sinners shall swear they have not tarried above an hour; so they were perverted.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcdlxv{%
But those who have been given knowledge and faith shall say, 'You have tarried in God's Book till the Day of the Upraising, This is the Day of the Upraising, but you did not know.'\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcdlxvi{%
So that day their excuses will not profit the evildoers, nor will they be suffered to make amends.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcdlxvii{%
Indeed, We have struck for the people in this Koran every manner of similitude; and if thou bringest them a sign, those who are unbelievers will certainly say, 'You do nothing but follow falsehood.'\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcdlxviii{%
Even so God seals the hearts of those that know not.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcdlxix{%
So be thou patient; surely God's promise is true; and let not those who have not sure faith make thee unsteady.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcdlxx{%
\basmalahen Alif Lam Mim\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcdlxxi{%
Those are the signs of the Wise Book\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcdlxxii{%
for a guidance and a mercy to the good-doers\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcdlxxiii{%
who perform the prayer, and pay the alms, and have sure faith in the Hereafter.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcdlxxiv{%
Those are upon guidance from their Lord; those are the prosperers.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcdlxxv{%
Some men there are who buy diverting talk to lead astray from the way of God without knowledge, and to take it in mockery; those -- there awaits them a humbling chastisement.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcdlxxvi{%
And when Our signs are recited to such a man he turns away, waxing proud, as though he heard them not, and in his ears were heaviness; so give him good tidings of a painful chastisement.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcdlxxvii{%
Surely those who believe, and do deeds of righteousness, there awaits them Gardens of Bliss\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcdlxxviii{%
therein to dwell forever -- God's promise in truth; and He is the All-mighty, the All-wise.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcdlxxix{%
He created the heavens without pillars you can see, and He cast on the earth firm mountains, lest it shake with you, and He scattered abroad in it all manner of crawling thing. And We sent down out of heaven water, and caused to grow in it of every generous kind.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcdlxxx{%
This is God's creation; now show me what those have created that are apart from Him! Nay, but the evildoers are in manifest error.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxi{%
Indeed, We gave Lokman wisdom: 'Give thanks to God. Whosoever gives thanks gives thanks only for his own soul's good, and whosoever is ungrateful -- surely God is All-sufficient, All-laudable.'\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxii{%
And when Lokman said to his son, admonishing him, 'O my son, do not associate others with God; to associate others with God is a mighty wrong.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxiii{%
(And We have charged man concerning his parents -- his mother bore him in weakness upon weakness, and his weaning was in two years -- 'Be thankful to Me, and to thy parents; to Me is the homecoming.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxiv{%
But if they strive with thee to make thee associate with Me that whereof thou hast no knowledge, then do not obey them. Keep them company honourable in this world; but follow the way of him who turns to Me. Then unto Me you shall return, and I shall tell you what you were doing.')\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxv{%
'O my son, if it should be but the weight of one grain of mustard-seed, and though it be in a rock, or in the heavens, or in the earth, God shall bring it forth; surely God is All-subtle, All-aware.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxvi{%
O my son, perform the prayer, and bid unto honour, and forbid dishonour. And bear patiently whatever may befall thee; surely that is true constancy.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxvii{%
Turn not thy cheek away from men in scorn, and walk not in the earth exultantly; God loves not any man proud and boastful.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxviii{%
Be modest in thy walk, and lower thy voice; the most hideous of voices is the ass's.'\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxix{%
Have you not seen how that God has subjected to you whatsoever is in the heavens and earth, and He has lavished on you His blessings, outward and inward? And among men there is such a one that disputes concerning God without knowledge or guidance, or an illuminating Book;\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcdxc{%
and when it is said to them, 'Follow what God has sent down,' they say, 'No; but we will follow such things as we found our fathers doing.' What? Even though Satan were calling them to the chastisement of the burning?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcdxci{%
And whosoever submits his will to God, being a good-doer, has laid hold of the most firm handle; and unto God is the issue of all affairs.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcdxcii{%
And whoso disbelieves, let not his disbelief grieve thee; unto Us they shall return, and We shall tell them what they did. Surely God knows all the thoughts within the breasts.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcdxciii{%
To them We give enjoyment a little, then We compel them to a harsh chastisement.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcdxciv{%
If thou askest them, 'Who created the heavens and the earth?' they will say, 'God.' Say: 'Praise belongs to God.' Nay, but most of them have no knowledge.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcdxcv{%
To God belongs all that is in the heavens and the earth; surely God -- He is the All-sufficient, the All-laudable.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcdxcvi{%
Though all the trees in the earth were pens, and the sea-seven seas after it to replenish it, yet would the Words of God not be spent. God is All-mighty, All-wise.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcdxcvii{%
Your creation and your upraising are as but as a single soul. God is All-hearing, All-seeing.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcdxcviii{%
Hast thou not seen how that God makes the night to enter into the day and makes the day to enter into the night. and He has subjected the sun and the moon, each of them running to a stated term, and that God is aware of what you do?\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcdxcix{%
That is because God -- He is the Truth, and that they call upon apart from Him -- that is the false; and for that God is the All-high, the All-great.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmd{%
Hast thou not seen how that the ships run upon the sea by the blessing of God, that He may show you some of His signs? Surely in that are signs for every man enduring, thankful.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdi{%
And when the waves cover them like shadows they call upon God, making their religion sincerely His; but when He has delivered them to the land, some of them are lukewarm. And none denies Our signs, except every ungrateful traitor.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdii{%
O men, fear your Lord, and dread a day when no father shall give satisfaction for his child, and no child shall give satisfaction for his father whatever. Surely God's promise is true; so let not the present life delude you, and let not the Deluder delude you concerning God.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdiii{%
Surely God -- He has knowledge of the Hour; He sends down the rain; He knows what is in the wombs. No soul knows what it shall earn tomorrow, and no soul knows in what land it shall die. Surely God is All-knowing, All-aware.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdiv{%
\basmalahen Alif Lam Mim\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdv{%
The sending down of the Book, wherein no doubt is, from the Lord of all Being.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdvi{%
Or do they say, 'He has forged it'? Say: 'Not so; it is the truth from thy Lord that thou mayest warn a people to whom no warner came before thee, that haply so they may be guided.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdvii{%
God is He that created the heavens and the earth, and what between them is, in six days, then seated Himself upon the Throne. Apart from Him, you have no protector neither mediator; will you not remember?\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdviii{%
He directs the affair from heaven to earth, then it goes up to Him in one day, whose measure is a thousand years of your counting.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdix{%
He is the knower of the Unseen and the Visible, the All-mighty, the All-compassionate,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdx{%
who has created all things well. And He originated the creation of man out of clay,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdxi{%
then He fashioned his progeny of an extraction of mean water,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdxii{%
then He shaped him, and breathed His spirit in him. And He appointed for you hearing, and sight, and hearts; little thanks you show.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdxiii{%
They say, 'What, when we have gone astray in the earth, shall we indeed be in a new creation?' Nay, but they disbelieve in the encounter with their Lord.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdxiv{%
Say: 'Death's angel, who has been charged with you, shall gather you, then to your Lord you shall be returned.'\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdxv{%
Ah, if thou couldst see the guilty hanging their heads before their Lord! 'Our Lord, we have seen and heard; now return us, that we may do righteousness, for we have sure faith.'\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdxvi{%
'If We had so willed, We could have given every soul its guidance; but now My Word is realized -- `` Assuredly I shall fill Gehenna with jinn and men all together."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdxvii{%
So now taste, for that you forgot the encounter of this your day! We indeed have forgotten you. Taste the chastisement of eternity for that you were doing!'\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdxviii{%
Only those believe in Our signs who, when they are reminded of them, fall down prostrate and proclaim the praise of their Lord, not waxing proud.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdxix{%
Their sides shun their couches as they call on their Lord in fear and hope; and they expend of that We have provided them.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdxx{%
No soul knows what comfort is laid up for them secretly, as a recompense for that they were doing.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdxxi{%
What? Is he who has been a believer like unto him who has been ungodly? They are not equal.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdxxii{%
As for those who believe, and do deeds of righteousness, there await them the Gardens of the Refuge, in hospitality for that they were doing.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdxxiii{%
But as for the ungodly, their refuge shall be the Fire; as often as they desire to come forth from it, they shall be restored into it, and it shall be said to them, 'Taste the chastisement of the Fire, which you cried lies to.'\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdxxiv{%
And We shall surely let them taste the nearer chastisement, before the greater; haply so they will return.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdxxv{%
And who does greater evil than he who is reminded of the signs of his Lord, then turns away from them? We shall take vengeance upon the sinners.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdxxvi{%
Indeed, We gave Moses the Book; so he not in doubt concerning the encounter with him; and We appointed it for a guidance to the Children of Israel.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdxxvii{%
And We appointed from among them leaders guiding by Our command, when they endured patiently, and had sure faith in Our signs.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdxxviii{%
Surely thy Lord will distinguish between them on the Resurrection Day, touching that whereon they were at variance.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdxxix{%
Is it not a guidance to them, how many generations We destroyed before them in whose dwelling-places they walk? Surely in that are signs; what, will they not hear?\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdxxx{%
Have they not seen how We drive the water to the dry land and bring forth crops therewith whereof their cattle and themselves eat? What, will they not see?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdxxxi{%
They also say, 'When shall be this Victory, if you speak truly?'\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdxxxii{%
Say: 'On the Day of Victory their faith shall not profit the unbelievers, nor shall they be respited.'\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdxxxiii{%
So turn thou away from them, and wait; they too are waiting.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdxxxiv{%
\basmalahen O Prophet, fear God, and obey not the unbelievers and the hypocrites. God is All-knowing, All-wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdxxxv{%
And follow what is revealed to thee from thy Lord; surely God is aware of the things you do.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdxxxvi{%
And put thy trust in God; God suffices as a guardian.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdxxxvii{%
God has not assigned to any man two hearts within his breast; nor has He made your wives, when you divorce, saying, 'Be as my mother's back,' truly your mothers, neither has He made your adopted sons your sons in fact. That is your own saying, the words of your mouths; but God speaks the truth, and guides on the way.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdxxxviii{%
Call them after their true fathers; that is more equitable in the sight of God. If you know not who their fathers were, then they are your brothers in religion, and your clients. There is no fault in you if you make mistakes, but only in what your hearts premeditate. God is All-forgiving, All-compassionate.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdxxxix{%
The Prophet is nearer to the believers than their selves; his wives are their mothers. Those who are bound by blood are nearer to one another in the Book of God than the believers and the emigrants; nevertheless you should act towards your friends honourably; that stands inscribed in the Book.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdxl{%
And when We took compact from the Prophets, and from thee, and from Noah, and Abraham, Moses, and Jesus, Mary's son; We took from them a solemn compact,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdxli{%
that He might question the truthful concerning their truthfulness; and He has prepared for the unbelievers a painful chastisement.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdxlii{%
O believers, remember God's blessing upon you when hosts came against you, and We loosed against them a wind, and hosts you saw not; and God sees the things you do.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdxliii{%
When they came against you from above you and from below you, and when your eyes swerved and your hearts reached your throats, while you thought thoughts about God;\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdxliv{%
there it was that the believers were tried, and shaken most mightily.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdxlv{%
And when tile hypocrites, and those in whose hearts is sickness, said, 'God and His Messenger promised us only delusion.'\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdxlvi{%
And when a party of them said, 'O people of Yathrib, there is no abiding here for you, therefore return!' And a part of them Were asking leave of the Prophet, saying, 'Our houses are exposed'; yet they were not exposed; they desired only to flee.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdxlvii{%
And if entrance had been forced against them from those quarters, and then they had been asked to apostatise, they would have done so, and but tarried about it briefly.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdxlviii{%
Yet they had made covenant with God before that, that they would not turn their backs; and covenants with God shall be questioned of\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdxlix{%
Say: 'Flight will not profit you, if you flee from death or slaying; you will be given enjoyment of days then but little.'\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdl{%
Say: 'Who is he that shall defend you from God, if lie desires evil for you, or desires mercy for you?' They shall find for themselves, apart from God, neither protector nor helper.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdli{%
God would surely know those of you who hinder, and those who say to their brothers, 'Come to us,' and come to battle but little,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdlii{%
being niggardly towards you. When fear comes upon them, thou seest them looking at thee, their eyes rolling like one who swoons of death; but when the fear departs, they flay you with sharp tongues, being niggardly to possess the good things. Those have never believed; God has made their works to fail; and that is easy for God.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdliii{%
They think the Confederates have not departed; and if the Confederates come, they will wish that they were desert-dwellers among the Bedoums asking for news of you. If they were among you, they would fight but little.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdliv{%
You have had a good example in God's Messenger for whosoever hopes for God and the Last Day, and remembers God oft.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdlv{%
When the believers saw the Confederates they said, 'This is what God and His Messenger promised us, and God and His Messenger have spoken truly.' And it only increased them in faith and surrender.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdlvi{%
Among the believers are men who were true to their covenant with God; some of them have fulfilled their vow by death, and some are still awaiting, and they have not changed in the least;\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdlvii{%
that God may recompense the truthful ones for their truthfulness, and chastise the hypocrites, if He will, or turn again unto them. Surely God is All-forgiving, All-compassionate.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdlviii{%
And God sent back those that were unbelievers in their rage, and they attained no good; God spared the believers of fighting. Surely God is All-strong, All-mighty.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdlix{%
And He brought down those of the People of the Book who supported them from their fortresses and cast terror in their hearts; some you slew, some you made captive.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdlx{%
And He bequeathed upon you their lands, their habitations, and their possessions, and a land you never trod. God is powerful over everything.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdlxi{%
O Prophet, say to thy wives: 'If you desire the present life and its adornment, come now, I will make you provision, and set you free with kindliness.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdlxii{%
But if you desire God and His Messenger and the Last Abode, surely God has prepared for those amongst you such as do good a mighty wage.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdlxiii{%
Wives of the Prophet, whosoever among you commits a flagrant indecency, for her the chastisement shall be doubled; that is easy for God.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdlxiv{%
But whosoever of you is obedient to God and His Messenger, and does righteousness, We shall pay her her wage twice over; We have prepared for her a generous provision.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdlxv{%
Wives of the Prophet, you are not as other women. If you are godfearing, be not abject in your speech, so that he in whose heart is sickness may be lustful; but speak honourable words.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdlxvi{%
Remain in your houses; and display not your finery, as did the pagans of old. And perform the prayer, and pay the alms, and obey God and His Messenger. People of the House, God only desires to put away from you abomination and to cleanse you.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdlxvii{%
And remember that which is recited in your houses of the signs of God and the Wisdom; God is All-subtle, All-aware.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdlxviii{%
Men and women who have surrendered, believing men and believing women, obedient men and obedient women, truthful men and truthful women, enduring men and enduring women, humble men and humble women, men and women who give in charity, men who fast and women who fast, men and women who guard their private parts, men and women who remember God oft -- for them God has prepared forgiveness and a mighty wage.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdlxix{%
It is not for any believer, man or woman, when God and His Messenger have decreed a matter, to have the choice in the affair. Whosoever disobeys God and His Messenger has gone astray into manifest error.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdlxx{%
When thou saidst to him whom God had blessed and thou hadst favoured, 'Keep thy wife to thyself, and fear God,' and thou wast concealing within thyself what God should reveal, fearing other men; and God has better right for thee to fear Him. So when Zaid had accomplished what he would of her, then We gave her in marriage to thee, so that there should not be any fault in the believers, touching the wives of their adopted sons, when they have accomplished what they would of them; and God's commandment must be performed.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdlxxi{%
There is no fault in the Prophet, touching what God has ordained for him -- God's wont with those who passed away before; and God's commandment is doom decreed;\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdlxxii{%
who were delivering the Messages of God, and were fearing Him, and fearing not any one except Him; and God suffices as a reckoner.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdlxxiii{%
Muhammad is not the father of any one of your men, but the Messenger of God, and the Seal of the Prophets; God has knowledge of everything.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdlxxiv{%
O believers, remember God oft,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdlxxv{%
and give Him glory at the dawn and in the evening.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdlxxvi{%
It is He who blesses you, and His angels, to bring you forth from the shadows into the light. He is All-compassionate to the believers.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdlxxvii{%
Their greeting, on the day when they shall meet Him, will be 'Peace!' And He has prepared for them a generous wage.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdlxxviii{%
O Prophet, We have sent thee as a witness, and good tidings to bear and warning,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdlxxix{%
calling unto God by His leave, and as a light-giving lamp.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdlxxx{%
Give good tidings to the believers that there awaits them with God great bounty.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdlxxxi{%
And obey not the unbelievers and the hypocrites; heed not their hurt, but put thy trust in God; God suffices as a guardian.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdlxxxii{%
O believers, when you marry believing women and then divorce them before you touch them, you have no period to reckon against them; so make provision for them, and set them free with kindliness.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdlxxxiii{%
O Prophet, We have made lawful for thee thy wives whom thou hast given their wages and what thy right hand owns, spoils of war that God has given thee, and the daughters of thy uncles paternal and aunts paternal, thy uncles maternal and aunts maternal, who have emigrated with thee, and any woman believer, if she give herself to the Prophet and if the Prophet desire to take her in marriage, for thee exclusively, apart from the believers -- We know what We have imposed upon them touching their wives and what their right hands own -- that there may be no fault in thee; God is All-forgiving, All-compassionate.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdlxxxiv{%
Thou mayest put off whom thou wilt of them, and whom thou wilt thou mayest take to thee; and if thou seekest any thou hast set aside there is no fault in thee. So it is likelier they will be comforted, and not sorrow, and every one of them will be well-pleased with what thou givest her. God knows what is in your hearts; God is All-knowing, All-clement.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdlxxxv{%
Thereafter women are not lawful to thee, neither for thee to take other wives in exchange for them, though their beauty please thee, except what thy right hand owns; God is watchful over everything.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdlxxxvi{%
O believers, enter not the houses of the Prophet, except leave is given you for a meal, without watching for its hour. But when you are invited, then enter; and when you have had the meal, disperse, neither lingering for idle talk; that is hurtful to the Prophet, and he is ashamed before you; but God is not ashamed before the truth. And when you ask his wives for any object, ask them from behind a curtain; that is cleaner for your hearts and theirs. It is not for you to hurt God's Messenger, neither to marry his wives after him, ever; surely that would be, in God's sight, a monstrous thing.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdlxxxvii{%
Whether you reveal anything, or whether you conceal it, surely God has knowledge of everything.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdlxxxviii{%
There is no fault in the Prophet's wives touching their fathers, their sons, their brothers, their brothers' sons, their sisters' sons, their women, and what their right hands own. And fear you God; surely God is witness of everything.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdlxxxix{%
God and His angels bless the Prophet. O believers, do you also bless him, and pray him peace.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdxc{%
Those who hurt God and His Messenger -- them God has cursed in the present world and the world to come, and has prepared for them a humbling chastisement.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdxci{%
And those who hurt believing men and believing women, without that they have earned it, have laid upon themselves calumny and manifest sin.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdxcii{%
O Prophet, say to thy wives and daughters and the believing women, that they draw their veils close to them; so it is likelier they will be known, and not hurt. God is All-forgiving, All-compassionate.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdxciii{%
Now; if the hypocrites do not give over, and those in whose hearts there is sickness and they that make commotion in the city, We shall assuredly urge thee against them and then they will be thy neighbours there only a little;\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdxciv{%
cursed they shalt be, and wheresoever they are come upon they shall be seized and slaughtered all --\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdxcv{%
God's wont with those who passed away before; and thou shall find no changing the wont of God.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdxcvi{%
The people will question thee concerning the Hour. Say: 'The knowledge of it is only with God; what shall make thee know? Haply the Hour is nigh.'\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdxcvii{%
God has cursed the unbelievers, and prepared for them a Blaze,\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdxcviii{%
therein to dwell for ever; they shall find neither protector nor helper.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdxcix{%
Upon the day when their faces are turned about in the Fire they shall say, 'Ah, would we had obeyed God and the Messenger!\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdc{%
They shall say, 'Our Lord, we obeyed our chiefs and great ones, and they led us astray from the way.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdci{%
Our Lord, give them chastisement twofold, and curse them with a mighty curse!'\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdcii{%
O believers, be not as those who hurt Moses, but God declared him quit of what they said, and he was high honoured with God.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdciii{%
O believers, fear God, and speak words hitting the mark,\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdciv{%
and He will set right your deeds for you and will forgive you your sins. Whosoever obeys God and His Messenger has won a mighty triumph.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdcv{%
We offered the trust to the heavens and the earth and the mountains, but they refused to carry it and were afraid of it; and man carried it. Surely he is sinful, very foolish.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdcvi{%
That God may chastise the hypocrites, men and women alike, and the idolaters, men and women alike; and that God may turn again unto the believers, men and women alike. God is All-forgiving, All-compassionate.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdcvii{%
\basmalahen Praise belongs to God to whom belongs whatsoever is in the heavens and whatsoever is in the earth. To Him belongs praise also in the Hereafter; He is the All-wise, the All-aware.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdcviii{%
He knows what penetrates into the earth, and what comes forth from it, what comes down from heaven, and what goes up to it; He is the All-compassionate, the All-forgiving.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdcix{%
The unbelievers say, 'The Hour will never come to us.' Say: 'Yes indeed, by my Lord, it shall come to you, by Him who knows the Unseen; not so much as the weight of an ant in heaven and earth escapes from Him, neither is aught smaller than that, or greater, but it is in a Manifest Book;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdcx{%
that He may recompense those who believe, and do righteous deeds; theirs shall be forgiveness and generous provision.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdcxi{%
'And those who strive against Our signs to void them -- theirs shall be a chastisement of painful wrath.'\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdcxii{%
Those who have been given the knowledge see that what has been sent down to thee from thy Lord is the truth, and guides to the path of the All-mighty, the All-laudable.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdcxiii{%
The unbelievers say, 'Shall we point you to a man who will tell you, when you have been utterly torn to pieces, then you shall be in a new creation?'\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdcxiv{%
What, has he forged against God a lie, or is he possessed? Not so; but those who believe not in the Hereafter are in chastisement and far error.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdcxv{%
Have they not regarded what lies before them and what lies behind them of heaven and earth? Did We will, We would make the earth to swallow them, or We would drop down on them lumps from heaven. Surely in that is a sign to every penitent servant.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdcxvi{%
And We gave David bounty from Us: 'O you mountains, echo God's praises with him, and you birds!' And We softened for him iron:\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdcxvii{%
'Fashion wide coats of mail, and measure well the links. ' -- And do ye righteousness, for surely I see the things you do.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdcxviii{%
And to Solomon the wind; its morning course was a month's journey, and its evening course was a month's journey. And We made the Fount of Molten Brass to flow for him. And of the jinn, some worked before him by the leave of his Lord; and such of them as swerved away from Our commandment, We would let them taste the chastisement of the Blaze;\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdcxix{%
fashioning for him whatsoever he would -- places of worship, statues, porringers like water-troughs, and anchored cooking-pots. 'Labour, O House of David, in thankfulness; for few indeed are those that are thankful among My servants.'\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdcxx{%
And when We decreed that he should die, naught indicated to them that he was dead but the Beast of the Earth devouring his staff; and when he fell down, the jinn saw clearly that, had they only known the Unseen, they would not have continued in the humbling chastisement.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdcxxi{%
For Sheba also there was a sign in their dwelling-place -- two gardens, one on the right and one on the left: 'Eat of your Lord's provision, and give thanks to Him; a good land, and a Lord All-forgiving.'\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdcxxii{%
But they turned away; so We loosed on them the Flood of Arim, and We gave them, in exchange for their two gardens, two gardens bearing bitter produce and tamarisk-bushes, and here and there a few lote-trees.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdcxxiii{%
Thus We recompensed them for their unbelief; and do 'We ever recompense any hut the unbeliever?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdcxxiv{%
And We set, between them and the cities that We have blessed, cities apparent and well We measured the journey between them: 'Journey among them by night and day in security!'\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdcxxv{%
But they said, 'Our Lord, prolong the stages of our travel'; and they wronged themselves, so We made them as but tales, and We tore them utterly to pieces. Surely in that are signs for every man enduring, thankful.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdcxxvi{%
Iblis proved true his opinion of them, and they followed him, except a party of the believers.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdcxxvii{%
Yet he had no authority over them, but that We might know him who believed in the Hereafter from him who was in doubt thereof Thy Lord is Guardian over everything.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdcxxviii{%
Say: 'Call on those you have asserted apart from God; they possess not so much as the weight of an ant in the heavens nor in the earth; they have no partnership in either of them, nor has He in them any supporter.'\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdcxxix{%
Intercession will not avail with Him save for him to whom He gives leave; till, when terror is lifted from their hearts, they will say, ``What said your Lord?' They will say, 'The truth; and He is the All-high; the All-great.'\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdcxxx{%
Say: 'Who provides for you out of the heavens and the earth?' Say: 'God.' Surely, either we or you are upon right guidance, or in manifest error.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdcxxxi{%
Say: 'You will not be questioned concerning our sins, neither shall we be questioned as to what you do.'\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdcxxxii{%
Say: 'Our Lord will bring us together, then make deliverance between us by the truth. He is the Deliverer, the All-knowing.'\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdcxxxiii{%
Say: 'Show me those you have joined to Him as associates. No indeed; rather He is God, the All-mighty, the All-wise.'\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdcxxxiv{%
We have sent thee not, except to mankind entire, good tidings to bear, and warning; but most men do not know it.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdcxxxv{%
They say, 'When shall this promise come to pass, if you speak the truth?'\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcxxxvi{%
Say: 'You have the tryst of a day that you shall not put back by a single hour nor put it forward.'\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcxxxvii{%
The unbelievers say, 'We will not believe in this Koran, nor in that before it.' Ah, if thou couldst see when the evildoers are stationed before their Lord, bandying argument the one against the other! Those that were abased will say to those that waxed proud, 'Had it not been for you, we would have been believers.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcxxxviii{%
Those that waxed proud will say to those that were abased, 'What, did we bar you from the guidance after it came to you? Nay, rather you were sinners.'\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcxxxix{%
And those that were abased will say to those that waxed proud, 'Nay, but devising night and day, when you were ordering us to disbelieve in God, and to set up compeers to Him.' They will be secretly remorseful when they see the chastisement and We put fetters on the necks of the unbelievers; shall they be recompensed except for what they were doing?\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcxl{%
We sent no warner into any city except its men who lived at ease said, 'We disbelieve in the Message you have been sent with.'\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcxli{%
They also said, 'We are more abundant in wealth and children, and we shall not be chastised.'\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcxlii{%
Say: 'My Lord outspreads and straitens His provision to whomsoever He will, but most men do not know it.'\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcxliii{%
It is not your wealth nor your children that shall bring you nigh in nearness to Us, except for him who believes, and does righteousness; those -- there awaits them the double recompense for that they did, and they shall be in the lofty chambers in security.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcxliv{%
And those who strive against Our signs to void them -- those shall be arraigned into the chastisement.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcxlv{%
Say: 'My Lord outspreads and straitens His provision to whomsoever He will of His servants; and whatever thing you shall expend, He will replace it. He is the best of providers.'\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcxlvi{%
Upon the day when He shall muster them all together, then He shall say to the angels, 'Was it you these were serving?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcxlvii{%
They shall say, 'Glory be to Thee'! Thou art our Protector, apart from them; nay rather, they were serving the jinn; most of them believed in them.'\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdcxlviii{%
'Therefore today none of you shall have power to profit or hurt another.' And We shall say to the evildoers, 'Taste the chastisement of the Fire, which you cried lies to!'\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcxlix{%
And when Our signs are recited to them, clear signs, they say, 'This is naught but a man who desires to bar you from that your fathers served'; and they say, 'This is nothing but a forged calumny.' And the unbelievers say to the truth, when it has come to them, 'This is nothing but manifest sorcery.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcl{%
We have not given them any Books to study, nor have We sent them before thee any warner.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdcli{%
Those that were before them also cried lies, yet they reached not a tenth of what We gave them; they cried lies to My Messengers, and how was My horror!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdclii{%
Say: 'I give you but one admonition, that you stand unto God, two by two and one by one, and then reflect: no madness is in your comrade. He is naught but a warner unto you, before a terrible chastisement.'\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcliii{%
Say: 'I have asked no wage of you; that shall be yours. My wage falls only upon God; and He is witness over everything.'\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdcliv{%
Say: 'My Lord hurls the truth -- the Knower of the Unseen.'\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdclv{%
Say. 'Truth has come; falsehood originates not, nor brings again.'\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdclvi{%
Say: 'If I go astray, I go astray only to my own loss; if I am guided, it is by what my Lord reveals to me. He is All-hearing, Ever-nigh.'\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdclvii{%
Ah, if thou couldst see when they are terrified, and there is no escape, and they are seized from a place near at hand,\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdclviii{%
and they say, 'We believe in it'; but how can they reach from a place far away,\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdclix{%
seeing they disbelieved in it before, guessing at the Unseen from a place far away?\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdclx{%
And a barrier is set between them and that they desire, as was done with the likes of them aforetime; they were in doubt disquieting.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdclxi{%
\basmalahen Praise belongs to God, Originator of the heavens and earth, who appointed the angels to be messengers having wings two, three and four, increasing creation as He wills. Surely God is powerful over everything.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdclxii{%
Whatsoever mercy God opens to men, none can withhold and whatsoever He withholds, none can loose after Him. He is the All-mighty, the All-wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdclxiii{%
O men, remember God's blessing upon you; is there any creator, apart from God, who provides for you out of heaven and earth? There is no god but He: how then are you perverted?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdclxiv{%
If they cry lies to thee, Messengers before thee were cried lies to; and unto God all matters are returned.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdclxv{%
O men, God's promise is true; so let not the present life delude you, and let not the Deluder delude you concerning God.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdclxvi{%
Surely Satan is an enemy to you; so take him for an enemy. He calls his party only that they may be among the inhabitants of the Blaze.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdclxvii{%
Those who disbelieve -- there awaits them a terrible chastisement; but those who believe, and do deeds of righteousness -- theirs shall be forgiveness and a great wage.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdclxviii{%
And what of him, the evil of whose deeds has been decked out fair to him, so that he thinks it is good? God leads astray whomsoever He will, and whomsoever He will He guides; so let not thy soul be wasted in regrets for them; God has knowledge of the things they work.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdclxix{%
God is He that looses the winds, that stir up cloud, then We drive it to a dead land and therewith revive the earth, after it is dead. Even so is the Uprising.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdclxx{%
Whosoever desires glory, the glory altogether belongs to God. To Him good words go up, and the righteous deed -- He uplifts it; but those who devise evil deeds -- theirs shall be a terrible chastisement, and their devising shall come to naught.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdclxxi{%
God created you of dust then of a sperm-drop, then He made you pairs. No female bears or brings forth, save with His knowledge; and none is given long life who is given long life neither is any diminished in his life, but it is in a Book. Surely that is easy for God.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdclxxii{%
Not equal are the two seas; this is sweet, grateful to taste, delicious to drink, and that is salt, bitter to the tongue. Yet of both you eat fresh flesh, and bring forth out of it ornaments for you to wear; and thou mayest see the ships cleaving through it, that you may seek of His bounty, and so haply you will be thankful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdclxxiii{%
He makes the night to enter into the day and makes the day to enter into the night, and He has subjected the sun and the moon, each of them running to a stated term. That is God, your Lord; to Him belongs the Kingdom; and those you call upon, apart from Him, possess not so much as the skin of a date-stone.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdclxxiv{%
If you call upon them, they will not hear your prayer, and if they heard, they would not answer you; and on the Day of Resurrection they will disown your partnership. None can tell thee like One who is aware.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdclxxv{%
O men, you are the ones that have need of God; He is the All-sufficient, the All-laudable.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdclxxvi{%
If He will, He can put you away and bring a new creation;\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdclxxvii{%
that is surely no great matter for God.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdclxxviii{%
No soul laden bears the load of another; and if one heavy-burdened calls for its load to be carried, not a thing of it will be carried, though he be a near kinsman. Thou warnest only those who fear their Lord in the Unseen and perform the prayer; and whosoever purifies himself, purifies himself only for his own soul's good. To God is the homecoming.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdclxxix{%
Not equal are the blind and the seeing man,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdclxxx{%
the shadows and the light,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdclxxxi{%
the shade and the torrid heat;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdclxxxii{%
not equal are the living and the dead. God makes to hear whomsoever He will; thou canst not make those in their tombs to hear -\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdclxxxiii{%
thou art naught but a warner.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdclxxxiv{%
Surely We have sent thee with the truth good tidings to bear, and warning; not a nation there is, but there has passed away in it a warner.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdclxxxv{%
If they cry thee lies, those before them also cried lies; their Messengers came to them with the clear signs, the Psalms, the Illuminating Book;\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdclxxxvi{%
then I seized the unbelievers, and how was My horror!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdclxxxvii{%
Hast thou not seen how that God sends down out of heaven water, and therewith We bring forth fruits of diverse hues? And in the mountains are streaks white and red, of diverse hues, and pitchy black;\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdclxxxviii{%
men too, and beasts and cattle -- diverse are their hues. Even so only those of His servants fear God who have knowledge; surely God is All-mighty, All-forgiving.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdclxxxix{%
Surely those who recite the Book of God and perform the prayer, and expend of that We have provided them, secretly and in public, look for a commerce that comes not to naught,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcxc{%
that He may pay them in full their wages and enrich them of His bounty; surely He is All-forgiving, All-thankful.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcxci{%
And that We have revealed to thee of the Book is the truth, confirming what is before it; God is aware of and sees His servants.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcxcii{%
Then We bequeathed the Book on those of Our servants We chose; but of them some wrong themselves, some of them are lukewarm, and some are outstrippers in good works by the leave of God; that is the great bounty.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcxciii{%
Gardens of Eden they shall enter; therein they shall be adorned with bracelets of gold and with pearls, and their apparel there shall be of silk.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcxciv{%
And they shall say, 'Praise belongs to God who has put away all sorrow from us. Surely our Lord is All-forgiving, All-thankful,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcxcv{%
who of His bounty has made us to dwell in the abode of everlasting life wherein no weariness assails us neither fatigue.'\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcxcvi{%
As for the unbelievers, theirs shall be the fire of Gehenna; they shall neither be done with and die, nor shall its chastisement be lightened for them. Even so We recompense every ungrateful one.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcxcvii{%
Therein they shall shout, 'Our Lord, bring us forth, and we will do righteousness, other than what we have done.' 'What, did We not give you long life, enough to remember in for him who would remember? To you the warner came; taste you now! The evildoers shall have no helper.'\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcxcviii{%
God knows the Unseen in the heavens and the earth; He knows the thoughts within the breasts.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcxcix{%
It is He who appointed you viceroys in the earth. So whosoever disbelieves, his unbelief shall be charged against him; their unbelief increases the disbelievers only in hate in God's sight; their unbelief increases the disbelievers only in loss.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcc{%
Say: 'Have you considered your associates on whom you call, apart from God? Show me what they have created in the earth; or have they a partnership in the heavens?' Or have We given them a Book, so that they are upon a clear sign from it? Nay, but the evildoers promise one another naught but delusion.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcci{%
God holds the heavens and the earth, lest they remove; did they remove, none would hold them after Him. Surely He is All-clement, All-forgiving.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdccii{%
They have sworn by God the most earnest oaths that if a warner came to them, they would be more rightly guided than any one of the nations; but when a warner came to them, it increased them only in aversion,\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcciii{%
waxing proud in the land, and devising evil; but evil devising encompasses only those who do it; So do they expect anything but the wont of the ancients? And thou shalt never find any changing the Wont of God, and thou shalt never find any altering the wont of God.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcciv{%
What, have they not journeyed in the land and beheld how was the end of those before them? They were stronger than themselves in might; but God -- there is naught in the heavens or the earth that can frustrate Him. Surely He is All-knowing, All-powerful.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdccv{%
If God should take men to task for what they have earned He would not leave upon the face of the earth one creature that crawls; but He is deferring them to a stated term. But when their term is come -- surely God sees His servants.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdccvi{%
\basmalahen Ya Sin\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdccvii{%
By the Wise Koran,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdccviii{%
thou art truly among the Envoys\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdccix{%
on a straight path;\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdccx{%
the sending down of the All-mighty, the All-wise,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdccxi{%
that thou mayest warn a people whose fathers were never warned, so they are heedless.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdccxii{%
The Word has been realised against most of them, yet they do not believe.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdccxiii{%
Surely We have put on their necks fetters up to the chin, so their heads are raised;\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdccxiv{%
and We have put before them a barrier and behind them a barrier; and We have covered them, so they do not see.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdccxv{%
Alike it is to them whether thou hast warned them or thou hast not warned them, they do not believe.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdccxvi{%
Thou only warnest him who follows the Remembrance and who fears the All-merciful in the Unseen; so give him the good tidings of forgiveness and a generous wage.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdccxvii{%
Surely it is We who bring the dead to life and write down what they have forwarded and what they have left behind; everything We have numbered in a clear register.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdccxviii{%
Strike for them a similitude -- the inhabitants of the city, when the Envoys came to it;\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdccxix{%
when We sent unto them two men, but they cried them lies, so We sent a third as reinforcement. They said, 'We are assuredly Envoys unto you.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdccxx{%
They said, 'You are naught but mortals like us; the All-merciful has not sent down anything. You are speaking only lies.'\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdccxxi{%
They said, 'Our Lord knows we are Envoys unto you;\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdccxxii{%
and it is only for us to deliver the Manifest Message.'\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdccxxiii{%
They said, 'We augur ill of you. If you give not over, we will stone you and there shall visit you from us a painful chastisement.'\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdccxxiv{%
They said, 'Your augury is with you; if you are reminded? But you are a prodigal people.'\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdccxxv{%
Then came a man from the furthest part of the city, running; he said, 'My people, follow the Envoys!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdccxxvi{%
Follow such as ask no wage of you, that are right-guided.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdccxxvii{%
And why should I not serve Him who originated me, and unto whom you shall be returned?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdccxxviii{%
What, shall I take, apart from Him, gods whose intercession, if the All-merciful desires affliction for me, shall not avail me anything, and who will never deliver me?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdccxxix{%
Surely in that case I should be in manifest error.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdccxxx{%
Behold, I believe in your Lord; therefore hear me!'\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdccxxxi{%
It was said, 'Enter Paradise!' He said, 'Ah, would that my people had knowledge\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdccxxxii{%
that my Lord has forgiven me and that He has placed me among the honoured.'\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdccxxxiii{%
And We sent not down upon his people, after him, any host out of heaven; neither would We send any down.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdccxxxiv{%
It was only one Cry and lo, they were silent and still.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdccxxxv{%
Ah, woe for those servants! Never comes unto them a Messenger, but they mock at him.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdccxxxvi{%
What, have they not seen how many generations We have destroyed before them, and that it is not unto them that they return?\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdccxxxvii{%
They shall every one of them be arraigned before Us.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdccxxxviii{%
And a sign for them is the dead land, that We quickened and brought forth from it grain, whereof they eat;\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdccxxxix{%
and We made therein gardens of palms and vines, and therein We caused fountains to gush forth,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdccxl{%
that they might eat of its fruits and their hands' labour. What, will they not be thankful?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdccxli{%
Glory be to Him, who created all the pairs of what the earth produces, and of themselves, and of what they know not.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdccxlii{%
And a sign for them is the night; We strip it of the day and lo, they are in darkness.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdccxliii{%
And the sun -- it runs to a fixed resting-place; that is the ordaining of the All-mighty, the All-knowing.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdccxliv{%
And the moon -- We have determined it by stations, till it returns like an aged palm-bough.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdccxlv{%
It behoves not the sun to overtake the moon, neither does the night outstrip the day, each swimming in a sky.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdccxlvi{%
And a sign for them is that We carried their seed in the laden ship,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdccxlvii{%
and We have created for them the like of it whereon they ride;\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdccxlviii{%
and if We will, We drown them, then none have they to cry to, neither are they delivered,\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdccxlix{%
save as a mercy from Us, and enjoyment for a while.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdccl{%
And when it is said to them, 'Fear what is before you and what is behind you; haply you will find mercy' --\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdccli{%
yet never any sign of the signs of their Lord comes to them, but they are turning away from it.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcclii{%
And when it is said to them, 'Expend of that God has provided you,' the unbelievers say to the believers, 'What, shall we feed such a one whom, if God willed, He would feed? You are only in manifest error!'\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdccliii{%
They also say, 'When shall this promise come to pass, if you speak truly?'\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdccliv{%
They are awaiting only for one Cry to seize them while they are yet disputing,\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdcclv{%
then they will not be able to make any testament, nor will they return to their people.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdcclvi{%
And the Trumpet shall be blown; then behold, they are sliding down from their tombs unto their Lord.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdcclvii{%
They say, 'Alas for us! Who roused us out of our sleeping place? This is what the All-merciful promised, and the Envoys spoke truly.'\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdcclviii{%
'It was only one Cry; then behold, they are all arraigned before Us.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdcclix{%
So today no soul shall be wronged anything, and you shall not be recompensed, except according to what you have been doing.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdcclx{%
See, the inhabitants of Paradise today are busy in their rejoicing,\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdcclxi{%
they and their spouses, reclining upon couches in the shade;\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdcclxii{%
therein they have fruits, and they have all that they call for.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdcclxiii{%
'Peace!' -- such is the greeting, from a Lord All-compassionate.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdcclxiv{%
'Now keep yourselves apart, you sinners, upon this day!\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdcclxv{%
Made I not covenant with you, Children of Adam, that you should not serve Satan -- surely he is a manifest foe to you --\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdcclxvi{%
and that you should serve Me? This is a straight path.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdcclxvii{%
He led astray many a throng of you; did you not understand?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdcclxviii{%
This is Gehenna, then, the same that you were promised;\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdcclxix{%
roast well in it today, for that you were unbelievers!'\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdcclxx{%
Today We set a seal on their mouths, and their hands speak to Us, and their feet bear witness as to what they have been earning.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdcclxxi{%
Did We will, We would have obliterated their eyes, then they would race to the path, but how would they see?\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdcclxxii{%
Did We will, We would have changed them where they were, then they could not go on, nor could they return.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdcclxxiii{%
And to whomsoever We give long life, We bend him over in His constitution; what, do they not understand?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdcclxxiv{%
We have not taught him poetry; it is not seemly for him. It is only a Remembrance and a Clear Koran,\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdcclxxv{%
that he may warn whosoever is living, and that the Word may be realized against the unbelievers.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdcclxxvi{%
Have they not seen how that We have created for them of that Our hands wrought cattle that they own?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdcclxxvii{%
We have subdued them to them, and some of them they ride, and some they eat;\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdcclxxviii{%
other uses also they have in them, and beverages. What, will they not be thankful?\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdcclxxix{%
Yet they have taken, apart from God, gods; haply they might be helped.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmdcclxxx{%
They cannot help them, though they be hosts made ready for them.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxi{%
So do not let their saying grieve thee; assuredly We know what they keep secret and what they publish.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxii{%
Has not man regarded how that We created him of a sperm-drop? Then lo, he is a manifest adversary.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxiii{%
And he has struck for Us a similitude and forgotten his creation; he says, 'Who shall quicken the bones when they are decayed?'\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxiv{%
Say: 'He shall quicken them, who originated them the first time; He knows all creation,\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxv{%
who has made for you out of the green tree fire and lo, from it you kindle.'\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxvi{%
Is not He, who created the heavens and earth, able to create the like of them? Yes indeed; He is the All-creator, the All-knowing.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxvii{%
His command, when He desires a thing, is to say to it 'Be,' and it is.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxviii{%
So glory be to Him, in whose hand is the dominion of everything, and unto whom you shall be returned.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxix{%
\basmalahen By the rangers ranging\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdccxc{%
and the scarers scaring\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdccxci{%
and the reciters of a Remembrance,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdccxcii{%
surely your God is One,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdccxciii{%
Lord of the heavens and the earth, and of what between them is Lord of the Easts.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdccxciv{%
We have adorned the lower heaven with the adornment of the stars\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdccxcv{%
and to preserve against every rebel Satan;\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdccxcvi{%
they listen not to the High Council, for they are pelted from every side,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdccxcvii{%
rejected, and theirs is an everlasting chastisement,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdccxcviii{%
except such as snatches a fragment, and he is pursued by a piercing flame.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdccxcix{%
So ask them for a pronouncement -- Are they stronger in constitution, or those We created? We created them of clinging clay.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdccc{%
Nay, thou marvellest; and they scoff\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdccci{%
and, when reminded, do not remember\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdcccii{%
and, when they see a sign, would scoff;\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdccciii{%
and they say, 'This is nothing but manifest sorcery.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdccciv{%
What, when we are dead and become dust and bones, shall we indeed be raised up?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdcccv{%
What, and our fathers, the ancients?'\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdcccvi{%
Say: 'Yes, and in all lowliness.'\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdcccvii{%
For it is only a single scaring, then behold, they are watching\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdcccviii{%
and they say, 'Woe, alas for us! This is the Day of Doom.'\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdcccix{%
'This is the Day of Decision, even that you cried lies to.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdcccx{%
Muster those who did evil, their wives, and that they were serving,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdcccxi{%
apart from God, and guide them unto the path of Hell!\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdcccxii{%
And halt them, to be questioned:\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdcccxiii{%
``Why help you not one another?"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdcccxiv{%
No indeed; but today they resign themselves in submission\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdcccxv{%
and advance one upon another, asking each other questions.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdcccxvi{%
These say, 'Why, you of old would come to us from the right hand.'\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdcccxvii{%
Those say, 'No; on the contrary, you were not believers;\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcccxviii{%
we had no authority over you; no, you were an insolent people.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcccxix{%
So our Lord's Word is realised against us; we are tasting it.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcccxx{%
Therefore we perverted you, and we ourselves were perverts.'\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcccxxi{%
So all of them on that day are sharers in the chastisement.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcccxxii{%
Even so We do with the sinners;\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcccxxiii{%
for when it was said to them, 'There is no god but God,' they were ever waxing proud,\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcccxxiv{%
saying, 'What, shall we forsake our gods for a poet possessed?'\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcccxxv{%
'No indeed; but he brought the truth, and confirmed the Envoys.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcccxxvi{%
Now certainly you shall be tasting the painful chastisement,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcccxxvii{%
and not be recompensed, except according to what you were doing.'\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcccxxviii{%
Except for God's sincere servants;\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcccxxix{%
for them awaits a known provision,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdcccxxx{%
fruits -- and they high-honoured\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxi{%
in the Gardens of Bliss\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxii{%
upon couches, set face to face,\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxiii{%
a cup from a spring being passed round to them,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxiv{%
white, a delight to the drinkers,\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxv{%
wherein no sickness is, neither intoxication;\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxvi{%
and with them wide-eyed maidens restraining their glances\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxvii{%
as if they were hidden pearls.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxviii{%
They advance one upon another, asking each other questions.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxix{%
One of them says, 'I had a comrade\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdcccxl{%
who would say, ``Are you a confirmer?\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdcccxli{%
What, when we are dead and become dust and bones, shall we indeed be requited?"\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdcccxlii{%
He says, 'Are you looking down?'\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdcccxliii{%
Then he looks, and sees him in the midst of Hell.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdcccxliv{%
He says, 'By God, wellnigh thou didst destroy me;\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdcccxlv{%
But for my Lord's blessing, I were one of the arraigned.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdcccxlvi{%
What, do we then not die\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdcccxlvii{%
except for our first death, and are we not chastised?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdcccxlviii{%
This is indeed the mighty triumph,\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdcccxlix{%
for the like of this let the workers work.'\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdcccl{%
Is that better as a hospitality, or the Tree of Ez-Zakkoum?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdcccli{%
We have appointed it as a trial for the evildoers.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdccclii{%
It is a tree that comes forth in the root of Hell;\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdcccliii{%
its spathes are as the heads of Satans,\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdcccliv{%
and they eat of it, and of it fill their bellies,\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdccclv{%
then on top of it they have a brew of boiling water,\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdccclvi{%
then their return is unto Hell.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdccclvii{%
They found their fathers erring,\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdccclviii{%
and they run in their footsteps.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdccclix{%
Before them erred most of the ancients,\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdccclx{%
and We sent among them warners;\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdccclxi{%
and behold, how was the end of them that were warned,\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdccclxii{%
except for God's sincere servants.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmdccclxiii{%
Noah called to Us; and how excellent were the Answerers!\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmdccclxiv{%
And We delivered him and his people from the great distress,\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmdccclxv{%
and We made his seed the survivors,\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmdccclxvi{%
and left for him among the later folk\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmdccclxvii{%
'Peace be upon Noah among all beings!'\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmdccclxviii{%
Even so We recompense the good-doers;\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmdccclxix{%
he was among Our believing servants.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmdccclxx{%
Then afterwards We drowned the rest.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmdccclxxi{%
Of his party was also Abraham;\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmdccclxxii{%
when he came unto his Lord with a pure heart,\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmdccclxxiii{%
when he said to his father and his folk, 'What do you serve?\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmdccclxxiv{%
Is it a calumny, gods apart from God, that you desire?\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmdccclxxv{%
What think you then of the Lord of all Being?'\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmdccclxxvi{%
And he cast a glance at the stars,\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmdccclxxvii{%
and he said, 'Surely I am sick.'\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmdccclxxviii{%
But they went away from him, turning their backs.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmdccclxxix{%
Then he turned to their gods, and said, 'What do you eat?\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmdccclxxx{%
What ails you, that you speak not?'\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxi{%
And he turned upon them smiting them with his right hand.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxii{%
Then came the others to him hastening.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxiii{%
He said, 'Do you serve what you hew,\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxiv{%
and God created you and what you make?'\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxv{%
They said, 'Build him a building, and cast him into the furnace!'\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxvi{%
They desired to outwit him; so We made them the lower ones.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxvii{%
He said, 'I am going to my Lord; He will guide me.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxviii{%
My Lord, give me one of the righteous.'\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxix{%
Then We gave him the good tidings of a prudent boy;\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmmdcccxc{%
and when he had reached the age of running with him, he said, 'My son, I see in a dream that I shall sacrifice thee; consider, what thinkest thou?' He said, 'My father, do as thou art bidden; thou shalt find me, God willing, one of the steadfast.'\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmmdcccxci{%
When they had surrendered, and he flung him upon his brow,\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmmdcccxcii{%
We called unto him, 'Abraham,\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmmdcccxciii{%
thou hast confirmed the vision; even so We recompense the good-doers.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmmdcccxciv{%
This is indeed the manifest trial.'\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmmdcccxcv{%
And We ransomed him with a mighty sacrifice,\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmmdcccxcvi{%
and left for him among the later folk\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmmdcccxcvii{%
'Peace be upon Abraham!'\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmmdcccxcviii{%
Even so We recompense the good-doers;\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmmdcccxcix{%
he was among Our believing servants.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmmcm{%
Then We gave him the good tidings of Isaac, a Prophet, one of the righteous.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmmcmi{%
And We blessed him, and Isaac; and of their seed some are good-doers, and some manifest self-wrongers.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmmcmii{%
We also favoured Moses and Aaron,\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmmcmiii{%
and We delivered them and their people from the great distress.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmmcmiv{%
And We helped them, so that they were the victors;\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmmcmv{%
and We gave them the Manifesting Book,\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmmcmvi{%
and guided them in the straight path,\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmmcmvii{%
and left for them among the later folk\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmmcmviii{%
'Peace be upon Moses and, Aaron!'\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmmcmix{%
Even so We recompense the good-doers;\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmmcmx{%
they were among Our believing servants.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmmcmxi{%
Elias too was one of the Envoys;\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmmcmxii{%
when he said to his people, 'Will you not be godfearing?\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmmcmxiii{%
Do you call on Baal, and abandon the Best of creators?\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmmcmxiv{%
God, your Lord, and the Lord of your fathers, the ancients?'\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmmcmxv{%
But they cried him lies; so they will be among the arraigned,\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmmcmxvi{%
except for God's sincere servants;\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmmcmxvii{%
and We left for him among the later folk\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmmcmxviii{%
'Peace be upon Elias!'\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmmcmxix{%
Even so We recompense the good-doers;\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmmcmxx{%
he was among Our believing servants.\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmmcmxxi{%
Lot too was one of the Envoys;\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmmcmxxii{%
when We delivered him and his people all together,\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmmcmxxiii{%
save an old woman among those that tarried;\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmmcmxxiv{%
then We destroyed the others,\qt@no{136}}%
\qt@newcmd\qurantrans@en@mmmcmxxv{%
and you pass by them in the morning\qt@no{137}}%
\qt@newcmd\qurantrans@en@mmmcmxxvi{%
and in the night; will you not understand?\qt@no{138}}%
\qt@newcmd\qurantrans@en@mmmcmxxvii{%
Jonah too was one of the Envoys;\qt@no{139}}%
\qt@newcmd\qurantrans@en@mmmcmxxviii{%
when he ran away to the laden ship\qt@no{140}}%
\qt@newcmd\qurantrans@en@mmmcmxxix{%
and cast lots, and was of the rebutted,\qt@no{141}}%
\qt@newcmd\qurantrans@en@mmmcmxxx{%
then the whale swallowed him down, and he blameworthy.\qt@no{142}}%
\qt@newcmd\qurantrans@en@mmmcmxxxi{%
Now had he not been of those that glorify God,\qt@no{143}}%
\qt@newcmd\qurantrans@en@mmmcmxxxii{%
he would have tarried in its belly until the day they shall be raised;\qt@no{144}}%
\qt@newcmd\qurantrans@en@mmmcmxxxiii{%
but We cast him upon the wilderness, and he was sick,\qt@no{145}}%
\qt@newcmd\qurantrans@en@mmmcmxxxiv{%
and We caused to grow over him a tree of gourds.\qt@no{146}}%
\qt@newcmd\qurantrans@en@mmmcmxxxv{%
Then We sent him unto a hundred thousand, or more,\qt@no{147}}%
\qt@newcmd\qurantrans@en@mmmcmxxxvi{%
and they believed; so We gave them enjoyment for a while.\qt@no{148}}%
\qt@newcmd\qurantrans@en@mmmcmxxxvii{%
So ask them for a pronouncement -- Has thy Lord daughters, and they sons?\qt@no{149}}%
\qt@newcmd\qurantrans@en@mmmcmxxxviii{%
Or did We create the angels females, while they were witnesses?\qt@no{150}}%
\qt@newcmd\qurantrans@en@mmmcmxxxix{%
Is it not of their own calumny that they say,\qt@no{151}}%
\qt@newcmd\qurantrans@en@mmmcmxl{%
'God has begotten?' They are truly liars.\qt@no{152}}%
\qt@newcmd\qurantrans@en@mmmcmxli{%
Has He chosen daughters above sons?\qt@no{153}}%
\qt@newcmd\qurantrans@en@mmmcmxlii{%
What ails you then, how you judge?\qt@no{154}}%
\qt@newcmd\qurantrans@en@mmmcmxliii{%
What, and will you not remember?\qt@no{155}}%
\qt@newcmd\qurantrans@en@mmmcmxliv{%
Or have you a clear authority?\qt@no{156}}%
\qt@newcmd\qurantrans@en@mmmcmxlv{%
Bring your Book, if you speak truly!\qt@no{157}}%
\qt@newcmd\qurantrans@en@mmmcmxlvi{%
They have set up a kinship between Him and the jinn; and the jinn know that they shall be arraigned.\qt@no{158}}%
\qt@newcmd\qurantrans@en@mmmcmxlvii{%
Glory be to God above that they describe,\qt@no{159}}%
\qt@newcmd\qurantrans@en@mmmcmxlviii{%
except for God's sincere servants.\qt@no{160}}%
\qt@newcmd\qurantrans@en@mmmcmxlix{%
But as for you, and that you serve,\qt@no{161}}%
\qt@newcmd\qurantrans@en@mmmcml{%
you shall not tempt any against Him\qt@no{162}}%
\qt@newcmd\qurantrans@en@mmmcmli{%
except him who shall roast in Hell.\qt@no{163}}%
\qt@newcmd\qurantrans@en@mmmcmlii{%
None of us is there, but has a known station;\qt@no{164}}%
\qt@newcmd\qurantrans@en@mmmcmliii{%
we are the rangers,\qt@no{165}}%
\qt@newcmd\qurantrans@en@mmmcmliv{%
we are they that give glory.\qt@no{166}}%
\qt@newcmd\qurantrans@en@mmmcmlv{%
What though they would say,\qt@no{167}}%
\qt@newcmd\qurantrans@en@mmmcmlvi{%
'If only we had had a Reminder from the ancients,\qt@no{168}}%
\qt@newcmd\qurantrans@en@mmmcmlvii{%
then were we God's sincere servants.'\qt@no{169}}%
\qt@newcmd\qurantrans@en@mmmcmlviii{%
But they disbelieved in it; soon they shall know!\qt@no{170}}%
\qt@newcmd\qurantrans@en@mmmcmlix{%
Already Our Word has preceded to Our servants, the Envoys;\qt@no{171}}%
\qt@newcmd\qurantrans@en@mmmcmlx{%
assuredly they shall be helped,\qt@no{172}}%
\qt@newcmd\qurantrans@en@mmmcmlxi{%
and Our host -- they are the victors.\qt@no{173}}%
\qt@newcmd\qurantrans@en@mmmcmlxii{%
So turn thou from them for a while,\qt@no{174}}%
\qt@newcmd\qurantrans@en@mmmcmlxiii{%
and see them; soon they shall see!\qt@no{175}}%
\qt@newcmd\qurantrans@en@mmmcmlxiv{%
What, do they seek to hasten Our chastisement?\qt@no{176}}%
\qt@newcmd\qurantrans@en@mmmcmlxv{%
When it lights in their courtyard, how evil will be the morning of them that are warned!\qt@no{177}}%
\qt@newcmd\qurantrans@en@mmmcmlxvi{%
So turn thou from them for a while,\qt@no{178}}%
\qt@newcmd\qurantrans@en@mmmcmlxvii{%
and see; soon they shall see!\qt@no{179}}%
\qt@newcmd\qurantrans@en@mmmcmlxviii{%
Glory be to thy Lord, the Lord of Glory, above that they describe!\qt@no{180}}%
\qt@newcmd\qurantrans@en@mmmcmlxix{%
And peace be upon the Envoys;\qt@no{181}}%
\qt@newcmd\qurantrans@en@mmmcmlxx{%
and praise belongs to God, the Lord of all Being.\qt@no{182}}%
\qt@newcmd\qurantrans@en@mmmcmlxxi{%
\basmalahen Sad. By the Koran, containing the Remembrance --\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcmlxxii{%
nay, but the unbelievers glory in their schism.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcmlxxiii{%
How many a generation We destroyed before them, and they called, but time was none to escape.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcmlxxiv{%
Now they marvel that a warner has come to them from among them; and the unbelievers say, 'This is a lying sorcerer.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcmlxxv{%
What, has he made the gods One God? This is indeed a marvellous thing.'\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcmlxxvi{%
And the Council of them depart, saying 'Go! Be steadfast to your gods; this is a thing to be desired.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcmlxxvii{%
We have not heard of this in the last religion; this is surely an invention.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcmlxxviii{%
What, has the Remembrance been sent down on him out of us all?' Nay, but they are in doubt of My Remembrance; nay, they have not yet tasted My chastisement.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcmlxxix{%
Or have they the treasuries of thy Lord's mercy, the All-mighty, the All-giving?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcmlxxx{%
Or is theirs the kingdom of the heavens and earth and of what between them is? Why, then let them ascend the cords!\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxi{%
A very host of parties is routed there!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxii{%
Cried lies before them the people of Noah, and Ad, and Pharaoh, he of the tent-pegs,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxiii{%
and Thamood, and the people of Lot, and the men of the Thicket - those were the parties;\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxiv{%
not one, that cried not lies to the Messengers, so My retribution was just.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxv{%
These are only awaiting for a single Cry, to which there is no delay.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxvi{%
They say, 'Our Lord, hasten to us our share before the Day of Reckoning.'\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxvii{%
Bear patiently what they say, and remember Our servant David, the man of might; he was a penitent.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxviii{%
With him We subjected the mountains to give glory at evening and sunrise,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxix{%
and the birds, duly mustered, every one to him reverting;\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcmxc{%
We strengthened his kingdom, and gave him wisdom and speech decisive.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcmxci{%
Has the tiding of the dispute come to thee? When they scaled the Sanctuary,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcmxcii{%
when they entered upon David, and he took fright at them; and they said, 'Fear not; two disputants we are -- one of us has injured the other; so judge between us justly, and transgress not, and guide us to the right path.'\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcmxciii{%
'Behold, this my brother has ninety-nine ewes, and I have one ewe. So he said, ``Give her into my charge"; and he overcame me in the argument.'\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcmxciv{%
Said he, 'Assuredly he has wronged thee in asking for thy ewe in addition to his sheep; and indeed many intermixers do injury one against the other, save those who believe, and do deeds of righteousness -- and how few they are!' And David thought that We had only tried him; therefore he sought forgiveness of his Lord, and he fell down, bowing, and he repented.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcmxcv{%
Accordingly We forgave him that, and he has a near place in Our presence and a fair resort.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcmxcvi{%
'David, behold, We have appointed thee a viceroy in the earth; therefore judge between men justly, and follow not caprice, lest it lead thee astray from the way of God. Surely those who go astray from the way of God -- there awaits them a terrible chastisement, for that they have forgotten the Day of Reckoning.'\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcmxcvii{%
We have not created the heavens and earth, and what between them is, for vanity; such is the thought of the unbelievers, wherefore woe unto the unbelievers because of the Fire!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcmxcviii{%
Or shall We make those who believe and do righteous deeds as the workers of corruption in the earth, or shall We make the godfearing as the transgressors?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcmxcix{%
A Book We have sent down to thee, Blessed, that men possessed of minds may ponder its signs and so remember.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmm{%
And We gave unto David Solomon; how excellent a servant he was! He was a penitent.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmi{%
When in the evening were presented to him the standing steeds,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmii{%
he said, 'Lo, I have loved the love of good things better than the remembrance of my Lord, until the sun was bidden behind the veil.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmiii{%
Return them to me!' And he began to stroke their shanks and necks.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmiv{%
Certainly We tried Solomon, and We cast upon his throne a mere body; then he repented.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmv{%
He said, 'My Lord, forgive me, and give me a kingdom such as may not befall anyone after me; surely Thou art the All-giver.'\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmvi{%
So We subjected to him the wind, that ran at his commandment, softly, wherever he might light on,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmvii{%
and the Satans, every builder and diver\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmviii{%
and others also, coupled in fetters:\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmix{%
'This is Our gift; bestow or withhold without reckoning.'\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmx{%
And he had a near place in Our presence and a fair resort.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmxi{%
Remember also Our servant Job; when he called to his Lord, 'Behold, Satan has visited me with weariness and chastisement.'\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmxii{%
'Stamp thy foot! This is a laving-place cool, and a drink.'\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmxiii{%
And We gave to him his family, and the like of them with them, as a mercy from us, and a reminder unto men possessed of minds;\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmxiv{%
and, 'Take in thy hand a bundle of rushes, and strike therewith, and do not fail in thy oath.' Surely We found him a steadfast man. How excellent a servant he was! He was a penitent.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmxv{%
Remember also Our servants Abraham, Isaac and Jacob -- men of might they and of vision.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmxvi{%
Assuredly We purified them with a quality most pure, the remembrance of the Abode,\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmxvii{%
and in Our sight they are of the chosen, the excellent.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmxviii{%
Remember also Our servants Ishmael, Elisha, and Dhul Kifl; each is among the excellent.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmxix{%
This is a Remembrance; and for the godfearing is a fair resort,\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmxx{%
Gardens of Eden, whereof the gates are open to them,\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmxxi{%
wherein they recline, and wherein they call for fruits abundant, and sweet potions,\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmxxii{%
and with them maidens restraining their glances of equal age.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmxxiii{%
'This is what you were promised for the Day of Reckoning;\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmxxiv{%
this is Our provision, unto which there is no end.'\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmxxv{%
All this; but for the insolent awaits an ill resort,\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmxxvi{%
Gehenna, wherein they are roasted - an evil cradling!\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmxxvii{%
All this; so let them taste it - boiling water and pus,\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmxxviii{%
and other torments of the like kind coupled together.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmxxix{%
'This is a troop rushing in with you; there is no Welcome for them; they shall roast in the Fire.'\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmxxx{%
They say, 'No, it is you have no Welcome; you forwarded it for us; how evil a stablishment!'\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmxxxi{%
They say, 'Our Lord, whoso forwarded this for us, give him a double chastisement in the Fire!'\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmxxxii{%
They say, 'How is it with us, that we do not see men here that we counted among the wicked?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmxxxiii{%
What, did we take them for a laughing-stock? Or have our eyes swerved away from them?'\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmxxxiv{%
Surely that is true -- the disputing of the inhabitants of the Fire.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmxxxv{%
Say: 'I am only a warner. There is not any god but God, the One, the Omnipotent,\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmxxxvi{%
Lord of the heavens and earth, and of what between them is, the All-mighty, the All-forgiving.'\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmxxxvii{%
Say: 'It is a mighty tiding\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmxxxviii{%
from which you are turning away.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmxxxix{%
I had no knowledge of the High Council when they disputed.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmxl{%
This alone is revealed to me, that I am only a clear warner.'\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmxli{%
When thy Lord said to the angels, 'See, I am creating a mortal of a clay.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmxlii{%
When I have shaped him, and breathed My spirit in him, fall you down, bowing before him!'\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmxliii{%
Then the angels bowed themselves all together,\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmxliv{%
save Iblis; he waxed proud, and was one of the unbelievers.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmxlv{%
Said He, 'Iblis, what prevented thee to bow thyself before that I created with My own hands? Hast thou waxed proud, or art thou of the lofty ones?'\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmxlvi{%
Said he, 'I am better than he; Thou createdst me of fire, and him Thou createdst of clay.'\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmxlvii{%
Said He, 'Then go thou forth hence; thou art accursed.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmxlviii{%
Upon thee shall rest My curse, till the Day of Doom.'\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmxlix{%
Said he, 'My Lord, respite me till the day they shall be raised.'\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmml{%
Said He, 'Thou art among the ones that are respited\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmli{%
until the day of the known time.'\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmlii{%
Said he, 'Now, by Thy glory, I shall pervert them all together,\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmliii{%
excepting those Thy servants among them that are sincere.'\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmliv{%
Said He, 'This is the truth, and the truth I say;\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmlv{%
I shall assuredly fill Gehenna with thee, and with whosoever of them follows thee, all together.'\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmlvi{%
Say: 'I ask of you no wage for it, neither am I of those who take things upon themselves.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmlvii{%
It is nothing but a reminder unto all beings,\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmlviii{%
and you shall surely know its tiding after a while.'\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmlix{%
\basmalahen The sending down of the Book is from God the All-mighty, the All-wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmlx{%
We have sent down to thee the Book with the truth; so worship God, making thy religion His sincerely.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmlxi{%
Belongs not sincere religion to God? And those who take protectors, apart from Him -- 'We only serve them that they may bring us nigh in nearness to God' -- surely God shall judge between them touching that whereon they are at variance. Surely God guides not him who is a liar, unthankful.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmlxii{%
Had God desired to take to Him a son, He would have chosen whatever He willed of that He has created. Glory be to Him! He is God, the One, the Omnipotent.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmlxiii{%
He created the heavens and the earth in truth, wrapping night about the day, and wrapping the day about the night; and He has subjected the sun and the moon, each of them running to a stated term. Is not He the All-mighty, the All-forgiving?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmlxiv{%
He created you of a single soul, then from it He appointed its mate; and He sent down to you of the cattle eight couples. He creates you in your mothers' wombs creation after creation in threefold shadows. That then is God, your Lord; to Him belongs the Kingdom; there is no god but He; so how are you turned about?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmlxv{%
If you are unthankful, God is independent of you, yet He approves not unthankfulness in His servants; but if you are thankful, He will approve it in you. And no soul laden bears the load of another. Then to your Lord shall you return, and He will tell you what you have been doing. He knows the thoughts within the breasts.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmlxvi{%
When some affliction visits a man, he calls upon his Lord, turning to him; then when He confers on him a blessing from Him he forgets that he was calling to before and sets up compeers to God, to lead astray from His way. Say: 'Enjoy thy unbelief a little; thou shalt be among the inhabitants of the Fire.'\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmlxvii{%
Or is he who is obedient in the watches of the night, bowing himself and standing, he being afraid of the world to come and hoping for the mercy of his Lord..? Say: 'Are they equal -- those who know and those who know not?' Only men possessed of minds remember.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmlxviii{%
Say: 'My servants who believe, fear your Lord. For those who do good in this world good, and God's earth is wide. Surely the patient will be paid their wages in full without reckoning.'\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmlxix{%
Say: 'I have been commanded to serve God making my religion His sincerely;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmlxx{%
and I have been commanded to be the first of those that surrender.'\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmlxxi{%
Say: 'Truly I fear, if I should rebel against my Lord, the chastisement of a dreadful day.'\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmlxxii{%
Say: 'God I serve, making my religion His sincerely;\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmlxxiii{%
so serve what you will apart from Him.' Say: 'Surely the losers are they who lose themselves and their families on the Day of Resurrection; is not that the manifest loss?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmlxxiv{%
Above them they shall have overshadowings. of the Fire, and underneath them overshadowings; that it is wherewith God frightens His servants: ``O My servants, so fear you Me!"'\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmlxxv{%
Those who eschew the serving of idols and turn penitent to God, for them is good tidings! So give thou good tidings to My servants\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmlxxvi{%
who give ear to the Word and follow the fairest of it. Those are they whom God has guided; those -- they are men possessed of minds.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmlxxvii{%
He against whom the word of chastisement is realized -- shalt thou deliver him out of the Fire?\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmlxxviii{%
But those who fear their Lord -- for them await lofty chambers, above which are built lofty chambers, underneath which rivers flow -- God's promise; God fails not the tryst.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmlxxix{%
Hast thou not seen how that God has sent down out of heaven water and threaded it as springs in the earth, then He brings forth therewith crops of diverse hues, then they wither, and thou seest them turning yellow, then He makes them broken orts? Surely in that is a reminder for men possessed of minds.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmlxxx{%
Is he whose breast God has expanded unto Islam, so he walks in a light from his Lord...? But woe to those whose hearts are hardened against the remembrance of God! Those are in manifest error.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmlxxxi{%
God has sent down the fairest discourse as a Book, consimilar in its oft-repeated, whereat shiver the skins of those who fear their Lord; then their skins and their hearts soften to the remembrance of God. That is God's guidance, whereby. He guides whomsoever He will; and whomsoever God leads astray, no guide has he.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmlxxxii{%
Is he who guards himself with his face against the evil of the chastisement on the Day of Resurrection...? And it is said to the evildoers, 'Taste now that you were earning!'\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmlxxxiii{%
Those that were before them cried lies, then the chastisement came upon them from whence they were not aware;\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmlxxxiv{%
so God let them taste degradation in this present life; and the chastisement of the world to come is assuredly greater, did they but know.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmlxxxv{%
Indeed We have struck for the people in this Koran every manner of similitude; haply they will remember;\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmlxxxvi{%
Koran, wherein there is no crookedness; haply they will be godfearing.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmlxxxvii{%
God has struck a similitude -- a man in whom partners disagreeing share, and a man the property of one man. Are the two equal in likeness? Praise belongs to God! Nay, but most of them do not know.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmlxxxviii{%
Thou art mortal, and they are mortal;\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmlxxxix{%
then on the Day of Resurrection before your Lord you shall dispute.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmxc{%
But who does greater evil than he who lies against God and cries lies to the very truth, when it comes to him? Is there not in Gehenna a lodging for the unbelievers?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmxci{%
And he who has come with the very truth and confirms it, those they are the godfearing.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmxcii{%
They shall have whatsoever they will with their Lord; that is the recompense of the good-doers,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmxciii{%
that God may acquit them of the worst of what they did, and recompense them with the wages of the fairest of what they were doing.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmxciv{%
Shall not God suffice His servant, though they frighten thee with those apart from Him? And whomsoever God leads astray, no guide has he.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmxcv{%
But whomso God guides, none shall lead him astray; is not God All-mighty, All-vengeful?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmxcvi{%
If thou askest them, 'Who created the heavens and the earth?' they will say, 'God.' Say: 'What think you? That you call upon apart from God -- if God desires affliction for me, shall they remove His affliction? Or if He desires mercy for me, shall they withhold His mercy?' Say: 'God is enough for me; in Him all those put their trust who put their trust.'\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmxcvii{%
Say: 'My people, act according to your station; I am acting; and soon you will know\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmxcviii{%
to whom will come a chastisement degrading him, and upon whom lights a lasting chastisement.'\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmxcix{%
Surely We have sent down upon thee the Book for mankind with the truth. Whosoever is guided, is only guided to his own gain, and whosoever goes astray, it is only to his own loss; thou art not a guardian over them.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmc{%
God takes the souls at the time of their death, and that which has not died, in its sleep; He withholds that against which He has decreed death, but looses the other till a stated term. Surely in that are signs for a people who reflect. Or have they taken intercessors apart from God?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmci{%
Say: 'What, even though they have no power whatever and no understanding?'\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcii{%
Say: 'To God belongs intercession altogether. His is the kingdom of the heavens and the earth; then unto Him you will be returned.'\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmciii{%
When God is mentioned alone, then shudder the hearts of those who believe not in the Hereafter, but when those apart from Him are mentioned behold, they rejoice.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmciv{%
Say: 'O God, Thou originator of the heavens and the earth who knowest the Unseen and the Visible, Thou shalt judge between Thy servants touching that whereon they are at variance.'\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcv{%
If the evildoers possessed all that is in the earth, and the like of it with it, they would offer it to ransom themselves from the evil of the chastisement on the Day of Resurrection; yet there would appear to them from God that they never reckoned with,\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcvi{%
and there would appear to them die evils of that they have earned, and they would be encompassed by that they mocked at.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcvii{%
When some affliction visits a man, he calls unto Us; then, when We confer on him a blessing from Us, he says, 'I was given it only because of a knowledge.' Nay, it is a trial, but most of them do not know it.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcviii{%
So said those that were before them; but that they earned did not avail them,\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcix{%
in that the evils of that they earned smote them. The evildoers of these men, they too shall be smitten by the evils -- of that they earned; they will not be able to frustrate it.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcx{%
Do they know that God outspreads and straitens His provision to whomsoever He will? Surely in that are signs for a people who believe.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcxi{%
Say: 'O my people who have been prodigal against yourselves, do not despair of God's mercy; surely God forgives sins altogether; surely He is the All-forgiving, the All-compassionate.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcxii{%
Turn unto your Lord and surrender to Him, ere the chastisement comes upon you, then you will not be helped.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcxiii{%
And follow the fairest of what has been sent down to you from your Lord, ere the chastisement comes upon you suddenly while you are unaware.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcxiv{%
Lest any soul should say, 'Alas for me, in that I neglected my duty to God, and was a scoffer,'\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcxv{%
or lest it should say, 'If only God had guided me, I should have been or lest among the godfearing,'\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcxvi{%
it should say, when it sees the chastisement, 'O that I might return again, and be among the good-doers.'\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcxvii{%
'Yes indeed! My signs did come to thee, but thou hast cried them lies, and thou hast waxed proud, and become one of the unbelievers.'\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcxviii{%
And upon the Day of Resurrection thou shalt see those who lied against God, their faces blackened; is there not in Gehenna a lodging for those that are proud?\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcxix{%
But God shall deliver those that were godfearing in their security; evil shall not visit them, neither shall they sorrow.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcxx{%
God is the Creator of every thing; He is Guardian over every thing;\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcxxi{%
unto Him belong the keys of the heavens and the earth. And those who disbelieve in the signs of God, those they are the losers.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcxxii{%
Say: 'Is it other than God you bid me serve, you ignorant ones?'\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcxxiii{%
It has been revealed to thee, and to those before thee, 'If thou associatest other gods with God, thy work shall surely fail and thou wilt be among the losers.'\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcxxiv{%
Nay, but God do thou serve; and be thou among the thankful.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcxxv{%
They measure not God with His true measure. The earth altogether shall be His handful on the Day of Resurrection, and the heavens shall be rolled up in His right hand. Glory be to Him! High be He exalted above that they associate!\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcxxvi{%
For the Trumpet shall be blown, and whosoever is in the heavens and whosoever is in the earth shall swoon, save whom God wills. Then it shall be blown again, and lo, they shall stand, beholding.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcxxvii{%
And the earth shall shine with the light of its Lord, and the Book shall be set in place, and the Prophets and witnesses shall be brought, and justly the issue be decided between them, and they not wronged.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcxxviii{%
Every soul shall be paid in full for what it has wrought; and He knows very well what they do.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcxxix{%
Then the unbelievers shall be driven in companies into Gehenna till, when they have come thither, then its gates will be opened and its keepers will say to them, 'Did not Messengers come to you from among yourselves, reciting to you the signs of your Lord and warning you against the encounter of this your day?' They shall say, 'Yes indeed; but the word of the chastisement has been realized against the unbelievers.'\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcxxx{%
It shall be said, 'Enter the gates of Gehenna, to dwell therein forever.' How evil is the lodging of those that are proud!\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcxxxi{%
Then those that feared their Lord shall be driven in companies into Paradise, till, when they have come thither, and its gates are opened, and its keepers will say to them, 'Peace be upon you! Well you have fared; enter in, to dwell forever.'\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcxxxii{%
And they shall say, 'Praise belongs to God, who has been true in His promise to us, and has bequeathed upon us the earth, for us to make our dwelling wheresoever we will in Paradise.' How excellent is the wage of those that labour!\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcxxxiii{%
And thou shalt see the angels encircling about the Throne proclaiming the praise of their Lord; and justly the issue shall be decided between them; and it shall be said, 'Praise belongs to God, the Lord of all Being.'\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcxxxiv{%
\basmalahen Ha Mim\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcxxxv{%
The sending down of the Book is from God the All-mighty, the All-knowing,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcxxxvi{%
Forgiver of sins, Accepter of penitence, Terrible in retribution, the Bountiful; there is no god but He, and unto Him is the homecoming.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcxxxvii{%
None but the unbelievers dispute concerning the signs of God; so let not their going to and fro in the land delude thee.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcxxxviii{%
The people of Noah before them also cried lies, and the parties after them; every nation purposed against their Messenger to seize him, and disputed with falsehood that they might rebut thereby the truth. Then I seized them; and how was My retribution!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcxxxix{%
Even so the Word of thy Lord was realised against the unbelievers, that they are the inhabitants of the Fire.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcxl{%
Those who bear the Throne, and those round about it proclaim the praise of their Lord, and believe in Him, and they ask forgiveness for those who believe: 'Our Lord, Thou embracest every thing in mercy and knowledge; therefore forgive those who have repented, and follow Thy way, and guard them against the chastisement of Hell.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcxli{%
Our Lord, and admit them to the Gardens of Eden that Thou hast promised them and those who were righteous of their fathers, and their wives, and their seed; surely Thou art the All-mighty, the All-wise.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcxlii{%
And guard them against evil deeds; whomsoever Thou guardest against evil deeds on that day, on him Thou hast had mercy; and that is indeed the mighty triumph.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcxliii{%
It shall be proclaimed to the unbelievers, 'Surely God's hatred is greater than your hatred one of another, when you were called unto belief, and disbelieved.'\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcxliv{%
They shall say, 'Our Lord, Thou hast caused us to die two deaths and Thou hast given us twice to live; now we confess our sins. Is there any way to go forth?'\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcxlv{%
That is because, when God was called to alone, you disbelieved; but if others are associated with Him, then you believe. Judgment belongs to God, the All-high, the All-great.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcxlvi{%
It is He who shows you His signs and sends down to you out of heaven provision; yet none remembers but he who repents.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcxlvii{%
So call unto God, making your religion His sincerely, though the unbelievers be averse.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcxlviii{%
Exalter of ranks is He, Possessor of the Throne, casting the Spirit of His bidding upon whomever He will of His servants, that he may warn them of the Day of Encounter,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcxlix{%
the day they sally forth, and naught of theirs is hidden from God. 'Whose is' the Kingdom today?' 'God's, the One, the Omnipotent.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcl{%
Today each soul shall be recompensed for that it has earned; no wrong today. Surely God is swift at the reckoning.'\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcli{%
And warn them against the Day of the Imminent when, choking with anguish, the hearts are in the throats and the evildoers have not one loyal friend, no intercessor to be heeded.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmclii{%
He knows the treachery of the eyes and what the breasts conceal.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcliii{%
God shall decide justly, and those they call on, apart from Him, shall not decide by any means. surely God is the All-hearing, the All-seeing.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcliv{%
What, have they not journeyed in the land and beheld how was the end of those before them? They were stronger than themselves in might and left firmer traces in the earth; yet God seized them in their sins, and they had none to defend them from God.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmclv{%
That was because their Messengers came to them with the clear signs; but they disbelieved, so God seized them. Surely He is All-strong, terrible in retribution.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmclvi{%
We also sent Moses with Our signs and a clear authority,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmclvii{%
to Pharaoh, Haman and Korah; they said, 'A lying sorcerer!'\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmclviii{%
And when he brought them the truth from Us, they said, 'Slay the sons of those who believe with him, and spare their women.' But the guile of the unbelievers is ever in error.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmclix{%
And Pharaoh said, 'Let me slay Moses, and let him call to his Lord. I fear that he may change, your religion, or that he may cause corruption to appear in the land.'\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmclx{%
And Moses said, 'I take refuge in my Lord and your Lord from every man who is proud, and believes not in the Day of Reckoning.'\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmclxi{%
Then said a certain man, a believer 'of Pharaoh's folk that kept hidden his belief, 'What, will you slay a man because he says, ``My Lord is God," yet he has brought you the clear signs from your Lord? If he is a liar, his lying is upon his own head; but if he is truthful, somewhat of that he promises you will smite you. Surely God guides not him who is prodigal and a liar.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmclxii{%
O my people, today the kingdom is yours, who are masters in the land. But who will help us, against the might of God, if it comes upon us?' Said Pharaoh, 'I only let you see what I see; I only guide you in the way of rectitude.'\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmclxiii{%
Then said he who believed, 'My people, truly I fear for you the like of the day of the parties,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmclxiv{%
the like of the case of Noah's people, Ad, Thamood, and those after them; and God desires not wrong for His servants.'\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmclxv{%
O my people, I fear for you the Day of Invocation,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmclxvi{%
the day you turn about, retreating, having none to defend you from God; and whomsoever God leads astray, no guide has he.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmclxvii{%
Joseph brought you the clear signs before, yet you continued in doubt concerning that he brought you until, when he perished, you said, ``God will never send forth a Messenger after him." Even, so God leads astray the prodigal and the doubter.'\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmclxviii{%
(Those who dispute concerning the signs of God, without any authority come to them, very hateful is that in the sight of God and the believers; 'so God sets a seal on every heart proud', arrogant.)\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmclxix{%
Pharaoh said, 'Haman, build for me a tower, that haply so I may reach the cords,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmclxx{%
the cords of the heavens, and look upon Moses' God; for I think that he is a liar.' So the evil of his deeds was decked out fair to Pharaoh, and he was barred from the way, and Pharaoh's guile came only to ruin.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmclxxi{%
Then said he who believed, 'My people, follow me, and I will guide you in the way of rectitude.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmclxxii{%
O my people, surely this present life is but a passing enjoyment; surely the world to come is the abode of stability.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmclxxiii{%
Whosoever does an evil deed shall be recompensed only with the like of it, but whosoever does a righteous deed, be it male or female, believing -- those shall enter Paradise, therein provided without reckoning.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmclxxiv{%
O my people, how is it with me, that I call you to salvation, and you call me to the Fire?\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmclxxv{%
You call me to disbelieve in God, and to associate with Him that whereof I have no knowledge, while I call you to the All-mighty, the All-forgiving.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmclxxvi{%
No doubt that what you call me to has no call heard, in this world or in the world to come, that to God we return, and that the prodigal are the inhabitants of the Fire.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmclxxvii{%
You will remember what I say to you. I commit my affair to God; surely God sees His servants.'\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmclxxviii{%
So God guarded him against the evil things of their devising, and there encompassed the folk of Pharaoh the evil chastisement,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmclxxix{%
the Fire, to which they shall be exposed morning and evening; and on the day when the Hour is come: 'Admit the folk of Pharaoh into the most terrible chastisement!'\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmclxxx{%
And when they argue one with the other in the Fire, and the weak say unto those who waxed proud, 'Why, we were your followers; will you avail us now against any part of the Fire?'\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmclxxxi{%
Then those who waxed proud shall say, 'Every one of us is in it; indeed, God already has passed judgment between His servants.'\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmclxxxii{%
And those who are in the Fire will say to the keepers of Gehenna, 'Call on your Lord, to lighten for us one day of the chastisement!'\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmclxxxiii{%
They shall say, 'Did not your Messengers bring you the clear signs?' They shall say, 'Yes indeed.' They shall say, 'Then do you call!' But the calling of the unbelievers is only in error.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmclxxxiv{%
Surely We shall help Our Messengers and those who have believed, in the present life, and upon the day when the witnesses arise,\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmclxxxv{%
upon the day when their excuses shall not profit the evildoers, and theirs shall be the curse, and theirs the evil abode.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmclxxxvi{%
We also gave Moses the guidance, and We bequeathed upon the Children of Israel the Book\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmclxxxvii{%
for a guidance and for a reminder to men possessed of minds.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmclxxxviii{%
So be thou patient; surely God's promise is true. And ask forgiveness for thy sin, and proclaim the praise of thy Lord at evening and dawn.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmclxxxix{%
Those who dispute concerning the signs of God, without any authority come to them, in their breasts is only pride, that they shall never attain. So seek thou refuge in God; surely He is the All-hearing, the All-seeing.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcxc{%
Certainly the creation of the heavens and earth is greater than the creation of men; but most men know it not.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcxci{%
Not equal are the blind and the seeing man, those who believe and do deeds of righteousness, and the wrong-doer. Little do you reflect.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcxcii{%
The Hour is coming, no doubt of it, but most men do not believe.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcxciii{%
Your Lord has said, 'Call upon Me and I will answer you. Surely those who wax too proud to do Me service shall enter Gehenna utterly abject.'\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcxciv{%
It is God who made for you the night, to repose in it, and the day, to see. Surely God is bountiful to men, but most men are not thankful.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcxcv{%
That then is God, your Lord, the Creator of everything; there is no god but He. How then are you perverted?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcxcvi{%
Even so perverted are they who deny the signs of God.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcxcvii{%
It is God who made for you the earth a fixed place and heaven for an edifice; And He shaped you, and shaped you well, and provided you with the good things. That then is God, your Lord, so blessed be God, the Lord of all Being.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcxcviii{%
He is the Living One; there is no god but He. So call upon Him, making your religion His sincerely. Praise belongs to God, the Lord of all Being.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcxcix{%
Say: 'I am forbidden to serve those you call on apart from God once the clear signs came to me from my Lord; and I am commanded to surrender to the Lord of All Being.'\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcc{%
It is He who created you of dust then of a sperm-drop, then of a blood-clot, then He delivers you as infants, then that you may come of age, then that you may be old men -- though some of you there are who die before it -- and that you may reach a stated term; haply you will understand.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcci{%
It is He who gives life, and makes to die; and when He decrees a thing, He but says to it 'Be,' and it is.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmccii{%
Hast thou not regarded those who dispute concerning the signs of God, how they are turned about?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcciii{%
Those who cry lies to the Book and that wherewith We sent Our Messengers -- soon they will know!\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcciv{%
When the fetters and chains are on their necks, and they dragged\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmccv{%
into the boiling water, then into the Fire they are poured;\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmccvi{%
then it is said to them, 'Where are those you associated, apart from God?'\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmccvii{%
They shall say, 'They have gone astray from us; nay, but it was nothing at all that we called upon aforetime.' Even so God leads astray the unbelievers.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmccviii{%
'That is because you rejoiced in the earth without right, and were exultant.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmccix{%
Enter the gates of Gehenna, to dwell therein forever.' How evil is the lodging of those that are proud!\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmccx{%
So be thou patient; surely God's promise is true. Whether We show thee a part of that We promise them, or We call thee unto Us, to Us they shall be returned.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmccxi{%
We sent Messengers before thee; of some We have related to thee, and some We have not related to thee. It was not for any Messenger to bring a sign, save by God's leave. When God's command comes, justly the issue shall be decided; then the vain-doers shall be lost.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmccxii{%
It is God who appointed for you the cattle, some of them to ride and of some you eat;\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmccxiii{%
other uses also you have in them; and that on them you may attain a need in your breasts, and upon them and on the ships you are carried.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmccxiv{%
And He shows you His signs; then which of God's signs do you reject?\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmccxv{%
What, have they not journeyed in the land and beheld how was the end of those before them? They were stronger than themselves in might and left firmer traces in the earth; yet that they earned did not avail them.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmccxvi{%
So, when their Messengers brought them the clear signs, they rejoiced in what knowledge they had, and were encompassed by that they mocked at.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmccxvii{%
Then, when they saw Our might, they said, 'We believe in God alone, and we disbelieve in that we were associating with Him.'\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmccxviii{%
But their belief when they saw Our might did not profit them -- the wont of God, as in the past, touching His servants; then the unbelievers shall be lost.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmccxix{%
\basmalahen Ha Mim\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmccxx{%
A sending down from the Merciful, the Compassionate.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmccxxi{%
A Book whose signs have been distinguished as an Arabic Koran for a people having knowledge,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmccxxii{%
good tidings to bear, and warning, but most of them have turned away, and do not give ear.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmccxxiii{%
They say, 'Our hearts are veiled from what thou callest us to, and in our ears is a heaviness, and between us and thee there is a veil; so act; we are acting!'\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmccxxiv{%
Say: 'I am only a mortal, like you are. To me it has been revealed that your God is One God; so go straight with Him, and ask for His forgiveness; and woe to the idolaters\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmccxxv{%
who pay not the alms, and disbelieve in the world to come.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmccxxvi{%
Surely those who believe, and do righteous deeds shall have a wage unfailing.'\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmccxxvii{%
Say: 'What, do you disbelieve in Him who created the earth in two days, and do you set up compeers to Him? That is the Lord of all Being.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmccxxviii{%
'And He set therein firm mountains over it, and He blessed it, and He ordained therein its diverse sustenance in four days, equal to those who ask.'\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmccxxix{%
Then He lifted Himself to heaven when it was smoke, and said to it and to the earth, ``Come willingly, or unwillingly!" They said, ``We come willingly."\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmccxxx{%
So He determined them as seven heavens in two days, and revealed its commandment in every heaven.'\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmccxxxi{%
And We adorned the lower heaven with lamps, and to reserve; that is the ordaining of the All-mighty, the All-knowing. But if they turn away, then say, 'I warn you of a thunderbolt like to the thunderbolt of Ad and Thamood.'\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmccxxxii{%
When the Messengers came unto them from before them and from behind them, saying, 'Serve none but God,' they said, 'Had our Lord willed, surely He would have sent down angels; so we disbelieve in the Message you were sent with.'\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmccxxxiii{%
As for Ad, they waxed proud in the earth without right, and they said, 'Who is stronger than we in might?' What, did they not see that God, who created them, was stronger than they in might? And they denied Our signs.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmccxxxiv{%
Then We loosed against them a wind clamorous in days of ill fortune, that We might let them taste the chastisement of degradation in the present life; and the chastisement of the world to come is even more degrading, and they shall not be helped.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmccxxxv{%
As for Thamood, We guided them, but they preferred blindness above guidance, so the thunderbolt of the chastisement of humiliation seized them for that they were earning.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmccxxxvi{%
And We delivered those who believed and were godfearing.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmccxxxvii{%
Upon the day when God's enemies are mustered to the Fire, duly disposed,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmccxxxviii{%
till when they are come to it, their hearing, their eyes and their skins bear witness against them concerning what they have been doing,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmccxxxix{%
and they will say to their skins, 'Why bore you witness against us?' They shall say, 'God gave us speech, as He gave everything speech. He created you the first time, and unto Him you shall be returned.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmccxl{%
Not so did you cover yourselves, that your hearing, your eyes and your skins should not bear witness against you; but you thought that God would never know much of the things that you were working.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmccxli{%
That then, the thought you thought about your Lord, has destroyed you, and therefore you find yourselves this morning among the losers.'\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmccxlii{%
Then if they persist, the Fire shall be a lodging for them; and if they ask amends yet no amends shall be made to them.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmccxliii{%
We have allotted them comrades, and they have decked out fair to them that which is before them and behind them. So against them has been realized the Word concerning nations that passed away before them, men and jinn alike; surely they were losers.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmccxliv{%
The unbelievers say, 'Do not give ear to this Koran, and talk idly about it; haply you will overcome.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccxlv{%
So We shall let the unbelievers taste a terrible chastisement, and shall recompense them with the worst of what they were working.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmccxlvi{%
That is the recompense of God's enemies -- the Fire, wherein they shall have the Abode of Eternity as a recompense, for that they denied Our signs.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmccxlvii{%
And the unbelievers shall say, 'Our Lord, show us those that led us astray, both jinn and men, and we shall set them underneath our feet, that they may be among the lower ones.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmccxlviii{%
Those who have said, 'Our Lord is God.' then have gone straight, upon them the angels descend, saying, 'Fear not, neither sorrow; rejoice in Paradise that you were promised.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccxlix{%
We are your friends in the present life and in the world to come; therein you shall have all that your souls desire, all that you call for,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccl{%
as hospitality from One All-forgiving, One All-compassionate.'\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmccli{%
And who speaks fairer than he who calls unto God and does righteousness and says, 'Surely I am of them that surrender'?\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcclii{%
Not equal are the good deed and the evil deed. Repel with that which is fairer and behold, he between whom and thee there is enmity shall be as if he were a loyal friend.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmccliii{%
Yet none shall receive it, except the steadfast; none shall receive it, except a man of mighty fortune.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmccliv{%
If a provocation from Satan should provoke thee, seek refuge in God; He is the All-hearing, the All-knowing.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcclv{%
And of His signs are the night and the day, the sun and the moon. Bow not yourselves to the sun and moon, but bow yourselves to God who created them, if Him you serve.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcclvi{%
And if they wax proud, yet those who are with thy Lord do glorify Him by night and day, and grow not weary.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcclvii{%
And of His signs is that thou seest the earth humble; then, when We send down water upon it, it quivers, and swells. Surely He who quickens it is He who quickens the dead; surely He is powerful over everything.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcclviii{%
Those who blaspheme Our signs are not hidden from Us. What, is he who shall be cast into the Fire better, or he who comes on the Day of Resurrection in security? Do what you will; surely He sees the things you do.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcclix{%
Those who disbelieve in the Remembrance when it comes to them -- and surely it is a Book Sublime;\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcclx{%
falsehood comes not to it from before it nor from behind it; a sending down from One All-wise, All-laudable.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcclxi{%
Naught is said to thee but what already was said to the Messengers before thee. Surely thy Lord is a Lord of forgiveness and of painful retribution.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcclxii{%
If We had made it a barbarous Koran, they would have said, 'Why are its signs not distinguished? What, barbarous and Arabic?' Say: 'To the believers it is a guidance, and a healing; but those who believe not, in their ears is a heaviness, and to them it is a blindness; those -- they are called from a far place.'\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcclxiii{%
And We gave Moses the Book; and there was difference concerning it, and but for a Word that preceded from thy Lord, it had been decided between them; and they are in doubt of it disquieting.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcclxiv{%
Whoso does righteousness, it is to his own gain, and whoso does evil, it is to his own loss. Thy Lord wrongs not His servants.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcclxv{%
To Him is referred the knowledge of the Hour. Not a fruit comes forth from its sheath, no female bears or brings forth, save with His knowledge. Upon the day when He shall call to them, 'Where now are My associates?' they shall say, 'We proclaim to Thee, there is not a witness among us.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcclxvi{%
Then that they called upon before will go astray from them and they will think that they have no asylum.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcclxvii{%
Man wearies not of praying for good; but when evil visits him, then he is cast down and desperate.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcclxviii{%
And if We let him taste mercy from Us after hardship that has visited him, he surely says, 'This is mine; I think not the Hour is coming. If I am returned to my Lord, surely the reward most fair with Him will be mine.' Then We shall tell the unbelievers the things they have done, and assuredly We shall let them taste a harsh chastisement.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcclxix{%
And when We bless man, he turns away and withdraws aside; but when evil visits him, he is full of endless prayers.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcclxx{%
Say: 'What think you? If it is from God, then you disbelieve in it, who is further astray than he who is in wide schism?'\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcclxxi{%
We shall show them Our signs in the horizons and in themselves, till it is clear to them that it is the truth. Suffices it not as to thy Lord, that He is witness over everything?\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcclxxii{%
Are they not in doubt touching the encounter with their Lord? Does He not encompass everything?\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcclxxiii{%
\basmalahen Ha Mim\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcclxxiv{%
Ain Sin Qaf\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcclxxv{%
So reveals to thee, and to those before thee, God, the All-mighty, the All-wise.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcclxxvi{%
To Him belongs whatsoever is in the heavens and whatsoever is in the earth; and He is the All-high, the All-glorious.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcclxxvii{%
The heavens wellnigh are rent above them, when the angels proclaim the praise of their Lord, and ask forgiveness for those on earth. Surely God -- He is the All-forgiving, the All-compassionate.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcclxxviii{%
And those who have taken to them protectors apart from Him -- God is Warden over them; thou art not a guardian over them.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcclxxix{%
And so We have revealed to thee an Arabic Koran, that thou mayest warn the Mother of Cities and those who dwell about it, and that thou mayest warn of the Day of Gathering, wherein is no doubt -- a party in Paradise, and a party in the Blaze.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcclxxx{%
If God had willed, He would have made them one nation; but He admits whomsoever He will into His mercy, and the evildoers shall have neither protector nor helper.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxi{%
Or have they taken to them protectors apart from Him? But God -- He is the Protector; He quickens the dead, and He is powerful over everything.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxii{%
And whatever you are at variance on, the judgment thereof belongs to God. That then is God, my Lord; in Him I have put my trust, and to Him I turn, penitent.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxiii{%
The Originator of the heavens and the earth; He has appointed for you, of yourselves, pairs, and pairs also of the cattle, therein multiplying you. Like Him there is naught; He is the All-hearing, the All-seeing.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxiv{%
To Him belong the keys of the heavens and the earth. He outspreads and straitens His provision to whom He will; surely He has knowledge of everything.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxv{%
He has laid down for you as religion that He charged Noah with, and that We have revealed to thee, and that We charged Abraham with, Moses and Jesus: 'Perform the religion, and scatter not regarding it. Very hateful is that for the idolaters, that thou callest them to. God chooses unto Himself whomsoever He will, and He guides to Himself whosoever turns, penitent.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxvi{%
They scattered not, save after knowledge had come to them, being insolent one to another; and but for a Word that preceded from thy Lord until a stated term, it had been decided between them. But those to whom the Book has been given as an inheritance after them, behold, they are in doubt of it disquieting.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxvii{%
Therefore call thou, and go straight as thou hast been commanded; do not follow their caprices. And say: 'I believe in whatever Book God has sent down; I have been commanded to be just between you. God is our Lord and your Lord. We have our deeds, and you have your deeds; there is no argument between us and you; God shall bring us together, and unto Him is the homecoming.'\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxviii{%
And those who argue concerning God after that answer has been made to Him, their argument is null and void in the sight of their Lord; anger shall rest upon them, and there awaits them a terrible chastisement.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxix{%
God it is who has sent down the Book with the truth, and also the Balance. And what shall make thee know? Haply the Hour is nigh.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmccxc{%
Those that believe not therein seek to hasten it; but those who believe in it go in fear of it, knowing that it is the truth. Why, surely those who are in doubt concerning the Hour are indeed in far error.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmccxci{%
God is All-gentle to His servants, providing for whomsoever He will. He is the All-strong, the All-mighty.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmccxcii{%
Whoso desires the tillage of the world to come, We shall give him increase in his tillage; and whoso desires the tillage of this world, We shall give him of it, but in the world to come he will have no share.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmccxciii{%
Or have they associates who have laid down for them as religion that for which God gave not leave? But for the Word of Decision, it had been decided between them. For the evildoers there awaits a painful chastisement.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmccxciv{%
Thou seest the evildoers going in fear of that they have earned, that is about to fall on them; but those who believe and do righteous deeds are in Meadows of the Gardens; whatsoever they will they shall have with their Lord; that is the great bounty.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmccxcv{%
That is the good tidings God gives to His servants who believe and do righteous deeds. Say: 'I do not ask of you a wage for this, except love for the kinsfolk; and whosoever gains a good deed, We shall give him increase of good in respect of it. Surely God is All-forgiving, All-thankful.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmccxcvi{%
Or do they say, 'He has forged against God a lie?' But if God wills, He will set a seal on thy heart; and God blots out falsehood and verifies the truth by His words; He knows the thoughts within the breasts.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmccxcvii{%
It is He who accepts repentance from His servants, and pardons evil deeds; He knows the things you do.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmccxcviii{%
And He answers those who believe and do righteous deeds, and He gives them increase of His bounty. And the unbelievers -- for them awaits a terrible chastisement.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccxcix{%
Had God expanded His provision to His servants, they would have been insolent in the earth; but He sends down in measure whatsoever He will; surely He is aware of and sees His servants.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmccc{%
And it is He who sends down the rain after they have despaired, and He unfolds His mercy; He is the Protector, the All-laudable.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmccci{%
And of His signs is the creation of the heavens and earth and the crawling things He has scattered abroad in them; and He is able to gather them whenever He will.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcccii{%
Whatever affliction may visit you is for what you own hands have earned; and He pardons much.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccciii{%
You are not able to frustrate Him in the earth; and, apart from God, you have neither protector nor helper.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccciv{%
And of His signs are the ships that run on the sea like landmarks;\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcccv{%
and if He wills, He stills the wind, and they remain motionless on its back. Surely in that are signs for every man enduring, thankful.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcccvi{%
Or He wrecks them for what they have earned; and He pardons much;\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcccvii{%
and that those who dispute concerning Our signs may know they have no asylum.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcccviii{%
Whatever thing you have been given is the enjoyment of the present life; but what is with God is better and more enduring for those who believe and put their trust in their Lord.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcccix{%
And those who avoid the heinous sins and indecencies and when they are angry forgive,\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcccx{%
and those who answer their Lord, and perform the prayer, their affair being counsel between them, and they expend of that We have provided them,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcccxi{%
and who, when insolence visits them, do help themselves --\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcccxii{%
and the recompense of evil is evil the like of it; but whoso pardons and puts things right, his wage falls upon God; surely He loves not the evildoers.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcccxiii{%
And whosoever helps himself after he has been wronged -- against them there is no way.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcccxiv{%
The way is only open against those who do wrong to the people, and are insolent in the earth wrongfully; there awaits them a painful chastisement.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcccxv{%
But surely he who bears patiently and is forgiving -- surely that is true constancy.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcccxvi{%
Whomsoever God leads astray, he has no protector after him; and thou shalt see the evildoers, when they see the chastisement, saying, 'Is there any way to be sent back?'\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcccxvii{%
And thou shalt see them, as they are exposed to it, abject in humbleness, looking with furtive glance; and the believers shall say, 'Surely the losers are they who lose themselves and their families on the Day of Resurrection; surely the evildoers are in lasting chastisement.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcccxviii{%
They have no protectors to help them, apart from God, and whomsoever God leads astray, no way has he.'\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcccxix{%
Answer your Lord, before there comes a day from God that cannot be turned back; upon that day you shall have no shelter, no denial.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcccxx{%
But if they turn away, We sent thee not to be a guardian over them. It is for thee only to deliver the Message. And when We let man taste mercy from Us, he rejoices in it; but if some evil befalls him for that his own hands have forwarded, then surely man is unthankful.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcccxxi{%
To God belongs the Kingdom of the heavens and the earth; He creates what He will; He gives to whom He will females, and He gives to whom He will males\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcccxxii{%
or He couples them, both males and females; and He makes whom He will barren. Surely He is All-knowing, All-powerful.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcccxxiii{%
It belongs not to any mortal that God should speak to him, except by revelation, or from behind a veil, or that He should send a messenger and he reveal whatsoever He will, by His leave; surely He is All-high, All-wise.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcccxxiv{%
Even so We have revealed to thee a Spirit of Our bidding. Thou knewest not what the Book was, nor belief; but We made it a light, whereby We guide whom We will of Our servants. And thou, surely thou shalt guide unto a straight path --\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcccxxv{%
the path of God, to whom belongs whatsoever is in the heavens, and whatsoever is in the earth. Surely unto God all things come home.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcccxxvi{%
\basmalahen Ha Mim\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcccxxvii{%
By the Clear Book,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcccxxviii{%
behold, We have made it an Arabic Koran; haply you will understand;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcccxxix{%
and behold, it is in the Essence of the Book, with Us; sublime indeed, wise.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcccxxx{%
Shall We turn away the Remembrance from you, for that you are a prodigal people?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxi{%
How many a Prophet We sent among the ancients,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxii{%
but not a Prophet came to them, without they mocked at him;\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxiii{%
so We destroyed men stronger in valour than they, and the example of the ancients passed away.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxiv{%
If thou askest them, 'Who created the heavens and earth?' they will say, 'The All-mighty, the All-knowing created them.'\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxv{%
He who appointed the earth to be a cradle for you, and appointed ways for you therein, that haply you may be guided;\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxvi{%
and who sent down out of heaven water in measure; and We revived thereby a land that was dead; even so you shall be brought forth;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxvii{%
and who created the pairs, all of them, and appointed for you ships and cattle such as you ride,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxviii{%
that you may be seated on their backs and then remember your Lord's blessing when you are seated on them, and say, 'Glory be to Him, who has subjected this to us, and we ourselves were not equal to it;\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxix{%
surely unto our Lord we are turning.'\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcccxl{%
Yet they have assigned to Him a part of His own servants! Man is dearly unthankful.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcccxli{%
Or has He taken to Himself, from that He creates, daughters, and favoured you with sons?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcccxlii{%
And when any of them is given the good tidings of that he has likened to the All-merciful, his face is darkened, and he chokes inwardly.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcccxliii{%
What, one who is reared amid ornaments and, when the time of altercation comes, is not to be seen?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcccxliv{%
And they have made the angels, who are themselves servants of the All-merciful, females. What, did they witness their creation? Their witness shall be written down, and they shall be questioned.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcccxlv{%
They say, 'Had the All-merciful so willed, we would not have served them.' They have no knowledge of that; they are only conjecturing.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcccxlvi{%
Or did We bring them a Book aforetime to which they hold?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcccxlvii{%
Nay, but they say, 'We found our fathers upon a community, and we are guided upon their traces.'\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcccxlviii{%
Even so We sent never before thee any warner into any city, except that its men who lived at ease said, 'We indeed found our fathers upon a community, and we are following upon their traces.'\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcccxlix{%
Say: 'What, though I should bring you a better guidance than you found your fathers upon?' They say, 'We disbelieve in that you were sent with.'\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcccl{%
So We took vengeance upon them; and behold how was the end of them that cried lies.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcccli{%
And when Abraham said to his father and his people, 'Surely I am quit of that you serve,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccclii{%
except Him who originated me; and He will guide me.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcccliii{%
And he made it a word enduring among his posterity; haply so they would return.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcccliv{%
Nay, but I gave these and their fathers enjoyment of days, until the truth came unto them, and a manifest Messenger.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmccclv{%
And when the truth came to them, they said, 'This is a sorcery, and in it we are unbelievers.'\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccclvi{%
They say, 'Why was this Koran not sent down upon some man of moment in the two cities?'\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccclvii{%
What, is it they who divide the mercy of the Lord? We have divided between them their livelihood in the present life, and raised some of them above others in rank, that some of them may take others in servitude; and the mercy of thy Lord is better than that they amass.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmccclviii{%
And were it not that mankind would be one nation, We would have appointed for those who disbelieve in the All-merciful roofs of silver to their houses, and stairs whereon to mount,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmccclix{%
and doors to their houses, and couches whereon to recline,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmccclx{%
and ornaments; surely all this is but the enjoyment of the present life, and the world to come with thy Lord is for the godfearing.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmccclxi{%
Whoso blinds himself to the Remembrance of the All-merciful, to him We assign a Satan for comrade;\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmccclxii{%
and they bar them from the way, and they think they are guided,\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmccclxiii{%
till, when he comes to Us, he says, 'Would there had been between me and thee the distance of the two Easts!' An evil comrade!\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmccclxiv{%
It shall not profit you today, since you did evil, that you are partners in the chastisement.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmccclxv{%
What, shalt thou make the deaf to hear, or shalt thou guide the blind and him who is in manifest error?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmccclxvi{%
Whether We take thee away, We shall take vengeance upon them,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmccclxvii{%
or We show thee a part of that We promised them, surely We have power over them.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmccclxviii{%
So hold thou fast unto that which has been revealed unto thee; surely thou art upon a straight path.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmccclxix{%
Surely it is a Reminder to thee and to thy people; and assuredly you will be questioned.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmccclxx{%
Ask those of Our Messengers We sent before thee: Have We appointed, apart from the All-merciful, gods to be served?\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmccclxxi{%
We also sent Moses with Our signs to Pharaoh and his Council, and he said, 'Surely, I am the Messenger of the Lord of all Being.'\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmccclxxii{%
But when he brought them Our signs, lo, they laughed at them.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmccclxxiii{%
And not a sign We showed them, but it was greater than its sister sign; and We seized them with chastisement, that haply they should return.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmccclxxiv{%
And they said, 'Sorcerer, pray to thy Lord for us by the covenant He has made with thee, and surely we shall be right-guided.'\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmccclxxv{%
But when We removed from them the chastisement, behold, they broke their troth.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmccclxxvi{%
And Pharaoh proclaimed among his people: 'O my people, do I not possess the kingdom of Egypt, and these rivers flowing beneath me? What, do you not see?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmccclxxvii{%
Or am I better than this man, who is contemptible and scarcely makes things clear?\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmccclxxviii{%
Why then have bracelets of gold not been cast on him, or angels not come with him conjoined?'\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmccclxxix{%
So he made his people unsteady, and they obeyed him; surely they were an ungodly people.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmccclxxx{%
So, when they had angered Us, We took vengeance on them, and We drowned them all together;\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxi{%
and We made them a thing past, and We appointed them for an example to later folk.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxii{%
And when the son of Mary is cited as an example, behold, thy people turn away from it\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxiii{%
and say, 'What, are our gods better, or he?' They cite not him to thee, save to dispute;. nay, but they are a people contentious.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxiv{%
He is only a servant We blessed, and We made him to be an example to the Children of Israel.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxv{%
Had We willed, We would have appointed angels among you to be successors in the earth.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxvi{%
It is knowledge of the Hour; doubt not concerning it, and follow me. This is a straight path.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxvii{%
Let not Satan bar you; he is for you a manifest foe.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxviii{%
And when Jesus came with the clear signs he said, 'I have come to you with wisdom, and that I may make clear to you some of that whereon you are at variance; so fear you God and obey you me.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxix{%
Assuredly God is my Lord and your Lord; therefore serve Him; this is a straight path.'\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcccxc{%
But the parties among them fell into variance; so woe unto those who did evil, because of the chastisement of a painful day.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcccxci{%
Are they looking for aught but the Hour, that it shall come upon them suddenly, when they are not aware?\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcccxcii{%
Friends on that day shall be foes to one another, but the god-fearing.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcccxciii{%
'O My servants, today no fear is on you, neither do you sorrow' --\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcccxciv{%
even those who believed in Our signs, and had surrendered themselves\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcccxcv{%
'Enter Paradise, you and your wives, walking with joy!'\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcccxcvi{%
There shall be passed around them platters of gold, and cups, therein being whatever the souls desire, and the eyes delight in. 'And therein, you shall dwell forever.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcccxcvii{%
This is the Paradise that you have been given for an inheritance for the things that you were doing.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcccxcviii{%
Therein you have abundant fruits, whereof you may eat.'\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcccxcix{%
But the evildoers dwell forever in the chastisement of Gehenna\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcd{%
that is not abated for them and therein they are sore confounded.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcdi{%
We never wronged them, but they themselves did the wrong.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmcdii{%
And they shall call, 'O\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmcdiii{%
'We brought you the truth, but most of you were averse to the truth.'\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmcdiv{%
Or have they contrived some matter? We too are contriving.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmcdv{%
Or do they think We hear not their secret and what they conspire together? Yes indeed, and Our messengers are present with them writing it down.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmcdvi{%
Say: 'If the All-merciful has a son, then I am the first to serve him.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmcdvii{%
Glory be to the Lord of the heavens and the earth, the Lord of the Throne, above that they describe.'\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmcdviii{%
Then leave them alone to plunge and play, until they encounter that day of theirs which they are promised.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmcdix{%
And it is He who in heaven is God and in earth is God; He is the All-wise, the All-knowing.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmcdx{%
Glory be to Him, to whom belongs the Kingdom of the heavens and the earth and all that between them is; with Him is the knowledge of the Hour, and to Him you shall be returned.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmcdxi{%
Those they call upon, apart from Him, have no power of intercession, save such as have testified to the truth, and that knowingly.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmcdxii{%
If thou askest them, 'Who created you?' they will say, 'God.' How then are they perverted?\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmcdxiii{%
And for his saying, 'My Lord, surely these are a people who believe not' --\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmcdxiv{%
yet pardon them, and say, 'Peace!' Soon they will know.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmmcdxv{%
\basmalahen Ha Mim\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcdxvi{%
By the Clear Book.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcdxvii{%
We have sent it down in a blessed night (We are ever warning)\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcdxviii{%
therein every wise bidding\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcdxix{%
determined as a bidding from Us, (We are ever sending)\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcdxx{%
as a mercy from thy Lord (surely He is the All-hearing, the All-knowing)\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcdxxi{%
Lord of the heavens and earth, and all that between them is if you have faith.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcdxxii{%
There is no god but He; He gives life and makes to die; your Lord and the Lord of your fathers, the ancients.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcdxxiii{%
Nay, but they are in doubt, playing.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcdxxiv{%
So be on the watch for a day when heaven shall bring a manifest smoke\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcdxxv{%
covering the people; this is a painful chastisement.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcdxxvi{%
'O our Lord, remove Thou from us the chastisement; we are believers.'\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcdxxvii{%
How should they have the Reminder, seeing a clear Messenger already came to them,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcdxxviii{%
then they turned away from him and said, 'A man tutored, possessed!'\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcdxxix{%
'Behold, We are removing the chastisement a little; behold, you revert!'\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcdxxx{%
Upon the day when We shall assault most mightily, then We shall take Our vengeance.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxi{%
Already before them We tried the people of Pharaoh, and a noble Messenger came unto them,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxii{%
saying, 'Deliver to me God's servants; I am for you a faithful Messenger,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxiii{%
and, 'Rise not up against God; behold, I come to you with a clear authority,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxiv{%
and I take refuge in my Lord and your Lord, lest you should stone me.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxv{%
'But if so be that you believe me not, go you apart from me!'\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxvi{%
And he called to his Lord, saying, 'These are a sinful people.'\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxvii{%
'Then set thou forth with My servants in a watch of the night; surely you will be followed.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxviii{%
And leave the sea becalmed; they are a drowned host.'\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxix{%
They left how many gardens and fountains,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcdxl{%
sown fields, and how noble a station,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmcdxli{%
and what prosperity they had rejoiced in!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcdxlii{%
Even so; and We bequeathed them upon another people.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcdxliii{%
Neither heaven nor earth wept for them, nor were they respited;\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcdxliv{%
and We delivered the Children of Israel from the humbling chastisement,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmcdxlv{%
from Pharaoh; surely he was a high One, of the prodigals;\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmcdxlvi{%
and We chose them, out of a knowledge, above all beings,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcdxlvii{%
and gave them signs wherein there was a manifest trial.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcdxlviii{%
These men do say,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcdxlix{%
'There is nothing but our first death; we shall not be revived.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcdl{%
Bring us our fathers, if you speak truly!'\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcdli{%
Are they better, or the people of Tubba' and those before them whom We destroyed? They were surely sinners.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcdlii{%
We created not the heavens and earth, and all that between them is, in play;\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcdliii{%
We created them not save in truth; but most of them know it not.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcdliv{%
Surely the Day of Decision shall be their appointed time, all together,\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcdlv{%
the day a master shall avail nothing a client, and they shall not be helped,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcdlvi{%
save him upon whom God has mercy; He is the All-mighty, the All-compassionate.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcdlvii{%
Lo, the Tree of Ez-Zakkoum\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcdlviii{%
is the food of the guilty,\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcdlix{%
like molten copper, bubbling in the belly\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcdlx{%
as boiling water bubbles.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcdlxi{%
'Take him, and thrust him into the midst of Hell,\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcdlxii{%
then pour over his head the chastisement of boiling water!'\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcdlxiii{%
'Taste! Surely thou art the mighty, the noble.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcdlxiv{%
This is that concerning which you were doubting.'\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcdlxv{%
Surely the godfearing shall be in a station secure\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcdlxvi{%
among gardens and fountains,\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcdlxvii{%
robed in silk and brocade, set face to face.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcdlxviii{%
Even so; and We shall espouse them to wide-eyed houris,\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcdlxix{%
therein calling for every fruit, secure.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcdlxx{%
They shall not taste therein of death, save the first death, And He shall guard them against the chastisement of Hell --\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxi{%
a bounty from thy Lord; that is the mighty triumph.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxii{%
Now We have made it easy by thy tongue, that haply they may remember.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxiii{%
So be on the watch; they too are on the watch.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxiv{%
\basmalahen Ha Mim\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxv{%
The sending down of the Book is from God, the All-mighty, the All-wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxvi{%
Surely in the heavens and earth there are signs for the believers;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxvii{%
and in your creation, and the crawling things He scatters abroad, there are signs for a people having sure faith,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxviii{%
and in the alternation of night and day, and the provision God sends down from heaven, and therewith revives the earth after it is dead, and the turning about of the winds, there are signs for a people who understand.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxix{%
Those are the signs of God that We recite to thee in truth; in what manner of discourse then, after God and His signs, will they believe?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxx{%
Woe to every guilty impostor\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxi{%
who hears the signs of God being recited to him, then perseveres in waxing proud, as if he has not heard them; so give him the good tidings of a painful chastisement.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxii{%
And when he knows anything of Our signs, he takes them in mockery; those for them awaits a humbling chastisement.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxiii{%
Behind them Gehenna; and that they have earned shall not avail them aught, nor those they took as protectors, apart from God; for them awaits a mighty chastisement.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxiv{%
This is guidance; and those who disbelieve in the signs of their Lord, there awaits them a painful chastisement of wrath.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxv{%
God is He who has subjected to you the sea, that the ships may run on it at His commandment, and that you may seek His bounty; haply so you will be thankful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxvi{%
And He has subjected to you what is in the heavens and what is in the earth, all together, from Him. Surely in that are signs for a people who reflect.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxvii{%
Say unto those who believe, that they forgive those who do not look for the days of God, that He may recompense a people for that they have been earning.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxviii{%
Whoso does righteousness, it is to his own gain, and whoso does evil, it is to his own loss; then to your Lord you shall be returned.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxix{%
Indeed, We gave the Children of Israel the Book, the Judgment, and the Prophethood, and We provided them with good things, and We preferred them above all beings.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcdxc{%
We gave them clear signs of the Command; so they differed not, except after the knowledge had come to them, being insolent one to another. Surely thy Lord will decide between them on the Day of Resurrection touching their differences.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcdxci{%
Then We set thee upon an open way of the Command; therefore follow it, and follow not the caprices of those who do not know.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcdxcii{%
Surely they will not avail thee aught against God. Surely the evildoers are friends one of the other; God is the friend of the godfearing.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcdxciii{%
This is clear proofs for men, and a guidance, and a mercy to a people having sure faith.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcdxciv{%
Or do those who commit evil deeds think that We shall make them as those who believe and do righteous deeds, equal their living and their dying? How ill they judge!\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcdxcv{%
God created the heavens and the earth in truth, and that every soul may be recompensed for what it has earned; they shall not be wronged.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcdxcvi{%
Hast thou seen him who has taken his caprice to be his god, and God has led him astray out of a knowledge, and set a seal upon his hearing and his heart, and laid a covering on his eyes? Who shall guide him after God? What, will you not remember?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcdxcvii{%
They say, 'There is nothing but our present life; we die, and we live, and nothing but Time destroys us.' Of that they have no knowledge; they merely conjecture.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcdxcviii{%
And when Our signs are recited to them, clear signs, their only argument is that they say, 'Bring us our fathers, if you speak truly.'\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcdxcix{%
Say: 'God gives you life, then makes you die, then He shall gather you to the Day of Resurrection, wherein is no doubt, but most men do not know.'\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmd{%
To God belongs the Kingdom of the heavens and the earth. And on the day when the Hour is come, upon that day the vain-doers shall lose.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdi{%
And thou shalt see every nation hobbling on their knees, every nation being summoned unto its Book: 'Today you shall be recompensed for that you were doing.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdii{%
This is Our Book, that speaks against you the truth; We have been registering all that you were doing.'\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdiii{%
And as for those who have believed and done deeds of righteousness, their Lord shall admit them into His mercy; that is the manifest triumph.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdiv{%
But as for those who have disbelieved: 'Were not My signs recited to you, and you waxed proud, and were a sinful people?\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdv{%
And when it was said, ``God's promise is true, and the Hour, there is no doubt of it," you said; ``We know not what the Hour may be; we have only a surmise, and are by no means certain."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdvi{%
And the evil deeds that they have done shall appear to them, and they shall be encompassed by that they mocked at.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdvii{%
And it shall be said, 'Today We do forget you, even as you forgot the encounter of this your day; and your refuge is the Fire, and you shall have no helpers.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdviii{%
That is for that you took God's signs in mockery, and the present life deluded you.' So today they shall not be brought forth from it, nor will they be suffered to make amends.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdix{%
So to God belongs praise, the Lord of the heavens and the Lord of the earth, Lord of all Being.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdx{%
His is the Domination an the heavens and the earth; He is the All-mighty, the All-wise.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdxi{%
\basmalahen Ha Mim\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdxii{%
The sending down of the Book is from God, the All-mighty, the All-wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdxiii{%
We have not created the heavens and the earth, and what between them is, save with the truth and a stated term; but the unbelievers are turning away from that they were warned of.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdxiv{%
Say: 'Have you considered that you call upon apart from God? Show me what they have created of the earth; or have they a partnership in the heavens? Bring me a Book before this, or some remnant of a knowledge, if you speak truly.'\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdxv{%
And who is further astray than he who calls, apart from God, upon such a one as shall not answer him till the Day of Resurrection? Such as are heedless of their calling,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdxvi{%
and when mankind are mustered, shall be enemies to them, and shall deny their service.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdxvii{%
And when Our signs are recited to them, clear signs, the unbelievers say to the truth when it has come to them, 'This is manifest sorcery.'\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdxviii{%
Or do they say, 'He has forged it'? Say: 'If I have forged it, you have no power to help me against God. He knows very well what you are pressing upon; He suffices as a witness between me and you; He is the All-forgiving, the All-compassionate.'\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdxix{%
Say: 'I am not an innovation among the Messengers, and I know not what shall be done with me or with you. I only follow what is revealed to me; I am only a clear warner.'\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdxx{%
Say: 'Have you considered? If it be from God, and you disbelieve in it, and a witness from among the Children of Israel hears witness to its like, and believes, and you wax proud, God guides not the people of the evildoers.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdxxi{%
The unbelievers say, as regards the believers, 'If it had been aught good, they had not outstripped us to it.' And since they are not guided by it, certainly they will say, 'This is an old calumny!'\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdxxii{%
Yet before it was the Book of Moses for a model and a mercy; and this is a Book confirming, in Arabic tongue, to warn the evildoers, and good tidings to the good-doers.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdxxiii{%
Surely those who say, 'Our Lord is God' and then go straight, no fear shall be on them, neither shall they sorrow.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdxxiv{%
Those are the inhabitants of Paradise, therein dwelling forever, as a recompense for that they have been doing.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdxxv{%
We have charged man, that he be kind to his parents; his mother bore him painfully, and painfully she gave birth to him; his bearing and his weaning are thirty months. Until, when he is fully grown, and reaches forty years, he says, 'O my Lord, dispose me that I may be thankful for Thy blessing wherewith Thou hast blessed me and my father and mother, and that I may do righteousness well-pleasing to Thee; and make me righteous also in my seed. Behold, I repent to Thee, and am among those that surrender.'\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdxxvi{%
Those are they from whom We shall accept the best of what they have done, and We shall pass over their evil deeds. They are among the inhabitants of Paradise -- the promise of the very truth, which they were promised.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdxxvii{%
But he who says to his father and his mother, 'Fie upon you! Do you promise me that I shall be brought forth, when already generations have passed away before me?' while they call upon God for succour -- 'Woe upon thee! Believe; surely God's promise is true'; then he says, 'This is naught but the fairy-tales of the ancients' --\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdxxviii{%
such men are they against whom has been realized the Word concerning nations that passed away before them, men and jinn alike; they were losers.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdxxix{%
All shall have their degrees, according to what they have wrought, and that He may pay them in full for their works, and they not being wronged.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdxxx{%
Upon the day when the unbelievers are exposed to the Fire: 'You dissipated your good things in your present life, and you took your enjoyment in them; therefore today you shall be recompensed with the chastisement of humiliation for that you waxed proud in the earth without right, and for your ungodliness.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdxxxi{%
And remember the brother of Ad, when he warned his people beside the sand-dunes -- and already warners had passed away alike before him and behind him -- saying, 'Serve none but God! Truly I fear for you the chastisement of a dreadful day.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdxxxii{%
They said, 'What, hast thou come to pervert us from our gods? Then bring us that thou promisest us, if indeed thou speakest truly.'\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdxxxiii{%
He said, 'Knowledge is only with God, and I deliver to you the Message with which I was sent; but I see you are an ignorant people.'\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdxxxiv{%
Then, when they saw it as a sudden cloud coming towards their valleys, they said, 'This is a cloud, that shall give us rain!' 'Not so; rather it is that you sought to hasten -- a wind, wherein is a painful chastisement,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdxxxv{%
destroying everything by the commandment of its Lord.' So in the morning there was naught to be seen but their dwelling-places. Even so do We recompense the people of the sinners.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdxxxvi{%
And We had established them in that wherein We have not established you, and We appointed for them hearing, and sight, and hearts; and yet their hearing, their sight and their hearts availed them nothing, since they denied the signs of God, and they were encompassed by that they mocked at.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdxxxvii{%
And We destroyed the cities about you, and We turned about the signs, that haply they would return.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdxxxviii{%
Then why did those not help them that they had taken to themselves as mediators, gods apart from God? Not so; but they went astray from them, and that was their calumny, and what they had been forging.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdxxxix{%
And when We turned to thee a company of jinn giving ear to the Koran; and when they were in its presence they said, 'Be silent!' Then, when it was finished, they turned back to their people, warning.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdxl{%
They said, 'Our people, we have heard a Book that was sent down after Moses, confirming what was before it, guiding to the truth and to a straight path.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdxli{%
O our people, answer God's summoner, and believe in Him, and He will forgive you some of your sins, and protect you from a painful chastisement.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdxlii{%
Whosoever answers not God's summoner cannot frustrate God in the earth, and he has no protectors apart from Him; those are in manifest error.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdxliii{%
What, have they not seen that God who created the heavens and earth, not being wearied by creating them, is able to give life to the dead? Yes indeed; He is powerful over everything.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdxliv{%
Upon the day when the unbelievers are exposed to the Fire: 'Is not this the truth?' They shall say, 'Yes, by our Lord!' He shall say, 'Then taste the chastisement of your unbelief!'\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdxlv{%
So be thou patient, as the Messengers possessed of constancy were also patient. Seek not to hasten it for them -- it shall be as if on the day they see that they are promised, they had not tarried but for an hour of a single day. A Message to be delivered! And shall any be destroyed but the people of the ungodly?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdxlvi{%
\basmalahen Those who disbelieve and bar from God's way, God will send their works astray.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdxlvii{%
But those who believe and do righteous deeds and believe in what is sent down to Muhammad -- and it is the truth from their Lord -- He will acquit them of their evil deeds, and dispose their minds aright.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdxlviii{%
That is because those who disbelieve follow falsehood, and those who believe follow the truth from their Lord. Even so God strikes their similitudes for men.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdxlix{%
When you meet the unbelievers, smite their necks, then, when you have made wide slaughter among them, tie fast the bonds; then set them free, either by grace or ransom, till the war lays down its loads. So it shall be; and if God had willed, He would have avenged Himself upon them; but that He may try some of you by means of others. And those who are slain in the way of God, He will not send their works astray.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdl{%
He will guide them, and dispose their minds aright,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdli{%
and He will admit them to Paradise, that He has made known to them.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdlii{%
O believers, if you help God, He will help you, and confirm your feet.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdliii{%
But as for the unbelievers, ill chance shall befall them! He will send their works astray.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdliv{%
That is because they have been averse to what God has sent down, so He has made their works to fail.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdlv{%
What, have they not journeyed in the land and beheld how was the end of those before them? God destroyed them; the unbelievers shall have the likes thereof.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdlvi{%
That is because God is the Protector of the believers, and that the unbelievers have no protector.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdlvii{%
God shall surely admit those who believe and do righteous deeds into gardens underneath which rivers flow. As for the unbelievers, they take their enjoyment and eat as cattle eat; and the Fire shall be their lodging.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdlviii{%
How many a city that was stronger in might than thy city which has expelled thee have We destroyed! And there was no helper for them.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdlix{%
What, is he who is upon a clear sign from his Lord like unto such a one unto whom his evil deeds have been decked out fair, and they have followed their caprices?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdlx{%
This is the similitude of Paradise which the godfearing have been promised: therein are rivers of water unstaling, rivers of milk unchanging in flavour, and rivers of wine -- a delight to the drinkers, rivers, too, of honey purified; and therein for them is every fruit, and forgiveness from their Lord -- Are they as he who dwells forever in the Fire, such as are given to drink boiling water, that tears their bowels asunder?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdlxi{%
And some of them there are give ear to thee, till, when they go forth from thee, they say to those who have been given knowledge, 'What said he just now?' Those are they upon whose hearts God has set a seal, and they have followed their caprices.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdlxii{%
But those who are guided aright, them He increases in guidance, and gives them their godfearing.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdlxiii{%
Are they looking for aught but the Hour, that it shall come upon them suddenly? Already its tokens have come; so, when it has come to them, how shall they have their Reminder?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdlxiv{%
Know thou therefore that there is no god but God, and ask forgiveness for thy sin, and for the believers, men and women. God knows your going to and fro, and your lodging.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdlxv{%
Those who believe say, 'Why has a sura not been sent down?' Then, when a clear sura is sent down, and therein fighting is mentioned, thou seest those in whose hearts is sickness looking at thee as one who swoons of death; but better for them would be\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdlxvi{%
obedience, and words honourable. Then, when the matter is resolved, if they were true to God, it would be better for them.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdlxvii{%
If you turned away, would you then haply work corruption in the land, and break your bonds of kin?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdlxviii{%
Those are they whom God has cursed, and so made them deaf, and blinded their eyes.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdlxix{%
What, do they not ponder the Koran? Or is it that there are locks upon their hearts?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdlxx{%
Those who have turned back in their traces after the guidance has become clear to them, Satan it was that tempted them, and God respited them.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdlxxi{%
That is because they said to those who were averse to what God sent down, 'We will obey you in some of the affair'; and God knows their secrets.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdlxxii{%
How shall it be, when the angels take them, beating their faces and their backs?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdlxxiii{%
That is because they have followed what angers God, and have been averse to His good pleasure, so He has made their works to fail.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdlxxiv{%
Or did those in whose hearts is sickness think that God would not bring to light their rancour?\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdlxxv{%
Did We will, We would show them to thee, then thou wouldst know them by their mark; and thou shalt certainly know them in the twisting of their speech; and God knows your deeds.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdlxxvi{%
And We shall assuredly try you until We know those of you who struggle and are steadfast, and try your tidings.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdlxxvii{%
Those who disbelieve and bar from God's way and make a breach with the Messenger after the guidance has become clear to them, they will nothing hurt God, and He will make their works to fail.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdlxxviii{%
O believers, obey God, and obey the Messenger, and do not make your own works vain.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdlxxix{%
Those who disbelieve and bar from God's way and then die disbelieving, them God will not forgive.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdlxxx{%
So do not faint and call for peace; you shall be the upper ones, and God is with you, and will not deprive you of your works.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxi{%
The present life is naught but a sport and a diversion; and if you believe and are godfearing, He will give you your wages, and will not ask of you your goods.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxii{%
If He asks you for them, and presses you, you are niggardly, and He brings to light your rancour.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxiii{%
Ha, there you are; you are called upon to expend in God's way, and some of you are niggardly. Whoso is niggardly is niggardly only to his own soul. God is the All-sufficient; you are the needy ones. If you turn away, He will substitute another people instead of you, then they will not be your likes.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxiv{%
\basmalahen Surely We have given thee a manifest victory,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxv{%
that God may forgive thee thy former and thy latter sins, and complete His blessing upon thee, and guide thee on a straight path,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxvi{%
and that God may help thee with mighty help.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxvii{%
It is He who sent down the Shechina (tranquillity) into the hearts of the believers, that they might add faith to their faith -- to God belong the hosts of the heavens and the earth; God is All-knowing, All-wise --\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxviii{%
and that He may admit the believers, men and women alike, into gardens underneath which rivers flow, therein to dwell forever, and acquit them of their evil deeds; that is in God's sight a mighty triumph;\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxix{%
and that He may chastise the hypocrites, men and women alike, and the idolaters men and women alike, and those who think evil thoughts of God; against them shall be the evil turn of fortune. God is wroth with them, and has cursed them, and has prepared for them Gehenna -- an evil homecoming!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdxc{%
To God belong the hosts of the heavens and the earth; God is All-mighty, All-wise.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdxci{%
Surely We have sent thee as a witness, good tidings to bear, and warning,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdxcii{%
that you may believe in God and His Messenger and succour Him, and reverence Him, and that you may give Him glory at the dawn and in the evening.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdxciii{%
Those who swear fealty to thee swear fealty in truth to God; God's hand is over their hands. Then whosoever breaks his oath breaks it but to his own hurt; and whoso fulfils his covenant made with God, God will give him a mighty wage.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdxciv{%
The Bedouins who were left behind will say to thee, 'We were occupied by our possessions and our families; so ask forgiveness for us!' They say with their tongues what is not in their hearts. Say: 'Who can avail you aught against God, if He desires hurt for you, or desires profit for you? Nay, but God is ever aware of the things you do.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdxcv{%
Nay, but you thought that the Messenger and the believers would never return to their families, and that was decked out fair in your hearts, and you thought evil thoughts, and you were a people corrupt.'\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdxcvi{%
Whoso believes not in God and His Messenger, We have prepared for the unbelievers a Blaze.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdxcvii{%
To God belongs the kingdom of the heavens and of the earth; whomsoever He will He forgives, and whomsoever He will He chastises; God is All-forgiving, All-compassionate.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdxcviii{%
The Bedouins who were left behind will say, when you set forth after spoils, to take them, 'Let us follow you,' desiring to change God's words. Say: 'You shall not follow us; so God said before.' Then they will say, 'Nay, but you' are jealous of us.' Nay, but they have not understood except a little.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdxcix{%
Say to the Bedouins who were left behind: 'You shall be called against a people possessed of great might' to fight them, or they surrender. If you obey, God will give you a goodly wage; but if you turn your backs, as you turned your backs before, He will chastise you with a painful chastisement.'\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdc{%
There is no fault in the blind, and there is no fault in the lame, and there is no fault in the sick. And whosoever obeys God and His Messenger, He will admit him into gardens underneath which rivers flow; but whosoever turns his back, him He will chastise with a painful chastisement.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdci{%
God was well pleased with the believers when they were swearing fealty to thee under the tree, and He knew what was in their hearts, so He sent down the Shechina upon them, and rewarded them with a nigh victory\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcii{%
and many spoils to take; and God is ever All-mighty, All-wise.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdciii{%
God has promised you many spoils to take; these He has hastened to you, and has restrained the hands of men from you, and that it may be a sign to the believers, and to guide you on a straight path,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdciv{%
and other spoils you were not able to take; God had encompassed them already. God is powerful over everything.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcv{%
If the unbelievers had fought you, they would have turned their backs, and then found neither protector nor helper;\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcvi{%
the wont of God, as in the past before, and thou shalt never find any changing the wont of God.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcvii{%
It is He who restrained their hands from you, and your hands from them, in the hollow of Mecca, after that He made you victors over them. God sees the things you do.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcviii{%
They are the ones who disbelieved, and barred you from the Holy Mosque and the offering, detained so as not to reach its place of sacrifice. If it had not been for certain men believers and certain women believers whom you knew not, lest you should trample them, and there befall you guilt unwittingly on their account (that God may admit into His mercy whom He will), had they been separated clearly, then We would have chastised the unbelievers among them with a painful chastisement.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcix{%
When the unbelievers set in their hearts fierceness, the fierceness of pagandom, then God sent down His Shechina upon His Messenger and the believers, and fastened to them the word of godfearing to which they have better right and are worthy of; and God has' knowledge of everything.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcx{%
God has indeed fulfilled the vision He vouchsafed to His Messenger truly: 'You shall enter the Holy Mosque, if God wills, in security, your heads shaved, your hair cut short, not fearing.' He knew what you knew not, and appointed ere that a nigh victory.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcxi{%
It is He who has sent His Messenger with the guidance and the religion of truth, that He may uplift it above every religion. God suffices as a witness.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcxii{%
Muhammad is the Messenger of God, and those who are with him are hard against the unbelievers, merciful one to another. Thou seest them bowing, prostrating, seeking bounty from God and good pleasure. Their mark is on their faces, the trace of prostration. That is their likeness in the Torah, and their likeness in the Gospel: as a seed that puts forth its shoot, and strengthens it, and it grows stout and rises straight upon its stalk, pleasing the sowers, that through them He may enrage the unbelievers. God has promised those of them who believe and do deeds of righteousness forgiveness and a mighty wage.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcxiii{%
\basmalahen O believers, advance not before God and His Messenger; and fear God. God is All-hearing, All-knowing.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcxiv{%
O believers, raise not your voices above the Prophet's voice, and be not loud in your speech to him, as you are loud one to another, lest your works fail while you are not aware.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcxv{%
Surely those who lower their voices in the presence of God's Messenger, those are they whose hearts God has tested for godfearing; they shall have forgiveness and a mighty wage.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcxvi{%
Surely those who call unto thee from behind the apartments, the most of them do not understand.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcxvii{%
And if they had patience, until thou comest out to them, that would be better for them; and God is All-forgiving, All-compassionate.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdcxviii{%
O believers, if an ungodly man comes to you with a tiding, make clear, lest you afflict a people unwittingly, and then repent of what you have done.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcxix{%
And know that the Messenger of God is among you. If he obeyed you in much of the affair, you would suffer; but God has endeared to you belief, decking it fair in your hearts, and He has made detestable to you unbelief and ungodliness and disobedience. Those -- they are the right-minded,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcxx{%
by God's favour and blessing; God is All-knowing, All-wise.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdcxxi{%
If two parties of the believers fight, put things right between them; then, if one of them is insolent against the other, fight the insolent one till it reverts to God's commandment. If it reverts, set things right between them equitably, and be just. Surely God loves the just.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdcxxii{%
The believers indeed are brothers; so set things right between your two brothers, and fear God; haply so you will find mercy.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdcxxiii{%
O believers, let not any people scoff at another people who may be better than they; neither let women scoff at women who may be better than themselves. And find not fault with one another, neither revile one another by nicknames. An evil name is ungodliness after belief. And whoso repents not, those -- they are the evildoers.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdcxxiv{%
O believers, eschew much suspicion; some suspicion is a sin. And do not spy, neither backbite one another; would any of you like to eat the flesh of his brother dead? You would abominate it. And fear you God; assuredly God turns, and He is All-compassionate.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdcxxv{%
O mankind, We have created you male and female, and appointed you races and tribes, that you may know one another. Surely the noblest among you in the sight of God is the most godfearing of you. God is All-knowing, All-aware.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdcxxvi{%
The Bedouins say, 'We believe.' Say: 'You do not believe; rather say, ``We surrender"; for belief has not yet entered your hearts. If you obey God and His Messenger, He will not diminish you anything of your works. God is All-forgiving, All-compassionate.'\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxxvii{%
The believers are those who believe in God and His Messenger, then have not doubted, and have struggled with their possessions and their selves in the way of God; those -- they are the truthful ones.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxxviii{%
Say: 'What, would you teach God what your religion is, and God knows what is in the heavens and what is in the earth? And God has knowledge of everything.'\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxxix{%
They count it as a favour to thee that they have surrendered! Say: 'Do not count your surrendering as a favour to me; nay, but rather God confers a favour upon you, in that He has guided you to belief, if it be that you are truthful.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxxx{%
God knows the Unseen of the heavens and of the earth; and God sees the things you do.'\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxi{%
\basmalahen Qaf. By the glorious Koran!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxii{%
Nay, but they marvel that a warner has come to them from among them; and the unbelievers say, 'This is a marvellous thing!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxiii{%
What, when we are dead and become dust? That is a far returning!'\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxiv{%
We know what the earth diminishes of them; with Us is a book recording.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxv{%
Nay, but they cried lies to the truth when it came to them, and so they are in a case confused.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxvi{%
What, have they not beheld heaven above them, how We have built it, and decked it out fair, and it has no cracks?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxvii{%
And the earth -- We stretched it forth, and cast on it firm mountains, and We caused to grow therein of every joyous kind\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxviii{%
for an insight and a reminder to every penitent servant.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxix{%
And We sent down out of heaven water blessed, and caused to grow thereby gardens and grain of harvest\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdcxl{%
and tall palm-trees with spathes compact,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdcxli{%
a provision for the servants, and thereby We revived a land that was dead. Even so is the coming forth.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdcxlii{%
Cried lies before them the people of Noah and the men of Er-Rass, and Thamood,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdcxliii{%
and Ad and Pharaoh, the brothers of Lot,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdcxliv{%
the men of the Thicket, the people of Tubba'. Every one cried lies to the Messengers, and My threat came true.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxlv{%
What, were We wearied by the first creation? No indeed; but they are in uncertainty as to the new creation.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxlvi{%
We indeed created man; and We know what his soul whispers within him, and We are nearer to him than the jugular vein.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxlvii{%
When the two angels meet together, sitting one on the right, and one on the left,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxlviii{%
not a word he utters, but by him is an observer ready.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxlix{%
And death's agony comes in truth; that is what thou wast shunning!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcl{%
And the Trumpet shall be blown; that is the Day of the Threat.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcli{%
And every soul shall come, and with it a driver and a witness.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdclii{%
'Thou wast heedless of this; therefore We have now removed from thee thy covering, and so thy sight today is piercing.'\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcliii{%
And his comrade shall say, 'This is what I have, made ready.'\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcliv{%
'Cast, you twain, into Gehenna every froward unbeliever,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdclv{%
every hinderer of the good, transgressor, disquieter,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdclvi{%
who set up with God another god; therefore, you twain, cast him into the terrible chastisement.'\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdclvii{%
And his comrade shall say, 'Our Lord, I made him not insolent, but he was in far error.'\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdclviii{%
He shall say, 'Dispute not before Me! For I sent you beforehand -- the threat.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdclix{%
The Word is not changed with Me; I wrong not My servants.'\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdclx{%
Upon the day We shall say unto Gehenna, 'Art thou filled?' And it shall say, 'Are there any more to come?'\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdclxi{%
And Paradise shall be brought forward to the godfearing, not afar:\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdclxii{%
'This is that you were promised; it is for every mindful penitent.'\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdclxiii{%
Whosoever fears the All-merciful in the Unseen, and comes with a penitent heart:\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdclxiv{%
'Enter it in peace! This is the Day of Eternity.'\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdclxv{%
Therein they shall have whatever they will; and with Us there is yet more.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdclxvi{%
How many a generation We destroyed before them that was stronger in valour than they, then they searched about in the land; was there any asylum?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdclxvii{%
Surely in that there is a reminder to him who has a heart, or will give ear with a present mind.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdclxviii{%
We created the heavens and the earth, and what between them is, in six days, and no weariness touched Us.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdclxix{%
So be thou patient under what they say, and proclaim thy Lord's praise before the rising of the sun, and before its setting,\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdclxx{%
and proclaim thy Lord's praise in the night, and at the ends of the prostrations.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdclxxi{%
And listen thou for the day when the caller shall call from a near place.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdclxxii{%
On the day they hear the Cry in truth, that is the day of coming forth.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdclxxiii{%
It is We who give life, and make to die, and to Us is the homecoming.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdclxxiv{%
Upon the day when the earth is split asunder from about them as they hasten forth; that is a mustering easy for Us.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdclxxv{%
We know very well what they say; thou art not a tyrant over them. Therefore remind by the Koran him who fears My threat.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdclxxvi{%
\basmalahen By the swift scatterers\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdclxxvii{%
and the burden-bearers\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdclxxviii{%
and the smooth runners\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdclxxix{%
and the partitioners,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdclxxx{%
surely that you are promised is true,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxi{%
and surely the Doom is about to fall!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxii{%
By heaven with all its tracks\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxiii{%
surely you speak at variance,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxiv{%
and perverted therefrom are some.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxv{%
Perish the conjecturers\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxvi{%
who are dazed in perplexity\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxvii{%
asking, 'When shall be the Day of Doom?'\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxviii{%
Upon the day when they shall be tried at the Fire:\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxix{%
'Taste your trial! This is that you were seeking to hasten.'\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxc{%
Surely the godfearing shall be among gardens and fountains\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxci{%
taking whatsoever their Lord has given them; they were good-doers before that.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxcii{%
Little of the night would they slumber,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxciii{%
and in the mornings they would ask for forgiveness;\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxciv{%
and the beggar and the outcast had a share in their wealth.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcxcv{%
In the earth are signs for those having sure faith;\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcxcvi{%
and in your selves; what, do you not see?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcxcvii{%
And in heaven is your provision, and that you are promised.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcxcviii{%
So by the Lord of heaven and earth, it is as surely true as that you have speech.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcxcix{%
Hast thou received the story of the honoured guests of Abraham?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcc{%
When they entered unto him, saying 'Peace!' he said 'Peace! You are a people unknown to me.'\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcci{%
Then he turned to his household and brought a fattened calf,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdccii{%
and he laid it before them saying, 'Will you not eat?'\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcciii{%
Then he conceived a fear of them. They said, 'Be not afraid!' And they gave him good tidings of a cunning boy.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcciv{%
Then came forward his wife, clamouring, and she smote her face, and said, 'An old woman, barren!'\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdccv{%
They said, 'So says thy Lord; He is the All-wise, the All-knowing.'\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdccvi{%
Said he, 'And what is your business, envoys?'\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdccvii{%
They said, 'We have been sent to a people of sinners,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdccviii{%
to loose upon them stones of clay\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdccix{%
marked with thy Lord for the prodigal.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdccx{%
So We brought forth such believers as were in it,\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdccxi{%
but We found not therein except one house of those that have surrendered themselves.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdccxii{%
And therein We left a sign to those who fear the painful chastisement.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdccxiii{%
And also in Moses, when We sent him unto Pharaoh, with a clear authority,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdccxiv{%
but he turned his back, with his court, saying, 'A sorcerer, or a man possessed!'\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdccxv{%
So We seized him and his hosts, and We cast them into the sea, and he blameworthy.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdccxvi{%
And also in Ad, when We loosed against them the withering wind\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdccxvii{%
that left nothing it came upon, but made it as stuff decayed.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdccxviii{%
And also in Thamood, when it was said to them, 'Take your enjoyment for a while!'\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdccxix{%
Then they turned in disdain from the commandment of their Lord, and the thunderbolt took them and they themselves beholding\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdccxx{%
and they were not able to stand upright, and were not helped.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdccxxi{%
And the people of Noah before; surely they were an ungodly people.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdccxxii{%
And heaven -- We built it with might, and We extend it wide.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdccxxiii{%
And the earth -- We spread it forth; O excellent Smoothers!\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdccxxiv{%
And of everything created We two kinds; haply you will remember.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdccxxv{%
Therefore flee unto God! I am a clear warner from Him to you.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdccxxvi{%
And set not up with God another god; I am a clear warner from Him to you.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdccxxvii{%
Even so not a Messenger came to those before them but they said, 'A sorcerer, or a man possessed!'\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdccxxviii{%
What, have they bequeathed it one to another? Nay, but they are an insolent people.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmdccxxix{%
So turn thou from them; thou wilt not be reproached.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmdccxxx{%
And remind; the Reminder profits the believers.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxi{%
I have not created jinn and mankind except to serve Me.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxii{%
I desire of them no provision, neither do I desire that they should feed Me.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxiii{%
Surely God is the All-provider, the Possessor of Strength, the Ever-Sure.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxiv{%
The evildoers shall have their portion, like the portion of their fellows; so let them not hasten Me!\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxv{%
So woe to the unbelievers, for that day of theirs that they are promised.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxvi{%
\basmalahen By the Mount\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxvii{%
and a Book inscribed\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxviii{%
in a parchment unrolled,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxix{%
by the House inhabited\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdccxl{%
and the roof uplifted\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccxli{%
and the sea swarming,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdccxlii{%
surely thy Lord's chastisement is about to fall;\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdccxliii{%
there is none to avert it.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccxliv{%
Upon the day when heaven spins dizzily\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccxlv{%
and the mountains are in motion,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccxlvi{%
woe that day unto those that cry lies,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccxlvii{%
such as play at plunging,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccxlviii{%
the day when they shall be pitched into the fire of Gehenna:\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccxlix{%
'This is the fire that you cried lies to!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccl{%
What, is this magic, or is it you that do not see?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccli{%
Roast in it! And bear you patiently, or bear not patiently, equal it is to you; you are only being recompensed for that you were working.'\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcclii{%
Surely the godfearing shall be in gardens and bliss,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdccliii{%
rejoicing in that their Lord has given them; and their Lord shall guard them against the chastisement of Hell.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccliv{%
'Eat and drink, with wholesome appetite, for that you were working.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcclv{%
Reclining upon couches ranged in rows; and We shall espouse them to wide-eyed houris.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcclvi{%
And those who believed, and their seed followed them in belief, We shall join their seed with them, and We shall not defraud them of aught of their work; every man shall be pledged for what he earned.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcclvii{%
And We shall succour them with fruits and flesh such as they desire\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcclviii{%
while they pass therein a cup one to another wherein is no idle talk, no cause of sin,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcclix{%
and there go round them youths, their own, as if they were hidden pearls.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcclx{%
They advance one upon another, asking each other questions.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcclxi{%
They say, 'We were before among our people, ever going in fear,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcclxii{%
and God was gracious to us, and guarded us against the chastisement of the burning wind;\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcclxiii{%
we were before ever calling upon Him; surely He is the All-benign, the All-compassionate.'\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcclxiv{%
Therefore remind! by thy Lord's blessing thou art not a soothsayer neither possessed.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcclxv{%
Or do they say, 'He is a poet for whom we await Fate's uncertainty'?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdcclxvi{%
Say: 'Await! I shall be awaiting with you.'\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdcclxvii{%
Or do their intellects bid them do this? Or are they an insolent people?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdcclxviii{%
Or do they say, 'He has invented it?' Nay, but they do not believe.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdcclxix{%
Then let them bring a discourse like it, if they speak truly.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdcclxx{%
Or were they created out of nothing? Or are they the creators?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxi{%
Or did they create the heavens and earth? Nay, but they have not sure faith.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxii{%
Or are thy Lord's treasuries in their keeping? Or are they the registrars?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxiii{%
Or have they a ladder whereon they listen? Then let any of them that has listened bring a clear authority.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxiv{%
Or has He daughters, and they sons?\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxv{%
Or askest thou them for a wage, and so they are weighed down with debt?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxvi{%
Or is the Unseen in their keeping, and so they are writing it down?\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxvii{%
Or desire they to outwit? The unbelievers, they are the outwitted.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxviii{%
Or have they a god, other than God? Glory be to God, above that which they associate!\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxix{%
Even if they saw lumps falling from heaven, they would say, 'A massed cloud!'\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxx{%
Then leave them, till they encounter their day wherein they shall be thunderstruck,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxi{%
the day when their guile shall avail them naught, and they shall not be helped.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxii{%
And there surely awaits the evildoers a chastisement beyond even that, but most of them know it not.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxiii{%
And be thou patient under the judgment of thy Lord; surely thou art before Our eyes. And proclaim the praise of thy Lord when thou arisest,\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxiv{%
and proclaim the praise of thy Lord in the night, and at the declining of the stars.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxv{%
\basmalahen By the Star when it plunges,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxvi{%
your comrade is not astray, neither errs,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxvii{%
nor speaks he out of caprice.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxviii{%
This is naught but a revelation revealed,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxix{%
taught him by one terrible in power,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccxc{%
very strong; he stood poised,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdccxci{%
being on the higher horizon,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdccxcii{%
then drew near and suspended hung,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccxciii{%
two bows' length away, or nearer,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccxciv{%
then revealed to his servant that he revealed.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccxcv{%
His heart lies not of what he saw;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccxcvi{%
what, will you dispute with him what he sees?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccxcvii{%
Indeed, he saw him another time\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccxcviii{%
by the Lote-Tree of the Boundary\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccxcix{%
nigh which is the Garden of the Refuge,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccc{%
when there covered the Lote-Tree that which covered;\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdccci{%
his eye swerved not; nor swept astray.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcccii{%
Indeed, he saw one of the greatest signs of his Lord.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccciii{%
Have you considered El-Lat and El-'Uzza\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdccciv{%
and Manat the third, the other?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcccv{%
What, have you males, and He females?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcccvi{%
That were indeed an unjust division.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcccvii{%
They are naught but names yourselves have named, and your fathers; God has sent down no authority touching them. They follow only surmise, and what the souls desire; and yet guidance has come to them from their Lord.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcccviii{%
Or shall man have whatever he fancies?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcccix{%
And to God belongs the First and the Last.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcccx{%
How many an angel there is in the heavens whose intercession avails not anything, save after that God gives leave to whomsoever He wills and is well-pleased.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcccxi{%
Those who do not believe in the world to come name the angels with the names of females.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcccxii{%
They have not any knowledge thereof; they follow only surmise, and surmise avails naught against truth.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcccxiii{%
So turn thou from him who turns away from Our Remembrance, and desires only the present life.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcccxiv{%
That is their attainment of knowledge. Surely thy Lord knows very well those who have gone astray from His way, and He knows very well those who are guided.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdcccxv{%
To God belongs whatsoever is in the heavens and whatsoever is in the earth, that He may recompense those who do evil for what they have done, and recompense those who have done good with the reward most fair.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdcccxvi{%
Those who avoid the heinous sins and indecencies, save lesser offences surely thy Lord is wide in His forgiveness. Very well He knows you, when He produced you from the earth, and when you were yet unborn in your mothers' wombs; therefore hold not yourselves purified; God knows very well him who is godfearing.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdcccxvii{%
Hast thou considered him who turns his back\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdcccxviii{%
and gives a little, and then grudgingly?\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdcccxix{%
Does he possess the knowledge of the Unseen, and therefore he sees?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdcccxx{%
Or has he not been told of what is in the scrolls of Moses,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxi{%
and Abraham, he who paid his debt in full?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxii{%
That no soul laden bears the load of another,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxiii{%
and that a man shall have to his account only as he has laboured,\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxiv{%
and that his labouring shall surely be seen,\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxv{%
then he shall be recompensed for it with the fullest recompense,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxvi{%
and that the final end is unto thy Lord,\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxvii{%
and that it is He who makes to laugh, and that makes to weep,\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxviii{%
and that it is He who makes to die, and that makes to live,\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxix{%
and that He Himself created the two kinds, male and female,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxx{%
of a sperm-drop, when it was cast forth,\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxi{%
and that upon Him rests the second growth,\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxii{%
and that it is He who gives wealth and riches,\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxiii{%
and that it is He who is the Lord of Sirius,\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxiv{%
and that He destroyed Ad, the ancient,\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxv{%
and Thamood, and He did not spare them,\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxvi{%
and the people of Noah before -- certainly they did exceeding evil, and were insolent\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxvii{%
and the Subverted City He also overthrew,\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxviii{%
so that there covered it that which covered.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxix{%
Then which of thy Lord's bounties disputest thou?\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmdcccxl{%
This is a warner, of the warners of old.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmdcccxli{%
The Imminent is imminent;\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlii{%
apart from God none can disclose it.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmdcccxliii{%
Do you then marvel at this discourse,\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmdcccxliv{%
and do you laugh, and do you not weep,\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlv{%
while you make merry?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlvi{%
So bow yourselves before God, and serve Him!\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlvii{%
\basmalahen The Hour has drawn nigh: the moon is split.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlviii{%
Yet if they see a sign they turn away, and they say 'A continuous sorcery!'\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlix{%
They have cried lies, and followed their caprices; but every matter is settled.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcccl{%
And there have come to them such tidings as contain a deterrent --\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcccli{%
a Wisdom far-reaching; yet warnings do not avail.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccclii{%
So turn thou away from them. Upon the day when the Caller shall call unto a horrible thing,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcccliii{%
abasing their eyes, they shall come forth from the tombs as if they were scattered grasshoppers,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcccliv{%
running with outstretched necks to the Caller. The unbelievers shall say, 'This is a hard day!'\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccclv{%
The people of Noah cried lies before them; they cried lies to Our servant, and said, 'A man possessed!' And he was rejected.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccclvi{%
And so he called unto his Lord, saying, 'I am vanquished; do Thou succour me!'\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccclvii{%
Then We opened the gates of heaven unto water torrential,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccclviii{%
and made the earth to gush with fountains, and the waters met for a matter decreed.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccclix{%
And We bore him upon a well-planked vessel well-caulked\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccclx{%
running before Our eyes-a recompense for him denied.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccclxi{%
And We left it for a sign. Is there any that will remember?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccclxii{%
How then were My chastisement and My warnings?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdccclxiii{%
Now We have made the Koran easy for Remembrance. Is there any that will remember?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdccclxiv{%
Ad cried lies. How then were My chastisement and My warnings?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccclxv{%
We loosed against them a wind clamorous in a day of ill fortune continuous,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdccclxvi{%
plucking up men as if they were stumps of uprooted palm-trees.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdccclxvii{%
How then were My chastisement and My warnings?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdccclxviii{%
Now We have made the Koran easy for Remembrance. Is there any that will remember?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdccclxix{%
Thamood cried lies to the warnings\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdccclxx{%
and said, 'What, shall we follow a mortal, one out of ourselves? Then indeed we should be in error and insanity!\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxi{%
Has the Reminder been cast upon him alone among us? Nay, rather he is an impudent liar.'\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxii{%
'They shall surely know tomorrow who is the impudent liar.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxiii{%
They shall send the She-camel as a trial for them; so watch thou them and keep patience.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxiv{%
And tell them that the water is to be divided between them, each drink for each in turn.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxv{%
Then they called their comrade, and he took in hand, and hamstrung her.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxvi{%
How then were My chastisement and My warnings?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxvii{%
We loosed against them one Cry, and they were as the wattles of a pen-builder.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxviii{%
Now We have made the Koran easy for Remembrance. Is there any that will remember?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxix{%
The people of Lot cried lies to the warnings.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxx{%
We loosed against them a squall of pebbles except the folk of Lot; We delivered them at the dawn --\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxi{%
a blessing from Us; even so We recompense him who is thankful.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxii{%
He had warned them of Our assault, but they disputed the warnings.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxiii{%
Even his guests they had solicited of him; so We obliterated their eyes, saying, 'Taste now My chastisement and My warnings!'\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxiv{%
In the morning early there came upon them a settled chastisement:\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxv{%
'Taste now My chastisement and My warnings!'\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxvi{%
Now We have made the Koran easy for Remembrance. Is there any that will remember?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxvii{%
The warnings came also to Pharaoh's folk.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxviii{%
They cried lies to Our signs, all of them, so We seized them with the seizing of One mighty, omnipotent.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxix{%
What, are your unbelievers better than those? Or have you an immunity in the Scrolls?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcccxc{%
Or do they say, 'We are a congregation that shall be succoured?'\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcccxci{%
Certainly the host shall be routed, and turn their backs.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcii{%
Nay, but the Hour is their tryst, and the Hour is very calamitous and bitter.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcccxciii{%
Surely the sinners are in error and insanity!\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcccxciv{%
The day when they are dragged on their faces into the Fire: 'Taste now the touch of Sakar!'\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcv{%
Surely We have created everything in measure.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcvi{%
Our commandment is but one word, as the twinkling of an eye.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcvii{%
We have destroyed the likes of you; is there any that will remember?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcviii{%
Every thing that they have done is in the Scrolls,\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcix{%
and everything, great and small, is inscribed.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcm{%
Surely the godfearing shall dwell amid gardens and a river\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcmi{%
in a sure abode, in the presence of a King Omnipotent.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcmii{%
\basmalahen The All-merciful\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcmiii{%
has taught the Koran.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcmiv{%
He created man\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcmv{%
and He has taught him the Explanation.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcmvi{%
The sun and the moon to a reckoning,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcmvii{%
and the stars and the trees bow themselves;\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcmviii{%
and heaven -- He raised it up, and set the Balance.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcmix{%
(Transgress not in the Balance,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcmx{%
and weigh with justice, and skimp not in the Balance.)\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcmxi{%
And earth -- He set it down for all beings,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcmxii{%
therein fruits, and palm-trees with sheaths,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcmxiii{%
and grain in the blade, and fragrant herbs.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcmxiv{%
O which of your Lord's bounties will you and you deny?\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcmxv{%
He created man of a clay like the potter's,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcmxvi{%
and He created the jinn of a smokeless fire.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcmxvii{%
O which of your Lord's bounties will you and you deny?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcmxviii{%
Lord of the Two Easts, Lord of the Two Wests,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcmxix{%
O which of your Lord's bounties will you and you deny?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcmxx{%
He let forth the two seas that meet together,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcmxxi{%
between them a barrier they do not overpass.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcmxxii{%
O which of your Lord's bounties will you and you deny?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcmxxiii{%
From them come forth the pearl and the coral.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcmxxiv{%
O which of your Lord's bounties will you and you deny?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcmxxv{%
His too are the ships that run, raised up in the sea like land-marks.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcmxxvi{%
O which of your Lord's bounties will you and you deny?\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcmxxvii{%
All that dwells upon the earth is perishing,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmcmxxviii{%
yet still abides the Face of thy Lord, majestic, splendid.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcmxxix{%
O which of your Lord's bounties will you and you deny?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcmxxx{%
Whatsoever is in the heavens and the earth implore Him; every day He is upon some labour.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxi{%
O which of your Lord's bounties will you and you deny?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxii{%
We shall surely attend to you at leisure, you weight and you weight!\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxiii{%
O which of your Lord's bounties will you and you deny?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxiv{%
O tribe of jinn and of men, if you are able to pass through the confines of heaven and earth, pass through them! You shall not pass through except with an authority.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxv{%
O which of your Lord's bounties will you and you deny?\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxvi{%
Against you shall be loosed a flame of fire, and molten brass; and you shall not be helped.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxvii{%
O which of your Lord's bounties will you and you deny?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxviii{%
And when heaven is split asunder, and turns crimson like red leather --\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxix{%
O which of our Lord's bounties will you and you deny?\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcmxl{%
on that day none shall be questioned about his sin, neither man nor jinn.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcmxli{%
O which of your Lord's bounties will you and you deny?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcmxlii{%
The sinners shall be known by their mark, and they shall be seized by their forelocks and their feet.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcmxliii{%
O which of your Lord's bounties will you and you deny?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcmxliv{%
This is Gehenna, that sinners cried lies to;\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcmxlv{%
they shall go round between it and between hot, boiling water.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcmxlvi{%
O which of your Lord's bounties will you and you deny?\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcmxlvii{%
But such as fears the Station of his Lord, for them shall be two gardens --\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcmxlviii{%
O which of your Lord's bounties will you and you deny?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcmxlix{%
abounding in branches --\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcml{%
O which of your Lord's bounties will you and you deny?\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcmli{%
therein two fountains of running water --\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcmlii{%
O which of your Lord's bounties will you and you deny?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcmliii{%
therein of every fruit two kinds --\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcmliv{%
O which of your Lord's bounties will you and you deny?\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcmlv{%
reclining upon couches lined with brocade, the fruits of the gardens nigh to gather --\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcmlvi{%
O which of your Lord's bounties will you and you deny?\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcmlvii{%
therein maidens restraining their glances, untouched before them by any man or jinn --\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcmlviii{%
O which of your Lord's bounties will you and you deny?\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcmlix{%
lovely as rubies, beautiful as coral --\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcmlx{%
O which of your Lord's bounties will you and you deny?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcmlxi{%
Shall the recompense of goodness be other than goodness?\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcmlxii{%
O which of your Lord's bounties will you and you deny?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcmlxiii{%
And besides these shall be two gardens --\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcmlxiv{%
O which of your Lord's bounties will you and you deny?\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcmlxv{%
green, green pastures --\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcmlxvi{%
O which of your Lord's bounties will you and you deny?\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcmlxvii{%
therein two fountains of gushing water --\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcmlxviii{%
O which of your Lord's bounties will you and you deny?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcmlxix{%
therein fruits, and palm-trees, and pomegranates --\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcmlxx{%
O which of your Lord's bounties will you and you deny?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxi{%
therein maidens good and comely --\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxii{%
O which of your Lord's bounties will you and you deny?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxiii{%
houris, cloistered in cool pavilions --\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxiv{%
O which of your Lord's bounties will you and you deny?\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxv{%
untouched before them by any man or jinn --\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxvi{%
O which of your Lord's bounties will you and you deny?\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxvii{%
reclining upon green cushions and lovely druggets --\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxviii{%
O which of your Lord's bounties will you and you deny?\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxix{%
Blessed be the Name of thy Lord, majestic, splendid.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxx{%
\basmalahen When the Terror descends\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxi{%
(and none denies its descending)\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxii{%
abasing, exalting,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxiii{%
when the earth shall be rocked\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxiv{%
and the mountains crumbled\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxv{%
and become a dust, scattered,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxvi{%
and you shall be three bands --\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxvii{%
Companions of the Right (O Companions of the Right!)\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxviii{%
Companions of the Left (O Companions of the Left!)\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxix{%
and the Outstrippers: the Outstrippers\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcmxc{%
those are they brought nigh the Throne,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcmxci{%
in the Gardens of Delight\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcmxcii{%
(a throng of the ancients\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcmxciii{%
and how few of the later folk)\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcmxciv{%
upon close-wrought couches\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcmxcv{%
reclining upon them, set face to face,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcmxcvi{%
immortal youths going round about them\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcmxcvii{%
with goblets, and ewers, and a cup from a spring\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcmxcviii{%
(no brows throbbing, no intoxication)\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcmxcix{%
and such fruits as they shall choose,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmm{%
and such flesh of fowl as they desire,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmi{%
and wide-eyed houris\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmii{%
as the likeness of hidden pearls,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmiii{%
a recompense for that they laboured.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmiv{%
Therein they shall hear no idle talk, no cause of sin,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmv{%
only the saying 'Peace, Peace!'\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmvi{%
The Companions of the Right (O Companions of the Right!)\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmvii{%
mid thornless lote-trees\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmviii{%
and serried acacias,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmix{%
and spreading shade\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmx{%
and outpoured waters,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmxi{%
and fruits abounding\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmxii{%
unfailing, unforbidden,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmxiii{%
and upraised couches.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmxiv{%
Perfectly We formed them, perfect,\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmxv{%
and We made them spotless virgins,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmxvi{%
chastely amorous,\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmxvii{%
like of age for the Companions of the Right.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmxviii{%
A throng of the ancients\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmxix{%
and a throng of the later folk.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmxx{%
The Companions of the Left (O Companions of the Left!)\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmxxi{%
mid burning winds and boiling waters\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmxxii{%
and the shadow of a smoking blaze\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmxxiii{%
neither cool, neither goodly;\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmxxiv{%
and before that they lived at ease,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmxxv{%
and persisted in the Great Sin,\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmxxvi{%
ever saying, 'What, when we are dead and become dust and bones, shall we indeed be raised up?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmxxvii{%
What, and our fathers, the ancients?'\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmxxviii{%
Say: 'The ancients, and the later folk\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmxxix{%
shall be gathered to the appointed time of a known day.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmxxx{%
Then you erring ones, you that cried lies,\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmxxxi{%
you shall eat of a tree called Zakkoum,\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmxxxii{%
and you shall fill therewith your bellies\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmmxxxiii{%
and drink on top of that boiling water\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmmxxxiv{%
lapping it down like thirsty camels.'\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmmxxxv{%
This shall be their hospitality on the Day of Doom.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmmxxxvi{%
We created you; therefore why will you not believe?\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmmxxxvii{%
Have you considered the seed you spill?\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmmxxxviii{%
Do you yourselves create it, or are We the Creators?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmmxxxix{%
We have decreed among you Death; We shall not be outstripped;\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmmxl{%
that We may exchange the likes of you, and make you to grow again in a fashion you know not.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmmxli{%
You have known the first growth; so why will you not remember?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmmxlii{%
Have you considered the soil you till?\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmmxliii{%
Do you yourselves sow it, or are We the Sowers?\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmmxliv{%
Did We will, We would make it broken orts, and you would remain bitterly jesting --\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmmxlv{%
'We are debt-loaded;\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmmxlvi{%
nay, we have been robbed!'\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmmxlvii{%
Have you considered the water you drink?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmmxlviii{%
Did you send it down from the clouds, or did We send it?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmmxlix{%
Did We will, We would make it bitter; so why are you not thankful?\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmml{%
Have you considered the fire you kindle?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmmli{%
Did you make its timber to grow, or did We make it?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmmlii{%
We Ourselves made it for a reminder, and a boon to the desert-dwellers.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmmliii{%
Then magnify the Name of thy Lord, the All-mighty.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmmliv{%
No! I swear by the fallings of the stars\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmmlv{%
(and that is indeed a mighty oath, did you but know it)\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmmlvi{%
it is surely a noble Koran\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmmlvii{%
in a hidden Book\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmmlviii{%
none but the purified shall touch,\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmmlix{%
a sending down from the Lord of all Being.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmmlx{%
What, do you hold this discourse in disdain,\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmmlxi{%
and do you make it your living to cry lies?\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmmlxii{%
Why, but when the soul leaps to the throat of the dying\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmmlxiii{%
and that hour you are watching\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmmlxiv{%
(And We are nigher him than you, but you do not see Us)\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmmlxv{%
why, if you are not at Our disposal,\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmmlxvi{%
do you not bring back his soul, if you speak truly?\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmmlxvii{%
Then, if he be of those brought nigh the Throne,\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmmlxviii{%
there shall be repose and ease, and a Garden of Delight;\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmmmlxix{%
and if he be a Companion of the Right:\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmmmlxx{%
'Peace be upon thee, Companion of the Right!'\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmmmlxxi{%
But if he be of them that cried lies, and went astray,\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmmmlxxii{%
there shall be a hospitality of boiling water\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmmmlxxiii{%
and the roasting in Hell.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmmmlxxiv{%
Surely this is the truth of certainty.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmmmlxxv{%
Then magnify the Name of thy Lord, the All-mighty.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmmmlxxvi{%
\basmalahen All that is in the heavens and the earth magnifies God; He is the All-mighty, the All-wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmlxxvii{%
To Him belongs the Kingdom of the heavens and the earth; He gives life, and He makes to die, and He is powerful over everything.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmlxxviii{%
He is the First and the Last, the Outward and the Inward; He has knowledge of everything.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmlxxix{%
It is He that created the heavens and the earth in six days then seated Himself upon the Throne. He knows what penetrates into the earth, and what comes forth from it, -- what comes down from heaven, and what goes up unto it. He is with you wherever you are; and God sees the things you do.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmlxxx{%
To Him belongs the Kingdom of the heavens and the earth; and unto Him all matters are returned.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxi{%
He makes the night to enter into the day and makes the day to enter into the night. He knows the thoughts within the breasts.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxii{%
Believe in God and His Messenger, and expend of that unto which He has made you successors. And those of you who believe and expend shall have a mighty wage.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxiii{%
How is it with you, that you believe not in God seeing that the Messenger is calling you to believe in your Lord, and He has taken compact with you, if you are believers?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxiv{%
It is He who sends down upon His servant signs, clear signs, that He may bring you forth from the shadows into the light. Surely God is to you All-gentle, All-compassionate.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxv{%
How is it with you, that you expend not in the way of God, and to God belongs the inheritance of the heavens and the earth? Not equal is he among you who spent, and who fought before the victory; those are mightier in rank than they who spent and fought afterwards; and unto each God has promised the reward most fair; and God is aware of the things you do.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxvi{%
Who is he that will lend to God a good loan, and He will multiply it for him, and his shall be a generous wage?\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxvii{%
Upon the day when thou seest the believers, men and women, their light running before them, and on their right hands. 'Good tidings for you today! Gardens underneath which rivers flow, therein to dwell for ever; that is indeed the mighty triumph.'\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxviii{%
Upon the day when the hypocrites, men and women, shall say to those who have believed, 'Wait for us, so that we may borrow your light!' It shall be said, 'Return you back behind, and seek for a light!' And a wall shall be set up between them, having a door in the inward whereof is mercy, and against the outward thereof is chastisement.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxix{%
They shall be calling unto them, 'Were we not with you?' They shall say, 'Yes indeed; but you tempted yourselves, and you awaited, and you were in doubt, and fancies deluded you, until God's commandment came, and the Deluder deluded you concerning God.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmxc{%
Therefore today no ransom shall be taken from you, neither from those who disbelieved. Your refuge is the Fire, that is your master -- an evil homecoming!'\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmxci{%
Is it not time that the hearts of those who believe should be humbled to the Remembrance of God and the Truth which He has sent down, and that they should not be as those to whom the Book was given aforetime, and the term seemed over long to them, so that their hearts have become hard, and many of them are ungodly?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmxcii{%
Know that God revives the earth after it was dead. We have indeed made clear for you the signs, that haply you will understand.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmxciii{%
Surely those, the men and the women, who make freewill offerings and have lent to God a good loan, it shall be multiplied for them, and theirs shall be a generous wage.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmxciv{%
And those who believe in God and His Messengers -- they are the just men and the martyrs in their Lord's sight; they have their wage, and their light. But the unbelievers, who have cried lies to Our signs, they are the inhabitants of Hell.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmxcv{%
Know that the present life is but a sport and a diversion, an adornment and a cause for boasting among you, and a rivalry in wealth and children. It is as a rain whose vegetation pleases the unbelievers; then it withers, and thou seest it turning yellow, then it becomes broken orts. And in the world to come there is a terrible chastisement, and forgiveness from God and good pleasure; and the present life is but the joy of delusion.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmxcvi{%
Race to forgiveness from your Lord, and a Garden the breadth whereof is as the breadth of heaven and earth, made ready for those who believe in God and His Messengers. That is the bounty of God; He gives it unto whomsoever He will; and God is of bounty abounding.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmxcvii{%
No affliction befalls in the earth or in yourselves, but it is in a Book, before We create it; that is easy for God;\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmxcviii{%
that you may not grieve for what escapes you, nor rejoice in what has come to you; God loves not any man proud and boastful,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmxcix{%
such as are niggardly, and bid men to be niggardly. And whosoever turns away, God is the All-sufficient, the All-laudable.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmc{%
Indeed, We sent Our Messengers with the clear signs, and We sent down with them the Book and the Balance so that men might uphold justice. And We sent down iron, wherein is great might, and many uses for men, and so that God might know who helps Him, and His Messengers, in the Unseen. Surely God is All-strong, All-mighty.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmci{%
And We sent Noah, and Abraham, and We appointed the Prophecy and the Book to be among their seed; and some of them are guided, and many of them are ungodly.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcii{%
Then We sent, following in their footsteps, Our Messengers; and We sent, following, Jesus son of Mary, and gave unto him the Gospel. And We set in the hearts of those who followed him tenderness and mercy. And monasticism they invented -- We did not prescribe it for them -- only seeking the good pleasure of God; but they observed it not as it should be observed. So We gave those of them who believed their wage; and many of them are ungodly.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmciii{%
O believers, fear God, and believe in His Messenger, and He will give you a twofold portion of His mercy; and He will appoint for you a light whereby you shall walk, and forgive you; God is All-forgiving, All-compassionate;\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmciv{%
that the People of the Book may know that they have no power over anything of God's bounty, and that bounty is in the hand of God; He gives it unto whomsoever He will; and God is of bounty abounding.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcv{%
\basmalahen God has heard the words of her that disputes with thee concerning her husband, and makes complaint unto God. God hears the two of you conversing together; surely God is All-hearing, All-seeing.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcvi{%
Those of you who say, regarding their wives, 'Be as my mother's back,' they are not truly their mothers; their mothers are only those who gave them birth, and they are surely saying a dishonourable saying, and a falsehood. Yet surely God is All-pardoning, All-forgiving.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcvii{%
And those who say, regarding their wives, 'Be as my mother's back,' and then retract what they have said, they shall set free a slave, before the two of them touch one another. By that you are admonished; and God is aware of the things you do.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcviii{%
But whosoever finds not the means, then let him fast two successive months, before the two of them touch one another. And if any man is not able to, then let him feed sixty poor persons -- that, that you may believe in God and His Messenger. Those are God's bounds; and for the unbelievers there awaits yet a painful chastisement.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcix{%
Surely those who oppose God and His Messenger shall be frustrated as those before them were frustrated. Now We have sent down signs, clear signs; and for the unbelievers awaits a humbling chastisement,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcx{%
upon the day when God shall raise them up all together, then He shall tell them what they did.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxi{%
God has numbered it, and they have forgotten it. God is witness over everything. Hast thou not seen that God knows whatsoever is in the heavens, and whatsoever is in the earth? Three men conspire not secretly together, but He is the fourth of them, neither five men, but He is the sixth of them, neither fewer than that, neither more, but He is with them, wherever they may be; then He shall tell them what they have done, on the Day of Resurrection. Surely God has knowledge of everything.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxii{%
Hast thou not regarded those who were forbidden to converse secretly together, then they return to that they were forbidden, and they converse secretly together in sin and enmity, and in disobedience to the Messenger? Then, when they come to thee, they greet thee with a greeting God never greeted thee withal; and they say within themselves, 'Why does God not chastise us for what we say?' Sufficient for them shall be Gehenna, at which they, shall be roasted -- an evil homecoming!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxiii{%
O believers, when you conspire secretly, then conspire not together in sin and enmity and disobedience to the Messenger, but conspire in piety and godfearing. Fear God, unto whom you shall be mustered.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxiv{%
Conspiring secretly together is of Satan, that the believers may sorrow; but he will not hurt them anything, except by the leave of God. And in God let the believers put all their trust.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxv{%
O believers, when it is said to you 'Make room in the assemblies', then make room, and God will make room for you; and when it is said, 'Move up', move up, and God will raise up in rank those of you who believe and have been given knowledge. And God is aware of the things you do.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcxvi{%
O believers, when you conspire with the Messenger, before your conspiring advance a freewill offering; that is better for you and purer. Yet if you find not means, God is All-forgiving, All-compassionate.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcxvii{%
Are you afraid, before your conspiring, to advance freewill offerings? If you do not so, and God turns again unto you, then perform the prayer, and pay the alms, and obey God and His Messenger. God is aware of the things you do.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcxviii{%
Hast thou not regarded those who have taken for friends a people against whom God is wrathful? They belong neither to you nor to them; and they swear upon falsehood, and that wittingly.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcxix{%
God has made ready for them a chastisement terrible; surely they -- evil are the things they have been doing.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcxx{%
They have taken their oaths as a covering, and barred from God's way; so there awaits them a humbling chastisement.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcxxi{%
Neither their riches nor their children shall avail them anything against God; those -- they are the inhabitants of the Fire, therein dwelling forever.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcxxii{%
Upon the day when God shall raise them up all together, and they will swear to Him, as they swear to you, and think they are on something. Surely, they are the liars!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcxxiii{%
Satan has gained the mastery over them, and caused them to forget God's Remembrance. Those are Satan's party; why, Satan's party, surely, they are the losers!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcxxiv{%
Surely those who oppose God and His Messenger, those are among the most abject.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcxxv{%
God has written, 'I shall assuredly be the victor, I and My Messengers.' Surely God is All-strong, All-mighty.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcxxvi{%
Thou shalt not find any people who believe in God and the Last Day who are loving to anyone who opposes. God and His Messenger, not though they were their fathers, or their sons, or their brothers, or their clan. Those -- He has written faith upon their hearts, and He has confirmed them with a Spirit from Himself; and He shall admit them into gardens underneath which rivers flow, therein to dwell forever, God being well-pleased with them, and they well-pleased with Him. Those are God's party; why, surely God's party -- they are the prosperers.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcxxvii{%
\basmalahen All that is in the heavens and the earth magnifies God; He is the All-mighty, the All-wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcxxviii{%
It is He who expelled from their habitations the unbelievers among the People of the Book at the first mustering. You did not think that they would go forth, and they thought that their fortresses would defend them against God; then God came upon them from whence they had not reckoned, and He cast terror into their hearts as they destroyed their houses with their own hands, and the hands of the believers; therefore take heed, you who have eyes!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcxxix{%
Had God not prescribed dispersal for them, He would have chastised them in this world; and there awaits them in the world to come the chastisement of the Fire.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcxxx{%
That is because they made a breach with God and His Messenger; and whosoever makes a breach with God, God is terrible in retribution.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxi{%
Whatever palm-trees you cut down, or left standing upon their roots, that was by God's leave, and that He might degrade the ungodly.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxii{%
And whatever spoils of war God has given unto His Messenger from them, against that you pricked neither horse nor camel; but God gives authority to His Messengers over whomsoever He will. God is powerful over everything.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxiii{%
Whatsoever spoils of war God has given to His Messenger from the people of the cities belongs to God, and His Messenger, and the near kinsman, orphans, the needy and the traveller, so that it be not a thing taken in turns among the rich of you. Whatever the Messenger gives you, take; whatever he forbids you, give over. And fear God; surely God is terrible in retribution.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxiv{%
It is for the poor emigrants, who were expelled from their habitations and their possessions, seeking bounty from God and good pleasure, and helping God and His Messenger; those -- they are the truthful ones.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxv{%
And those who made their dwelling in the abode, and in belief, before them; love whosoever has emigrated to them, not finding in their breasts any need for what they have been given, and preferring others above themselves, even though poverty be their portion. And whoso is guarded against the avarice of his own soul, those -- they are the prosperers.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxvi{%
And as for those who came after them, they say, 'Our Lord, forgive us and our brothers, who preceded us in belief, and put Thou not into our hearts any rancour towards those who believe. Our Lord, surely Thou art the All-gentle, the All-compassionate.'\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxvii{%
Hast thou not regarded the hypocrites, saying to their brothers of the People of the Book who disbelieve, 'If you are expelled, we will go forth with you, and we will never obey anyone in regard to you. If you are fought against, we will help you.' And God bears witness that they are truly liars.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxviii{%
If those are expelled, they will not go forth with them, and if they are fought against, they will not help them. Even if they helped them, they would surely turn their backs, then they would not be helped.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxix{%
Why, you arouse greater fear in their hearts than God; that is because they are a people who understand not.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcxl{%
They will not fight against you all together except in fortified cities, or from behind walls. Their valour is great, among themselves; you think of them as a host; but their hearts are scattered; that is because they are a people who have no sense.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcxli{%
Like those who a short time before them tasted the mischief of their action; there awaits them a painful chastisement.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcxlii{%
Like Satan, when he said to man, 'Disbelieve'; then, when he disbelieved, he said, 'Surely I am quit of you. Surely I fear God, the Lord of all Being.'\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcxliii{%
Their end is, both are in the Fire, there dwelling forever; that is the recompense of the evildoers.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcxliv{%
O believers, fear God. Let every soul consider what it has forwarded for the morrow. And fear God; God is aware of the things you do.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcxlv{%
Be not as those who forgot God, and so He caused them to forget their souls; those -- they are the ungodly.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcxlvi{%
Not equal are the inhabitants of the Fire and the inhabitants of Paradise. The inhabitants of Paradise -- they are the triumphant.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcxlvii{%
If We had sent down this Koran upon a mountain, thou wouldst have seen it humbled, split asunder out of the fear of God. And those similitudes -- We strike them for men; haply they will reflect.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcxlviii{%
He is God; there is no god but He. He is the knower of the Unseen and the Visible; He is the All-merciful, the All-compassionate.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcxlix{%
He is God; there is no god but He. He is the King, the All-holy, the All-peaceable, the All-faithful, the All-preserver, the All-mighty, the All-compeller, the All-sublime. Glory be to God, above that they associate!\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcl{%
He is God, the Creator, the Maker, the Shaper. To Him belong the Names Most Beautiful. All that is in the heavens and the earth magnifies Him; He is the All-mighty, the All-wise.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcli{%
\basmalahen O believers, take not My enemy and your enemy for friends, offering them love, though they have disbelieved in the truth that has come to you, expelling the Messenger and you because you believe in God your Lord. If you go forth to struggle in My way and seek My good pleasure, secretly loving them, yet I know very well what you conceal and what you publish; and whosoever of you does that, has gone astray from the right way.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclii{%
If they come on you, they will be enemies to you, and stretch against you their hands and their tongues, to do you evil, and they wish that you may disbelieve.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcliii{%
Neither your blood-kindred nor your children shall profit you upon the Day of Resurrection; He shall distinguish between you. And God sees the things you do.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcliv{%
You have had a good example in Abraham, and those with him, when they said to their people, 'We are quit of you and that you serve, apart from God. We disbelieve in you, and between us and you enmity has shown itself, and hatred for ever, until you believe in God alone. (Except that Abraham said unto his father, 'Certainly I shall ask pardon for thee; but I have no power to do aught for thee against God.') 'Our Lord, in Thee we trust; to Thee we turn; to Thee is the homecoming.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclv{%
Our Lord, make us not a temptation to those who disbelieve; and forgive us. Our. Lord, Thou art the All-mighty, the All-wise.'\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclvi{%
You have had a good example in them for whoever hopes for God and the Last Day. And whosoever turns away, surely God is the All-sufficient, the All-laudable.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclvii{%
It may be God will yet establish between you and those of them with whom you are at enmity love. God is All-powerful; God is All-forgiving, All-compassionate.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclviii{%
God forbids you not, as regards those who have not fought you in religion's cause, nor expelled you from your habitations, that you should be kindly to them, and act justly towards them; surely God loves the just.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclix{%
God only forbids you as to those who have fought you in religion's cause, and expelled you from your habitations, and have supported in your expulsion, that you should take them for friends. And whosoever takes them for friends, those -- they are the evildoers.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclx{%
O believers, when believing women come to you as emigrants, test them. God knows very well their belief. Then, if you know them to be believers, return them not to the unbelievers. They are not permitted to the unbelievers, nor are the unbelievers permitted to them. Give the unbelievers what they have expended; and there is no fault in you to marry them when you have given them their wages. Do not hold fast to the ties of unbelieving women, and ask what you have expended, and let them ask what they have expended. That is God's judgment; He judges between you; and God is All-knowing, All-wise.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxi{%
And if any of your wives slips away from you to the unbelievers, and then you retaliate, give those whose wives have gone away the like of what they have expended. And fear God, in whom you believe.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxii{%
O Prophet, when believing women come to thee, swearing fealty to thee upon the terms that they will not associate with God anything, and will not steal, neither commit adultery, nor slay their children, nor bring a calumny they forge between their hands and their feet, nor disobey thee in aught honourable, ask God's forgiveness for them; God is All-forgiving, All-compassionate.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmclxiii{%
O believers, take not for friends a people against whom God is wrathful, and who have despaired of the world to come, even as the unbelievers have despaired of the inhabitants of the tombs.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmclxiv{%
\basmalahen All that is in the heavens and the earth magnifies God; He is the All-mighty; the All-wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclxv{%
O you who believe, wherefore do you say what you do not?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmclxvi{%
Very hateful is it to God, that you say what you do not.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmclxvii{%
God loves those who fight in His way in ranks, as though they were a building well-compacted.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclxviii{%
And when Moses said to his people, 'O my people, why do you hurt me, though you know I am the Messenger of God to you?' When they swerved, God caused their hearts to swerve; and God. guides never the people of the ungodly.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclxix{%
And when Jesus son of Mary said, 'Children of Israel, I am indeed the Messenger of God to you, confirming the Torah that is before me, and giving good tidings of a Messenger who shall come after me, whose name shall be Ahmad.' Then, when he brought them the clear signs, they said, 'This is a manifest sorcery.'\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclxx{%
And who does greater evil than he who forges against God falsehood, when he is being called unto surrender? And God guides never the people of the evildoers.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclxxi{%
They desire to extinguish with their mouths, the light of God; but God will perfect His light, though the unbelievers be averse.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclxxii{%
It is He who has sent His Messenger with the guidance and the religion of truth, that he may uplift it above every religion, though the unbelievers be averse.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclxxiii{%
O believers, shall I direct you to a commerce that shall deliver you from a painful chastisement?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxxiv{%
You shall believe in God and His Messenger, and struggle in the way of God with your possessions and your selves. That is better for you, did you but know.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxxv{%
He will forgive you your sins and admit you into gardens underneath which rivers flow, and to dwelling-places goodly in Gardens of Eden; that is the mighty triumph;\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmclxxvi{%
and other things you love, help from God and a nigh victory. Give thou good tidings to the believers!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmclxxvii{%
O believers, be you God's helpers, as Jesus, Mary's son, said to the Apostles. 'Who will be my helpers unto God?' The Apostles said, 'We will be helpers of God.' And a party of the Children of Israel believed, and a party disbelieved. So We confirmed those who believed against their enemy, and they became masters.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmclxxviii{%
\basmalahen All that is in the heavens and the earth magnifies God, the King, the All-holy, the All-mighty, the All-wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclxxix{%
It is He who has raised up from among the common people a Messenger from among them, to recite His signs to them and to purify them, and to teach them the Book and the Wisdom, though before that they were in manifest error,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmclxxx{%
and others of them who have not yet joined them. And He is the All-mighty, the All-wise.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxi{%
That is the bounty of God; He gives it to whom He will, and God is of bounty abounding.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxii{%
The likeness of those who have been loaded with the Torah then they have not carried it, is as the likeness of an ass carrying books. Evil is the likeness of the people who have cried lies to God's signs. God guides never the people of the evildoers.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxiii{%
Say: 'You of Jewry, if you assert that you are the friends of God, apart from other men, then do you long for death, if you speak truly.'\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxiv{%
But they will never long for it, because of that their hands have forwarded; God knows the evildoers.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxv{%
Say: 'Surely death, from which you flee, shall encounter you; then you shall be returned to the Knower of the Unseen and the Visible, and He will tell you that you have been doing.'\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxvi{%
O believers, when proclamation is made for prayer on the Day of Congregation, hasten to God's remembrance and leave trafficking aside; that is better for you, did you but know.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxvii{%
Then, when the prayer is finished, scatter in the land and seek God's bounty, and remember God frequently; haply you will prosper.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxviii{%
But when they see merchandise or diversion they scatter off to it, and they leave thee standing. Say: 'What is with God is better than diversion and merchandise. God is the best of providers.'\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxix{%
\basmalahen When the hypocrites come to thee they say, 'We bear witness that thou art indeed the Messenger of God.' And God knows that thou art indeed His Messenger, and God bears witness that the hypocrites are truly liars.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcxc{%
They have taken their oaths as a covering, then they have barred from the way of God. Surely they -- evil are the things they have been doing.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcxci{%
That is because they have believed, then they have disbelieved; therefore a seal has been set on their hearts, and they do not understand.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcxcii{%
When thou seest them, their bodies please thee; but when they speak, thou listenest to their speech, and it is as they were propped-up timbers. They think every cry is against them. They are the enemy; so beware of them. God assail them! How they are perverted!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcxciii{%
And when it is said to them, 'Come now, and God's Messenger will ask forgiveness for you,' they twist their heads, and thou seest them turning their faces away, waxing proud.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcxciv{%
Equal it is for them, whether thou askest forgiveness for them or thou askest not forgiveness for them; God will never forgive them. God guides not the people of the ungodly.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxcv{%
Those are they that say, 'Do not expend on them that are with God's Messenger until they scatter off'; yet unto God belong the treasuries of the heavens and of the earth, but the hypocrites do not understand.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxcvi{%
They say, 'If we return to the City, the mightier ones of it will expel the more abased'; yet glory belongs unto God, and unto His Messenger and the believers, but the hypocrites do not know it.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxcvii{%
O believers, let not your possessions neither your children divert you from God's remembrance; whoso does that, they are the losers.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxcviii{%
Expend of what We have provided you before that death comes upon one of you and he says, 'O my Lord, if only Thou wouldst defer me unto a near term, so that I may make freewill offering, and so I may become one of the righteous.'\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxcix{%
But God will never defer any soul when its term comes. And God is aware of the things you do.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcc{%
\basmalahen All that is in the heavens and the earth magnifies God. His is the Kingdom, and His is the praise, and He is powerful over everything.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcci{%
It is He who created you. One of you is an unbeliever, and one of you a believer; and God sees the things you do.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccii{%
He created the heavens and the earth with the truth, and He shaped you, and shaped you well; and unto Him is the homecoming.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcciii{%
He knows whatever is in the heavens and the earth, and He knows what you conceal and what you publish. God knows the thoughts within the breasts.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcciv{%
Has there not come to you the tidings of those that disbelieved before, then tasted the mischief of their action, and there yet awaits them a painful chastisement?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccv{%
That is because their Messengers came to them with the clear signs, and then they said, 'What, shall mortals be our guides?' Therefore they disbelieved, and turned away; and God was in no need of them. And God is All-sufficient, All-laudable.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccvi{%
The unbelievers assert that they will never be raised up. Say: 'Yes indeed, by my Lord! You shall be raised up, then you shall be told the things you did. That is easy for God.'\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccvii{%
Therefore believe in God and His Messenger, and in the Light which We have sent down. And God is aware of the things you do.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccviii{%
Upon the day when He shall gather you for the Day of Gathering; that shall be the Day of Mutual Fraud. And whosoever believes in God, and does righteousness, God will acquit him of his evil deeds, and admit him into gardens underneath which rivers flow, therein to dwell for ever and ever; that is the mighty triumph.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccix{%
And those who disbelieved and cried lies to Our signs, those shall be the inhabitants of the Fire. therein to dwell forever -- an evil homecoming!\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccx{%
No affliction befalls, except it be by the leave of God. Whosoever believes in God, He will guide his heart. And God has knowledge of everything.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxi{%
And obey God, and obey the Messenger; but if you turn your backs, it is only for the Messenger to deliver the Manifest Message.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxii{%
God -- there is no god but He. And in God let the believers put their trust.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmccxiii{%
O believers, among your wives and children there is an enemy to you; so beware of them. But if you pardon, and overlook, and if you forgive, surely God is All-forgiving, All-compassionate.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmccxiv{%
Your wealth and your children are only a trial; and with God is a mighty wage.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmccxv{%
So fear God as far as you are able, and give ear, and obey, and expend well for yourselves. And whosoever is guarded against the avarice of his own soul, those -- they are the prosperers.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmccxvi{%
If you lend to God a good loan, He will multiply it for you, and will forgive you. God is All-thankful, All-clement,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmccxvii{%
Knower He of the Unseen and the Visible, the All-mighty, the All-wise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmccxviii{%
\basmalahen O Prophet, when you divorce women, divorce them when they have reached their period. Count the period, and fear God your Lord. Do not expel them from their houses, nor let them go forth, except when they commit a flagrant indecency. Those are God's bounds; whosoever trespasses the bounds of God has done wrong to himself. Thou knowest not, perchance after that God will bring something new to pass.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxix{%
Then, when they have reached their term, retain them honourably, or part from them honourably. And call in to witness two men of equity from among yourselves; and perform the witnessing to God Himself. By this then is admonished whosoever believes in God and the Last Day. And whosoever fears God, He will appoint for him a way out,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxx{%
and He will provide for him from whence he never reckoned. And whosoever puts his trust in God, He shall suffice him. God attains his purpose. God has appointed a measure for everything.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxxi{%
As for your women who have despaired of further menstruating, if you are in doubt, their period shall be three months; and those who have not menstruated as yet. And those who are with child, their term is when they bring forth their burden. Whoso fears God, God will appoint for him, of His command, easiness.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxxii{%
That is God's command, that He has sent down unto you. And whosoever fears God, He will acquit him of his evil deeds, and He will give him a mighty wage.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxxiii{%
Lodge them where you are lodging, according to your means, and do not press them, so as to straiten their circumstances. If they are with child, expend upon them until they bring forth their burden. If they suckle for you, give them their wages, and consult together honourably. If you both make difficulties, another woman shall suckle for him.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxxiv{%
Let the man of plenty expend out of his plenty. As for him whose provision is stinted to him, let him expend of what God has given him. God charges no soul save with what He has given him. God will assuredly appoint, after difficulty, easiness.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxxv{%
How many a city turned in disdain from the commandment of its Lord and His Messengers; and then We made with it a terrible reckoning and chastised it with a horrible chastisement.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccxxvi{%
So it tasted the mischief of its action, and the end of its affair was loss.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccxxvii{%
God prepared for them a terrible chastisement. So fear God, O men possessed of minds! Believers, God has sent down to you, for a remembrance,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccxxviii{%
a Messenger reciting to you the signs of God, clear signs, that He may bring forth those who believe and do righteous deeds from the shadows into the light. Whosoever believes in God, and does righteousness, He will admit him to gardens underneath which rivers flow; therein they shall dwell for ever and ever. God has made for him a goodly provision.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxxix{%
It is God who created seven heavens, and of earth their like, between them the Command descending, that you may know that God is powerful over everything and that God encompasses everything in knowledge.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxxx{%
\basmalahen O Prophet, why forbiddest thou what God has made lawful to thee, seeking the good pleasure of thy wives? And God is All-forgiving, All-compassionate.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxi{%
God has ordained for you the absolution of your oaths. God is your Protector, and He is the All-knowing, the All-wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxii{%
And when the Prophet confided to one of his wives a certain matter; and then, when she told of it, and God disclosed that to him, he made known part of it, and turned aside from part; then, when he told her of it, she said, 'Who told thee this?' He said, 'I was told of it by the All-knowing, the All-aware.'\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxiii{%
If you two repent to God, yet your hearts certainly inclined; but if you support one another against him, God is his Protector, and Gabriel, and the righteous among the believers; and, after that, the angels are his supporters.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxiv{%
It is possible that, if he divorces you, his Lord will give him in exchange wives better than you, women who have surrendered, believing, obedient, penitent, devout, given to fasting, who have been married and virgins too.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxv{%
Believers, guard yourselves and your families against a Fire whose fuel is men and stones, and over which are harsh, terrible angels who disobey not God in what He commands them and do what they are commanded.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxvi{%
'O you unbelievers, do not excuse yourselves today; you are only being recompensed for what you were doing.'\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxvii{%
Believers, turn to God in sincere repentance; it may be that your Lord will acquit you of your evil deeds, and will admit you into gardens underneath which rivers flow. Upon the day when God will not degrade the Prophet and those who believe with him, their light running before them, and on their right hands; and they say, 'Our 'Lord, perfect for us our light, and forgive us; surely Thou art powerful over everything.'\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxviii{%
O Prophet, struggle with the unbelievers and the hypocrites, and be thou harsh with them; their refuge shall be Gehenna -- an evil homecoming!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxix{%
God has struck a similitude for the unbelievers -- the wife of Noah, and the wife of Lot; for they were under two of Our righteous servants, but they betrayed them, so they availed them nothing whatsoever against God; so it was said, 'Enter, you two, the Fire with those who enter.'\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccxl{%
God has struck a similitude for the believers -- the wife of Pharaoh, when she said, 'My Lord, build for me a house in Paradise, in Thy presence, and deliver me from Pharaoh and his work, and do Thou deliver me from the people of the evildoers.'\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxli{%
And Mary, Imran's daughter, who guarded her virginity, so We breathed into her of Our Spirit, and she confirmed the Words of her Lord and His Books, and became one of the obedient.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxlii{%
\basmalahen Blessed be He in whose hand is the Kingdom -- He is powerful over everything --\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxliii{%
who created death and life, that He might try you which of you is fairest in works; and He is the All-mighty, the All-forgiving --\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxliv{%
who created seven heavens one upon another. Thou seest not in the creation of the All-merciful any imperfection. Return thy gaze; seest thou any fissure?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxlv{%
Then return thy gaze again, and again, and thy gaze comes back to thee dazzled, aweary.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxlvi{%
And We adorned the lower heaven with lamps, and made them things to stone Satans; and We have prepared for them the chastisement of the Blaze.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxlvii{%
And for those who disbelieve in their Lord there awaits the chastisement of Gehenna -- an evil homecoming!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxlviii{%
When they are cast into it they will hear it sighing, the while it boils\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxlix{%
and wellnigh bursts asunder with rage. As often as a troop is cast into it, its keepers ask them, 'Came there no warner to you?';\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccl{%
They say, 'Yes indeed, a warner came to us; but we cried lies, saying, ``God has not sent down anything; you are only in great error.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccli{%
They also say, 'If we had only heard, or had understood, we would not have been of the inhabitants of the Blaze.'\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcclii{%
So they confess their sins. Curse the inhabitants of the Blaze!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccliii{%
Surely those who fear their Lord in the Unseen -- there awaits them forgiveness and a great wage.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccliv{%
Be secret in your speech, or proclaim it, He knows the thoughts within the breasts.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcclv{%
Shall He not know, who created? And He is the All-subtle, the All-aware.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcclvi{%
It is He who made the earth submissive to you; therefore walk in its tracts, and eat of His provision; to Him is the Uprising.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcclvii{%
Do you feel secure that He who is in heaven will not cause the earth to swallow you, the while it rocks?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcclviii{%
Do you feel secure that He who is in heaven will not loose against you a squall of pebbles, then you shall know how My warning is?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcclix{%
Those that were before them also cried lies; then how was My horror!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcclx{%
Have they not regarded the birds above them spreading their wings, and closing them? Naught holds them but the All-merciful. Surely He sees everything.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcclxi{%
Or who is this that shall be a host for you to help you, apart from the All-merciful? The unbelievers are only in delusion.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcclxii{%
Or who is this that shall provide for you if He withholds His provision? No, but they persist in disdain and aversion.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcclxiii{%
What, is he who walks prone upon his face better guided than he who walks upright on a straight path?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcclxiv{%
Say: 'It is He who produced you, and appointed for you hearing and sight and hearts; little thanks you show!'\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcclxv{%
Say: 'It is He who scattered you in the earth, and unto Him you shall be mustered.'\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcclxvi{%
They say, 'When shall this promise come to pass, if you speak truly?'\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcclxvii{%
Say: 'The knowledge is with God; I am only a clear warner.'\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcclxviii{%
Then, when they see it nigh at hand, the faces of the unbelievers will be vexed, and it will be said, 'This is what you were promised.'\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcclxix{%
Say: 'What think you? If God destroys me and those with me, or has mercy on us, then who will protect the unbelievers from a painful chastisement?'\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcclxx{%
Say: 'He is the All-merciful. We believe in Him, and in Him we put all our trust. Assuredly, you will soon, know who is in manifest error.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxi{%
Say: 'What think you? If in the morning your water should have vanished into the earth, then who would bring you running water?'\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxii{%
\basmalahen Nun. By the Pen, and what they inscribe,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxiii{%
thou art not, by the blessing of thy Lord, a man possessed.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxiv{%
Surely thou shalt have a wage unfailing;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxv{%
surely thou art upon a mighty morality.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxvi{%
So thou shalt see, and they will see,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxvii{%
which of you is the demented.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxviii{%
Surely thy Lord knows very well those who have gone astray from His way, and He knows very well those who are guided.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxix{%
So obey thou not those who cry lies.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxx{%
They wish that thou shouldst compromise, then they would compromise.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxi{%
And obey thou not every mean swearer,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxii{%
backbiter, going about with slander,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxiii{%
hinderer of good, guilty aggressor, coarse-grained,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxiv{%
moreover ignoble,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxv{%
because he has wealth and sons.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxvi{%
When Our signs are recited to him, he says, 'Fairy-tales of the ancients!'\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxvii{%
We shall brand him upon the muzzle!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxviii{%
Now We have tried them, even as We tried the owners of the garden when they swore they would pluck in the morning\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxix{%
and they added not the saving words.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmccxc{%
Then a visitation from thy Lord visited it, while they were sleeping,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmccxci{%
and in the morning it was as if it were a garden plucked.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmccxcii{%
In the morning they called to one another,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmccxciii{%
'Come forth betimes upon your tillage, if you would pluck!'\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmccxciv{%
So they departed, whispering together,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmccxcv{%
'No needy man shall enter it today against your will.'\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmccxcvi{%
And they went forth early, determined upon their purpose.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmccxcvii{%
But when they saw it, they said, 'Surely we are gone astray;\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmccxcviii{%
nay, rather we have been robbed!'\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmccxcix{%
Said the most moderate of them, 'Did I not say to you, ``Why do you not give glory?"'\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmccc{%
They said, 'Glory be to God, our Lord; truly, we were evildoers.'\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmccci{%
And they advanced one upon another, blaming each other.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcccii{%
They said, 'Woe, alas for us! Truly, we were insolent.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmccciii{%
It may be that our Lord will give us in exchange a better than it; to our Lord we humbly turn.'\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmccciv{%
Such is the chastisement; and the chastisement of the world to come, is assuredly greater, did they but know.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmcccv{%
Surely for the godfearing shall be Gardens of Bliss with their Lord.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmcccvi{%
What, shall we make those who have surrendered like to the sinners?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmcccvii{%
What ails you then, how you judge?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmcccviii{%
Or have you a Book wherein you study?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmcccix{%
Surely therein you shall have whatever you choose!\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmcccx{%
Or have you oaths from Us, reaching to the Day of Resurrection? Surely you shall have whatever you judge!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmcccxi{%
Ask them, which of them will guarantee that!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmcccxii{%
Or do they have associates? Then let them bring their associates, if they speak truly.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmcccxiii{%
Upon the day when the leg shall be bared, and they shall be summoned to bow themselves, but they cannot;\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmcccxiv{%
humbled shall be their eyes, and abasement shall overspread them, for they had been summoned to bow themselves while they were whole.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmcccxv{%
So leave Me with him who cries lies to this discourse! We will draw them on little by little whence they know not;\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmcccxvi{%
and I shall respite them -- assuredly My guile is sure.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmcccxvii{%
Or askest thou them for a wage, and so they are weighed down with debt?\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmcccxviii{%
Or is the Unseen in their keeping, and so they are writing it down?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmcccxix{%
So be thou patient under the judgment of thy Lord, and be not as the Man of the Fish, when he called, choking inwardly.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmcccxx{%
Had there not overtaken him a blessing from his Lord he would have been cast upon the wilderness, being condemned.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxi{%
But his Lord had chosen him, and He placed him among the righteous.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxii{%
The unbelievers wellnigh strike thee down with their glances, when they hear the Reminder, and they say, 'Surely he is a man possessed!'\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxiii{%
And it is nothing but a Reminder unto all beings.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxiv{%
\basmalahen The Indubitable!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxv{%
What is the Indubitable?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxvi{%
And what will teach thee what is the Indubitable?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxvii{%
Thamood and Ad cried lies to the Clatterer.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxviii{%
As for Thamood, they were destroyed by the Screamer;\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxix{%
and as for Ad, they were destroyed by a wind clamorous,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxx{%
violent that He compelled against them seven nights and eight days, uninterruptedly, and thou mightest see the people laid prostrate in it as if they were the stumps of fallen down palm-trees.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxi{%
Now dost thou see any remnant of them?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxii{%
Pharaoh likewise, and those before him, and the Subverted Cities -- they committed error,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxiii{%
and they rebelled against the Messenger of their Lord, and He seized them with a surpassing grip.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxiv{%
Lo, when the waters rose, We bore you in the running ship\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxv{%
that We might make it a reminder for you and for heeding ears to hold.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxvi{%
So, when the Trumpet is blown with a single blast\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxvii{%
and the earth and the mountains are lifted up and crushed with a single blow,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxviii{%
then, on that day, the Terror shall come to pass,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxix{%
and heaven shall be split, for upon that day it shall be very frail,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcccxl{%
and the angels shall stand upon its borders, and upon that day eight shall carry above them the Throne of thy Lord.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcccxli{%
On that day you shall be exposed, not one secret of yours concealed.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlii{%
Then as for him who is given his book in his right hand, he shall say, 'Here, take and read my book!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcccxliii{%
Certainly I thought that I should encounter my reckoning.'\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcccxliv{%
So he shall be in a pleasing life\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlv{%
in a lofty Garden,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlvi{%
its clusters nigh to gather.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlvii{%
'Eat and drink with wholesome appetite for that you did long ago, in the days gone by.'\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlviii{%
But as for him who is given his book in his left hand, he shall say, 'Would that I had not been given my book\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlix{%
and not known my reckoning!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcccl{%
Would it had been the end!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcccli{%
My wealth has not availed me,\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmccclii{%
my authority is gone from me.'\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcccliii{%
'Take him, and fetter him,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcccliv{%
and then roast him in Hell,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmccclv{%
then in a chain of seventy cubits' length insert him!\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmccclvi{%
Behold, he never believed in God the All-mighty,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmccclvii{%
and he never urged the feeding of the needy;\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmccclviii{%
therefore he today has not here one loyal friend,\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmccclix{%
neither any food saving foul pus,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmccclx{%
that none excepting the sinners eat.'\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmccclxi{%
No! I swear by that you see\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmccclxii{%
and by that you do not see,\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmccclxiii{%
it is the speech of a noble Messenger.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmccclxiv{%
It is not the speech of a poet (little do you believe)\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmccclxv{%
nor the speech of a soothsayer (little do you remember).\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmccclxvi{%
A sending down from the Lord of all Being.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmccclxvii{%
Had he invented against Us any sayings,\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmccclxviii{%
We would have seized him by the right hand,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmccclxix{%
then We would surely have cut his life-vein\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmccclxx{%
and not one of you could have defended him.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxi{%
Surely it is a Reminder to the godfearing;\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxii{%
but We know that some of you will cry lies.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxiii{%
Surely it is a sorrow to the unbelievers;\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxiv{%
yet indeed it is the truth of certainty.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxv{%
Then magnify the Name of thy Lord, the All-mighty.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxvi{%
\basmalahen A questioner asked of a chastisement about to fall\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxvii{%
for the unbelievers, which none may avert,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxviii{%
from God, the Lord of the Stairways.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxix{%
To Him the angels and the Spirit mount up, in a day whereof the measure is fifty thousand years.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxx{%
So be thou patient with a sweet patience;\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxi{%
behold, they see it as if far off;\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxii{%
but We see it is nigh.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxiii{%
Upon the day when heaven shall be as molten copper\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxiv{%
and the mountains shall be as plucked wool-tufts,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxv{%
no loyal friend shall question loyal friend,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxvi{%
as they are given sight of them. The sinner will wish that he might ransom himself from the chastisement of that day even by his sons,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxvii{%
his companion wife, his brother,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxviii{%
his kin who sheltered him,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxix{%
and whosoever is in the earth, all together, so that then it might deliver him.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcccxc{%
Nay, verily it is a furnace\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcccxci{%
snatching away the scalp,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcii{%
calling him who drew back and turned away,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcccxciii{%
who amassed and hoarded.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcccxciv{%
Surely man was created fretful,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcv{%
when evil visits him, impatient,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcvi{%
when good visits him, grudging,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcvii{%
save those that pray\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcviii{%
and continue at their prayers,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcix{%
those in whose wealth is a right known\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcd{%
for the beggar and the outcast,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdi{%
who confirm the Day of Doom\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdii{%
and go in fear of the chastisement of their Lord\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdiii{%
(from their Lord's chastisement none feels secure)\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdiv{%
and guard their private parts\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcdv{%
save from their wives and what their right hands own, then not being blameworthy\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcdvi{%
(but whoso seeks after more than that, they are the transgressors),\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmcdvii{%
and who preserve their trusts and their covenant,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmcdviii{%
and perform their witnessings,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmcdix{%
and who observe their prayers.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmcdx{%
Those shall be in Gardens, high-honoured.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmcdxi{%
What ails the unbelievers, running with outstretched necks\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmcdxii{%
towards thee on the right hand and on the left hand in knots?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmcdxiii{%
What, is every man of them eager to be admitted to a Garden of Bliss?\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmcdxiv{%
Not so; for We have created them of what they know.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmcdxv{%
No! I swear by the Lord of the Easts and Wests, surely We are able\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmcdxvi{%
to substitute a better than they; We shall not be outstripped.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmcdxvii{%
Then leave them alone to plunge and play until they encounter that day of theirs which they are promised,\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmcdxviii{%
the day they shall come forth from the tombs hastily, as if they were hurrying unto a waymark,\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmcdxix{%
humbled their eyes, overspreading them abasement. That is the day which they were promised.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmcdxx{%
\basmalahen We sent Noah to his people, saying, 'Warn thy people, ere there come on them a painful chastisement.'\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxi{%
He said, 'O my people, I am unto you a clear warner,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxii{%
saying, ``Serve God, and fear Him, and obey you me,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxiii{%
and He will forgive you your sins, and defer you to a stated term; God's term, when it comes, cannot be deferred, did you but know."'\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxiv{%
He said; 'My Lord, I have called my people by night and by day,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxv{%
but my calling has only increased them in flight.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxvi{%
And whenever I called them, that Thou mightest forgive them, they put their fingers in their ears, and wrapped them in their garments, and persisted, and waxed very proud.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxvii{%
Then indeed I called them openly;\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxviii{%
then indeed I spoke publicly unto them, and I spoke unto them secretly,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxix{%
and I said, ``Ask you forgiveness of your Lord; surely He is ever All-forgiving,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxx{%
and He will loose heaven upon you in torrents\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxi{%
and will succour you with wealth and sons, and will appoint for you gardens, and will appoint for you rivers.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxii{%
What ails you, that you look not for majesty in God,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxiii{%
seeing He created you by stages?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxiv{%
Have you not regarded how God created seven heavens one upon another,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxv{%
and set the moon therein for a light and the sun for a lamp?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxvi{%
And God caused you to grow out of the earth,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxvii{%
then He shall return you into it, and bring you forth.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxviii{%
And God has laid the earth for you as a carpet,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxix{%
that thereof you may thread ways, ravines."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdxl{%
Noah said, 'My Lord, they have rebelled against me, and followed him whose wealth and children increase him only in loss,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcdxli{%
and have devised a mighty device\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlii{%
and have said, ``Do not leave your gods, and do not leave Wadd, nor Suwa', Yaghuth, Ya'uq, neither Nasr."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcdxliii{%
And they have led many astray. Increase Thou not the evildoers save in error!'\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcdxliv{%
And because of their transgressions they were drowned, and admitted into a Fire, for they found not, apart from God, any to help them.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlv{%
And Noah said, 'My Lord, leave not upon the earth of the unbelievers even one.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlvi{%
Surely, if Thou leavest them, they will lead Thy servants astray, and will beget none but unbelieving libertines.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlvii{%
My Lord, forgive me and my parents and whosoever enters my house as a believer, and the believers, men and women alike; and do Thou not increase the evildoers save in ruin!'\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlviii{%
\basmalahen Say: 'It has been revealed to me that a company of the jinn gave ear, then they said, ``We have indeed heard a Koran wonderful,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlix{%
guiding to rectitude. We believe in it, and we will not associate with our Lord anyone.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdl{%
He -- exalted be our Lord's majesty! has not taken to Himself either consort or a son.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdli{%
The fool among us spoke against God outrage,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdlii{%
and we had thought that men and jinn would never speak against God a lie.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdliii{%
But there were certain men of mankind who would take refuge with certain men of the jinn, and they increased them in vileness,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdliv{%
and they thought, even as you also thought, that God would never raise up anyone.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdlv{%
And we stretched towards heaven, but we found it filled with terrible guards and meteors.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdlvi{%
We would sit there on seats to hear; but any listening now finds a meteor in wait for him.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdlvii{%
And so we know not whether evil is intended for those in the earth, or whether their Lord intends for them rectitude.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdlviii{%
And some of us are the righteous, and some of us are otherwise; we are sects differing.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdlix{%
Indeed, we thought that we should never be able to frustrate God in the earth, neither be able to frustrate Him by flight.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdlx{%
When we heard the guidance, we believed in it; and whosoever believes in his Lord, he shall fear neither paltriness nor vileness.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxi{%
And some of us have surrendered, and some of us have deviated. Those who have surrendered sought rectitude;\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxii{%
but as for those who have deviated, they have become firewood for Gehenna!"'\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxiii{%
Would they but go straight on the way, We would give them to drink of water copious,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxiv{%
that We might try them therein. And whosoever turns away from the Remembrance of his Lord, He will thrust him into chastisement rigorous.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxv{%
The places of worship belong to God; so call not, along with God, upon anyone.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxvi{%
When the servant of God stood calling on Him, they were wellnigh upon him in swarms.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxvii{%
Say: 'I call only upon my Lord, and I do not associate with Him anyone.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxviii{%
Say: 'Surely I possess no power over you, either for hurt or for rectitude.'\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxix{%
Say: 'From God shall protect me not anyone, and I shall find, apart from Him, no refuge,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxx{%
excepting a Deliverance from God and His Messages. And whoso rebels against God and His messenger, for him there awaits the Fire of Gehenna; therein they shall dwell forever.'\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxi{%
Until, when they see that which they are promised, then they will know who is weaker in helpers and fewer in numbers.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxii{%
Say: 'I do not know whether that which you are promised is nigh, or whether my Lord will appoint for it a space;\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxiii{%
Knower He of the Unseen, and He discloses not His Unseen to anyone,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxiv{%
save only to such a Messenger as He is well-pleased with; then He despatches before him and behind him watchers,\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxv{%
that He may know they have delivered the Messages of their Lord; and He encompasses all that is with them, and He has numbered everything in numbers.'\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxvi{%
\basmalahen O thou enwrapped in thy robes,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxvii{%
keep vigil the night, except a little\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxviii{%
(a half of it, or diminish a little,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxix{%
or add a little), and chant the Koran very distinctly;\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxx{%
Behold, We shall cast upon thee a weighty word;\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxi{%
surely the first part of the night is heavier in tread, more upright in speech,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxii{%
surely in the day thou hast long business.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiii{%
And remember the Name of thy Lord, and devote thyself unto Him very devoutly.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiv{%
Lord of the East and the West; there is no god but He; so take Him for a Guardian.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxv{%
And bear thou patiently what they say, and forsake them graciously.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvi{%
Leave Me to those who cry lies, those prosperous ones, and respite them a little,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvii{%
for with Us there are fetters, and a furnace,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxviii{%
and food that chokes, and a painful chastisement,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxix{%
upon the day when the earth and the mountains shall quake and the mountains become a slipping heap of sand.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdxc{%
Surely We have sent unto you a Messenger as a witness over you, even as We sent to Pharaoh a Messenger,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdxci{%
but Pharaoh rebelled against the Messenger, so We seized him remorselessly.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcii{%
If therefore you disbelieve, how will you guard yourselves against a day that shall make the children grey-headed?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdxciii{%
Whereby heaven shall be split, and its promise shall be performed.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdxciv{%
Surely this is a Reminder; so let him who will take unto his Lord a way.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcv{%
Thy Lord knows that thou keepest vigil nearly two-thirds of the night, or a half of it, or a third of it, and a party of those with thee; and God determines the night and the day. He knows that you will not number it, and He has turned towards you. Therefore recite of the Koran so much as is feasible. He knows that some of you are sick, and others journeying in the land, seeking the bounty of God, and others fighting in the way of God. So recite of it so much as is feasible. And perform the prayer, and pay the alms, and lend to God a good loan. Whatever good you shall forward to your souls' account, you shall find it with God as better, and mightier a wage. And ask God's forgiveness; God is All-forgiving, All-compassionate.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcvi{%
\basmalahen O thou shrouded in thy mantle,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcvii{%
arise, and warn!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcviii{%
Thy Lord magnify\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcix{%
thy robes purify\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmd{%
and defilement flee!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdi{%
Give not, thinking to gain greater\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdii{%
and be patient unto thy Lord.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdiii{%
For when the Trump is sounded\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdiv{%
that day will be a harsh day,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdv{%
for the unbelievers not easy.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdvi{%
Leave Me with him whom I created alone,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdvii{%
and appointed for him ample wealth\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdviii{%
and sons standing before him,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdix{%
and made all things smooth for him;\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdx{%
then he is eager that I should do more.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdxi{%
Nay! He is forward unto Our signs;\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdxii{%
and I shall constrain him to a hard ascent.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdxiii{%
Lo! He reflected, and determined --\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdxiv{%
death seize him, how he determined!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdxv{%
Again, death seize him, how he determined!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdxvi{%
Then he beheld,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdxvii{%
then he frowned, and scowled,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdxviii{%
then he retreated, and waxed proud.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdxix{%
He said, 'This is naught but a trumped-up sorcery;\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdxx{%
'this is nothing but mortal speech.'\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdxxi{%
I shall surely roast him in Sakar;\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdxxii{%
and what will teach thee what is Sakar?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdxxiii{%
It spares not, neither leaves alone\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdxxiv{%
scorching the flesh;\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdxxv{%
over it are nineteen.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdxxvi{%
We have appointed only angels to be masters of the Fire, and their number We have appointed only as a trial for the unbelievers, that those who were given the Book may have certainty, and that those who believe may increase in belief, and that those who were given the Book and those who believe may not be in-doubt, and that those in whose hearts there is sickness, and the unbelievers, may say, 'What did God intend by this as a similitude?' So God leads astray whomsoever He will, and He guides whomsoever He will; and none knows the hosts of thy Lord but He. And it is naught but a Reminder to mortals.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdxxvii{%
Nay! By the moon\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdxxviii{%
and the night when it retreats\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdxxix{%
and the dawn when it is white,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdxxx{%
surely it is one of the greatest things\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxi{%
as a warner to mortals.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxii{%
to whoever of you desires to go forward or lag behind.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxiii{%
Every soul shall be pledged for what it has earned,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxiv{%
save the Companions of the Right;\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxv{%
in Gardens they will question\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxvi{%
concerning the sinners,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxvii{%
'What thrusted you into Sakar?'\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxviii{%
They shall say, 'We were not of those who prayed, and\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxix{%
we fed not the needy,\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdxl{%
and we plunged along with the plungers,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdxli{%
and we cried lies to the Day of Doom,\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdxlii{%
till the Certain came to us.' --\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmdxliii{%
Then the intercession of the intercessors shall not profit them.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmdxliv{%
What ails them, that they turn away from the Reminder,\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmdxlv{%
as if they were startled asses\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmdxlvi{%
fleeing -- before a lion?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmdxlvii{%
Nay, every man of them desires to be -- given -- scrolls unrolled.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmdxlviii{%
No indeed; but they do not fear the Hereafter.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmmdxlix{%
No indeed; surely it is a Reminder;\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmmdl{%
so whoever wills shall remember it.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmmdli{%
And they will not remember, except that God wills; He is worthy to be feared, -- worthy to forgive.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmmdlii{%
\basmalahen No! I swear by the Day of Resurrection.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdliii{%
No! I swear by the reproachful soul.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdliv{%
What, does man reckon We shall not gather his bones?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdlv{%
Yes indeed; We are able to shape again his fingers.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdlvi{%
Nay, but man desires to continue on as a libertine,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdlvii{%
asking, 'When shall be the Day of Resurrection?'\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdlviii{%
But when the sight is dazed\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdlix{%
and the moon is eclipsed,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdlx{%
and the sun and moon are brought together,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdlxi{%
upon that day man shall say, 'Whither to flee?'\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdlxii{%
No indeed; not a refuge!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdlxiii{%
Upon that day the recourse shall be to thy Lord.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdlxiv{%
Upon that day man shall be told his former deeds and his latter;\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdlxv{%
nay, man shall be a clear proof against himself,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdlxvi{%
even though he offer his excuses.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdlxvii{%
Move not thy tongue with it to hasten it;\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdlxviii{%
Ours it is to gather it, and to recite it.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdlxix{%
So, when We recite it, follow thou its recitation.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdlxx{%
Then Ours it is to explain it.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxi{%
No indeed; but you love the hasty world,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxii{%
and leave be the Hereafter.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxiii{%
Upon that day faces shall be radiant,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxiv{%
gazing upon their Lord;\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxv{%
and upon that day faces shall be scowling,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxvi{%
thou mightest think the Calamity has been wreaked on them.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxvii{%
No indeed; when it reaches the clavicles\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxviii{%
and it is said, 'Who is an enchanter?'\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxix{%
and he thinks that it is the parting\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxx{%
and leg is intertwined with leg,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxi{%
upon that day unto thy Lord shall be the driving.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxii{%
For he confirmed it not, and did not pray,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxiii{%
but he cried it lies, and he turned away,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxiv{%
then he went to his household arrogantly.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxv{%
Nearer to thee and nearer\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxvi{%
then nearer to thee and nearer!\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxvii{%
What, does man reckon he shall be left to roam at will?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxviii{%
Was he not a sperm-drop spilled?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxix{%
Then he was a blood-clot, and He created and formed,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdxc{%
and He made of him two kinds, male and female.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdxci{%
What, is He not able to quicken the dead?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdxcii{%
\basmalahen Has there come on man a while of time when he was a thing unremembered?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdxciii{%
We created man of a sperm-drop, a mingling, and We made him hearing, seeing.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdxciv{%
Surely We guided him upon the way whether he be thankful or unthankful.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdxcv{%
Surely We have prepared for the unbelievers chains, fetters, and a Blaze.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdxcvi{%
Surely the pious shall drink of a cup whose mixture is camphor,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdxcvii{%
a fountain whereat drink the servants of God, making it to gush forth plenteously.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdxcviii{%
They fulfil their vows, and fear a day whose evil is upon the wing;\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdxcix{%
they give food, for the love of Him, to the needy, the orphan, the captive:\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdc{%
'We feed you only for the Face of God; we desire no recompense from you, no thankfulness;\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdci{%
for we fear from our Lord a frowning day, inauspicious.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcii{%
So God has guarded them from the evil of that day, and has procured them radiancy and gladness,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdciii{%
and recompensed them for their patience with a Garden, and silk;\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdciv{%
therein they shall recline upon couches, therein they shall see neither sun nor bitter cold;\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcv{%
near them shall be its shades, and its clusters hung meekly down,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcvi{%
and there shall be passed around them vessels of silver, and goblets of crystal,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcvii{%
crystal of silver that they have measured -- very exactly.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcviii{%
And therein they shall be given to drink a cup whose mixture is ginger,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcix{%
therein a fountain whose name is called Salsabil.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcx{%
Immortal youths shall go about them; when thou seest them, thou supposest them scattered pearls,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxi{%
when thou seest them then thou seest bliss and a great kingdom.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxii{%
Upon them shall be green garments of silk and brocade; they are adorned with bracelets of silver, and their Lord shall give them to drink a pure draught.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxiii{%
Behold, this is a recompense for you, and your striving is thanked.'\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxiv{%
Surely We have sent down the Koran on thee, a sending down;\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxv{%
so be thou patient under the judgment of thy Lord, and obey not one of them, sinner or unbeliever.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxvi{%
And remember the Name of thy Lord at dawn and in the evening\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxvii{%
and part of the night; bow down before Him and magnify Him through the long night.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxviii{%
Surely these men love the hasty world, and leave be behind them a heavy day.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcxix{%
We created them, and We strengthened their joints; and, when We will, We shall exchange their likes.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcxx{%
Surely this is a Reminder; so he who will, takes unto his Lord a way.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxi{%
But you will not unless God wills; surely God is ever All-knowing, All-wise.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxii{%
For He admits into His mercy whomsoever He will; as for the evildoers, He has prepared for them a painful chastisement.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxiii{%
\basmalahen By the loosed ones successively\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxiv{%
storming tempestuously\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxv{%
by the scatterers scattering\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxvi{%
and the severally severing\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxvii{%
and those hurling a reminder\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxviii{%
excusing or warning,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxix{%
surely that which you are promised is about to fall!\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxx{%
When the stars shall be extinguished,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxi{%
when heaven shall be split\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxii{%
when the mountains shall be scattered\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxiii{%
and when the Messengers' time is set,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxiv{%
to what day shall they be delayed?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxv{%
To the Day of Decision.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxvi{%
And what shall teach thee what is the Day of Decision?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxvii{%
Woe that day unto those who cry it lies!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxviii{%
Did We not destroy the ancients,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxix{%
and then follow them with the later folk?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcxl{%
So We serve the sinners.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcxli{%
Woe that day unto those who cry it lies!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlii{%
Did We not create you of a mean water,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxliii{%
that We laid within a sure lodging\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxliv{%
till a known term decreed?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlv{%
We determined; excellent determiners are We.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlvi{%
Woe that day unto those who cry it lies!\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlvii{%
Made We not the earth to be a housing\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlviii{%
for the living and for the dead?\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlix{%
Set We not therein soaring mountains? Sated you with sweetest water?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcl{%
Woe that day unto those who cry it lies!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcli{%
Depart to that you cried was lies!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdclii{%
Depart to a triple-massing shadow\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcliii{%
unshading against the blazing flame\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcliv{%
that shoots sparks like dry faggots,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdclv{%
sparks like to golden herds.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdclvi{%
Woe that day unto those who cry it lies!\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdclvii{%
This is the day they shall not speak\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdclviii{%
neither be given leave, and excuse themselves.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdclix{%
Woe that day unto those who cry it lies!\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdclx{%
'This is the Day of Decision; We have joined you with the ancients;\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdclxi{%
if you have a trick, try you now to trick Me!'\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdclxii{%
Woe that day unto those who cry it lies!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdclxiii{%
Truly the godfearing shall dwell amid shades and fountains,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdclxiv{%
and such fruits as their hearts desire:\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdclxv{%
'Eat and drink, with wholesome appetite, for that you were working.'\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdclxvi{%
Even so do We recompense the good-doers.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdclxvii{%
Woe that day unto those who cry it lies!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdclxviii{%
'Eat and take your joy a little; you are sinners!'\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdclxix{%
Woe that day unto those who cry it lies!\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmdclxx{%
When it is said to them, 'Prostrate yourselves!' they prostrate not.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxi{%
Woe that day unto those who cry it lies!\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxii{%
In what discourse after this will they believe?\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxiii{%
\basmalahen Of what do they question one another?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxiv{%
Of the mighty tiding\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxv{%
whereon they are at variance.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxvi{%
No indeed; they shall soon know!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxvii{%
Again, no indeed; they shall soon know!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxviii{%
Have We not made the earth as a cradle\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxix{%
and the mountains as pegs?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxx{%
And We created you in pairs,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxi{%
and We appointed your sleep for a rest;\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxii{%
and We appointed night for a garment,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxiii{%
and We appointed day for a livelihood.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxiv{%
And We have built above you seven strong ones,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxv{%
and We appointed a blazing lamp\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxvi{%
and have sent down out of the rainclouds water cascading\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxvii{%
that We may bring forth thereby grain and plants,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxviii{%
and gardens luxuriant.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxix{%
Surely the Day of Decision is an appointed time,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcxc{%
the day the Trumpet is blown, and you shall come in troops,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcxci{%
and heaven is opened, and become gates,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcii{%
and the mountains are set in motion, and become a vapour.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxciii{%
Behold, Gehenna has become an ambush,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxciv{%
for the insolent a resort,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcv{%
therein to tarry for ages,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcvi{%
tasting therein neither coolness nor any drink\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcvii{%
save boiling water and pus\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcviii{%
for a suitable recompense.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcix{%
They indeed hoped not for a reckoning,\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcc{%
and they cried loud lies to Our signs;\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcci{%
and everything We have numbered in a Book.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccii{%
'Taste! We shall increase you not save in chastisement.'\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcciii{%
Surely for the godfearing awaits a place of security,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcciv{%
gardens and vineyards\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccv{%
and maidens with swelling breasts, like of age,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccvi{%
and a cup overflowing.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccvii{%
Therein they shall hear no idle talk, no cry of lies,\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccviii{%
for a recompense from thy Lord, a gift, a reckoning,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccix{%
Lord of the heavens and earth, and all that between them is, the All-merciful of whom they have no power to speak.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccx{%
Upon the day when the Spirit and the angels stand in ranks they shall speak not, save him to whom the All-merciful has given leave, and who speaks aright.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccxi{%
That is the true day; so whosoever wills takes unto his Lord a resort.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdccxii{%
Lo, We have warned you of a nigh chastisement, upon the day when a man shall behold what his hands have forwarded, and the unbeliever shall say, 'O would that I were dust!'\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccxiii{%
\basmalahen By those that pluck out vehemently\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdccxiv{%
and those that draw out violently,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccxv{%
by those that swim serenely\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccxvi{%
and those that outstrip suddenly\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdccxvii{%
by those that direct an affair!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdccxviii{%
Upon the day when the first blast shivers\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdccxix{%
and the second blast follows it,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdccxx{%
hearts upon that day shall be athrob\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxi{%
and their eyes shall be humbled.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxii{%
They shall say, 'What, are we being restored as we were before?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxiii{%
What, when we are bones old and wasted?'\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxiv{%
They shall say, 'That then were a losing return!'\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxv{%
But it shall be only a single scare,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxvi{%
and behold, they are awakened.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxvii{%
Hast thou received the story of Moses?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxviii{%
When his Lord called to him in the holy valley, Towa:\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxix{%
'Go to Pharaoh; he has waxed insolent.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxx{%
And say, ``Hast thou the will to purify thyself;\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxi{%
and that I should guide thee to thy Lord, then thou shalt fear?"'\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxii{%
So he showed him the great sign,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxiii{%
but he cried lies, and rebelled,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxiv{%
then he turned away hastily,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxv{%
then he mustered\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxvi{%
and proclaimed, and he said, 'I am your Lord, the Most High!'\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxvii{%
So God seized him with the chastisement of the Last World and the First.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxviii{%
Surely in that is a lesson for him who fears!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxix{%
What, are you stronger in constitution or the heaven He built?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdccxl{%
He lifted up its vault, and levelled it,\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdccxli{%
and darkened its night, and brought forth its forenoon;\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlii{%
and the earth-after that He spread it out,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdccxliii{%
therefrom brought forth its waters and its pastures,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccxliv{%
and the mountains He set firm,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlv{%
an enjoyment for you and your flocks.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlvi{%
Then, when the Great Catastrophe comes\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlvii{%
upon the day when man shall remember what he has striven,\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlviii{%
and Hell is advanced for whoever sees,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlix{%
then as for him who was insolent\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccl{%
and preferred the present life,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccli{%
surely Hell shall be the refuge.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdcclii{%
But as for him who feared the Station of his Lord and forbade the soul its caprice,\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccliii{%
surely Paradise shall be the refuge.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdccliv{%
They will question thee concerning the Hour, when it shall berth.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdcclv{%
What art thou about, to mention it?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdcclvi{%
Unto thy Lord is the final end of it.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdcclvii{%
Thou art only the warner of him who fears it.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdcclviii{%
It shall be as if; on the day they see it, they have but tarried for an evening, or its forenoon.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdcclix{%
\basmalahen He frowned and turned away\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcclx{%
that the blind man came to him.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxi{%
And what should teach thee? Perchance he would cleanse him,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxii{%
or yet remember, and the Reminder profit him.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxiii{%
But the self-sufficient,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxiv{%
to him thou attendest\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxv{%
though it is not thy concern, if he does not cleanse himself.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxvi{%
And he who comes to thee eagerly\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxvii{%
and fearfully,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxviii{%
to him thou payest no heed.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxix{%
No indeed; it is a Reminder\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxx{%
(and whoso wills, shall remember it)\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxi{%
upon pages high-honoured,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxii{%
uplifted, purified,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxiii{%
by the hands of scribes\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxiv{%
noble, pious.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxv{%
Perish Man! How unthankful he is!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxvi{%
Of what did He create him?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxvii{%
Of a sperm-drop He created him, and determined him,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxviii{%
then the way eased for him,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxix{%
then makes him to die, and buries him,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxx{%
then, when He wills, He raises him.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxi{%
No indeed! Man has not accomplished His bidding.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxii{%
Let Man consider his nourishment.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiii{%
We poured out the rains abundantly,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiv{%
then We split the earth in fissures\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxv{%
and therein made the grains to grow\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvi{%
and vines, and reeds,\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvii{%
and olives, and palms,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxviii{%
and dense-tree'd gardens,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxix{%
and fruits, and pastures,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccxc{%
an enjoyment for you and your flocks.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccxci{%
And when the Blast shall sound,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcii{%
upon the day when a man shall flee from his brother,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccxciii{%
his mother, his father,\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccxciv{%
his consort, his sons,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcv{%
every man that day shall have business to suffice him.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcvi{%
Some faces on that day shall shine\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcvii{%
laughing, joyous;\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcviii{%
some faces on that day shall be dusty\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcix{%
o'erspread with darkness --\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdccc{%
those -- they are the unbelievers, the libertines.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdccci{%
\basmalahen When the sun shall be darkened,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccii{%
when the stars shall be thrown down,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccciii{%
when the mountains shall be set moving,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccciv{%
when the pregnant camels shall be neglected,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccv{%
when the savage beasts shall be mustered,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccvi{%
when the seas shall be set boiling,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccvii{%
when the souls shall be coupled,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccviii{%
when the buried infant shall be asked\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccix{%
for what sin she was slain,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccx{%
when the scrolls shall be unrolled,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxi{%
when heaven shall be stripped off;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxii{%
when Hell shall be set blazing,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxiii{%
when Paradise shall be brought nigh,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxiv{%
then shall a soul know what it has produced.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxv{%
No! I swear by the slinkers,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxvi{%
the runners, the sinkers,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxvii{%
by the night swarming,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxviii{%
by the dawn sighing,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxix{%
truly this is the word of a noble Messenger\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxx{%
having power, with the Lord of the Throne secure,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxi{%
obeyed, moreover trusty.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxii{%
Your companion is not possessed;\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxiii{%
he truly saw him on the clear horizon;\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxiv{%
he is not niggardly of the Unseen.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxv{%
And it is not the word of an accursed Satan;\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxvi{%
where then are you going?\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxvii{%
It is naught but a Reminder unto all beings,\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxviii{%
for whosoever of you who would go straight;\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxix{%
but will you shall not, unless God wills, the Lord of all Being.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxx{%
\basmalahen When heaven is split open,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxi{%
when the stars are scattered,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxii{%
when the seas swarm over,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiii{%
when the tombs are overthrown,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiv{%
then a soul shall know its works, the former and the latter.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxv{%
O Man! What deceived thee as to thy generous Lord\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvi{%
who created thee and shaped thee and wrought thee in symmetry\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvii{%
and composed thee after what form He would?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxviii{%
No indeed; but you cry lies to the Doom;\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxix{%
yet there are over you watchers\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxl{%
noble, writers\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxli{%
who know whatever you do.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlii{%
Surely the pious shall be in bliss,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxliii{%
and the libertines shall be in a fiery furnace\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxliv{%
roasting therein on the Day of Doom,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlv{%
nor shall they ever be absent from it.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlvi{%
And what shall teach thee what is the Day of Doom?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlvii{%
Again, what shall teach thee what is the Day of Doom?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlviii{%
A day when no soul shall possess aught to succour another soul; that day the Command shall belong unto God.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlix{%
\basmalahen Woe to the stinters who,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccl{%
when they measure against the people, take full measure\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcccli{%
but, when they measure for them or weigh for them, do skimp.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccclii{%
Do those not think that they shall be raised up\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccliii{%
unto a mighty day\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccliv{%
a day when mankind shall stand before the Lord of all Being?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdccclv{%
No indeed; the Book of the libertines is in Sijjin;\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdccclvi{%
and what shall teach thee what is Sijjin?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdccclvii{%
A book inscribed.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdccclviii{%
Woe that day unto those who cry it lies,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdccclix{%
who cry lies to the Day of Doom;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdccclx{%
and none cries lies to it but every guilty aggressor.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxi{%
When our signs are recited to him, he says, 'Fairy-tales of the ancients!'\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxii{%
No indeed; but that they were earning has rusted upon their hearts.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxiii{%
No indeed; but upon that day they shall be veiled from their Lord,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxiv{%
then they shall roast in Hell.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxv{%
Then it shall be said to them, 'This is that you cried lies to.'\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxvi{%
No indeed; the book of the pious is in Illiyun;\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxvii{%
and what shall teach thee what is Illiyun?\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxviii{%
A book inscribed,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxix{%
witnessed by those brought nigh.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxx{%
Surely the pious shall be in bliss,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxi{%
upon couches gazing;\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxii{%
thou knowest in their faces the radiancy of bliss\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxiii{%
as they are given to drink of a wine sealed\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxiv{%
whose seal is musk -- so after that let the strivers strive --\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxv{%
and whose mixture is Tasnim,\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxvi{%
a fountain at which do drink those brought nigh.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxvii{%
Behold, the sinners were laughing at the believers,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxviii{%
when them passed them by winking at one another,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxix{%
and when they returned to their people they returned blithely,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxx{%
and when they saw them they said, 'Lo, these men are astray!'\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxi{%
Yet they were not sent as watchers over them.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxii{%
So today the believers are laughing at the unbelievers,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiii{%
upon couches gazing.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiv{%
Have the unbelievers been rewarded what they were doing?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxv{%
\basmalahen When heaven is rent asunder\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvi{%
and gives ear to its Lord, and is fitly disposed;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvii{%
when earth is stretched out\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxviii{%
and casts forth what is in it, and voids itself,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxix{%
and gives ear to its Lord, and is fitly disposed!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxc{%
O Man! Thou art labouring unto thy Lord laboriously, and thou shalt encounter Him.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxci{%
Then as for him who is given his book in his right hand,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcii{%
he shall surely receive an easy reckoning\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxciii{%
and he will return to his family joyfully.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxciv{%
But as for him who is given his book behind his back,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcv{%
he shall call for destruction\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcvi{%
and he shall roast at a Blaze.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcvii{%
He once lived among his family joyfully;\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcviii{%
he surely thought he would never revert.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcix{%
Yes indeed; his Lord had sight of him.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcm{%
No! I swear by the twilight\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmi{%
and the night and what it envelops\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmii{%
and the moon when it is at the full,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmiii{%
you shall surely ride stage after stage.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmiv{%
Then what ails them, that they believe not,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmv{%
and when the Koran is recited to them they do not bow?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmvi{%
Nay, but the unbelievers are crying lies,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmvii{%
and God knows very well what they are secreting.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcmviii{%
So give them good tidings of a painful chastisement,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcmix{%
except those that believe, and do righteous deeds -- theirs shall be a wage unfailing.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcmx{%
\basmalahen By heaven of the constellations,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxi{%
by the promised day,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxii{%
by the witness and the witnessed,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxiii{%
slain were the Men of the Pit,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxiv{%
the fire abounding in fuel,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxv{%
when they were seated over it\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmxvi{%
and were themselves witnesses of what they did with the believers.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmxvii{%
They took revenge on them only because they believed in the All-mighty, the Al-laudable,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmxviii{%
God to whom belongs the Kingdom of the heavens and the earth, and God is Witness over everything.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmxix{%
Those who persecute the believers, men and women, and then have not repented, there awaits them the chastisement of Gehenna, and there awaits them the chastisement of the burning.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmxx{%
Those who believe, and do righteous deeds, for them await gardens underneath which rivers flow; that is the great triumph.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxi{%
Surely thy Lord's assault is terrible.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxii{%
Surely it is He who originates, and brings again,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxiii{%
and He is the All-forgiving, the All-loving,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxiv{%
Lord of the Throne, the All-glorious,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxv{%
Performer of what He desires.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxvi{%
Hast thou received the story of the hosts,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxvii{%
Pharaoh and Thamood?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxviii{%
Nay, but the unbelievers still cry lies,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxix{%
and God is behind them, encompassing.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxx{%
Nay, but it is a glorious Koran,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxi{%
in a guarded tablet.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxii{%
\basmalahen By heaven and the night-star!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxiii{%
And what shall teach thee what is the night-star?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxiv{%
The piercing star!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxv{%
Over every soul there is a watcher.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxvi{%
So let man consider of what he was created;\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxvii{%
he was created of gushing water\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxviii{%
issuing between the loins and the breast-bones.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxix{%
Surely He is able to bring him back\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmxl{%
upon the day when the secrets are tried,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmxli{%
and he shall have no strength, no helper.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlii{%
By heaven of the returning rain,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmxliii{%
by earth splitting with verdure,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmxliv{%
surely it is a decisive word;\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlv{%
it is no merriment.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlvi{%
They are devising guile,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlvii{%
and I am devising guile.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlviii{%
So respite the unbelievers; delay with them awhile.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlix{%
\basmalahen Magnify the Name of thy Lord the Most High\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcml{%
who created and shaped,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmli{%
who determined and guided,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmlii{%
who brought forth the pasturage\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmliii{%
then made it a blackening wrack.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmliv{%
We shall make thee recite, to forget not\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmlv{%
save what God wills; surely He knows what is spoken aloud and what is hidden.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmlvi{%
We shall ease thee unto the Easing.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmlvii{%
Therefore remind, if the Reminder profits,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmlviii{%
and he who fears shall remember,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmlix{%
but the most wretched shall flout it,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmlx{%
even he who shall roast in the Great Fire,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxi{%
then he shall neither die therein, nor live.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxii{%
Prosperous is he who has cleansed himself,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxiii{%
and mentions the Name of his Lord, and prays.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxiv{%
Nay, but you prefer the present life;\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxv{%
and the world to come is better, and more enduring.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxvi{%
Surely this is in the ancient scrolls,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxvii{%
the scrolls of Abraham and Moses.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxviii{%
\basmalahen Hast thou received the story of the Enveloper?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxix{%
Faces on that day humbled,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxx{%
labouring, toilworn,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxi{%
roasting at a scorching fire,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxii{%
watered at a boiling fountain,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxiii{%
no food for them but cactus thorn\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxiv{%
unfattening, unappeasing hunger.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxv{%
Faces on that day jocund,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxvi{%
with their striving well-pleased,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxvii{%
in a sublime Garden,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxviii{%
hearing there no babble;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxix{%
therein a running fountain,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxx{%
therein uplifted couches\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxi{%
and goblets set forth\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxii{%
and cushions arrayed\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiii{%
and carpets outspread.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiv{%
What, do they not consider how the camel was created,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxv{%
how heaven was lifted up,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvi{%
how the mountains were hoisted,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvii{%
how the earth was outstretched?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxviii{%
Then remind them! Thou art only a reminder;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxix{%
thou art not charged to oversee them.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmxc{%
But he who turns his back, and disbelieves,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcmxci{%
God shall chastise him with the greatest chastisement.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcii{%
Truly, to Us is their return;\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcmxciii{%
then upon Us shall rest their reckoning.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcmxciv{%
\basmalahen By the dawn\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcv{%
and ten nights,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcvi{%
by the even and the odd,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcvii{%
by the night when it journeys on!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcviii{%
Is there in that an oath for a mindful man?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcix{%
Hast thou not seen how thy Lord did with Ad,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmm{%
Iram of the pillars,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmi{%
the like of which was never created in the land,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmii{%
and Thamood, who hollowed the rocks in the valley,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmiii{%
and Pharaoh, he of the tent-pegs,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmiv{%
who all were insolent in the land\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmv{%
and worked much corruption therein?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmvi{%
Thy Lord unloosed on them a scourge of chastisement;\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmvii{%
surely thy Lord is ever on the watch.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmviii{%
As for man, whenever his Lord tries him, and honours him, and blesses him, then he says, 'My Lord has honoured me.'\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmix{%
But when he tries him and stints for him his provision, then he says, 'My Lord has despised me.'\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmx{%
No indeed; but you honour not the orphan,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmxi{%
and you urge not the feeding of the needy,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmxii{%
and you devour the inheritance greedily,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmxiii{%
and you love wealth with an ardent love\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmxiv{%
No indeed! When the earth is ground to powder,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmmxv{%
and thy Lord comes, and the angels rank on rank,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmmxvi{%
and Gehenna is brought out, upon that day man will remember; and how shall the Reminder be for him?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmmxvii{%
He shall say, 'O would that I had forwarded for my life!'\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmmxviii{%
Upon that day none shall chastise as He chastises,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmmxix{%
none shall bind as He binds.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmmxx{%
'O soul at peace,\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmmxxi{%
return unto thy Lord, well-pleased, well-pleasing!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmmxxii{%
Enter thou among My servants!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmmxxiii{%
Enter thou My Paradise!'\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmmxxiv{%
\basmalahen No! I swear by this land,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxxv{%
and thou art a lodger in this land;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxxvi{%
by the begetter, and that he begot,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxxvii{%
indeed, We created man in trouble.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxxviii{%
What, does he think none has power over him,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxxix{%
saying, 'I have consumed wealth abundant'?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmxxx{%
What, does he think none has seen him?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxi{%
Have We not appointed to him two eyes,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxii{%
and a tongue, and two lips,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxiii{%
and guided him on the two highways?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxiv{%
Yet he has not assaulted the steep;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxv{%
and what shall teach thee what is the steep?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxvi{%
The freeing of a slave,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxvii{%
or giving food upon a day of hunger\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxviii{%
to an orphan near of kin\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxix{%
or a needy man in misery;\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmxl{%
then that he become of those who believe and counsel each other to be steadfast, and counsel each other to be merciful.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmxli{%
Those are the Companions of the Right Hand.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmxlii{%
And those who disbelieve in Our signs, they are the Companions of the Left Hand;\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmxliii{%
over them is a Fire covered down.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmxliv{%
\basmalahen By the sun and his morning brightness\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxlv{%
and by the moon when she follows him,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxlvi{%
and by the day when it displays him\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxlvii{%
and by the night when it enshrouds him!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxlviii{%
By the heaven and That which built it\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxlix{%
and by the earth and That which extended it!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmml{%
By the soul, and That which shaped it\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmli{%
and inspired it to lewdness and godfearing!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlii{%
Prosperous is he who purifies it,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmliii{%
and failed has he who seduces it.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmliv{%
Thamood cried lies in their insolence\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmlv{%
when the most wretched of them uprose,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmlvi{%
then the Messenger of God said to them, 'The She-camel of God; let her drink!'\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmlvii{%
But they cried him lies, and hamstrung her, so their Lord crushed them for their sin, and leveled them:\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmlviii{%
and He fears not the issue thereof.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmlix{%
\basmalahen By the night enshrouding\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmlx{%
and the day in splendour\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmlxi{%
and That which created the male and the female,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmlxii{%
surely your striving is to diverse ends.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmlxiii{%
As for him who gives and is godfearing\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmlxiv{%
and confirms the reward most fair,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmlxv{%
We shall surely ease him to the Easing.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmlxvi{%
But as for him who is a miser, and self-sufficient,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlxvii{%
and cries lies to the reward most fair,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmlxviii{%
We shall surely ease him to the Hardship;\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmlxix{%
his wealth shall not avail him when he perishes.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmlxx{%
Surely upon Us rests the guidance,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxi{%
and to Us belong the Last and the First.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxii{%
Now I have warned you of a Fire that flames,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxiii{%
whereat none but the most wretched shall be roasted,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxiv{%
even he who cried lies, and turned away;\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxv{%
and from which the most godfearing shall be removed,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxvi{%
even he who gives his wealth. to purify himself\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxvii{%
and confers no favour on any man for recompense,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxviii{%
only seeking the Face of his Lord the Most High;\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxix{%
and he shall surely be satisfied.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxx{%
\basmalahen By the white forenoon\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxi{%
and the brooding night!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxii{%
Thy Lord has neither forsaken thee nor hates thee\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxiii{%
and the Last shall be better for thee than the First.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxiv{%
Thy Lord shall give thee, and thou shalt be satisfied.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxv{%
Did He not find thee an orphan, and shelter thee?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxvi{%
Did He not find thee erring, and guide thee?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxvii{%
Did He not find thee needy, and suffice thee?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxviii{%
As for the orphan, do not oppress him,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxix{%
and as for the beggar, scold him not;\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmxc{%
and as for thy Lord's blessing, declare it.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmxci{%
\basmalahen Did We not expand thy breast for thee\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxcii{%
and lift from thee thy burden,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxciii{%
the burden that weighed down thy back?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxciv{%
Did We not exalt thy fame?\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxcv{%
So truly with hardship comes ease,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxcvi{%
truly with hardship comes ease.'\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmxcvii{%
So when thou art empty, labour,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmxcviii{%
and let thy Lord be thy Quest.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmxcix{%
\basmalahen By the fig and the olive\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmc{%
and the Mount Sinai\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmci{%
and this land secure!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcii{%
We indeed created Man in the fairest stature\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmciii{%
then We restored him the lowest of the low --\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmciv{%
save those who believe, and do righteous deeds; they shall have a wage unfailing.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcv{%
What then shall cry thee lies as to the Doom?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcvi{%
Is not God the justest of judges?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcvii{%
\basmalahen Recite: In the Name of thy Lord who created,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcviii{%
created Man of a blood-clot.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcix{%
Recite: And thy Lord is the Most Generous,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcx{%
who taught by the Pen,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxi{%
taught Man that he knew not.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxii{%
No indeed; surely Man waxes insolent,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxiii{%
for he thinks himself self-sufficient.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxiv{%
Surely unto thy Lord is the Returning.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxv{%
What thinkest thou? He who forbids\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmcxvi{%
a servant when he prays --\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmcxvii{%
What thinkest thou? If he were upon guidance\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmcxviii{%
or bade to godfearing --\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmcxix{%
What thinkest thou? If he cries lies, and turns away -\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmcxx{%
Did he not know that God sees?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxi{%
No indeed; surely, if he gives not over, We shall seize him by the forelock,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxii{%
a lying, sinful forelock.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxiii{%
So let him call on his concourse!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxiv{%
We shall call on the guards of Hell.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxv{%
No indeed; do thou not obey him, and bow thyself, and draw nigh.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxvi{%
\basmalahen Behold, We sent it down on the Night of Power;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxvii{%
And what shall teach thee what is the Night of Power?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxviii{%
The Night of Power is better than a thousand months;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxix{%
in it the angels and the Spirit descend, by the leave of their Lord, upon every command.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxx{%
Peace it is, till the rising of dawn.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxi{%
\basmalahen The unbelievers of the People of the Book and the idolaters would never leave off; till the Clear Sign came to them,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxii{%
a Messenger from God, reciting pages purified,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxiii{%
therein true Books.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxiv{%
And they scattered not, those that were given the Book, excepting after the Clear Sign came to them.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxv{%
They were commanded only to serve God, making the religion His sincerely, men of pure faith, and to perform the prayer, and pay the alms -- that is the religion of the True.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxvi{%
The unbelievers of the People of the Book and the idolaters shall be in the Fire of Gehenna, therein dwelling forever; those are the worst of creatures.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxvii{%
But those who believe, and do righteous deeds, those are the best of creatures;\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxviii{%
their recompense is with their Lord-Gardens of Eden, underneath which rivers flow, therein dwelling for ever and ever. God is well-pleased with them, and they are well-pleased with Him; that is for him who fears his Lord.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxix{%
\basmalahen When earth is shaken with a mighty shaking\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxl{%
and earth brings forth her burdens,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxli{%
and Man says., 'What ails her?'\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlii{%
upon that day she shall tell her tidings\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxliii{%
for that her Lord has inspired her.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxliv{%
Upon that day men shall issue in scatterings to see their works,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlv{%
and whoso has done an atom's weight of good shall see it,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlvi{%
and whoso has done an atom's weight of evil shall see it.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlvii{%
\basmalahen By the snorting chargers,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlviii{%
by the strikers of fire,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlix{%
by the dawn-raiders\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcl{%
blazing a trail of dust,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcli{%
cleaving there with a host!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclii{%
Surely Man is ungrateful to his Lord,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcliii{%
and surely he is a witness against that!\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcliv{%
Surely he is passionate in his love for good things.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclv{%
Knows he not that when that which is in the tombs is over-thrown,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclvi{%
and that which is in the breasts is brought out --\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmclvii{%
surely on that day their Lord shall be aware of them!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmclviii{%
\basmalahen The Clatterer!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclix{%
What is the Clatterer?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclx{%
And what shall teach thee what is the Clatterer?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxi{%
The day that men shall be like scattered moths,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxii{%
and the mountains shall be like plucked wool-tufts.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxiii{%
Then he whose deeds weigh heavy in the Balance\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxiv{%
shall inherit a pleasing life,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxv{%
but he whose deeds weigh light in the Balance\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxvi{%
shall plunge in the womb of the Pit.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclxvii{%
And what shall teach thee what is the Pit?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmclxviii{%
A blazing Fire!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmclxix{%
\basmalahen Gross rivalry diverts you,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxx{%
even till you visit the tombs.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxi{%
No indeed; but soon you shall know.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxii{%
Again, no indeed; but soon you shall know.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxiii{%
No indeed; did you know with the knowledge of certainty,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxiv{%
you shall surely see Hell;\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxv{%
Again, you shall surely see it with the eye of certainty\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxvi{%
then you shall be questioned that day concerning true bliss.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxvii{%
\basmalahen By the afternoon!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxviii{%
Surely Man is in the way of loss,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxix{%
save those who believe, and do righteous deeds, and counsel each other unto the truth, and counsel each other to be steadfast.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxx{%
\basmalahen Woe unto every backbiter, slanderer,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxi{%
who has gathered riches and counted them over\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxii{%
thinking his riches have made him immortal!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxiii{%
No indeed; he shall be thrust into the Crusher;\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxiv{%
and what shall teach thee what is the Crusher;\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxv{%
The Fire of God kindled\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxvi{%
roaring over the hearts\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxvii{%
covered down upon them,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxviii{%
in columns outstretched.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxix{%
\basmalahen Hast thou not seen how thy Lord did with the Men of the Elephant?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxc{%
Did He not make their guile to go astray?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxci{%
And He loosed upon them birds in flights,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcii{%
hurling against them stones of baked clay\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxciii{%
and He made them like green blades devoured.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxciv{%
\basmalahen For the composing of Koraish,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcv{%
their composing for the winter and summer caravan!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcvi{%
So let them serve the Lord of this House\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcvii{%
who has fed them against hunger and secured them from fear.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcviii{%
\basmalahen Hast thou seen him who cries lies to the Doom?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcix{%
That is he who repulses the orphan\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcc{%
and urges not the feeding of the needy.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcci{%
So woe to those that pray\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccii{%
and are heedless of their prayers,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcciii{%
to those who make display\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcciv{%
and refuse charity.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmccv{%
\basmalahen Surely We have given thee abundance;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccvi{%
so pray unto thy Lord and sacrifice.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccvii{%
Surely he that hates thee, he is the one cut off.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccviii{%
\basmalahen Say: 'O unbelievers,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccix{%
I serve not what you serve\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccx{%
and you are not serving what I serve,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxi{%
nor am I serving what you have served,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxii{%
neither are you serving what I serve\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxiii{%
To you your religion, and to me my religion!'\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmccxiv{%
\basmalahen When comes the help of God, and victory,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxv{%
and thou seest men entering God's religion in throngs,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxvi{%
then proclaim the praise of thy Lord, and seek His forgiveness; for He turns again unto men.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxvii{%
\basmalahen Perish the hands of Abu Lahab, and perish he!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxviii{%
His wealth avails him not, neither what he has earned;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxix{%
he shall roast at a flaming fire\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxx{%
and his wife, the carrier of the firewood,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxi{%
upon her neck a rope of palm-fibre.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxii{%
\basmalahen Say: 'He is God, One,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxiii{%
God, the Everlasting Refuge,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxiv{%
who has not begotten, and has not been begotten,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxv{%
and equal to Him is not any one.'\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxvi{%
\basmalahen Say: 'I take refuge with the Lord of the Daybreak\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxvii{%
from the evil of what He has created,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxviii{%
from the evil of darkness when it gathers,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxix{%
from the evil of the women who blow on knots,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxx{%
from the evil of an envier when he envies.'\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxi{%
\basmalahen Say: 'I take refuge with the Lord of men,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxii{%
the King of men,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxiii{%
the God of men,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxiv{%
from the evil of the slinking whisperer\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxv{%
who whispers in the breasts of men\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxvi{%
of jinn and men.'\qt@no{6}}%
%% End of file `qurantext-eniii.translation.def'
