\qt@newcmd\qurantrans@en@i{%
In the name of Allah, the Beneficent, the Merciful.\qt@no{1}}%
\qt@newcmd\qurantrans@en@ii{%
Praise be to Allah, Lord of the Worlds,\qt@no{2}}%
\qt@newcmd\qurantrans@en@iii{%
The Beneficent, the Merciful.\qt@no{3}}%
\qt@newcmd\qurantrans@en@iv{%
Master of the Day of Judgment,\qt@no{4}}%
\qt@newcmd\qurantrans@en@v{%
Thee (alone) we worship; Thee (alone) we ask for help.\qt@no{5}}%
\qt@newcmd\qurantrans@en@vi{%
Show us the straight path,\qt@no{6}}%
\qt@newcmd\qurantrans@en@vii{%
The path of those whom Thou hast favoured; Not the (path) of those who earn Thine anger nor of those who go astray.\qt@no{7}}%
\qt@newcmd\qurantrans@en@viii{%
\basmalahen Alif. Lam. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@ix{%
This is the Scripture whereof there is no doubt, a guidance unto those who ward off (evil).\qt@no{2}}%
\qt@newcmd\qurantrans@en@x{%
Who believe in the Unseen, and establish worship, and spend of that We have bestowed upon them;\qt@no{3}}%
\qt@newcmd\qurantrans@en@xi{%
And who believe in that which is revealed unto thee (Muhammad) and that which was revealed before thee, and are certain of the Hereafter.\qt@no{4}}%
\qt@newcmd\qurantrans@en@xii{%
These depend on guidance from their Lord. These are the successful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@xiii{%
As for the Disbelievers, Whether thou warn them or thou warn them not it is all one for them; they believe not.\qt@no{6}}%
\qt@newcmd\qurantrans@en@xiv{%
Allah hath sealed their hearing and their hearts, and on their eyes there is a covering. Theirs will be an awful doom.\qt@no{7}}%
\qt@newcmd\qurantrans@en@xv{%
And of mankind are some who say: We believe in Allah and the Last Day, when they believe not.\qt@no{8}}%
\qt@newcmd\qurantrans@en@xvi{%
They think to beguile Allah and those who believe, and they beguile none save themselves; but they perceive not.\qt@no{9}}%
\qt@newcmd\qurantrans@en@xvii{%
In their hearts is a disease, and Allah increaseth their disease. A painful doom is theirs because they lie.\qt@no{10}}%
\qt@newcmd\qurantrans@en@xviii{%
And when it is said unto them: Make not mischief in the earth, they say: We are peacemakers only.\qt@no{11}}%
\qt@newcmd\qurantrans@en@xix{%
Are not they indeed the mischief-makers? But they perceive not.\qt@no{12}}%
\qt@newcmd\qurantrans@en@xx{%
And when it is said unto them: believe as the people believe, they say: shall we believe as the foolish believe? are not they indeed the foolish? But they know not.\qt@no{13}}%
\qt@newcmd\qurantrans@en@xxi{%
And when they fall in with those who believe, they say: We believe; but when they go apart to their devils they declare: Lo! we are with you; verily we did but mock.\qt@no{14}}%
\qt@newcmd\qurantrans@en@xxii{%
Allah (Himself) doth mock them, leaving them to wander blindly on in their contumacy.\qt@no{15}}%
\qt@newcmd\qurantrans@en@xxiii{%
These are they who purchase error at the price of guidance, so their commerce doth not prosper, neither are they guided.\qt@no{16}}%
\qt@newcmd\qurantrans@en@xxiv{%
Their likeness is as the likeness of one who kindleth fire, and when it sheddeth its light around him Allah taketh away their light and leaveth them in darkness, where they cannot see,\qt@no{17}}%
\qt@newcmd\qurantrans@en@xxv{%
Deaf, dumb and blind; and they return not.\qt@no{18}}%
\qt@newcmd\qurantrans@en@xxvi{%
Or like a rainstorm from the sky, wherein is darkness, thunder and the flash of lightning. They thrust their fingers in their ears by reason of the thunder-claps, for fear of death, Allah encompasseth the disbelievers (in His guidance, His omniscience and His omnipotence).\qt@no{19}}%
\qt@newcmd\qurantrans@en@xxvii{%
The lightning almost snatcheth away their sight from them. As often as it flasheth forth for them they walk therein, and when it darkeneth against them they stand still. If Allah willed, He could destroy their hearing and their sight. Lo! Allah is able to do all things.\qt@no{20}}%
\qt@newcmd\qurantrans@en@xxviii{%
O mankind! worship your Lord, Who hath created you and those before you, so that ye may ward off (evil).\qt@no{21}}%
\qt@newcmd\qurantrans@en@xxix{%
Who hath appointed the earth a resting-place for you, and the sky a canopy; and causeth water to pour down from the sky, thereby producing fruits as food for you. And do not set up rivals to Allah when ye know (better).\qt@no{22}}%
\qt@newcmd\qurantrans@en@xxx{%
And if ye are in doubt concerning that which We reveal unto Our slave (Muhammad), then produce a surah of the like thereof, and call your witness beside Allah if ye are truthful.\qt@no{23}}%
\qt@newcmd\qurantrans@en@xxxi{%
And if ye do it not - and ye can never do it - then guard yourselves against the Fire prepared for disbelievers, whose fuel is of men and stones.\qt@no{24}}%
\qt@newcmd\qurantrans@en@xxxii{%
And give glad tidings (O Muhammad) unto those who believe and do good works; that theirs are Gardens underneath which rivers flow; as often as they are regaled with food of the fruit thereof, they say: this is what was given us aforetime; and it is given to them in resemblance. There for them are pure companions; there for ever they abide.\qt@no{25}}%
\qt@newcmd\qurantrans@en@xxxiii{%
Lo! Allah disdaineth not to coin the similitude even of a gnat. Those who believe know that it is the truth from their Lord; but those who disbelieve say: What doth Allah wish (to teach) by such a similitude? He misleadeth many thereby, and He guideth many thereby; and He misleadeth thereby only miscreants;\qt@no{26}}%
\qt@newcmd\qurantrans@en@xxxiv{%
Those who break the covenant of Allah after ratifying it, and sever that which Allah ordered to be joined, and (who) make mischief in the earth: Those are they who are the losers.\qt@no{27}}%
\qt@newcmd\qurantrans@en@xxxv{%
How disbelieve ye in Allah when ye were dead and He gave life to you! Then He will give you death, then life again, and then unto Him ye will return.\qt@no{28}}%
\qt@newcmd\qurantrans@en@xxxvi{%
He it is Who created for you all that is in the earth. Then turned He to the heaven, and fashioned it as seven heavens. And He is knower of all things.\qt@no{29}}%
\qt@newcmd\qurantrans@en@xxxvii{%
And when thy Lord said unto the angels: Lo! I am about to place a viceroy in the earth, they said: Wilt thou place therein one who will do harm therein and will shed blood, while we, we hymn Thy praise and sanctify Thee? He said: Surely I know that which ye know not.\qt@no{30}}%
\qt@newcmd\qurantrans@en@xxxviii{%
And He taught Adam all the names, then showed them to the angels, saying: Inform Me of the names of these, if ye are truthful.\qt@no{31}}%
\qt@newcmd\qurantrans@en@xxxix{%
They said: Be glorified! We have no knowledge saving that which Thou hast taught us. Lo! Thou, only Thou, art the Knower, the Wise.\qt@no{32}}%
\qt@newcmd\qurantrans@en@xl{%
He said: O Adam! Inform them of their names, and when he had informed them of their names, He said: Did I not tell you that I know the secret of the heavens and the earth? And I know that which ye disclose and which ye hide.\qt@no{33}}%
\qt@newcmd\qurantrans@en@xli{%
And when We said unto the angels: Prostrate yourselves before Adam, they fell prostrate, all save Iblis. He demurred through pride, and so became a disbeliever.\qt@no{34}}%
\qt@newcmd\qurantrans@en@xlii{%
And We said: O Adam! Dwell thou and thy wife in the Garden, and eat ye freely (of the fruits) thereof where ye will; but come not nigh this tree lest ye become wrong-doers.\qt@no{35}}%
\qt@newcmd\qurantrans@en@xliii{%
But Satan caused them to deflect therefrom and expelled them from the (happy) state in which they were; and We said: Fall down, one of you a foe unto the other! There shall be for you on earth a habitation and provision for a time.\qt@no{36}}%
\qt@newcmd\qurantrans@en@xliv{%
Then Adam received from his Lord words (of revelation), and He relented toward him. Lo! He is the relenting, the Merciful.\qt@no{37}}%
\qt@newcmd\qurantrans@en@xlv{%
We said: Go down, all of you, from hence; but verily there cometh unto you from Me a guidance; and whoso followeth My guidance, there shall no fear come upon them neither shall they grieve.\qt@no{38}}%
\qt@newcmd\qurantrans@en@xlvi{%
But they who disbelieve, and deny Our revelations, such are rightful Peoples of the Fire. They will abide therein.\qt@no{39}}%
\qt@newcmd\qurantrans@en@xlvii{%
O Children of Israel! Remember My favour wherewith I favoured you, and fulfil your (part of the) covenant, I shall fulfil My (part of the) covenant, and fear Me.\qt@no{40}}%
\qt@newcmd\qurantrans@en@xlviii{%
And believe in that which I reveal, confirming that which ye possess already (of the Scripture), and be not first to disbelieve therein, and part not with My revelations for a trifling price, and keep your duty unto Me.\qt@no{41}}%
\qt@newcmd\qurantrans@en@xlix{%
Confound not truth with falsehood, nor knowingly conceal the truth.\qt@no{42}}%
\qt@newcmd\qurantrans@en@l{%
Establish worship, pay the poor-due, and bow your heads with those who bow (in worship).\qt@no{43}}%
\qt@newcmd\qurantrans@en@li{%
Enjoin ye righteousness upon mankind while ye yourselves forget (to practise it)? And ye are readers of the Scripture! Have ye then no sense?\qt@no{44}}%
\qt@newcmd\qurantrans@en@lii{%
Seek help in patience and prayer; and truly it is hard save for the humble-minded,\qt@no{45}}%
\qt@newcmd\qurantrans@en@liii{%
Who know that they will have to meet their Lord, and that unto Him they are returning.\qt@no{46}}%
\qt@newcmd\qurantrans@en@liv{%
O Children of Israel! Remember My favour wherewith I favoured you and how I preferred you to (all) creatures.\qt@no{47}}%
\qt@newcmd\qurantrans@en@lv{%
And guard yourselves against a day when no soul will in aught avail another, nor will intercession be accepted from it, nor will compensation be received from it, nor will they be helped.\qt@no{48}}%
\qt@newcmd\qurantrans@en@lvi{%
And (remember) when We did deliver you from Pharaoh's folk, who were afflicting you with dreadful torment, slaying your sons and sparing your women: that was a tremendous trial from your Lord.\qt@no{49}}%
\qt@newcmd\qurantrans@en@lvii{%
And when We brought you through the sea and rescued you, and drowned the folk of Pharaoh in your sight.\qt@no{50}}%
\qt@newcmd\qurantrans@en@lviii{%
And when We did appoint for Moses forty nights (of solitude), and then ye chose the calf, when he had gone from you, and were wrong-doers.\qt@no{51}}%
\qt@newcmd\qurantrans@en@lix{%
Then, even after that, We pardoned you in order that ye might give thanks.\qt@no{52}}%
\qt@newcmd\qurantrans@en@lx{%
And when We gave unto Moses the Scripture and the criterion (of right and wrong), that ye might be led aright.\qt@no{53}}%
\qt@newcmd\qurantrans@en@lxi{%
And when Moses said unto his people: O my people! Ye have wronged yourselves by your choosing of the calf (for worship) so turn in penitence to your Creator, and kill (the guilty) yourselves. That will be best for you with your Creator and He will relent toward you. Lo! He is the Relenting, the Merciful.\qt@no{54}}%
\qt@newcmd\qurantrans@en@lxii{%
And when ye said: O Moses! We will not believe in thee till we see Allah plainly; and even while ye gazed the lightning seized you.\qt@no{55}}%
\qt@newcmd\qurantrans@en@lxiii{%
Then We revived you after your extinction, that ye might give thanks.\qt@no{56}}%
\qt@newcmd\qurantrans@en@lxiv{%
And We caused the white cloud to overshadow you and sent down on you the manna and the quails, (saying): Eat of the good things wherewith We have provided you - they wronged Us not, but they did wrong themselves.\qt@no{57}}%
\qt@newcmd\qurantrans@en@lxv{%
And when We said: Go into this township and eat freely of that which is therein, and enter the gate prostrate, and say: ``Repentance." We will forgive you your sins and will increase (reward) for the right-doers.\qt@no{58}}%
\qt@newcmd\qurantrans@en@lxvi{%
But those who did wrong changed the word which had been told them for another saying, and We sent down upon the evil-doers wrath from heaven for their evil-doing.\qt@no{59}}%
\qt@newcmd\qurantrans@en@lxvii{%
And when Moses asked for water for his people, We said: Smite with thy staff the rock. And there gushed out therefrom twelve springs (so that) each tribe knew their drinking-place. Eat and drink of that which Allah hath provided, and do not act corruptly, making mischief in the earth.\qt@no{60}}%
\qt@newcmd\qurantrans@en@lxviii{%
And when ye said: O Moses! We are weary of one kind of food; so call upon thy Lord for us that He bring forth for us of that which the earth groweth - of its herbs and its cucumbers and its corn and its lentils and its onions. He said: Would ye exchange that which is higher for that which is lower? Go down to settled country, thus ye shall get that which ye demand. And humiliation and wretchedness were stamped upon them and they were visited with wrath from Allah. That was because they disbelieved in Allah's revelations and slew the prophets wrongfully. That was for their disobedience and transgression.\qt@no{61}}%
\qt@newcmd\qurantrans@en@lxix{%
Lo! Those who believe (in that which is revealed unto thee, Muhammad), and those who are Jews, and Christians, and Sabaeans - whoever believeth in Allah and the Last Day and doeth right - surely their reward is with their Lord, and there shall no fear come upon them neither shall they grieve.\qt@no{62}}%
\qt@newcmd\qurantrans@en@lxx{%
And (remember, O Children of Israel) when We made a covenant with you and caused the mount to tower above you, (saying): Hold fast that which We have given you, and remember that which is therein, that ye may ward off (evil).\qt@no{63}}%
\qt@newcmd\qurantrans@en@lxxi{%
Then, even after that, ye turned away, and if it had not been for the grace of Allah and His mercy ye had been among the losers.\qt@no{64}}%
\qt@newcmd\qurantrans@en@lxxii{%
And ye know of those of you who broke the Sabbath, how We said unto them: Be ye apes, despised and hated!\qt@no{65}}%
\qt@newcmd\qurantrans@en@lxxiii{%
And We made it an example to their own and to succeeding generations, and an admonition to the Allah-fearing.\qt@no{66}}%
\qt@newcmd\qurantrans@en@lxxiv{%
And when Moses said unto his people: Lo! Allah commandeth you that ye sacrifice a cow, they said: Dost thou make game of us? He answered: Allah forbid that I should be among the foolish!\qt@no{67}}%
\qt@newcmd\qurantrans@en@lxxv{%
They said: Pray for us unto thy Lord that He make clear to us what (cow) she is. (Moses) answered: Lo! He saith, Verily she is a cow neither with calf nor immature; (she is) between the two conditions; so do that which ye are commanded.\qt@no{68}}%
\qt@newcmd\qurantrans@en@lxxvi{%
They said: Pray for us unto thy Lord that He make clear to us of what colour she is. (Moses) answered: Lo! He saith: Verily she is a yellow cow. Bright is her colour, gladdening beholders.\qt@no{69}}%
\qt@newcmd\qurantrans@en@lxxvii{%
They said: Pray for us unto thy Lord that He make clear to us what (cow) she is. Lo! cows are much alike to us; and Lo! if Allah wills, we may be led aright.\qt@no{70}}%
\qt@newcmd\qurantrans@en@lxxviii{%
(Moses) answered: Lo! He saith: Verily she is a cow unyoked; she plougheth not the soil nor watereth the tilth; whole and without mark. They said: Now thou bringest the truth. So they sacrificed her, though almost they did not.\qt@no{71}}%
\qt@newcmd\qurantrans@en@lxxix{%
And (remember) when ye slew a man and disagreed concerning it and Allah brought forth that which ye were hiding.\qt@no{72}}%
\qt@newcmd\qurantrans@en@lxxx{%
And We said: Smite him with some of it. Thus Allah bringeth the dead to life and showeth you His portents so that ye may understand.\qt@no{73}}%
\qt@newcmd\qurantrans@en@lxxxi{%
Then, even after that, your hearts were hardened and became as rocks, or worse than rocks, for hardness. For indeed there are rocks from out which rivers gush, and indeed there are rocks which split asunder so that water floweth from them. And indeed there are rocks which fall down for the fear of Allah. Allah is not unaware of what ye do.\qt@no{74}}%
\qt@newcmd\qurantrans@en@lxxxii{%
Have ye any hope that they will be true to you when a party of them used to listen to the word of Allah, then used to change it, after they had understood it, knowingly?\qt@no{75}}%
\qt@newcmd\qurantrans@en@lxxxiii{%
And when they fall in with those who believe, they say: We believe. But when they go apart one with another they say: Prate ye to them of that which Allah hath disclosed to you that they may contend with you before your Lord concerning it? Have ye then no sense?\qt@no{76}}%
\qt@newcmd\qurantrans@en@lxxxiv{%
Are they then unaware that Allah knoweth that which they keep hidden and that which they proclaim?\qt@no{77}}%
\qt@newcmd\qurantrans@en@lxxxv{%
Among them are unlettered folk who know the Scripture not except from hearsay. They but guess.\qt@no{78}}%
\qt@newcmd\qurantrans@en@lxxxvi{%
Therefore woe be unto those who write the Scripture with their hands and then say, ``This is from Allah," that they may purchase a small gain therewith. Woe unto them for that their hands have written, and woe unto them for that they earn thereby.\qt@no{79}}%
\qt@newcmd\qurantrans@en@lxxxvii{%
And they say: The Fire (of punishment) will not touch us save for a certain number of days. Say: Have ye received a covenant from Allah - truly Allah will not break His covenant - or tell ye concerning Allah that which ye know not?\qt@no{80}}%
\qt@newcmd\qurantrans@en@lxxxviii{%
Nay, but whosoever hath done evil and his sin surroundeth him; such are rightful owners of the Fire; they will abide therein.\qt@no{81}}%
\qt@newcmd\qurantrans@en@lxxxix{%
And those who believe and do good works: such are rightful owners of the Garden. They will abide therein.\qt@no{82}}%
\qt@newcmd\qurantrans@en@xc{%
And (remember) when We made a covenant with the Children of Israel, (saying): Worship none save Allah (only), and be good to parents and to kindred and to orphans and the needy, and speak kindly to mankind; and establish worship and pay the poor-due. Then, after that, ye slid back, save a few of you, being averse.\qt@no{83}}%
\qt@newcmd\qurantrans@en@xci{%
And when We made with you a covenant (saying): Shed not the blood of your people nor turn (a party of) your people out of your dwellings. Then ye ratified (Our covenant) and ye were witnesses (thereto).\qt@no{84}}%
\qt@newcmd\qurantrans@en@xcii{%
Yet ye it is who slay each other and drive out a party of your people from their homes, supporting one another against them by sin and transgression? - and if they came to you as captives ye would ransom them, whereas their expulsion was itself unlawful for you - Believe ye in part of the Scripture and disbelieve ye in part thereof? And what is the reward of those who do so save ignominy in the life of the world, and on the Day of Resurrection they will be consigned to the most grievous doom. For Allah is not unaware of what ye do.\qt@no{85}}%
\qt@newcmd\qurantrans@en@xciii{%
Such are those who buy the life of the world at the price of the Hereafter. Their punishment will not be lightened, neither will they have support.\qt@no{86}}%
\qt@newcmd\qurantrans@en@xciv{%
And verily We gave unto Moses the Scripture and We caused a train of messengers to follow after him, and We gave unto Jesus, son of Mary, clear proofs (of Allah's sovereignty), and We supported him with the Holy spirit. Is it ever so, that, when there cometh unto you a messenger (from Allah) with that which ye yourselves desire not, ye grow arrogant, and some ye disbelieve and some ye slay?\qt@no{87}}%
\qt@newcmd\qurantrans@en@xcv{%
And they say: Our hearts are hardened. Nay, but Allah hath cursed them for their unbelief. Little is that which they believe.\qt@no{88}}%
\qt@newcmd\qurantrans@en@xcvi{%
And when there cometh unto them a scripture from Allah, confirming that in their possession - though before that they were asking for a signal triumph over those who disbelieved - and when there cometh unto them that which they know (to be the truth) they disbelieve therein. The curse of Allah is on disbelievers.\qt@no{89}}%
\qt@newcmd\qurantrans@en@xcvii{%
Evil is that for which they sell their souls: that they should disbelieve in that which Allah hath revealed, grudging that Allah should reveal of His bounty unto whom He will of His slaves. They have incurred anger upon anger. For disbelievers is a shameful doom.\qt@no{90}}%
\qt@newcmd\qurantrans@en@xcviii{%
And when it is said unto them: Believe in that which Allah hath revealed, they say: We believe in that which was revealed unto us. And they disbelieve in that which cometh after it, though it is the truth confirming that which they possess. Say (unto them, O Muhammad): Why then slew ye the prophets of Allah aforetime, if ye are (indeed) believers?\qt@no{91}}%
\qt@newcmd\qurantrans@en@xcix{%
And Moses came unto you with clear proofs (of Allah's Sovereignty), yet, while he was away, ye chose the calf (for worship) and ye were wrong-doers.\qt@no{92}}%
\qt@newcmd\qurantrans@en@c{%
And when We made with you a covenant and caused the Mount to tower above you, (saying): Hold fast by that which We have given you, and hear (Our Word), they said: We hear and we rebel. And (worship of) the calf was made to sink into their hearts because of their rejection (of the covenant). Say (unto them): Evil is that which your belief enjoineth on you, if ye are believers.\qt@no{93}}%
\qt@newcmd\qurantrans@en@ci{%
Say (unto them): If the abode of the Hereafter in the providence of Allah is indeed for you alone and not for others of mankind (as ye pretend), then long for death (for ye must long for death) if ye are truthful.\qt@no{94}}%
\qt@newcmd\qurantrans@en@cii{%
But they will never long for it, because of that which their own hands have sent before them. Allah is aware of evil-doers.\qt@no{95}}%
\qt@newcmd\qurantrans@en@ciii{%
And thou wilt find them greediest of mankind for life and (greedier) than the idolaters. (Each) one of them would like to be allowed to live a thousand years. And to live (a thousand years) would be no means remove him from the doom. Allah is Seer of what they do.\qt@no{96}}%
\qt@newcmd\qurantrans@en@civ{%
Say (O Muhammad, to mankind): Who is an enemy to Gabriel! For he it is who hath revealed (this Scripture) to thy heart by Allah's leave, confirming that which was (revealed) before it, and a guidance and glad tidings to believers;\qt@no{97}}%
\qt@newcmd\qurantrans@en@cv{%
Who is an enemy to Allah, and His angels and His messengers, and Gabriel and Michael! Then, lo! Allah (Himself) is an enemy to the disbelievers.\qt@no{98}}%
\qt@newcmd\qurantrans@en@cvi{%
Verily We have revealed unto thee clear tokens, and only miscreants will disbelieve in them.\qt@no{99}}%
\qt@newcmd\qurantrans@en@cvii{%
Is it ever so that when they make a covenant a party of them set it aside? The truth is, most of them believe not.\qt@no{100}}%
\qt@newcmd\qurantrans@en@cviii{%
And when there cometh unto them a messenger from Allah, confirming that which they possess, a party of those who have received the Scripture fling the Scripture of Allah behind their backs as if they knew not,\qt@no{101}}%
\qt@newcmd\qurantrans@en@cix{%
And follow that which the devils falsely related against the kingdom of Solomon. Solomon disbelieved not; but the devils disbelieved, teaching mankind magic and that which was revealed to the two angels in Babel, Harut and Marut. Nor did they (the two angels) teach it to anyone till they had said: We are only a temptation, therefore disbelieve not (in the guidance of Allah). And from these two (angles) people learn that by which they cause division between man and wife; but they injure thereby no-one save by Allah's leave. And they learn that which harmeth them and profiteth them not. And surely they do know that he who trafficketh therein will have no (happy) portion in the Hereafter; and surely evil is the price for which they sell their souls, if they but knew.\qt@no{102}}%
\qt@newcmd\qurantrans@en@cx{%
And if they had believed and kept from evil, a recompense from Allah would be better, if they only knew.\qt@no{103}}%
\qt@newcmd\qurantrans@en@cxi{%
O ye who believe, say not (unto the Prophet): ``Listen to us" but say ``Look upon us," and be ye listeners. For disbelievers is a painful doom.\qt@no{104}}%
\qt@newcmd\qurantrans@en@cxii{%
Neither those who disbelieve among the people of the Scripture nor the idolaters love that there should be sent down unto you any good thing from your Lord. But Allah chooseth for His mercy whom He will, and Allah is of Infinite Bounty.\qt@no{105}}%
\qt@newcmd\qurantrans@en@cxiii{%
Nothing of our revelation (even a single verse) do we abrogate or cause be forgotten, but we bring (in place) one better or the like thereof. Knowest thou not that Allah is Able to do all things?\qt@no{106}}%
\qt@newcmd\qurantrans@en@cxiv{%
Knowest thou not that it is Allah unto Whom belongeth the Sovereignty of the heavens and the earth; and ye have not, beside Allah, any guardian or helper?\qt@no{107}}%
\qt@newcmd\qurantrans@en@cxv{%
Or would ye question your messenger as Moses was questioned aforetime? He who chooseth disbelief instead of faith, verily he hath gone astray from a plain road.\qt@no{108}}%
\qt@newcmd\qurantrans@en@cxvi{%
Many of the people of the Scripture long to make you disbelievers after your belief, through envy on their own account, after the truth hath become manifest unto them. Forgive and be indulgent (toward them) until Allah give command. Lo! Allah is Able to do all things.\qt@no{109}}%
\qt@newcmd\qurantrans@en@cxvii{%
Establish worship, and pay the poor-due; and whatever of good ye send before (you) for your souls, ye will find it with Allah. Lo! Allah is Seer of what ye do.\qt@no{110}}%
\qt@newcmd\qurantrans@en@cxviii{%
And they say: None entereth paradise unless he be a Jew or a Christian. These are their own desires. Say: Bring your proof (of what ye state) if ye are truthful.\qt@no{111}}%
\qt@newcmd\qurantrans@en@cxix{%
Nay, but whosoever surrendereth his purpose to Allah while doing good, his reward is with his Lord; and there shall no fear come upon them neither shall they grieve.\qt@no{112}}%
\qt@newcmd\qurantrans@en@cxx{%
And the Jews say the Christians follow nothing (true), and the Christians say the Jews follow nothing (true); yet both are readers of the Scripture. Even thus speak those who know not. Allah will judge between them on the Day of Resurrection concerning that wherein they differ.\qt@no{113}}%
\qt@newcmd\qurantrans@en@cxxi{%
And who doth greater wrong than he who forbiddeth the approach to the sanctuaries of Allah lest His name should be mentioned therein, and striveth for their ruin. As for such, it was never meant that they should enter them except in fear. Theirs in the world is ignominy and theirs in the Hereafter is an awful doom.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cxxii{%
Unto Allah belong the East and the West, and whithersoever ye turn, there is Allah's Countenance. Lo! Allah is All-Embracing, All-Knowing.\qt@no{115}}%
\qt@newcmd\qurantrans@en@cxxiii{%
And they say: Allah hath taken unto Himself a son. Be He glorified! Nay, but whatsoever is in the heavens and the earth is His. All are subservient unto Him.\qt@no{116}}%
\qt@newcmd\qurantrans@en@cxxiv{%
The Originator of the heavens and the earth! When He decreeth a thing, He saith unto it only: Be! and it is.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cxxv{%
And those who have no knowledge say: Why doth not Allah speak unto us, or some sign come unto us? Even thus, as they now speak, spake those (who were) before them. Their hearts are all alike. We have made clear the revelations for people who are sure.\qt@no{118}}%
\qt@newcmd\qurantrans@en@cxxvi{%
Lo! We have sent thee (O Muhammad) with the truth, a bringer of glad tidings and a warner. And thou wilt not be asked about the owners of hell-fire.\qt@no{119}}%
\qt@newcmd\qurantrans@en@cxxvii{%
And the Jews will not be pleased with thee, nor will the Christians, till thou follow their creed. Say: Lo! the guidance of Allah (Himself) is Guidance. And if thou shouldst follow their desires after the knowledge which hath come unto thee, then wouldst thou have from Allah no protecting guardian nor helper.\qt@no{120}}%
\qt@newcmd\qurantrans@en@cxxviii{%
Those unto whom We have given the Scripture, who read it with the right reading, those believe in it. And whoso disbelieveth in it, those are they who are the losers.\qt@no{121}}%
\qt@newcmd\qurantrans@en@cxxix{%
O Children of Israel! Remember My favour wherewith I favoured you and how I preferred you to (all) creatures.\qt@no{122}}%
\qt@newcmd\qurantrans@en@cxxx{%
And guard (yourselves) against a day when no soul will in aught avail another, nor will compensation be accepted from it, nor will intercession be of use to it; nor will they be helped.\qt@no{123}}%
\qt@newcmd\qurantrans@en@cxxxi{%
And (remember) when his Lord tried Abraham with (His) commands, and he fulfilled them, He said: Lo! I have appointed thee a leader for mankind. (Abraham) said: And of my offspring (will there be leaders)? He said: My covenant includeth not wrong-doers.\qt@no{124}}%
\qt@newcmd\qurantrans@en@cxxxii{%
And when We made the House (at Makka) a resort for mankind and sanctuary, (saying): Take as your place of worship the place where Abraham stood (to pray). And We imposed a duty upon Abraham and Ishmael, (saying): Purify My house for those who go around and those who meditate therein and those who bow down and prostrate themselves (in worship).\qt@no{125}}%
\qt@newcmd\qurantrans@en@cxxxiii{%
And when Abraham prayed: My Lord! Make this a region of security and bestow upon its people fruits, such of them as believe in Allah and the Last Day, He answered: As for him who disbelieveth, I shall leave him in contentment for a while, then I shall compel him to the doom of Fire - a hapless journey's end!\qt@no{126}}%
\qt@newcmd\qurantrans@en@cxxxiv{%
And when Abraham and Ishmael were raising the foundations of the House, (Abraham prayed): Our Lord! Accept from us (this duty). Lo! Thou, only Thou, art the Hearer, the Knower.\qt@no{127}}%
\qt@newcmd\qurantrans@en@cxxxv{%
Our Lord! And make us submissive unto Thee and of our seed a nation submissive unto Thee, and show us our ways of worship, and relent toward us. Lo! Thou, only Thou, art the Relenting, the Merciful.\qt@no{128}}%
\qt@newcmd\qurantrans@en@cxxxvi{%
Our Lord! And raise up in their midst a messenger from among them who shall recite unto them Thy revelations, and shall instruct them in the Scripture and in wisdom and shall make them grow. Lo! Thou, only Thou, art the Mighty, Wise.\qt@no{129}}%
\qt@newcmd\qurantrans@en@cxxxvii{%
And who forsaketh the religion of Abraham save him who befooleth himself? Verily We chose him in the world, and lo! in the Hereafter he is among the righteous.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cxxxviii{%
When his Lord said unto him: Surrender! he said: I have surrendered to the Lord of the Worlds.\qt@no{131}}%
\qt@newcmd\qurantrans@en@cxxxix{%
The same did Abraham enjoin upon his sons, and also Jacob, (saying): O my sons! Lo! Allah hath chosen for you the (true) religion; therefore die not save as men who have surrendered (unto Him).\qt@no{132}}%
\qt@newcmd\qurantrans@en@cxl{%
Or were ye present when death came to Jacob, when he said unto his sons: What will ye worship after me? They said: We shall worship thy god, the god of thy fathers, Abraham and Ishmael and Isaac, One Allah, and unto Him we have surrendered.\qt@no{133}}%
\qt@newcmd\qurantrans@en@cxli{%
Those are a people who have passed away. Theirs is that which they earned, and yours is that which ye earn. And ye will not be asked of what they used to do.\qt@no{134}}%
\qt@newcmd\qurantrans@en@cxlii{%
And they say: Be Jews or Christians, then ye will be rightly guided. Say (unto them, O Muhammad): Nay, but (we follow) the religion of Abraham, the upright, and he was not of the idolaters.\qt@no{135}}%
\qt@newcmd\qurantrans@en@cxliii{%
Say (O Muslims): We believe in Allah and that which is revealed unto us and that which was revealed unto Abraham, and Ishmael, and Isaac, and Jacob, and the tribes, and that which Moses and Jesus received, and that which the prophets received from their Lord. We make no distinction between any of them, and unto Him we have surrendered.\qt@no{136}}%
\qt@newcmd\qurantrans@en@cxliv{%
And if they believe in the like of that which ye believe, then are they rightly guided. But if they turn away, then are they in schism, and Allah will suffice thee (for defence) against them. He is the Hearer, the Knower.\qt@no{137}}%
\qt@newcmd\qurantrans@en@cxlv{%
(We take our) colour from Allah, and who is better than Allah at colouring. We are His worshippers.\qt@no{138}}%
\qt@newcmd\qurantrans@en@cxlvi{%
Say (unto the People of the Scripture): Dispute ye with us concerning Allah when He is our Lord and your Lord? Ours are our works and yours your works. We look to Him alone.\qt@no{139}}%
\qt@newcmd\qurantrans@en@cxlvii{%
Or say ye that Abraham, and Ishmael, and Isaac, and Jacob, and the tribes were Jews or Christians? Say: Do ye know best, or doth Allah? And who is more unjust than he who hideth a testimony which he hath received from Allah? Allah is not unaware of what ye do.\qt@no{140}}%
\qt@newcmd\qurantrans@en@cxlviii{%
Those are a people who have passed away; theirs is that which they earned and yours that which ye earn. And ye will not be asked of what they used to do.\qt@no{141}}%
\qt@newcmd\qurantrans@en@cxlix{%
The foolish of the people will say: What hath turned them from the qiblah which they formerly observed? Say: Unto Allah belong the East and the West. He guideth whom He will unto a straight path.\qt@no{142}}%
\qt@newcmd\qurantrans@en@cl{%
Thus We have appointed you a middle nation, that ye may be witnesses against mankind, and that the messenger may be a witness against you. And We appointed the qiblah which ye formerly observed only that We might know him who followeth the messenger, from him who turneth on his heels. In truth it was a hard (test) save for those whom Allah guided. But it was not Allah's purpose that your faith should be in vain, for Allah is Full of Pity, Merciful toward mankind.\qt@no{143}}%
\qt@newcmd\qurantrans@en@cli{%
We have seen the turning of thy face to heaven (for guidance, O Muhammad). And now verily We shall make thee turn (in prayer) toward a qiblah which is dear to thee. So turn thy face toward the Inviolable Place of Worship, and ye (O Muslims), wheresoever ye may be, turn your faces (when ye pray) toward it. Lo! Those who have received the Scripture know that (this revelation) is the Truth from their Lord. And Allah is not unaware of what they do.\qt@no{144}}%
\qt@newcmd\qurantrans@en@clii{%
And even if thou broughtest unto those who have received the Scripture all kinds of portents, they would not follow thy qiblah, nor canst thou be a follower of their qiblah; nor are some of them followers of the qiblah of others. And if thou shouldst follow their desires after the knowledge which hath come unto thee, then surely wert thou of the evil-doers.\qt@no{145}}%
\qt@newcmd\qurantrans@en@cliii{%
Those unto whom We gave the Scripture recognise (this revelation) as they recognise their sons. But lo! a party of them knowingly conceal the truth.\qt@no{146}}%
\qt@newcmd\qurantrans@en@cliv{%
It is the Truth from thy Lord (O Muhammad), so be not thou of those who waver.\qt@no{147}}%
\qt@newcmd\qurantrans@en@clv{%
And each one hath a goal toward which he turneth; so vie with one another in good works. Wheresoever ye may be, Allah will bring you all together. Lo! Allah is Able to do all things.\qt@no{148}}%
\qt@newcmd\qurantrans@en@clvi{%
And whencesoever thou comest forth (for prayer, O Muhammad) turn thy face toward the Inviolable Place of Worship. Lo! it is the Truth from thy Lord. Allah is not unaware of what ye do.\qt@no{149}}%
\qt@newcmd\qurantrans@en@clvii{%
Whencesoever thou comest forth turn thy face toward the Inviolable Place of Worship; and wheresoever ye may be (O Muslims) turn your faces toward it (when ye pray) so that men may have no argument against you, save such of them as do injustice - Fear them not, but fear Me! - and so that I may complete My grace upon you, and that ye may be guided.\qt@no{150}}%
\qt@newcmd\qurantrans@en@clviii{%
Even as We have sent unto you a messenger from among you, who reciteth unto you Our revelations and causeth you to grow, and teacheth you the Scripture and wisdom, and teacheth you that which ye knew not.\qt@no{151}}%
\qt@newcmd\qurantrans@en@clix{%
Therefore remember Me, I will remember you. Give thanks to Me, and reject not Me.\qt@no{152}}%
\qt@newcmd\qurantrans@en@clx{%
O ye who believe! Seek help in steadfastness and prayer. Lo! Allah is with the steadfast.\qt@no{153}}%
\qt@newcmd\qurantrans@en@clxi{%
And call not those who are slain in the way of Allah ``dead." Nay, they are living, only ye perceive not.\qt@no{154}}%
\qt@newcmd\qurantrans@en@clxii{%
And surely We shall try you with something of fear and hunger, and loss of wealth and lives and crops; but give glad tidings to the steadfast,\qt@no{155}}%
\qt@newcmd\qurantrans@en@clxiii{%
Who say, when a misfortune striketh them: Lo! we are Allah's and lo! unto Him we are returning.\qt@no{156}}%
\qt@newcmd\qurantrans@en@clxiv{%
Such are they on whom are blessings from their Lord, and mercy. Such are the rightly guided.\qt@no{157}}%
\qt@newcmd\qurantrans@en@clxv{%
Lo! (the mountains) As-Safa and Al-Marwah are among the indications of Allah. It is therefore no sin for him who is on pilgrimage to the House (of Allah) or visiteth it, to go around them (as the pagan custom is). And he who doeth good of his own accord, (for him) lo! Allah is Responsive, Aware.\qt@no{158}}%
\qt@newcmd\qurantrans@en@clxvi{%
Lo! Those who hide the proofs and the guidance which We revealed, after We had made it clear to mankind in the Scripture: such are accursed of Allah and accursed of those who have the power to curse.\qt@no{159}}%
\qt@newcmd\qurantrans@en@clxvii{%
Except those who repent and amend and make manifest (the truth). These it is toward whom I relent. I am the Relenting, the Merciful.\qt@no{160}}%
\qt@newcmd\qurantrans@en@clxviii{%
Lo! Those who disbelieve, and die while they are disbelievers; on them is the curse of Allah and of angels and of men combined.\qt@no{161}}%
\qt@newcmd\qurantrans@en@clxix{%
They ever dwell therein. The doom will not be lightened for them, neither will they be reprieved.\qt@no{162}}%
\qt@newcmd\qurantrans@en@clxx{%
Your Allah is One Allah; there is no Allah save Him, the Beneficent, the Merciful.\qt@no{163}}%
\qt@newcmd\qurantrans@en@clxxi{%
Lo! In the creation of the heavens and the earth, and the difference of night and day, and the ships which run upon the sea with that which is of use to men, and the water which Allah sendeth down from the sky, thereby reviving the earth after its death, and dispersing all kinds of beasts therein, and (in) the ordinance of the winds, and the clouds obedient between heaven and earth: are signs (of Allah's Sovereignty) for people who have sense.\qt@no{164}}%
\qt@newcmd\qurantrans@en@clxxii{%
Yet of mankind are some who take unto themselves (objects of worship which they set as) rivals to Allah, loving them with a love like (that which is the due) of Allah (only) - those who believe are stauncher in their love for Allah - Oh, that those who do evil had but known, (on the day) when they behold the doom, that power belongeth wholly to Allah, and that Allah is severe in punishment!\qt@no{165}}%
\qt@newcmd\qurantrans@en@clxxiii{%
(On the day) when those who were followed disown those who followed (them), and they behold the doom, and all their aims collapse with them.\qt@no{166}}%
\qt@newcmd\qurantrans@en@clxxiv{%
And those who were but followers will say: If a return were possible for us, we would disown them even as they have disowned us. Thus will Allah show them their own deeds as anguish for them, and they will not emerge from the Fire.\qt@no{167}}%
\qt@newcmd\qurantrans@en@clxxv{%
O mankind! Eat of that which is lawful and wholesome in the earth, and follow not the footsteps of the devil. Lo! he is an open enemy for you.\qt@no{168}}%
\qt@newcmd\qurantrans@en@clxxvi{%
He enjoineth upon you only the evil and the foul, and that ye should tell concerning Allah that which ye know not.\qt@no{169}}%
\qt@newcmd\qurantrans@en@clxxvii{%
And when it is said unto them: Follow that which Allah hath revealed, they say: We follow that wherein we found our fathers. What! Even though their fathers were wholly unintelligent and had no guidance?\qt@no{170}}%
\qt@newcmd\qurantrans@en@clxxviii{%
The likeness of those who disbelieve (in relation to the messenger) is as the likeness of one who calleth unto that which heareth naught except a shout and cry. Deaf, dumb, blind, therefore they have no sense.\qt@no{171}}%
\qt@newcmd\qurantrans@en@clxxix{%
O ye who believe! Eat of the good things wherewith We have provided you, and render thanks to Allah if it is (indeed) He Whom ye worship.\qt@no{172}}%
\qt@newcmd\qurantrans@en@clxxx{%
He hath forbidden you only carrion, and blood, and swineflesh, and that which hath been immolated to (the name of) any other than Allah. But he who is driven by necessity, neither craving nor transgressing, it is no sin for him. Lo! Allah is Forgiving, Merciful.\qt@no{173}}%
\qt@newcmd\qurantrans@en@clxxxi{%
Lo! those who hide aught of the Scripture which Allah hath revealed and purchase a small gain therewith, they eat into their bellies nothing else than fire. Allah will not speak to them on the Day of Resurrection, nor will He make them grow. Theirs will be a painful doom.\qt@no{174}}%
\qt@newcmd\qurantrans@en@clxxxii{%
Those are they who purchase error at the price of guidance, and torment at the price of pardon. How constant are they in their strife to reach the Fire!\qt@no{175}}%
\qt@newcmd\qurantrans@en@clxxxiii{%
That is because Allah hath revealed the Scripture with the truth. Lo! those who find (a cause of) disagreement in the Scripture are in open schism.\qt@no{176}}%
\qt@newcmd\qurantrans@en@clxxxiv{%
It is not righteousness that ye turn your faces to the East and the West; but righteous is he who believeth in Allah and the Last Day and the angels and the Scripture and the prophets; and giveth wealth, for love of Him, to kinsfolk and to orphans and the needy and the wayfarer and to those who ask, and to set slaves free; and observeth proper worship and payeth the poor-due. And those who keep their treaty when they make one, and the patient in tribulation and adversity and time of stress. Such are they who are sincere. Such are the Allah-fearing.\qt@no{177}}%
\qt@newcmd\qurantrans@en@clxxxv{%
O ye who believe! Retaliation is prescribed for you in the matter of the murdered; the freeman for the freeman, and the slave for the slave, and the female for the female. And for him who is forgiven somewhat by his (injured) brother, prosecution according to usage and payment unto him in kindness. This is an alleviation and a mercy from your Lord. He who transgresseth after this will have a painful doom.\qt@no{178}}%
\qt@newcmd\qurantrans@en@clxxxvi{%
And there is life for you in retaliation, O men of understanding, that ye may ward off (evil).\qt@no{179}}%
\qt@newcmd\qurantrans@en@clxxxvii{%
It is prescribed for you, when death approacheth one of you, if he leave wealth, that he bequeath unto parents and near relatives in kindness. (This is) a duty for all those who ward off (evil).\qt@no{180}}%
\qt@newcmd\qurantrans@en@clxxxviii{%
And whoso changeth (the will) after he hath heard it - the sin thereof is only upon those who change it. Lo! Allah is Hearer, Knower.\qt@no{181}}%
\qt@newcmd\qurantrans@en@clxxxix{%
But he who feareth from a testator some unjust or sinful clause, and maketh peace between the parties, (it shall be) no sin for him. Lo! Allah is Forgiving, Merciful.\qt@no{182}}%
\qt@newcmd\qurantrans@en@cxc{%
O ye who believe! Fasting is prescribed for you, even as it was prescribed for those before you, that ye may ward off (evil);\qt@no{183}}%
\qt@newcmd\qurantrans@en@cxci{%
(Fast) a certain number of days; and (for) him who is sick among you, or on a journey, (the same) number of other days; and for those who can afford it there is a ransom: the feeding of a man in need - but whoso doeth good of his own accord, it is better for him: and that ye fast is better for you if ye did but know -\qt@no{184}}%
\qt@newcmd\qurantrans@en@cxcii{%
The month of Ramadan in which was revealed the Qur'an, a guidance for mankind, and clear proofs of the guidance, and the Criterion (of right and wrong). And whosoever of you is present, let him fast the month, and whosoever of you is sick or on a journey, (let him fast the same) number of other days. Allah desireth for you ease; He desireth not hardship for you; and (He desireth) that ye should complete the period, and that ye should magnify Allah for having guided you, and that peradventure ye may be thankful.\qt@no{185}}%
\qt@newcmd\qurantrans@en@cxciii{%
And when My servants question thee concerning Me, then surely I am nigh. I answer the prayer of the suppliant when he crieth unto Me. So let them hear My call and let them trust in Me, in order that they may be led aright.\qt@no{186}}%
\qt@newcmd\qurantrans@en@cxciv{%
It is made lawful for you to go in unto your wives on the night of the fast. They are raiment for you and ye are raiment for them. Allah is Aware that ye were deceiving yourselves in this respect and He hath turned in mercy toward you and relieved you. So hold intercourse with them and seek that which Allah hath ordained for you, and eat and drink until the white thread becometh distinct to you from the black thread of the dawn. Then strictly observe the fast till nightfall and touch them not, but be at your devotions in the mosques. These are the limits imposed by Allah, so approach them not. Thus Allah expoundeth His revelation to mankind that they may ward off (evil).\qt@no{187}}%
\qt@newcmd\qurantrans@en@cxcv{%
And eat not up your property among yourselves in vanity, nor seek by it to gain the hearing of the judges that ye may knowingly devour a portion of the property of others wrongfully.\qt@no{188}}%
\qt@newcmd\qurantrans@en@cxcvi{%
They ask thee, (O Muhammad), of new moons, say: They are fixed seasons for mankind and for the pilgrimage. It is not righteousness that ye go to houses by the backs thereof (as do the idolaters at certain seasons), but the righteous man is he who wardeth off (evil). So go to houses by the gates thereof, and observe your duty to Allah, that ye may be successful.\qt@no{189}}%
\qt@newcmd\qurantrans@en@cxcvii{%
Fight in the way of Allah against those who fight against you, but begin not hostilities. Lo! Allah loveth not aggressors.\qt@no{190}}%
\qt@newcmd\qurantrans@en@cxcviii{%
And slay them wherever ye find them, and drive them out of the places whence they drove you out, for persecution is worse than slaughter. And fight not with them at the Inviolable Place of Worship until they first attack you there, but if they attack you (there) then slay them. Such is the reward of disbelievers.\qt@no{191}}%
\qt@newcmd\qurantrans@en@cxcix{%
But if they desist, then lo! Allah is Forgiving, Merciful.\qt@no{192}}%
\qt@newcmd\qurantrans@en@cc{%
And fight them until persecution is no more, and religion is for Allah. But if they desist, then let there be no hostility except against wrong-doers.\qt@no{193}}%
\qt@newcmd\qurantrans@en@cci{%
The forbidden month for the forbidden month, and forbidden things in retaliation. And one who attacketh you, attack him in like manner as he attacked you. Observe your duty to Allah, and know that Allah is with those who ward off (evil).\qt@no{194}}%
\qt@newcmd\qurantrans@en@ccii{%
Spend your wealth for the cause of Allah, and be not cast by your own hands to ruin; and do good. Lo! Allah loveth the beneficent.\qt@no{195}}%
\qt@newcmd\qurantrans@en@cciii{%
Perform the pilgrimage and the visit (to Makka) for Allah. And if ye are prevented, then send such gifts as can be obtained with ease, and shave not your heads until the gifts have reached their destination. And whoever among you is sick or hath an ailment of the head must pay a ransom of fasting or almsgiving or offering. And if ye are in safety, then whosoever contenteth himself with the visit for the pilgrimage (shall give) such gifts as can be had with ease. And whosoever cannot find (such gifts), then a fast of three days while on the pilgrimage, and of seven when ye have returned; that is, ten in all. That is for him whoso folk are not present at the Inviolable Place of Worship. Observe your duty to Allah, and know that Allah is severe in punishment.\qt@no{196}}%
\qt@newcmd\qurantrans@en@cciv{%
The pilgrimage is (in) the well-known months, and whoever is minded to perform the pilgrimage therein (let him remember that) there is (to be) no lewdness nor abuse nor angry conversation on the pilgrimage. And whatsoever good ye do Allah knoweth it. So make provision for yourselves (Hereafter); for the best provision is to ward off evil. Therefore keep your duty unto Me, O men of understanding.\qt@no{197}}%
\qt@newcmd\qurantrans@en@ccv{%
It is no sin for you that ye seek the bounty of your Lord (by trading). But, when ye press on in the multitude from 'Arafat, remember Allah by the sacred monument. Remember Him as He hath guided you, although before ye were of those astray.\qt@no{198}}%
\qt@newcmd\qurantrans@en@ccvi{%
Then hasten onward from the place whence the multitude hasteneth onward, and ask forgiveness of Allah. Lo! Allah is Forgiving, Merciful.\qt@no{199}}%
\qt@newcmd\qurantrans@en@ccvii{%
And when ye have completed your devotions, then remember Allah as ye remember your fathers or with a more lively remembrance. But of mankind is he who saith: ``Our Lord! Give unto us in the world," and he hath no portion in the Hereafter.\qt@no{200}}%
\qt@newcmd\qurantrans@en@ccviii{%
And of them (also) is he who saith: ``Our Lord! Give unto us in the world that which is good and in the Hereafter that which is good, and guard us from the doom of Fire."\qt@no{201}}%
\qt@newcmd\qurantrans@en@ccix{%
For them there is in store a goodly portion out of that which they have earned. Allah is swift at reckoning.\qt@no{202}}%
\qt@newcmd\qurantrans@en@ccx{%
Remember Allah through the appointed days. Then whoso hasteneth (his departure) by two days, it is no sin for him, and whoso delayeth, it is no sin for him; that is for him who wardeth off (evil). Be careful of your duty to Allah, and know that unto Him ye will be gathered.\qt@no{203}}%
\qt@newcmd\qurantrans@en@ccxi{%
And of mankind there is he whoso conversation on the life of this world pleaseth thee (Muhammad), and he calleth Allah to witness as to that which is in his heart; yet he is the most rigid of opponents.\qt@no{204}}%
\qt@newcmd\qurantrans@en@ccxii{%
And when he turneth away (from thee) his effort in the land is to make mischief therein and to destroy the crops and the cattle; and Allah loveth not mischief.\qt@no{205}}%
\qt@newcmd\qurantrans@en@ccxiii{%
And when it is said unto him: Be careful of thy duty to Allah, pride taketh him to sin. Hell will settle his account, an evil resting-place.\qt@no{206}}%
\qt@newcmd\qurantrans@en@ccxiv{%
And of mankind is he who would sell himself, seeking the pleasure of Allah; and Allah hath compassion on (His) bondmen.\qt@no{207}}%
\qt@newcmd\qurantrans@en@ccxv{%
O ye who believe! Come, all of you, into submission (unto Him); and follow not the footsteps of the devil. Lo! he is an open enemy for you.\qt@no{208}}%
\qt@newcmd\qurantrans@en@ccxvi{%
And if ye slide back after the clear proofs have come unto you, then know that Allah is Mighty, Wise.\qt@no{209}}%
\qt@newcmd\qurantrans@en@ccxvii{%
Wait they for naught else than that Allah should come unto them in the shadows of the clouds with the angels? Then the case would be already judged. All cases go back to Allah (for judgment).\qt@no{210}}%
\qt@newcmd\qurantrans@en@ccxviii{%
Ask of the Children of Israel how many a clear revelation We gave them! He who altereth the grace of Allah after it hath come unto him (for him), lo! Allah is severe in punishment.\qt@no{211}}%
\qt@newcmd\qurantrans@en@ccxix{%
Beautified is the life of the world for those who disbelieve; they make a jest of the believers. But those who keep their duty to Allah will be above them on the Day of Resurrection. Allah giveth without stint to whom He will.\qt@no{212}}%
\qt@newcmd\qurantrans@en@ccxx{%
Mankind were one community, and Allah sent (unto them) prophets as bearers of good tidings and as warners, and revealed therewith the Scripture with the truth that it might judge between mankind concerning that wherein they differed. And only those unto whom (the Scripture) was given differed concerning it, after clear proofs had come unto them, through hatred one of another. And Allah by His Will guided those who believe unto the truth of that concerning which they differed. Allah guideth whom He will unto a straight path.\qt@no{213}}%
\qt@newcmd\qurantrans@en@ccxxi{%
Or think ye that ye will enter paradise while yet there hath not come unto you the like of (that which came to) those who passed away before you? Affliction and adversity befell them, they were shaken as with earthquake, till the messenger (of Allah) and those who believed along with him said: When cometh Allah's help? Now surely Allah's help is nigh.\qt@no{214}}%
\qt@newcmd\qurantrans@en@ccxxii{%
They ask thee, (O Muhammad), what they shall spend. Say: that which ye spend for good (must go) to parents and near kindred and orphans and the needy and the wayfarer. And whatsoever good ye do, lo! Allah is Aware of it.\qt@no{215}}%
\qt@newcmd\qurantrans@en@ccxxiii{%
Warfare is ordained for you, though it is hateful unto you; but it may happen that ye hate a thing which is good for you, and it may happen that ye love a thing which is bad for you. Allah knoweth, ye know not.\qt@no{216}}%
\qt@newcmd\qurantrans@en@ccxxiv{%
They question thee (O Muhammad) with regard to warfare in the sacred month. Say: Warfare therein is a great (transgression), but to turn (men) from the way of Allah, and to disbelieve in Him and in the Inviolable Place of Worship, and to expel His people thence, is a greater with Allah; for persecution is worse than killing. And they will not cease from fighting against you till they have made you renegades from your religion, if they can. And whoso becometh a renegade and dieth in his disbelief: such are they whose works have fallen both in the world and the Hereafter. Such are rightful owners of the Fire: they will abide therein.\qt@no{217}}%
\qt@newcmd\qurantrans@en@ccxxv{%
Lo! those who believe, and those who emigrate (to escape the persecution) and strive in the way of Allah, these have hope of Allah's mercy. Allah is Forgiving, Merciful.\qt@no{218}}%
\qt@newcmd\qurantrans@en@ccxxvi{%
They question thee about strong drink and games of chance. Say: In both is great sin, and (some) utility for men; but the sin of them is greater than their usefulness. And they ask thee what they ought to spend. Say: that which is superfluous. Thus Allah maketh plain to you (His) revelations, that haply ye may reflect.\qt@no{219}}%
\qt@newcmd\qurantrans@en@ccxxvii{%
Upon the world and the Hereafter. And they question thee concerning orphans. Say: To improve their lot is best. And if ye mingle your affairs with theirs, then (they are) your brothers. Allah knoweth him who spoileth from him who improveth. Had Allah willed He could have overburdened you. Allah is Mighty, Wise.\qt@no{220}}%
\qt@newcmd\qurantrans@en@ccxxviii{%
Wed not idolatresses till they believe; for lo! a believing bondwoman is better than an idolatress though she please you; and give not your daughters in marriage to idolaters till they believe, for lo! a believing slave is better than an idolater though he please you. These invite unto the Fire, and Allah inviteth unto the Garden, and unto forgiveness by His grace, and expoundeth His revelations to mankind that haply they may remember.\qt@no{221}}%
\qt@newcmd\qurantrans@en@ccxxix{%
They question thee (O Muhammad) concerning menstruation. Say: It is an illness, so let women alone at such times and go not in unto them till they are cleansed. And when they have purified themselves, then go in unto them as Allah hath enjoined upon you. Truly Allah loveth those who turn unto Him, and loveth those who have a care for cleanness.\qt@no{222}}%
\qt@newcmd\qurantrans@en@ccxxx{%
Your women are a tilth for you (to cultivate) so go to your tilth as ye will, and send (good deeds) before you for your souls, and fear Allah, and know that ye will (one day) meet Him. Give glad tidings to believers, (O Muhammad).\qt@no{223}}%
\qt@newcmd\qurantrans@en@ccxxxi{%
And make not Allah, by your oaths, a hindrance to your being righteous and observing your duty unto Him and making peace among mankind. Allah is Hearer, Knower.\qt@no{224}}%
\qt@newcmd\qurantrans@en@ccxxxii{%
Allah will not take you to task for that which is unintentional in your oaths. But He will take you to task for that which your hearts have garnered. Allah is Forgiving, Clement.\qt@no{225}}%
\qt@newcmd\qurantrans@en@ccxxxiii{%
Those who forswear their wives must wait four months; then, if they change their mind, lo! Allah is Forgiving, Merciful.\qt@no{226}}%
\qt@newcmd\qurantrans@en@ccxxxiv{%
And if they decide upon divorce (let them remember that) Allah is Hearer, Knower.\qt@no{227}}%
\qt@newcmd\qurantrans@en@ccxxxv{%
Women who are divorced shall wait, keeping themselves apart, three (monthly) courses. And it is not lawful for them that they should conceal that which Allah hath created in their wombs if they are believers in Allah and the Last Day. And their husbands would do better to take them back in that case if they desire a reconciliation. And they (women) have rights similar to those (of men) over them in kindness, and men are a degree above them. Allah is Mighty, Wise.\qt@no{228}}%
\qt@newcmd\qurantrans@en@ccxxxvi{%
Divorce must be pronounced twice and then (a woman) must be retained in honour or released in kindness. And it is not lawful for you that ye take from women aught of that which ye have given them; except (in the case) when both fear that they may not be able to keep within the limits (imposed by) Allah. And if ye fear that they may not be able to keep the limits of Allah, in that case it is no sin for either of them if the woman ransom herself. These are the limits (imposed by) Allah. Transgress them not. For whoso transgresseth Allah's limits: such are wrong-doers.\qt@no{229}}%
\qt@newcmd\qurantrans@en@ccxxxvii{%
And if he hath divorced her (the third time), then she is not lawful unto him thereafter until she hath wedded another husband. Then if he (the other husband) divorce her it is no sin for both of them that they come together again if they consider that they are able to observe the limits of Allah. These are the limits of Allah. He manifesteth them for people who have knowledge.\qt@no{230}}%
\qt@newcmd\qurantrans@en@ccxxxviii{%
When ye have divorced women, and they have reached their term, then retain them in kindness or release them in kindness. Retain them not to their hurt so that ye transgress (the limits). He who doeth that hath wronged his soul. Make not the revelations of Allah a laughing-stock (by your behaviour), but remember Allah's grace upon you and that which He hath revealed unto you of the Scripture and of wisdom, whereby He doth exhort you. Observe your duty to Allah and know that Allah is Aware of all things.\qt@no{231}}%
\qt@newcmd\qurantrans@en@ccxxxix{%
And when ye have divorced women and they reach their term, place not difficulties in the way of their marrying their husbands if it is agreed between them in kindness. This is an admonition for him among you who believeth in Allah and the Last Day. That is more virtuous for you, and cleaner. Allah knoweth; ye know not.\qt@no{232}}%
\qt@newcmd\qurantrans@en@ccxl{%
Mothers shall suckle their children for two whole years; (that is) for those who wish to complete the suckling. The duty of feeding and clothing nursing mothers in a seemly manner is upon the father of the child. No-one should be charged beyond his capacity. A mother should not be made to suffer because of her child, nor should he to whom the child is born (be made to suffer) because of his child. And on the (father's) heir is incumbent the like of that (which was incumbent on the father). If they desire to wean the child by mutual consent and (after) consultation, it is no sin for them; and if ye wish to give your children out to nurse, it is no sin for you, provide that ye pay what is due from you in kindness. Observe your duty to Allah, and know that Allah is Seer of what ye do.\qt@no{233}}%
\qt@newcmd\qurantrans@en@ccxli{%
Such of you as die and leave behind them wives, they (the wives) shall wait, keeping themselves apart, four months and ten days. And when they reach the term (prescribed for them) then there is no sin for you in aught that they may do with themselves in decency. Allah is informed of what ye do.\qt@no{234}}%
\qt@newcmd\qurantrans@en@ccxlii{%
There is no sin for you in that which ye proclaim or hide in your minds concerning your troth with women. Allah knoweth that ye will remember them. But plight not your troth with women except by uttering a recognised form of words. And do not consummate the marriage until (the term) prescribed is run. Know that Allah knoweth what is in your minds, so beware of Him; and know that Allah is Forgiving, Clement.\qt@no{235}}%
\qt@newcmd\qurantrans@en@ccxliii{%
It is no sin for you if ye divorce women while yet ye have not touched them, nor appointed unto them a portion. Provide for them, the rich according to his means, and the straitened according to his means, a fair provision. (This is) a bounden duty for those who do good.\qt@no{236}}%
\qt@newcmd\qurantrans@en@ccxliv{%
If ye divorce them before ye have touched them and ye have appointed unto them a portion, then (pay the) half of that which ye appointed, unless they (the women) agree to forgo it, or he agreeth to forgo it in whose hand is the marriage tie. To forgo is nearer to piety. And forget not kindness among yourselves. Allah is Seer of what ye do.\qt@no{237}}%
\qt@newcmd\qurantrans@en@ccxlv{%
Be guardians of your prayers, and of the midmost prayer, and stand up with devotion to Allah.\qt@no{238}}%
\qt@newcmd\qurantrans@en@ccxlvi{%
And if ye go in fear, then (pray) standing or on horseback. And when ye are again in safety, remember Allah, as He hath taught you that which (heretofore) ye knew not.\qt@no{239}}%
\qt@newcmd\qurantrans@en@ccxlvii{%
(In the case of) those of you who are about to die and leave behind them wives, they should bequeath unto their wives a provision for the year without turning them out, but if they go out (of their own accord) there is no sin for you in that which they do of themselves within their rights. Allah is Mighty, Wise.\qt@no{240}}%
\qt@newcmd\qurantrans@en@ccxlviii{%
For divorced women a provision in kindness: a duty for those who ward off (evil).\qt@no{241}}%
\qt@newcmd\qurantrans@en@ccxlix{%
Thus Allah expoundeth unto you His revelations so that ye may understand.\qt@no{242}}%
\qt@newcmd\qurantrans@en@ccl{%
Bethink thee (O Muhammad) of those of old, who went forth from their habitations in their thousands, fearing death, and Allah said unto them: Die; and then He brought them back to life. Lo! Allah is a Lord of Kindness to mankind, but most of mankind give not thanks.\qt@no{243}}%
\qt@newcmd\qurantrans@en@ccli{%
Fight in the way of Allah, and know that Allah is Hearer, Knower.\qt@no{244}}%
\qt@newcmd\qurantrans@en@cclii{%
Who is it that will lend unto Allah a goodly loan, so that He may give it increase manifold? Allah straiteneth and enlargeth. Unto Him ye will return.\qt@no{245}}%
\qt@newcmd\qurantrans@en@ccliii{%
Bethink thee of the leaders of the Children of Israel after Moses, how they said unto a prophet whom they had: Set up for us a king and we will fight in Allah's way. He said: Would ye then refrain from fighting if fighting were prescribed for you? They said: Why should we not fight in Allah's way when we have been driven from our dwellings with our children? Yet, when fighting was prescribed for them, they turned away, all save a few of them. Allah is aware of evil-doers.\qt@no{246}}%
\qt@newcmd\qurantrans@en@ccliv{%
Their Prophet said unto them: Lo! Allah hath raised up Saul to be a king for you. They said: How can he have kingdom over us when we are more deserving of the kingdom than he is, since he hath not been given wealth enough? He said: Lo! Allah hath chosen him above you, and hath increased him abundantly in wisdom and stature. Allah bestoweth His Sovereignty on whom He will. Allah is All-Embracing, All-Knowing.\qt@no{247}}%
\qt@newcmd\qurantrans@en@cclv{%
And their Prophet said unto them: Lo! the token of his kingdom is that there shall come unto you the ark wherein is peace of reassurance from your Lord, and a remnant of that which the house of Moses and the house of Aaron left behind, the angels bearing it. Lo! herein shall be a token for you if (in truth) ye are believers.\qt@no{248}}%
\qt@newcmd\qurantrans@en@cclvi{%
And when Saul set out with the army, he said: Lo! Allah will try you by (the ordeal of) a river. Whosoever therefore drinketh thereof he is not of me, and whosoever tasteth it not he is of me, save him who taketh (thereof) in the hollow of his hand. But they drank thereof, all save a few of them. And after he had crossed (the river), he and those who believed with him, they said: We have no power this day against Goliath and his hosts. But those who knew that they would meet Allah exclaimed: How many a little company hath overcome a mighty host by Allah's leave! Allah is with the steadfast.\qt@no{249}}%
\qt@newcmd\qurantrans@en@cclvii{%
And when they went into the field against Goliath and his hosts they said: Our Lord! Bestow on us endurance, make our foothold sure, and give us help against the disbelieving folk.\qt@no{250}}%
\qt@newcmd\qurantrans@en@cclviii{%
So they routed them by Allah's leave and David slew Goliath; and Allah gave him the kingdom and wisdom, and taught him of that which He willeth. And if Allah had not repelled some men by others the earth would have been corrupted. But Allah is a Lord of Kindness to (His) creatures.\qt@no{251}}%
\qt@newcmd\qurantrans@en@cclix{%
These are the portents of Allah which We recite unto thee (Muhammad) with truth, and lo! thou art of the number of (Our) messengers;\qt@no{252}}%
\qt@newcmd\qurantrans@en@cclx{%
Of those messengers, some of whom We have caused to excel others, and of whom there are some unto whom Allah spake, while some of them He exalted (above others) in degree; and We gave Jesus, son of Mary, clear proofs (of Allah's Sovereignty) and We supported him with the holy Spirit. And if Allah had so wiled it, those who followed after them would not have fought one with another after the clear proofs had come unto them. But they differed, some of them believing and some disbelieving. And if Allah had so willed it, they would not have fought one with another; but Allah doeth what He will.\qt@no{253}}%
\qt@newcmd\qurantrans@en@cclxi{%
O ye who believe! spend of that wherewith We have provided you ere a day come when there will be no trafficking, nor friendship, nor intercession. The disbelievers, they are the wrong-doers.\qt@no{254}}%
\qt@newcmd\qurantrans@en@cclxii{%
Allah! There is no deity save Him, the Alive, the Eternal. Neither slumber nor sleep overtaketh Him. Unto Him belongeth whatsoever is in the heavens and whatsoever is in the earth. Who is he that intercedeth with Him save by His leave? He knoweth that which is in front of them and that which is behind them, while they encompass nothing of His knowledge save what He will. His throne includeth the heavens and the earth, and He is never weary of preserving them. He is the Sublime, the Tremendous.\qt@no{255}}%
\qt@newcmd\qurantrans@en@cclxiii{%
There is no compulsion in religion. The right direction is henceforth distinct from error. And he who rejecteth false deities and believeth in Allah hath grasped a firm handhold which will never break. Allah is Hearer, Knower.\qt@no{256}}%
\qt@newcmd\qurantrans@en@cclxiv{%
Allah is the Protecting Guardian of those who believe. He bringeth them out of darkness into light. As for those who disbelieve, their patrons are false deities. They bring them out of light into darkness. Such are rightful owners of the Fire. They will abide therein.\qt@no{257}}%
\qt@newcmd\qurantrans@en@cclxv{%
Bethink thee of him who had an argument with Abraham about his Lord, because Allah had given him the kingdom; how, when Abraham said: My Lord is He Who giveth life and causeth death, he answered: I give life and cause death. Abraham said: Lo! Allah causeth the sun to rise in the East, so do thou cause it to come up from the West. Thus was the disbeliever abashed. And Allah guideth not wrongdoing folk.\qt@no{258}}%
\qt@newcmd\qurantrans@en@cclxvi{%
Or (bethink thee of) the like of him who, passing by a township which had fallen into utter ruin, exclaimed: How shall Allah give this township life after its death? And Allah made him die a hundred years, then brought him back to life. He said: How long hast thou tarried? (The man) said: I have tarried a day or part of a day. (He) said: Nay, but thou hast tarried for a hundred years. Just look at thy food and drink which have not rotted! Look at thine ass! And, that We may make thee a token unto mankind, look at the bones, how We adjust them and then cover them with flesh! And when (the matter) became clear unto him, he said: I know now that Allah is Able to do all things.\qt@no{259}}%
\qt@newcmd\qurantrans@en@cclxvii{%
And when Abraham said (unto his Lord): My Lord! Show me how Thou givest life to the dead, He said: Dost thou not believe? Abraham said: Yea, but (I ask) in order that my heart may be at ease. (His Lord) said: Take four of the birds and cause them to incline unto thee, then place a part of them on each hill, then call them, they will come to thee in haste, and know that Allah is Mighty, Wise.\qt@no{260}}%
\qt@newcmd\qurantrans@en@cclxviii{%
The likeness of those who spend their wealth in Allah's way is as the likeness of a grain which groweth seven ears, in every ear a hundred grains. Allah giveth increase manifold to whom He will. Allah is All-Embracing, All-Knowing.\qt@no{261}}%
\qt@newcmd\qurantrans@en@cclxix{%
Those who spend their wealth for the cause of Allah and afterward make not reproach and injury to follow that which they have spent; their reward is with their Lord, and there shall no fear come upon them, neither shall they grieve.\qt@no{262}}%
\qt@newcmd\qurantrans@en@cclxx{%
A kind word with forgiveness is better than almsgiving followed by injury. Allah is Absolute, Clement.\qt@no{263}}%
\qt@newcmd\qurantrans@en@cclxxi{%
O ye who believe! Render not vain your almsgiving by reproach and injury, like him who spendeth his wealth only to be seen of men and believeth not in Allah and the Last Day. His likeness is as the likeness of a rock whereon is dust of earth; a rainstorm smiteth it, leaving it smooth and bare. They have no control of aught of that which they have gained. Allah guideth not the disbelieving folk.\qt@no{264}}%
\qt@newcmd\qurantrans@en@cclxxii{%
And the likeness of those who spend their wealth in search of Allah's pleasure, and for the strengthening of their souls, is as the likeness of a garden on a height. The rainstorm smiteth it and it bringeth forth its fruit twofold. And if the rainstorm smite it not, then the shower. Allah is Seer of what ye do.\qt@no{265}}%
\qt@newcmd\qurantrans@en@cclxxiii{%
Would any of you like to have a garden of palm-trees and vines, with rivers flowing underneath it, with all kinds of fruit for him therein; and old age hath stricken him and he hath feeble offspring; and a fiery whirlwind striketh it and it is (all) consumed by fire. Thus Allah maketh plain His revelations unto you, in order that ye may give thought.\qt@no{266}}%
\qt@newcmd\qurantrans@en@cclxxiv{%
O ye who believe! Spend of the good things which ye have earned, and of that which We bring forth from the earth for you, and seek not the bad (with intent) to spend thereof (in charity) when ye would not take it for yourselves save with disdain; and know that Allah is Absolute, Owner of Praise.\qt@no{267}}%
\qt@newcmd\qurantrans@en@cclxxv{%
The devil promiseth you destitution and enjoineth on you lewdness. But Allah promiseth you forgiveness from Himself with bounty. Allah is All-Embracing, All-knowing.\qt@no{268}}%
\qt@newcmd\qurantrans@en@cclxxvi{%
He giveth wisdom unto whom He will, and he unto whom wisdom is given, he truly hath received abundant good. But none remember except men of understanding.\qt@no{269}}%
\qt@newcmd\qurantrans@en@cclxxvii{%
Whatever alms ye spend or vow ye vow, lo! Allah knoweth it. Wrong-doers have no helpers.\qt@no{270}}%
\qt@newcmd\qurantrans@en@cclxxviii{%
If ye publish your almsgiving, it is well, but if ye hide it and give it to the poor, it will be better for you, and will atone for some of your ill-deeds. Allah is Informed of what ye do.\qt@no{271}}%
\qt@newcmd\qurantrans@en@cclxxix{%
The guiding of them is not thy duty (O Muhammad), but Allah guideth whom He will. And whatsoever good thing ye spend, it is for yourselves, when ye spend not save in search of Allah's Countenance; and whatsoever good thing ye spend, it will be repaid to you in full, and ye will not be wronged.\qt@no{272}}%
\qt@newcmd\qurantrans@en@cclxxx{%
(Alms are) for the poor who are straitened for the cause of Allah, who cannot travel in the land (for trade). The unthinking man accounteth them wealthy because of their restraint. Thou shalt know them by their mark: They do not beg of men with importunity. And whatsoever good thing ye spend, lo! Allah knoweth it.\qt@no{273}}%
\qt@newcmd\qurantrans@en@cclxxxi{%
Those who spend their wealth by night and day, by stealth and openly, verily their reward is with their Lord, and their shall no fear come upon them neither shall they grieve.\qt@no{274}}%
\qt@newcmd\qurantrans@en@cclxxxii{%
Those who swallow usury cannot rise up save as he ariseth whom the devil hath prostrated by (his) touch. That is because they say: Trade is just like usury; whereas Allah permitteth trading and forbiddeth usury. He unto whom an admonition from his Lord cometh, and (he) refraineth (in obedience thereto), he shall keep (the profits of) that which is past, and his affair (henceforth) is with Allah. As for him who returneth (to usury) - Such are rightful owners of the Fire. They will abide therein.\qt@no{275}}%
\qt@newcmd\qurantrans@en@cclxxxiii{%
Allah hath blighted usury and made almsgiving fruitful. Allah loveth not the impious and guilty.\qt@no{276}}%
\qt@newcmd\qurantrans@en@cclxxxiv{%
Lo! those who believe and do good works and establish worship and pay the poor-due, their reward is with their Lord and there shall no fear come upon them neither shall they grieve.\qt@no{277}}%
\qt@newcmd\qurantrans@en@cclxxxv{%
O ye who believe! Observe your duty to Allah, and give up what remaineth (due to you) from usury, if ye are (in truth) believers.\qt@no{278}}%
\qt@newcmd\qurantrans@en@cclxxxvi{%
And if ye do not, then be warned of war (against you) from Allah and His messenger. And if ye repent, then ye have your principal (without interest). Wrong not, and ye shall not be wronged.\qt@no{279}}%
\qt@newcmd\qurantrans@en@cclxxxvii{%
And if the debtor is in straitened circumstances, then (let there be) postponement to (the time of) ease; and that ye remit the debt as almsgiving would be better for you if ye did but know.\qt@no{280}}%
\qt@newcmd\qurantrans@en@cclxxxviii{%
And guard yourselves against a day in which ye will be brought back to Allah. Then every soul will be paid in full that which it hath earned, and they will not be wronged.\qt@no{281}}%
\qt@newcmd\qurantrans@en@cclxxxix{%
O ye who believe! When ye contract a debt for a fixed term, record it in writing. Let a scribe record it in writing between you in (terms of) equity. No scribe should refuse to write as Allah hath taught him, so let him write, and let him who incurreth the debt dictate, and let him observe his duty to Allah his Lord, and diminish naught thereof. But if he who oweth the debt is of low understanding, or weak, or unable himself to dictate, then let the guardian of his interests dictate in (terms of) equity. And call to witness, from among your men, two witnesses. And if two men be not (at hand) then a man and two women, of such as ye approve as witnesses, so that if the one erreth (through forgetfulness) the other will remember. And the witnesses must not refuse when they are summoned. Be not averse to writing down (the contract) whether it be small or great, with (record of) the term thereof. That is more equitable in the sight of Allah and more sure for testimony, and the best way of avoiding doubt between you; save only in the case when it is actual merchandise which ye transfer among yourselves from hand to hand. In that case it is no sin for you if ye write it not. And have witnesses when ye sell one to another, and let no harm be done to scribe or witness. If ye do (harm to them) lo! it is a sin in you. Observe your duty to Allah. Allah is teaching you. And Allah is knower of all things.\qt@no{282}}%
\qt@newcmd\qurantrans@en@ccxc{%
If ye be on a journey and cannot find a scribe, then a pledge in hand (shall suffice). And if one of you entrusteth to another let him who is trusted deliver up that which is entrusted to him (according to the pact between them) and let him observe his duty to Allah his Lord. Hide not testimony. He who hideth it, verily his heart is sinful. Allah is Aware of what ye do.\qt@no{283}}%
\qt@newcmd\qurantrans@en@ccxci{%
Unto Allah (belongeth) whatsoever is in the heavens and whatsoever is in the earth; and whether ye make known what is in your minds or hide it, Allah will bring you to account for it. He will forgive whom He will and He will punish whom He will. Allah is Able to do all things.\qt@no{284}}%
\qt@newcmd\qurantrans@en@ccxcii{%
The messenger believeth in that which hath been revealed unto him from his Lord and (so do) believers. Each one believeth in Allah and His angels and His scriptures and His messengers - We make no distinction between any of His messengers - and they say: We hear, and we obey. (Grant us) Thy forgiveness, our Lord. Unto Thee is the journeying.\qt@no{285}}%
\qt@newcmd\qurantrans@en@ccxciii{%
Allah tasketh not a soul beyond its scope. For it (is only) that which it hath earned, and against it (only) that which it hath deserved. Our Lord! Condemn us not if we forget, or miss the mark! Our Lord! Lay not on us such a burden as thou didst lay on those before us! Our Lord! Impose not on us that which we have not the strength to bear! Pardon us, absolve us and have mercy on us, Thou, our Protector, and give us victory over the disbelieving folk.\qt@no{286}}%
\qt@newcmd\qurantrans@en@ccxciv{%
\basmalahen Alim. Lam. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@ccxcv{%
Allah! There is no god save Him, the Alive, the Eternal.\qt@no{2}}%
\qt@newcmd\qurantrans@en@ccxcvi{%
He hath revealed unto thee (Muhammad) the Scripture with truth, confirming that which was (revealed) before it, even as He revealed the Torah and the Gospel.\qt@no{3}}%
\qt@newcmd\qurantrans@en@ccxcvii{%
Aforetime, for a guidance to mankind; and hath revealed the Criterion (of right and wrong). Lo! those who disbelieve the revelations of Allah, theirs will be a heavy doom. Allah is Mighty, Able to Requite (the wrong).\qt@no{4}}%
\qt@newcmd\qurantrans@en@ccxcviii{%
Lo! nothing in the earth or in the heavens is hidden from Allah.\qt@no{5}}%
\qt@newcmd\qurantrans@en@ccxcix{%
He it is Who fashioneth you in the wombs as pleaseth Him. There is no Allah save Him, the Almighty, the Wise.\qt@no{6}}%
\qt@newcmd\qurantrans@en@ccc{%
He it is Who hath revealed unto thee (Muhammad) the Scripture wherein are clear revelations - they are the substance of the Book - and others (which are) allegorical. But those in whose hearts is doubt pursue, forsooth, that which is allegorical seeking (to cause) dissension by seeking to explain it. None knoweth its explanation save Allah. And those who are of sound instruction say: We believe therein; the whole is from our Lord; but only men of understanding really heed.\qt@no{7}}%
\qt@newcmd\qurantrans@en@ccci{%
Our Lord! Cause not our hearts to stray after Thou hast guided us, and bestow upon us mercy from Thy Presence. Lo! Thou, only Thou, art the Bestower.\qt@no{8}}%
\qt@newcmd\qurantrans@en@cccii{%
Our Lord! Lo! it is Thou Who gatherest mankind together to a Day of which there is no doubt. Lo! Allah faileth not to keep the tryst.\qt@no{9}}%
\qt@newcmd\qurantrans@en@ccciii{%
(On that Day) neither the riches nor the progeny of those who disbelieve will aught avail them with Allah. They will be fuel for Fire.\qt@no{10}}%
\qt@newcmd\qurantrans@en@ccciv{%
Like Pharaoh's folk and those who were before them, they disbelieved Our revelations and so Allah seized them for their sins. And Allah is severe in punishment.\qt@no{11}}%
\qt@newcmd\qurantrans@en@cccv{%
Say (O Muhammad) unto those who disbelieve: Ye shall be overcome and gathered unto Hell, an evil resting-place.\qt@no{12}}%
\qt@newcmd\qurantrans@en@cccvi{%
There was a token for you in two hosts which met: one army fighting in the way of Allah, and another disbelieving, whom they saw as twice their number, clearly, with their very eyes. Thus Allah strengtheneth with His succour whom He will. Lo! herein verily is a lesson for those who have eyes.\qt@no{13}}%
\qt@newcmd\qurantrans@en@cccvii{%
Beautified for mankind is love of the joys (that come) from women and offspring; and stored-up heaps of gold and silver, and horses branded (with their mark), and cattle and land. That is comfort of the life of the world. Allah! With Him is a more excellent abode.\qt@no{14}}%
\qt@newcmd\qurantrans@en@cccviii{%
Say: Shall I inform you of something better than that? For those who keep from evil, with their Lord, are Gardens underneath which rivers flow wherein they will abide, and pure companions, and contentment from Allah. Allah is Seer of His bondmen,\qt@no{15}}%
\qt@newcmd\qurantrans@en@cccix{%
Those who say: Our Lord! Lo! we believe. So forgive us our sins and guard us from the punishment of Fire;\qt@no{16}}%
\qt@newcmd\qurantrans@en@cccx{%
The steadfast, and the truthful, and the obedient, those who spend (and hoard not), those who pray for pardon in the watches of the night.\qt@no{17}}%
\qt@newcmd\qurantrans@en@cccxi{%
Allah (Himself) is Witness that there is no Allah save Him. And the angels and the men of learning (too are witness). Maintaining His creation in justice, there is no Allah save Him the Almighty, the Wise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@cccxii{%
Lo! religion with Allah (is) the Surrender (to His Will and Guidance). Those who (formerly) received the Scripture differed only after knowledge came unto them, through transgression among themselves. Whoso disbelieveth the revelations of Allah (will find that) lo! Allah is swift at reckoning.\qt@no{19}}%
\qt@newcmd\qurantrans@en@cccxiii{%
And if they argue with thee, (O Muhammad), say: I have surrendered my purpose to Allah and (so have) those who follow me. And say unto those who have received the Scripture and those who read not: Have ye (too) surrendered? If they surrender, then truly they are rightly guided, and if they turn away, then it is thy duty only to convey the message (unto them). Allah is Seer of (His) bondmen.\qt@no{20}}%
\qt@newcmd\qurantrans@en@cccxiv{%
Lo! those who disbelieve the revelations of Allah, and slay the prophets wrongfully, and slay those of mankind who enjoin equity: promise them a painful doom.\qt@no{21}}%
\qt@newcmd\qurantrans@en@cccxv{%
Those are they whose works have failed in the world and the Hereafter; and they have no helpers.\qt@no{22}}%
\qt@newcmd\qurantrans@en@cccxvi{%
Hast thou not seen how those who have received a portion of the Scripture invoke the Scripture of Allah (in their disputes) that it may judge between them; then a faction of them turn away, being opposed (to it)?\qt@no{23}}%
\qt@newcmd\qurantrans@en@cccxvii{%
That is because they say: The Fire will not touch us save for a certain number of days. That which they used to invent hath deceived them regarding their religion.\qt@no{24}}%
\qt@newcmd\qurantrans@en@cccxviii{%
How (will it be with them) when We have brought them all together to a Day of which there is no doubt, when every soul will be paid in full what it hath earned, and they will not be wronged.\qt@no{25}}%
\qt@newcmd\qurantrans@en@cccxix{%
Say: O Allah! Owner of Sovereignty! Thou givest sovereignty unto whom Thou wilt, and Thou withdrawest sovereignty from whom Thou wilt. Thou exaltest whom Thou wilt, and Thou abasest whom Thou wilt. In Thy hand is the good. Lo! Thou art Able to do all things.\qt@no{26}}%
\qt@newcmd\qurantrans@en@cccxx{%
Thou causest the night to pass into the day, and Thou causest the day to pass into the night. And Thou bringest forth the living from the dead, and Thou bringest forth the dead from the living. And Thou givest sustenance to whom Thou choosest, without stint.\qt@no{27}}%
\qt@newcmd\qurantrans@en@cccxxi{%
Let not the believers take disbelievers for their friends in preference to believers. Whoso doeth that hath no connection with Allah unless (it be) that ye but guard yourselves against them, taking (as it were) security. Allah biddeth you beware (only) of Himself. Unto Allah is the journeying.\qt@no{28}}%
\qt@newcmd\qurantrans@en@cccxxii{%
Say, (O Muhammad): Whether ye hide that which is in your breasts or reveal it, Allah knoweth it. He knoweth that which is in the heavens and that which is in the earth, and Allah is Able to do all things.\qt@no{29}}%
\qt@newcmd\qurantrans@en@cccxxiii{%
On the Day when every soul will find itself confronted with all that it hath done of good and all that it hath done of evil (every soul) will long that there might be a mighty space of distance between it and that (evil). Allah biddeth you beware of Him. And Allah is Full of Pity for (His) bondmen.\qt@no{30}}%
\qt@newcmd\qurantrans@en@cccxxiv{%
Say, (O Muhammad, to mankind): If ye love Allah, follow me; Allah will love you and forgive you your sins. Allah is Forgiving, Merciful.\qt@no{31}}%
\qt@newcmd\qurantrans@en@cccxxv{%
Say: Obey Allah and the messenger. But if they turn away, lo! Allah loveth not the disbelievers (in His guidance).\qt@no{32}}%
\qt@newcmd\qurantrans@en@cccxxvi{%
Lo! Allah preferred Adam and Noah and the Family of Abraham and the Family of 'Imran above (all His) creatures.\qt@no{33}}%
\qt@newcmd\qurantrans@en@cccxxvii{%
They were descendants one of another. Allah is Hearer, Knower.\qt@no{34}}%
\qt@newcmd\qurantrans@en@cccxxviii{%
(Remember) when the wife of 'Imran said: My Lord! I have vowed unto Thee that which is in my belly as a consecrated (offering). Accept it from me. Lo! Thou, only Thou, art the Hearer, the Knower!\qt@no{35}}%
\qt@newcmd\qurantrans@en@cccxxix{%
And when she was delivered she said: My Lord! Lo! I am delivered of a female - Allah knew best of what she was delivered - the male is not as the female; and lo! I have named her Mary, and lo! I crave Thy protection for her and for her offspring from Satan the outcast.\qt@no{36}}%
\qt@newcmd\qurantrans@en@cccxxx{%
And her Lord accepted her with full acceptance and vouchsafed to her a goodly growth; and made Zachariah her guardian. Whenever Zachariah went into the sanctuary where she was, he found that she had food. He said: O Mary! Whence cometh unto thee this (food)? She answered: It is from Allah. Allah giveth without stint to whom He will.\qt@no{37}}%
\qt@newcmd\qurantrans@en@cccxxxi{%
Then Zachariah prayed unto his Lord and said: My Lord! Bestow upon me of Thy bounty goodly offspring. Lo! Thou art the Hearer of Prayer.\qt@no{38}}%
\qt@newcmd\qurantrans@en@cccxxxii{%
And the angels called to him as he stood praying in the sanctuary: Allah giveth thee glad tidings of (a son whose name is) John, (who cometh) to confirm a word from Allah lordly, chaste, a prophet of the righteous.\qt@no{39}}%
\qt@newcmd\qurantrans@en@cccxxxiii{%
He said: My Lord! How can I have a son when age hath overtaken me already and my wife is barren? (The angel) answered: So (it will be). Allah doeth what He will.\qt@no{40}}%
\qt@newcmd\qurantrans@en@cccxxxiv{%
He said: My Lord! Appoint a token for me. (The angel) said: The token unto thee (shall be) that thou shalt not speak unto mankind three days except by signs. Remember thy Lord much, and praise (Him) in the early hours of night and morning.\qt@no{41}}%
\qt@newcmd\qurantrans@en@cccxxxv{%
And when the angels said: O Mary! Lo! Allah hath chosen thee and made thee pure, and hath preferred thee above (all) the women of creation.\qt@no{42}}%
\qt@newcmd\qurantrans@en@cccxxxvi{%
O Mary! Be obedient to thy Lord, prostrate thyself and bow with those who bow (in worship).\qt@no{43}}%
\qt@newcmd\qurantrans@en@cccxxxvii{%
This is of the tidings of things hidden. We reveal it unto thee (Muhammad). Thou wast not present with them when they threw their pens (to know) which of them should be the guardian of Mary, nor wast thou present with them when they quarrelled (thereupon).\qt@no{44}}%
\qt@newcmd\qurantrans@en@cccxxxviii{%
(And remember) when the angels said: O Mary! Lo! Allah giveth thee glad tidings of a word from him, whose name is the Messiah, Jesus, son of Mary, illustrious in the world and the Hereafter, and one of those brought near (unto Allah).\qt@no{45}}%
\qt@newcmd\qurantrans@en@cccxxxix{%
He will speak unto mankind in his cradle and in his manhood, and he is of the righteous.\qt@no{46}}%
\qt@newcmd\qurantrans@en@cccxl{%
She said: My Lord! How can I have a child when no mortal hath touched me? He said: So (it will be). Allah createth what He will. If He decreeth a thing, He saith unto it only: Be! and it is.\qt@no{47}}%
\qt@newcmd\qurantrans@en@cccxli{%
And He will teach him the Scripture and wisdom, and the Torah and the Gospel,\qt@no{48}}%
\qt@newcmd\qurantrans@en@cccxlii{%
And will make him a messenger unto the Children of Israel, (saying): Lo! I come unto you with a sign from your Lord. Lo! I fashion for you out of clay the likeness of a bird, and I breathe into it and it is a bird, by Allah's leave. I heal him who was born blind, and the leper, and I raise the dead, by Allah's leave. And I announce unto you what ye eat and what ye store up in your houses. Lo! herein verily is a portent for you, if ye are to be believers.\qt@no{49}}%
\qt@newcmd\qurantrans@en@cccxliii{%
And (I come) confirming that which was before me of the Torah, and to make lawful some of that which was forbidden unto you. I come unto you with a sign from your Lord, so keep your duty to Allah and obey me.\qt@no{50}}%
\qt@newcmd\qurantrans@en@cccxliv{%
Lo! Allah is my Lord and your Lord, so worship Him. That is a straight path.\qt@no{51}}%
\qt@newcmd\qurantrans@en@cccxlv{%
But when Jesus became conscious of their disbelief, he cried: Who will be my helpers in the cause of Allah? The disciples said: We will be Allah's helpers. We believe in Allah, and bear thou witness that we have surrendered (unto Him).\qt@no{52}}%
\qt@newcmd\qurantrans@en@cccxlvi{%
Our Lord! We believe in that which Thou hast revealed and we follow him whom Thou hast sent. Enrol us among those who witness (to the truth).\qt@no{53}}%
\qt@newcmd\qurantrans@en@cccxlvii{%
And they (the disbelievers) schemed, and Allah schemed (against them): and Allah is the best of schemers.\qt@no{54}}%
\qt@newcmd\qurantrans@en@cccxlviii{%
(And remember) when Allah said: O Jesus! Lo! I am gathering thee and causing thee to ascend unto Me, and am cleansing thee of those who disbelieve and am setting those who follow thee above those who disbelieve until the Day of Resurrection. Then unto Me ye will (all) return, and I shall judge between you as to that wherein ye used to differ.\qt@no{55}}%
\qt@newcmd\qurantrans@en@cccxlix{%
As for those who disbelieve I shall chastise them with a heavy chastisement in the world and the Hereafter; and they will have no helpers.\qt@no{56}}%
\qt@newcmd\qurantrans@en@cccl{%
And as for those who believe and do good works, He will pay them their wages in full. Allah loveth not wrong-doers.\qt@no{57}}%
\qt@newcmd\qurantrans@en@cccli{%
This (which) We recite unto thee is a revelation and a wise reminder.\qt@no{58}}%
\qt@newcmd\qurantrans@en@ccclii{%
Lo! the likeness of Jesus with Allah is as the likeness of Adam. He created him of dust, then He said unto him: Be! and he is.\qt@no{59}}%
\qt@newcmd\qurantrans@en@cccliii{%
(This is) the truth from thy Lord (O Muhammad), so be not thou of those who waver.\qt@no{60}}%
\qt@newcmd\qurantrans@en@cccliv{%
And whoso disputeth with thee concerning him, after the knowledge which hath come unto thee, say (unto him): Come! We will summon our sons and your sons, and our women and your women, and ourselves and yourselves, then we will pray humbly (to our Lord) and (solemnly) invoke the curse of Allah upon those who lie.\qt@no{61}}%
\qt@newcmd\qurantrans@en@ccclv{%
Lo! This verily is the true narrative. There is no Allah save Allah, and lo! Allah, He verily is, is the Mighty, the Wise.\qt@no{62}}%
\qt@newcmd\qurantrans@en@ccclvi{%
And if they turn away, then lo! Allah is Aware of (who are) the corrupters.\qt@no{63}}%
\qt@newcmd\qurantrans@en@ccclvii{%
Say: O People of the Scripture! Come to an agreement between us and you: that we shall worship none but Allah, and that we shall ascribe no partner unto Him, and that none of us shall take others for lords beside Allah. And if they turn away, then say: Bear witness that we are they who have surrendered (unto Him).\qt@no{64}}%
\qt@newcmd\qurantrans@en@ccclviii{%
O People of the Scripture! Why will ye argue about Abraham, when the Torah and the Gospel were not revealed till after him? Have ye then no sense?\qt@no{65}}%
\qt@newcmd\qurantrans@en@ccclix{%
Lo! ye are those who argue about that whereof ye have some knowledge: Why then argue ye concerning that whereof ye have no knowledge? Allah knoweth. Ye know not.\qt@no{66}}%
\qt@newcmd\qurantrans@en@ccclx{%
Abraham was not a Jew, nor yet a Christian; but he was an upright man who had surrendered (to Allah), and he was not of the idolaters.\qt@no{67}}%
\qt@newcmd\qurantrans@en@ccclxi{%
Lo! those of mankind who have the best claim to Abraham are those who followed him, and this Prophet and those who believe (with him); and Allah is the Protecting Guardian of the believers.\qt@no{68}}%
\qt@newcmd\qurantrans@en@ccclxii{%
A party of the People of the Scripture long to make you go astray; and they make none to go astray except themselves, but they perceive not.\qt@no{69}}%
\qt@newcmd\qurantrans@en@ccclxiii{%
O People of the Scripture! Why disbelieve ye in the revelations of Allah, when ye (yourselves) bear witness (to their truth)?\qt@no{70}}%
\qt@newcmd\qurantrans@en@ccclxiv{%
O People of the Scripture! Why confound ye truth with falsehood and knowingly conceal the truth?\qt@no{71}}%
\qt@newcmd\qurantrans@en@ccclxv{%
And a party of the People of the Scripture say: Believe in that which hath been revealed unto those who believe at the opening of the day, and disbelieve at the end thereof, in order that they may return;\qt@no{72}}%
\qt@newcmd\qurantrans@en@ccclxvi{%
And believe not save in one who followeth your religion - Say (O Muhammad): Lo! the guidance is Allah's Guidance - that anyone is given the like of that which was given unto you or that they may argue with you in the presence of their Lord. Say (O Muhammad): Lo! the bounty is in Allah's hand. He bestoweth it on whom He will. Allah is All-Embracing, All-Knowing.\qt@no{73}}%
\qt@newcmd\qurantrans@en@ccclxvii{%
He selecteth for His mercy whom He will. Allah is of Infinite Bounty.\qt@no{74}}%
\qt@newcmd\qurantrans@en@ccclxviii{%
Among the People of the Scripture there is he who, if thou trust him with a weight of treasure, will return it to thee. And among them there is he who, if thou trust him with a piece of gold, will not return it to thee unless thou keep standing over him. That is because they say: We have no duty to the Gentiles. They speak a lie concerning Allah knowingly.\qt@no{75}}%
\qt@newcmd\qurantrans@en@ccclxix{%
Nay, but (the chosen of Allah is) he who fulfilleth his pledge and wardeth off (evil); for lo! Allah loveth those who ward off (evil).\qt@no{76}}%
\qt@newcmd\qurantrans@en@ccclxx{%
Lo! those who purchase a small gain at the cost of Allah's covenant and their oaths, they have no portion in the Hereafter. Allah will neither speak to them nor look upon them on the Day of Resurrection, nor will He make them grow. Theirs will be a painful doom.\qt@no{77}}%
\qt@newcmd\qurantrans@en@ccclxxi{%
And lo! there is a party of them who distort the Scripture with their tongues, that ye may think that what they say is from the Scripture, when it is not from the Scripture. And they say: It is from Allah, when it is not from Allah; and they speak a lie concerning Allah knowingly.\qt@no{78}}%
\qt@newcmd\qurantrans@en@ccclxxii{%
It is not (possible) for any human being unto whom Allah had given the Scripture and wisdom and the prophethood that he should afterwards have said unto mankind: Be slaves of me instead of Allah; but (what he said was): Be ye faithful servants of the Lord by virtue of your constant teaching of the Scripture and of your constant study thereof.\qt@no{79}}%
\qt@newcmd\qurantrans@en@ccclxxiii{%
And he commanded you not that ye should take the angels and the prophets for lords. Would he command you to disbelieve after ye had surrendered (to Allah)?\qt@no{80}}%
\qt@newcmd\qurantrans@en@ccclxxiv{%
When Allah made (His) covenant with the prophets, (He said): Behold that which I have given you of the Scripture and knowledge. And afterward there will come unto you a messenger, confirming that which ye possess. Ye shall believe in him and ye shall help him. He said: Do ye agree, and will ye take up My burden (which I lay upon you) in this (matter)? They answered: We agree. He said: Then bear ye witness. I will be a witness with you.\qt@no{81}}%
\qt@newcmd\qurantrans@en@ccclxxv{%
Then whosoever after this shall turn away: they will be miscreants.\qt@no{82}}%
\qt@newcmd\qurantrans@en@ccclxxvi{%
Seek they other than the religion of Allah, when unto Him submitteth whosoever is in the heavens and the earth, willingly or unwillingly, and unto Him they will be returned.\qt@no{83}}%
\qt@newcmd\qurantrans@en@ccclxxvii{%
Say (O Muhammad): We believe in Allah and that which is revealed unto us and that which was revealed unto Abraham and Ishmael and Isaac and Jacob and the tribes, and that which was vouchsafed unto Moses and Jesus and the prophets from their Lord. We make no distinction between any of them, and unto Him we have surrendered.\qt@no{84}}%
\qt@newcmd\qurantrans@en@ccclxxviii{%
And whoso seeketh as religion other than the Surrender (to Allah) it will not be accepted from him, and he will be a loser in the Hereafter.\qt@no{85}}%
\qt@newcmd\qurantrans@en@ccclxxix{%
How shall Allah guide a people who disbelieved after their belief and (after) they bore witness that the messenger is true and after clear proofs (of Allah's Sovereignty) had come unto them. And Allah guideth not wrongdoing folk.\qt@no{86}}%
\qt@newcmd\qurantrans@en@ccclxxx{%
As for such, their guerdon is that on them rests the curse of Allah and of angels and of men combined.\qt@no{87}}%
\qt@newcmd\qurantrans@en@ccclxxxi{%
They will abide therein. Their doom will not be lightened, neither will they be reprieved;\qt@no{88}}%
\qt@newcmd\qurantrans@en@ccclxxxii{%
Save those who afterward repent and do right. Lo! Allah is Forgiving, Merciful.\qt@no{89}}%
\qt@newcmd\qurantrans@en@ccclxxxiii{%
Lo! those who disbelieve after their (profession of) belief, and afterward grow violent in disbelief: their repentance will not be accepted. And such are those who are astray.\qt@no{90}}%
\qt@newcmd\qurantrans@en@ccclxxxiv{%
Lo! those who disbelieve, and die in disbelief, the (whole) earth full of gold would not be accepted from such an one if it were offered as a ransom (for his soul). Theirs will be a painful doom and they will have no helpers.\qt@no{91}}%
\qt@newcmd\qurantrans@en@ccclxxxv{%
Ye will not attain unto piety until ye spend of that which ye love. And whatsoever ye spend, Allah is Aware thereof.\qt@no{92}}%
\qt@newcmd\qurantrans@en@ccclxxxvi{%
All food was lawful unto the Children of Israel, save that which Israel forbade himself, (in days) before the Torah was revealed. Say: Produce the Torah and read it (unto us) if ye are truthful.\qt@no{93}}%
\qt@newcmd\qurantrans@en@ccclxxxvii{%
And whoever shall invent a falsehood after that concerning Allah, such will be wrong-doers.\qt@no{94}}%
\qt@newcmd\qurantrans@en@ccclxxxviii{%
Say: Allah speaketh truth. So follow the religion of Abraham, the upright. He was not of the idolaters.\qt@no{95}}%
\qt@newcmd\qurantrans@en@ccclxxxix{%
Lo! the first Sanctuary appointed for mankind was that at Becca, a blessed place, a guidance to the peoples;\qt@no{96}}%
\qt@newcmd\qurantrans@en@cccxc{%
Wherein are plain memorials (of Allah's guidance); the place where Abraham stood up to pray; and whosoever entereth it is safe. And pilgrimage to the House is a duty unto Allah for mankind, for him who can find a way thither. As for him who disbelieveth, (let him know that) lo! Allah is Independent of (all) creatures.\qt@no{97}}%
\qt@newcmd\qurantrans@en@cccxci{%
Say: O People of the Scripture! Why disbelieve ye in the revelations of Allah, when Allah (Himself) is Witness of what ye do?\qt@no{98}}%
\qt@newcmd\qurantrans@en@cccxcii{%
Say: O People of the Scripture! Why drive ye back believers from the way of Allah, seeking to make it crooked, when ye are witnesses (to Allah's guidance)? Allah is not unaware of what ye do.\qt@no{99}}%
\qt@newcmd\qurantrans@en@cccxciii{%
O ye who believe! If ye obey a party of those who have received the Scripture they will make you disbelievers after your belief.\qt@no{100}}%
\qt@newcmd\qurantrans@en@cccxciv{%
How can ye disbelieve, when it is ye unto whom Allah's revelations are recited, and His messenger is in your midst? He who holdeth fast to Allah, he indeed is guided unto a right path.\qt@no{101}}%
\qt@newcmd\qurantrans@en@cccxcv{%
O ye who believe! Observe your duty to Allah with right observance, and die not save as those who have surrendered (unto Him)\qt@no{102}}%
\qt@newcmd\qurantrans@en@cccxcvi{%
And hold fast, all of you together, to the cable of Allah, and do not separate. And remember Allah's favour unto you: How ye were enemies and He made friendship between your hearts so that ye became as brothers by His grace; and (how) ye were upon the brink of an abyss of fire, and He did save you from it. Thus Allah maketh clear His revelations unto you, that haply ye may be guided,\qt@no{103}}%
\qt@newcmd\qurantrans@en@cccxcvii{%
And there may spring from you a nation who invite to goodness, and enjoin right conduct and forbid indecency. Such are they who are successful.\qt@no{104}}%
\qt@newcmd\qurantrans@en@cccxcviii{%
And be ye not as those who separated and disputed after the clear proofs had come unto them. For such there is an awful doom,\qt@no{105}}%
\qt@newcmd\qurantrans@en@cccxcix{%
On the Day when (some) faces will be whitened and (some) faces will be blackened; and as for those whose faces have been blackened, it will be said unto them: Disbelieved ye after your (profession of) belief? Then taste the punishment for that ye disbelieved.\qt@no{106}}%
\qt@newcmd\qurantrans@en@cd{%
And as for those whose faces have been whitened, in the mercy of Allah they dwell for ever.\qt@no{107}}%
\qt@newcmd\qurantrans@en@cdi{%
These are revelations of Allah. We recite them unto thee in truth. Allah willeth no injustice to (His) creatures.\qt@no{108}}%
\qt@newcmd\qurantrans@en@cdii{%
Unto Allah belongeth whatsoever is in the heavens and whatsoever is in the earth; and unto Allah all things are returned.\qt@no{109}}%
\qt@newcmd\qurantrans@en@cdiii{%
Ye are the best community that hath been raised up for mankind. Ye enjoin right conduct and forbid indecency; and ye believe in Allah. And if the People of the Scripture had believed it had been better for them. Some of them are believers; but most of them are evil-livers.\qt@no{110}}%
\qt@newcmd\qurantrans@en@cdiv{%
They will not harm you save a trifling hurt, and if they fight against you they will turn and flee. And afterward they will not be helped.\qt@no{111}}%
\qt@newcmd\qurantrans@en@cdv{%
Ignominy shall be their portion wheresoever they are found save (where they grasp) a rope from Allah and a rope from men. They have incurred anger from their Lord, and wretchedness is laid upon them. That is because they used to disbelieve the revelations of Allah, and slew the prophets wrongfully. That is because they were rebellious and used to transgress.\qt@no{112}}%
\qt@newcmd\qurantrans@en@cdvi{%
They are not all alike. Of the People of the Scripture there is a staunch community who recite the revelations of Allah in the night season, falling prostrate (before Him).\qt@no{113}}%
\qt@newcmd\qurantrans@en@cdvii{%
They believe in Allah and the Last Day, and enjoin right conduct and forbid indecency, and vie one with another in good works. These are of the righteous.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cdviii{%
And whatever good they do, they will not be denied the meed thereof. Allah is Aware of those who ward off (evil).\qt@no{115}}%
\qt@newcmd\qurantrans@en@cdix{%
Lo! the riches and the progeny of those who disbelieve will not avail them aught against Allah; and such are rightful owners of the Fire. They will abide therein.\qt@no{116}}%
\qt@newcmd\qurantrans@en@cdx{%
The likeness of that which they spend in this life of the world is as the likeness of a biting, icy wind which smiteth the harvest of a people who have wronged themselves, and devastateth it. Allah wronged them not, but they do wrong themselves.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cdxi{%
O ye who believe! Take not for intimates others than your own folk, who would spare no pains to ruin you; they love to hamper you. Hatred is revealed by (the utterance of) their mouths, but that which their breasts hide is greater. We have made plain for you the revelations if ye will understand.\qt@no{118}}%
\qt@newcmd\qurantrans@en@cdxii{%
Lo! ye are those who love them though they love you not, and ye believe in all the Scripture. When they fall in with you they say: We believe; but when they go apart they bite their finger-tips at you, for rage. Say: Perish in your rage! Lo! Allah is Aware of what is hidden in (your) breasts.\qt@no{119}}%
\qt@newcmd\qurantrans@en@cdxiii{%
If a lucky chance befall you, it is evil unto them, and if disaster strike you they rejoice thereat. But if ye persevere and keep from evil their guile will never harm you. Lo! Allah is Surrounding what they do.\qt@no{120}}%
\qt@newcmd\qurantrans@en@cdxiv{%
And when thou settedst forth at daybreak from thy housefolk to assign to the believers their positions for the battle, Allah was Hearer, Knower.\qt@no{121}}%
\qt@newcmd\qurantrans@en@cdxv{%
When two parties of you almost fell away, and Allah was their Protecting Friend. In Allah let believers put their trust.\qt@no{122}}%
\qt@newcmd\qurantrans@en@cdxvi{%
Allah had already given you the victory at Badr, when ye were contemptible. So observe your duty to Allah in order that ye may be thankful.\qt@no{123}}%
\qt@newcmd\qurantrans@en@cdxvii{%
When thou didst say unto the believers: Is it not sufficient for you that your Lord should support you with three thousand angels sent down (to your help)?\qt@no{124}}%
\qt@newcmd\qurantrans@en@cdxviii{%
Nay, but if ye persevere, and keep from evil, and (the enemy) attack you suddenly, your Lord will help you with five thousand angels sweeping on.\qt@no{125}}%
\qt@newcmd\qurantrans@en@cdxix{%
Allah ordained this only as a message of good cheer for you, and that thereby your hearts might be at rest - Victory cometh only from Allah, the Mighty, the Wise -\qt@no{126}}%
\qt@newcmd\qurantrans@en@cdxx{%
That He may cut off a part of those who disbelieve, or overwhelm them so that they retire, frustrated.\qt@no{127}}%
\qt@newcmd\qurantrans@en@cdxxi{%
It is no concern at all of thee (Muhammad) whether He relent toward them or punish them; for they are evil-doers.\qt@no{128}}%
\qt@newcmd\qurantrans@en@cdxxii{%
Unto Allah belongeth whatsoever is in the heavens and whatsoever is in the earth. He forgiveth whom He will, and punisheth whom He will. Allah is Forgiving, Merciful.\qt@no{129}}%
\qt@newcmd\qurantrans@en@cdxxiii{%
O ye who believe! Devour not usury, doubling and quadrupling (the sum lent). Observe your duty to Allah, that ye may be successful.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cdxxiv{%
And ward off (from yourselves) the Fire prepared for disbelievers.\qt@no{131}}%
\qt@newcmd\qurantrans@en@cdxxv{%
And obey Allah and the messenger, that ye may find mercy.\qt@no{132}}%
\qt@newcmd\qurantrans@en@cdxxvi{%
And vie one with another for forgiveness from your Lord, and for a paradise as wide as are the heavens and the earth, prepared for those who ward off (evil);\qt@no{133}}%
\qt@newcmd\qurantrans@en@cdxxvii{%
Those who spend (of that which Allah hath given them) in ease and in adversity, those who control their wrath and are forgiving toward mankind; Allah loveth the good;\qt@no{134}}%
\qt@newcmd\qurantrans@en@cdxxviii{%
And those who, when they do an evil thing or wrong themselves, remember Allah and implore forgiveness for their sins - Who forgiveth sins save Allah only? - and will not knowingly repeat (the wrong) they did.\qt@no{135}}%
\qt@newcmd\qurantrans@en@cdxxix{%
The reward of such will be forgiveness from their Lord, and Gardens underneath which rivers flow, wherein they will abide for ever - a bountiful reward for workers!\qt@no{136}}%
\qt@newcmd\qurantrans@en@cdxxx{%
Systems have passed away before you. Do but travel in the land and see the nature of the consequence for those who did deny (the messengers).\qt@no{137}}%
\qt@newcmd\qurantrans@en@cdxxxi{%
This is a declaration for mankind, a guidance and an admonition unto those who ward off (evil)\qt@no{138}}%
\qt@newcmd\qurantrans@en@cdxxxii{%
Faint not nor grieve, for ye will overcome them if ye are (indeed) believers.\qt@no{139}}%
\qt@newcmd\qurantrans@en@cdxxxiii{%
If ye have received a blow, the (disbelieving) people have received a blow the like thereof. These are (only) the vicissitudes which We cause to follow one another for mankind, to the end that Allah may know those who believe and may choose witnesses from among you; and Allah loveth not wrong-doers.\qt@no{140}}%
\qt@newcmd\qurantrans@en@cdxxxiv{%
And that Allah may prove those who believe, and may blight the disbelievers.\qt@no{141}}%
\qt@newcmd\qurantrans@en@cdxxxv{%
Or deemed ye that ye would enter paradise while yet Allah knoweth not those of you who really strive, nor knoweth those (of you) who are steadfast?\qt@no{142}}%
\qt@newcmd\qurantrans@en@cdxxxvi{%
And verily ye used to wish for death before ye met it (in the field). Now ye have seen it with your eyes!\qt@no{143}}%
\qt@newcmd\qurantrans@en@cdxxxvii{%
Muhammad is but a messenger, messengers (the like of whom) have passed away before him. Will it be that, when he dieth or is slain, ye will turn back on your heels? He who turneth back on his heels doth no hurt to Allah, and Allah will reward the thankful.\qt@no{144}}%
\qt@newcmd\qurantrans@en@cdxxxviii{%
No soul can ever die except by Allah's leave and at a term appointed. Whoso desireth the reward of the world, We bestow on him thereof; and whoso desireth the reward of the Hereafter, We bestow on him thereof. We shall reward the thankful.\qt@no{145}}%
\qt@newcmd\qurantrans@en@cdxxxix{%
And with how many a prophet have there been a number of devoted men who fought (beside him). They quailed not for aught that befell them in the way of Allah, nor did they weaken, nor were they brought low. Allah loveth the steadfast.\qt@no{146}}%
\qt@newcmd\qurantrans@en@cdxl{%
Their cry was only that they said: Our Lord! forgive us for our sins and wasted efforts, make our foothold sure, and give us victory over the disbelieving folk.\qt@no{147}}%
\qt@newcmd\qurantrans@en@cdxli{%
So Allah gave them the reward of the world and the good reward of the Hereafter. Allah loveth those whose deeds are good.\qt@no{148}}%
\qt@newcmd\qurantrans@en@cdxlii{%
O ye who believe! if ye obey those who disbelieve, they will make you turn back on your heels, and ye turn back as losers.\qt@no{149}}%
\qt@newcmd\qurantrans@en@cdxliii{%
But Allah is your Protector, and He is the Best of Helpers.\qt@no{150}}%
\qt@newcmd\qurantrans@en@cdxliv{%
We shall cast terror into the hearts of those who disbelieve because they ascribe unto Allah partners, for which no warrant hath been revealed. Their habitation is the Fire, and hapless the abode of the wrong-doers.\qt@no{151}}%
\qt@newcmd\qurantrans@en@cdxlv{%
Allah verily made good His promise unto you when ye routed them by His leave, until (the moment) when your courage failed you, and ye disagreed about the order and ye disobeyed, after He had shown you that for which ye long. Some of you desired the world, and some of you desired the Hereafter. Therefore He made you flee from them, that He might try you. Yet now He hath forgiven you. Allah is a Lord of Kindness to believers.\qt@no{152}}%
\qt@newcmd\qurantrans@en@cdxlvi{%
When ye climbed (the hill) and paid no heed to anyone, while the messenger, in your rear, was calling you (to fight). Therefor He rewarded you grief for (his) grief, that (He might teach) you not to sorrow either for that which ye missed or for that which befell you. Allah is Informed of what ye do.\qt@no{153}}%
\qt@newcmd\qurantrans@en@cdxlvii{%
Then, after grief, He sent down security for you. As slumber did it overcome a party of you, while (the other) party, who were anxious on their own account, thought wrongly of Allah, the thought of ignorance. They said: Have we any part in the cause? Say (O Muhammad): The cause belongeth wholly to Allah. They hide within themselves (a thought) which they reveal not unto thee, saying: Had we had any part in the cause we should not have been slain here. Say: Even though ye had been in your houses, those appointed to be slain would have gone forth to the places where they were to lie. (All this hath been) in order that Allah might try what is in your breasts and prove what is in your hearts. Allah is Aware of what is hidden in the breasts (of men).\qt@no{154}}%
\qt@newcmd\qurantrans@en@cdxlviii{%
Lo! those of you who turned back on the day when the two hosts met, Satan alone it was who caused them to backslide, because of some of that which they have earned. Now Allah hath forgiven them. Lo! Allah is Forgiving, Clement.\qt@no{155}}%
\qt@newcmd\qurantrans@en@cdxlix{%
O ye who believe! Be not as those who disbelieved and said of their brethren who went abroad in the land or were fighting in the field: If they had been (here) with us they would not have died or been killed: that Allah may make it anguish in their hearts. Allah giveth life and causeth death; and Allah is Seer of what ye do.\qt@no{156}}%
\qt@newcmd\qurantrans@en@cdl{%
And what though ye be slain in Allah's way or die therein? Surely pardon from Allah and mercy are better than all that they amass.\qt@no{157}}%
\qt@newcmd\qurantrans@en@cdli{%
What though ye be slain or die, when unto Allah ye are gathered?\qt@no{158}}%
\qt@newcmd\qurantrans@en@cdlii{%
It was by the mercy of Allah that thou wast lenient with them (O Muhammad), for if thou hadst been stern and fierce of heart they would have dispersed from round about thee. So pardon them and ask forgiveness for them and consult with them upon the conduct of affairs. And when thou art resolved, then put thy trust in Allah. Lo! Allah loveth those who put their trust (in Him).\qt@no{159}}%
\qt@newcmd\qurantrans@en@cdliii{%
If Allah is your helper none can overcome you, and if He withdraw His help from you, who is there who can help you after Him? In Allah let believers put their trust.\qt@no{160}}%
\qt@newcmd\qurantrans@en@cdliv{%
It is not for any prophet to embezzle. Whoso embezzleth will bring what he embezzled with him on the Day of Resurrection. Then every soul will be paid in full what it hath earned; and they will not be wronged.\qt@no{161}}%
\qt@newcmd\qurantrans@en@cdlv{%
Is one who followeth the pleasure of Allah as one who hath earned condemnation from Allah, whose habitation is the Fire, a hapless journey's end?\qt@no{162}}%
\qt@newcmd\qurantrans@en@cdlvi{%
There are degrees (of grace and reprobation) with Allah, and Allah is Seer of what they do.\qt@no{163}}%
\qt@newcmd\qurantrans@en@cdlvii{%
Allah verily hath shown grace to the believers by sending unto them a messenger of their own who reciteth unto them His revelations, and causeth them to grow, and teacheth them the Scripture and wisdom; although before (he came to them) they were in flagrant error.\qt@no{164}}%
\qt@newcmd\qurantrans@en@cdlviii{%
And was it so, when a disaster smote you, though ye had smitten (them with a disaster) twice (as great), that ye said: How is this? Say (unto them, O Muhammad): It is from yourselves. Lo! Allah is Able to do all things.\qt@no{165}}%
\qt@newcmd\qurantrans@en@cdlix{%
That which befell you, on the day when the two armies met, was by permission of Allah; that He might know the true believers;\qt@no{166}}%
\qt@newcmd\qurantrans@en@cdlx{%
And that He might know the hypocrites, unto whom it was said: Come, fight in the way of Allah, or defend yourselves. They answered: If we knew aught of fighting we would follow you. On that day they were nearer disbelief than faith. They utter with their mouths a thing which is not in their hearts. Allah is Best Aware of what they hide.\qt@no{167}}%
\qt@newcmd\qurantrans@en@cdlxi{%
Those who, while they sat at home, said of their brethren (who were fighting for the cause of Allah): If they had been guided by us they would not have been slain. Say (unto them, O Muhammad): Then avert death from yourselves if ye are truthful.\qt@no{168}}%
\qt@newcmd\qurantrans@en@cdlxii{%
Think not of those, who are slain in the way of Allah, as dead. Nay, they are living. With their Lord they have provision.\qt@no{169}}%
\qt@newcmd\qurantrans@en@cdlxiii{%
Jubilant (are they) because of that which Allah hath bestowed upon them of His bounty, rejoicing for the sake of those who have not joined them but are left behind: That there shall no fear come upon them neither shall they grieve.\qt@no{170}}%
\qt@newcmd\qurantrans@en@cdlxiv{%
They rejoice because of favour from Allah and kindness, and that Allah wasteth not the wage of the believers.\qt@no{171}}%
\qt@newcmd\qurantrans@en@cdlxv{%
As for those who heard the call of Allah and His messenger after the harm befell them (in the fight); for such of them as do right and ward off (evil), there is great reward.\qt@no{172}}%
\qt@newcmd\qurantrans@en@cdlxvi{%
Those unto whom men said: Lo! the people have gathered against you, therefor fear them. (The threat of danger) but increased the faith of them and they cried: Allah is Sufficient for us! Most Excellent is He in Whom we trust!\qt@no{173}}%
\qt@newcmd\qurantrans@en@cdlxvii{%
So they returned with grace and favour from Allah, and no harm touched them. They followed the good pleasure of Allah, and Allah is of Infinite Bounty.\qt@no{174}}%
\qt@newcmd\qurantrans@en@cdlxviii{%
It is only the devil who would make (men) fear his partisans. Fear them not; fear Me, if ye are true believers.\qt@no{175}}%
\qt@newcmd\qurantrans@en@cdlxix{%
Let not their conduct grieve thee, who run easily to disbelief, for lo! they injure Allah not at all. It is Allah's Will to assign them no portion in the Hereafter, and theirs will be an awful doom.\qt@no{176}}%
\qt@newcmd\qurantrans@en@cdlxx{%
Those who purchase disbelief at the price of faith harm Allah not at all, but theirs will be a painful doom.\qt@no{177}}%
\qt@newcmd\qurantrans@en@cdlxxi{%
And let not those who disbelieve imagine that the rein We give them bodeth good unto their souls. We only give them rein that they may grow in sinfulness. And theirs will be a shameful doom.\qt@no{178}}%
\qt@newcmd\qurantrans@en@cdlxxii{%
It is not (the purpose) of Allah to leave you in your present state till He shall separate the wicked from the good. And it is not (the purpose of) Allah to let you know the Unseen. But Allah chooseth of His messengers whom He will, (to receive knowledge thereof). So believe in Allah and His messengers. If ye believe and ward off (evil), yours will be a vast reward.\qt@no{179}}%
\qt@newcmd\qurantrans@en@cdlxxiii{%
And let not those who hoard up that which Allah hath bestowed upon them of His bounty think that it is better for them. Nay, it is worse for them. That which they hoard will be their collar on the Day of Resurrection. Allah's is the heritage of the heavens and the earth, and Allah is Informed of what ye do.\qt@no{180}}%
\qt@newcmd\qurantrans@en@cdlxxiv{%
Verily Allah heard the saying of those who said, (when asked for contributions to the war): ``Allah, forsooth, is poor, and we are rich!" We shall record their saying with their slaying of the prophets wrongfully and We shall say: Taste ye the punishment of burning!\qt@no{181}}%
\qt@newcmd\qurantrans@en@cdlxxv{%
This is on account of that which your own hands have sent before (you to the judgment). Allah is no oppressor of (His) bondmen.\qt@no{182}}%
\qt@newcmd\qurantrans@en@cdlxxvi{%
(The same are) those who say: Lo! Allah hath charged us that we believe not in any messenger until he bring us an offering which fire (from heaven) shall devour. Say (unto them, O Muhammad): Messengers came unto you before me with miracles, and with that (very miracle) which ye describe. Why then did ye slay them? (Answer that) if ye are truthful!\qt@no{183}}%
\qt@newcmd\qurantrans@en@cdlxxvii{%
And if they deny thee, even so did they deny messengers who were before thee, who came with miracles and with the Psalms and with the Scripture giving light.\qt@no{184}}%
\qt@newcmd\qurantrans@en@cdlxxviii{%
Every soul will taste of death. And ye will be paid on the Day of Resurrection only that which ye have fairly earned. Whoso is removed from the Fire and is made to enter paradise, he indeed is triumphant. The life of this world is but comfort of illusion.\qt@no{185}}%
\qt@newcmd\qurantrans@en@cdlxxix{%
Assuredly ye will be tried in your property and in your persons, and ye will hear much wrong from those who were given the Scripture before you, and from the idolaters. But if ye persevere and ward off (evil), then that is of the steadfast heart of things.\qt@no{186}}%
\qt@newcmd\qurantrans@en@cdlxxx{%
And (remember) when Allah laid a charge on those who had received the Scripture (He said): Ye are to expound it to mankind and not to hide it. But they flung it behind their backs and bought thereby a little gain. Verily evil is that which they have gained thereby.\qt@no{187}}%
\qt@newcmd\qurantrans@en@cdlxxxi{%
Think not that those who exult in what they have given, and love to be praised for what they have not done - Think not, they are in safety from the doom. A painful doom is theirs.\qt@no{188}}%
\qt@newcmd\qurantrans@en@cdlxxxii{%
Unto Allah belongeth the Sovereignty of the heavens and the earth. Allah is Able to do all things.\qt@no{189}}%
\qt@newcmd\qurantrans@en@cdlxxxiii{%
Lo! In the creation of the heavens and the earth and (in) the difference of night and day are tokens (of His Sovereignty) for men of understanding,\qt@no{190}}%
\qt@newcmd\qurantrans@en@cdlxxxiv{%
Such as remember Allah, standing, sitting, and reclining, and consider the creation of the heavens and the earth, (and say): Our Lord! Thou createdst not this in vain. Glory be to Thee! Preserve us from the doom of Fire.\qt@no{191}}%
\qt@newcmd\qurantrans@en@cdlxxxv{%
Our Lord! Whom Thou causest to enter the Fire: him indeed Thou hast confounded. For evil-doers there will be no helpers.\qt@no{192}}%
\qt@newcmd\qurantrans@en@cdlxxxvi{%
Our Lord! Lo! we have heard a crier calling unto Faith: ``Believe ye in your Lord!" So we believed. Our Lord! Therefor forgive us our sins, and remit from us our evil deeds, and make us die the death of the righteous.\qt@no{193}}%
\qt@newcmd\qurantrans@en@cdlxxxvii{%
Our Lord! And give us that which Thou hast promised to us by Thy messengers. Confound us not upon the Day of Resurrection. Lo! Thou breakest not the tryst.\qt@no{194}}%
\qt@newcmd\qurantrans@en@cdlxxxviii{%
And their Lord hath heard them (and He saith): Lo! I suffer not the work of any worker, male or female, to be lost. Ye proceed one from another. So those who fled and were driven forth from their homes and suffered damage for My cause, and fought and were slain, verily I shall remit their evil deeds from them and verily I shall bring them into Gardens underneath which rivers flow - A reward from Allah. And with Allah is the fairest of rewards.\qt@no{195}}%
\qt@newcmd\qurantrans@en@cdlxxxix{%
Let not the vicissitude (of the success) of those who disbelieve, in the land, deceive thee (O Muhammad).\qt@no{196}}%
\qt@newcmd\qurantrans@en@cdxc{%
It is but a brief comfort. And afterward their habitation will be hell, an ill abode.\qt@no{197}}%
\qt@newcmd\qurantrans@en@cdxci{%
But those who keep their duty to their Lord, for them are Gardens underneath which rivers flow, wherein they will be safe for ever. A gift of welcome from their Lord. That which Allah hath in store is better for the righteous.\qt@no{198}}%
\qt@newcmd\qurantrans@en@cdxcii{%
And lo! of the People of the Scripture there are some who believe in Allah and that which is revealed unto you and that which was revealed unto them, humbling themselves before Allah. They purchase not a trifling gain at the price of the revelations of Allah. Verily their reward is with their Lord. Lo! Allah is swift to take account.\qt@no{199}}%
\qt@newcmd\qurantrans@en@cdxciii{%
O ye who believe! Endure, outdo all others in endurance, be ready, and observe your duty to Allah, in order that ye may succeed.\qt@no{200}}%
\qt@newcmd\qurantrans@en@cdxciv{%
\basmalahen O mankind! Be careful of your duty to your Lord Who created you from a single soul and from it created its mate and from them twain hath spread abroad a multitude of men and women. Be careful of your duty toward Allah in Whom ye claim (your rights) of one another, and toward the wombs (that bare you). Lo! Allah hath been a watcher over you.\qt@no{1}}%
\qt@newcmd\qurantrans@en@cdxcv{%
Give unto orphans their wealth. Exchange not the good for the bad (in your management thereof) nor absorb their wealth into your own wealth. Lo! that would be a great sin.\qt@no{2}}%
\qt@newcmd\qurantrans@en@cdxcvi{%
And if ye fear that ye will not deal fairly by the orphans, marry of the women, who seem good to you, two or three or four; and if ye fear that ye cannot do justice (to so many) then one (only) or (the captives) that your right hands possess. Thus it is more likely that ye will not do injustice.\qt@no{3}}%
\qt@newcmd\qurantrans@en@cdxcvii{%
And give unto the women (whom ye marry) free gift of their marriage portions; but if they of their own accord remit unto you a part thereof, then ye are welcome to absorb it (in your wealth).\qt@no{4}}%
\qt@newcmd\qurantrans@en@cdxcviii{%
Give not unto the foolish (what is in) your (keeping of their) wealth, which Allah hath given you to maintain; but feed and clothe them from it, and speak kindly unto them.\qt@no{5}}%
\qt@newcmd\qurantrans@en@cdxcix{%
Prove orphans till they reach the marriageable age; then, if ye find them of sound judgment, deliver over unto them their fortune; and devour it not by squandering and in haste lest they should grow up Whoso (of the guardians) is rich, let him abstain generously (from taking of the property of orphans); and whoso is poor let him take thereof in reason (for his guardianship). And when ye deliver up their fortune unto orphans, have (the transaction) witnessed in their presence. Allah sufficeth as a Reckoner.\qt@no{6}}%
\qt@newcmd\qurantrans@en@d{%
Unto the men (of a family) belongeth a share of that which parents and near kindred leave, and unto the women a share of that which parents and near kindred leave, whether it be little or much - a legal share.\qt@no{7}}%
\qt@newcmd\qurantrans@en@di{%
And when kinsfolk and orphans and the needy are present at the division (of the heritage), bestow on them therefrom and speak kindly unto them.\qt@no{8}}%
\qt@newcmd\qurantrans@en@dii{%
And let those fear (in their behaviour toward orphans) who if they left behind them weak offspring would be afraid for them. So let them mind their duty to Allah, and speak justly.\qt@no{9}}%
\qt@newcmd\qurantrans@en@diii{%
Lo! Those who devour the wealth of orphans wrongfully, they do but swallow fire into their bellies, and they will be exposed to burning flame.\qt@no{10}}%
\qt@newcmd\qurantrans@en@div{%
Allah chargeth you concerning (the provision for) your children: to the male the equivalent of the portion of two females, and if there be women more than two, then theirs is two-thirds of the inheritance, and if there be one (only) then the half. And to each of his parents a sixth of the inheritance, if he have a son; and if he have no son and his parents are his heirs, then to his mother appertaineth the third; and if he have brethren, then to his mother appertaineth the sixth, after any legacy he may have bequeathed, or debt (hath been paid). Your parents and your children: Ye know not which of them is nearer unto you in usefulness. It is an injunction from Allah. Lo! Allah is Knower, Wise.\qt@no{11}}%
\qt@newcmd\qurantrans@en@dv{%
And unto you belongeth a half of that which your wives leave, if they have no child; but if they have a child then unto you the fourth of that which they leave, after any legacy they may have bequeathed, or debt (they may have contracted, hath been paid). And unto them belongeth the fourth of that which ye leave if ye have no child, but if ye have a child then the eighth of that which ye leave, after any legacy ye may have bequeathed, or debt (ye may have contracted, hath been paid). And if a man or a woman have a distant heir (having left neither parent nor child), and he (or she) have a brother or a sister (only on the mother's side) then to each of them twain (the brother and the sister) the sixth, and if they be more than two, then they shall be sharers in the third, after any legacy that may have been bequeathed or debt (contracted) not injuring (the heirs by willing away more than a third of the heritage) hath been paid. A commandment from Allah. Allah is Knower, Indulgent.\qt@no{12}}%
\qt@newcmd\qurantrans@en@dvi{%
These are the limits (imposed by) Allah. Whoso obeyeth Allah and His messenger, He will make him enter Gardens underneath which rivers flow, where such will dwell for ever. That will be the great success.\qt@no{13}}%
\qt@newcmd\qurantrans@en@dvii{%
And whoso disobeyeth Allah and His messenger and transgresseth His limits, He will make him enter Fire, where he will dwell for ever; his will be a shameful doom.\qt@no{14}}%
\qt@newcmd\qurantrans@en@dviii{%
As for those of your women who are guilty of lewdness, call to witness four of you against them. And if they testify (to the truth of the allegation) then confine them to the houses until death take them or (until) Allah appoint for them a way (through new legislation).\qt@no{15}}%
\qt@newcmd\qurantrans@en@dix{%
And as for the two of you who are guilty thereof, punish them both. And if they repent and improve, then let them be. Lo! Allah is ever relenting, Merciful.\qt@no{16}}%
\qt@newcmd\qurantrans@en@dx{%
Forgiveness is only incumbent on Allah toward those who do evil in ignorance (and) then turn quickly (in repentance) to Allah. These are they toward whom Allah relenteth. Allah is ever Knower, Wise.\qt@no{17}}%
\qt@newcmd\qurantrans@en@dxi{%
The forgiveness is not for those who do ill-deeds until, when death attendeth upon one of them, he saith: Lo! I repent now; nor yet for those who die while they are disbelievers. For such We have prepared a painful doom.\qt@no{18}}%
\qt@newcmd\qurantrans@en@dxii{%
O ye who believe! It is not lawful for you forcibly to inherit the women (of your deceased kinsmen), nor (that) ye should put constraint upon them that ye may take away a part of that which ye have given them, unless they be guilty of flagrant lewdness. But consort with them in kindness, for if ye hate them it may happen that ye hate a thing wherein Allah hath placed much good.\qt@no{19}}%
\qt@newcmd\qurantrans@en@dxiii{%
And if ye wish to exchange one wife for another and ye have given unto one of them a sum of money (however great), take nothing from it. Would ye take it by the way of calumny and open wrong?\qt@no{20}}%
\qt@newcmd\qurantrans@en@dxiv{%
How can ye take it (back) after one of you hath gone in unto the other, and they have taken a strong pledge from you?\qt@no{21}}%
\qt@newcmd\qurantrans@en@dxv{%
And marry not those women whom your fathers married, except what hath already happened (of that nature) in the past. Lo! it was ever lewdness and abomination, and an evil way.\qt@no{22}}%
\qt@newcmd\qurantrans@en@dxvi{%
Forbidden unto you are your mothers, and your daughters, and your sisters, and your father's sisters, and your mother's sisters, and your brother's daughters and your sister's daughters, and your foster-mothers, and your foster-sisters, and your mothers-in-law, and your step-daughters who are under your protection (born) of your women unto whom ye have gone in - but if ye have not gone in unto them, then it is no sin for you (to marry their daughters) - and the wives of your sons who (spring) from your own loins. And (it is forbidden unto you) that ye should have two sisters together, except what hath already happened (of that nature) in the past. Lo! Allah is ever Forgiving, Merciful.\qt@no{23}}%
\qt@newcmd\qurantrans@en@dxvii{%
And all married women (are forbidden unto you) save those (captives) whom your right hands possess. It is a decree of Allah for you. Lawful unto you are all beyond those mentioned, so that ye seek them with your wealth in honest wedlock, not debauchery. And those of whom ye seek content (by marrying them), give unto them their portions as a duty. And there is no sin for you in what ye do by mutual agreement after the duty (hath been done). Lo! Allah is ever Knower, Wise.\qt@no{24}}%
\qt@newcmd\qurantrans@en@dxviii{%
And whoso is not able to afford to marry free, believing women, let them marry from the believing maids whom your right hands possess. Allah knoweth best (concerning) your faith. Ye (proceed) one from another; so wed them by permission of their folk, and give unto them their portions in kindness, they being honest, not debauched nor of loose conduct. And if when they are honourably married they commit lewdness they shall incur the half of the punishment (prescribed) for free women (in that case). This is for him among you who feareth to commit sin. But to have patience would be better for you. Allah is Forgiving, Merciful.\qt@no{25}}%
\qt@newcmd\qurantrans@en@dxix{%
Allah would explain to you and guide you by the examples of those who were before you, and would turn to you in mercy. Allah is Knower, Wise.\qt@no{26}}%
\qt@newcmd\qurantrans@en@dxx{%
And Allah would turn to you in mercy; but those who follow vain desires would have you go tremendously astray.\qt@no{27}}%
\qt@newcmd\qurantrans@en@dxxi{%
Allah would make the burden light for you, for man was created weak.\qt@no{28}}%
\qt@newcmd\qurantrans@en@dxxii{%
O ye who believe! Squander not your wealth among yourselves in vanity, except it be a trade by mutual consent, and kill not one another. Lo! Allah is ever Merciful unto you.\qt@no{29}}%
\qt@newcmd\qurantrans@en@dxxiii{%
Whoso doeth that through aggression and injustice, we shall cast him into Fire, and that is ever easy for Allah.\qt@no{30}}%
\qt@newcmd\qurantrans@en@dxxiv{%
If ye avoid the great (things) which ye are forbidden, We will remit from you your evil deeds and make you enter at a noble gate.\qt@no{31}}%
\qt@newcmd\qurantrans@en@dxxv{%
And covet not the thing in which Allah hath made some of you excel others. Unto men a fortune from that which they have earned, and unto women a fortune from that which they have earned. (Envy not one another) but ask Allah of His bounty. Lo! Allah is ever Knower of all things.\qt@no{32}}%
\qt@newcmd\qurantrans@en@dxxvi{%
And unto each We have appointed heirs of that which parents and near kindred leave; and as for those with whom your right hands have made a covenant, give them their due. Lo! Allah is ever Witness over all things.\qt@no{33}}%
\qt@newcmd\qurantrans@en@dxxvii{%
Men are in charge of women, because Allah hath made the one of them to excel the other, and because they spend of their property (for the support of women). So good women are the obedient, guarding in secret that which Allah hath guarded. As for those from whom ye fear rebellion, admonish them and banish them to beds apart, and scourge them. Then if they obey you, seek not a way against them. Lo! Allah is ever High, Exalted, Great.\qt@no{34}}%
\qt@newcmd\qurantrans@en@dxxviii{%
And if ye fear a breach between them twain (the man and wife), appoint an arbiter from his folk and an arbiter from her folk. If they desire amendment Allah will make them of one mind. Lo! Allah is ever Knower, Aware.\qt@no{35}}%
\qt@newcmd\qurantrans@en@dxxix{%
And serve Allah. Ascribe no thing as partner unto Him. (Show) kindness unto parents, and unto near kindred, and orphans, and the needy, and unto the neighbour who is of kin (unto you) and the neighbour who is not of kin, and the fellow-traveller and the wayfarer and (the slaves) whom your right hands possess. Lo! Allah loveth not such as are proud and boastful,\qt@no{36}}%
\qt@newcmd\qurantrans@en@dxxx{%
Who hoard their wealth and enjoin avarice on others, and hide that which Allah hath bestowed upon them of His bounty. For disbelievers We prepare a shameful doom;\qt@no{37}}%
\qt@newcmd\qurantrans@en@dxxxi{%
And (also) those who spend their wealth in order to be seen of men, and believe not in Allah nor the Last Day. Whoso taketh Satan for a comrade, a bad comrade hath he.\qt@no{38}}%
\qt@newcmd\qurantrans@en@dxxxii{%
What have they (to fear) if they believe in Allah and the Last Day and spend (aright) of that which Allah hath bestowed upon them, when Allah is ever Aware of them (and all they do)?\qt@no{39}}%
\qt@newcmd\qurantrans@en@dxxxiii{%
Lo! Allah wrongeth not even of the weight of an ant; and if there is a good deed, He will double it and will give (the doer) from His presence an immense reward.\qt@no{40}}%
\qt@newcmd\qurantrans@en@dxxxiv{%
But how (will it be with them) when We bring of every people a witness, and We bring thee (O Muhammad) a witness against these?\qt@no{41}}%
\qt@newcmd\qurantrans@en@dxxxv{%
On that day those who disbelieved and disobeyed the messenger will wish that they were level with the ground, and they can hide no fact from Allah.\qt@no{42}}%
\qt@newcmd\qurantrans@en@dxxxvi{%
O ye who believe! Draw not near unto prayer when ye are drunken, till ye know that which ye utter, nor when ye are polluted, save when journeying upon the road, till ye have bathed. And if ye be ill, or on a journey, or one of you cometh from the closet, or ye have touched women, and ye find not water, then go to high clean soil and rub your faces and your hands (therewith). Lo! Allah is Benign, Forgiving.\qt@no{43}}%
\qt@newcmd\qurantrans@en@dxxxvii{%
Seest thou not those unto whom a portion of the Scripture hath been given, how they purchase error, and seek to make you (Muslims) err from the right way?\qt@no{44}}%
\qt@newcmd\qurantrans@en@dxxxviii{%
Allah knoweth best (who are) your enemies. Allah is sufficient as a Guardian, and Allah is sufficient as a Supporter.\qt@no{45}}%
\qt@newcmd\qurantrans@en@dxxxix{%
Some of those who are Jews change words from their context and say: ``We hear and disobey; hear thou as one who heareth not" and ``Listen to us!" distorting with their tongues and slandering religion. If they had said: ``We hear and we obey: hear thou, and look at us" it had been better for them, and more upright. But Allah hath cursed them for their disbelief, so they believe not, save a few.\qt@no{46}}%
\qt@newcmd\qurantrans@en@dxl{%
O ye unto whom the Scripture hath been given! Believe in what We have revealed confirming that which ye possess, before We destroy countenances so as to confound them, or curse them as We cursed the Sabbath-breakers (of old time). The commandment of Allah is always executed.\qt@no{47}}%
\qt@newcmd\qurantrans@en@dxli{%
Lo! Allah forgiveth not that a partner should be ascribed unto Him. He forgiveth (all) save that to whom He will. Whoso ascribeth partners to Allah, he hath indeed invented a tremendous sin.\qt@no{48}}%
\qt@newcmd\qurantrans@en@dxlii{%
Hast thou not seen those who praise themselves for purity? Nay, Allah purifieth whom He will, and they will not be wronged even the hair upon a date-stone.\qt@no{49}}%
\qt@newcmd\qurantrans@en@dxliii{%
See, how they invent lies about Allah! That of itself is flagrant sin.\qt@no{50}}%
\qt@newcmd\qurantrans@en@dxliv{%
Hast thou not seen those unto whom a portion of the Scripture hath been given, how they believe in idols and false deities, and how they say of those (idolaters) who disbelieve: ``These are more rightly guided than those who believe"?\qt@no{51}}%
\qt@newcmd\qurantrans@en@dxlv{%
Those are they whom Allah hath cursed, and he whom Allah hath cursed, thou (O Muhammad) wilt find for him no helper.\qt@no{52}}%
\qt@newcmd\qurantrans@en@dxlvi{%
Or have they even a share in the Sovereignty? Then in that case, they would not give mankind even the speck on a date-stone.\qt@no{53}}%
\qt@newcmd\qurantrans@en@dxlvii{%
Or are they jealous of mankind because of that which Allah of His bounty hath bestowed upon them? For We bestowed upon the house of Abraham (of old) the Scripture and wisdom, and We bestowed on them a mighty kingdom.\qt@no{54}}%
\qt@newcmd\qurantrans@en@dxlviii{%
And of them were (some) who believed therein and of them were (some) who turned away from it. Hell is sufficient for (their) burning.\qt@no{55}}%
\qt@newcmd\qurantrans@en@dxlix{%
Lo! Those who disbelieve Our revelations, We shall expose them to the Fire. As often as their skins are consumed We shall exchange them for fresh skins that they may taste the torment. Lo! Allah is ever Mighty, Wise.\qt@no{56}}%
\qt@newcmd\qurantrans@en@dl{%
And as for those who believe and do good works, We shall make them enter Gardens underneath which rivers flow - to dwell therein for ever; there for them are pure companions - and We shall make them enter plenteous shade.\qt@no{57}}%
\qt@newcmd\qurantrans@en@dli{%
Lo! Allah commandeth you that ye restore deposits to their owners, and, if ye judge between mankind, that ye judge justly. Lo! comely is this which Allah admonisheth you. Lo! Allah is ever Hearer, Seer.\qt@no{58}}%
\qt@newcmd\qurantrans@en@dlii{%
O ye who believe! Obey Allah, and obey the messenger and those of you who are in authority; and if ye have a dispute concerning any matter, refer it to Allah and the messenger if ye are (in truth) believers in Allah and the Last Day. That is better and more seemly in the end.\qt@no{59}}%
\qt@newcmd\qurantrans@en@dliii{%
Hast thou not seen those who pretend that they believe in that which is revealed unto thee and that which was revealed before thee, how they would go for judgment (in their disputes) to false deities when they have been ordered to abjure them? Satan would mislead them far astray.\qt@no{60}}%
\qt@newcmd\qurantrans@en@dliv{%
And when it is said unto them: Come unto that which Allah hath revealed and unto the messenger, thou seest the hypocrites turn from thee with aversion.\qt@no{61}}%
\qt@newcmd\qurantrans@en@dlv{%
How would it be if a misfortune smote them because of that which their own hands have sent before (them)? Then would they come unto thee, swearing by Allah that they were seeking naught but harmony and kindness.\qt@no{62}}%
\qt@newcmd\qurantrans@en@dlvi{%
Those are they, the secrets of whose hearts Allah knoweth. So oppose them and admonish them, and address them in plain terms about their souls.\qt@no{63}}%
\qt@newcmd\qurantrans@en@dlvii{%
We sent no messenger save that he should be obeyed by Allah's leave. And if, when they had wronged themselves, they had but come unto thee and asked forgiveness of Allah, and asked forgiveness of the messenger, they would have found Allah Forgiving, Merciful.\qt@no{64}}%
\qt@newcmd\qurantrans@en@dlviii{%
But nay, by thy Lord, they will not believe (in truth) until they make thee judge of what is in dispute between them and find within themselves no dislike of that which thou decidest, and submit with full submission.\qt@no{65}}%
\qt@newcmd\qurantrans@en@dlix{%
And if We had decreed for them: Lay down your lives or go forth from your dwellings, but few of them would have done it; though if they did what they are exhorted to do it would be better for them, and more strengthening;\qt@no{66}}%
\qt@newcmd\qurantrans@en@dlx{%
And then We should bestow upon them from Our presence an immense reward,\qt@no{67}}%
\qt@newcmd\qurantrans@en@dlxi{%
And should guide them unto a straight path.\qt@no{68}}%
\qt@newcmd\qurantrans@en@dlxii{%
Whoso obeyeth Allah and the messenger, they are with those unto whom Allah hath shown favour, of the prophets and the saints and the martyrs and the righteous. The best of company are they!\qt@no{69}}%
\qt@newcmd\qurantrans@en@dlxiii{%
That is bounty from Allah, and Allah sufficeth as Knower.\qt@no{70}}%
\qt@newcmd\qurantrans@en@dlxiv{%
O ye who believe! Take your precautions, then advance the proven ones, or advance all together.\qt@no{71}}%
\qt@newcmd\qurantrans@en@dlxv{%
Lo! among you there is he who loitereth; and if disaster overtook you, he would say: Allah hath been gracious unto me since I was not present with them.\qt@no{72}}%
\qt@newcmd\qurantrans@en@dlxvi{%
And if a bounty from Allah befell you, he would surely cry, as if there had been no love between you and him: Oh, would that I had been with them, then should I have achieved a great success!\qt@no{73}}%
\qt@newcmd\qurantrans@en@dlxvii{%
Let those fight in the way of Allah who sell the life of this world for the other. Whoso fighteth in the way of Allah, be he slain or be he victorious, on him We shall bestow a vast reward.\qt@no{74}}%
\qt@newcmd\qurantrans@en@dlxviii{%
How should ye not fight for the cause of Allah and of the feeble among men and of the women and the children who are crying: Our Lord! Bring us forth from out this town of which the people are oppressors! Oh, give us from thy presence some protecting friend! Oh, give us from Thy presence some defender!\qt@no{75}}%
\qt@newcmd\qurantrans@en@dlxix{%
Those who believe do battle for the cause of Allah; and those who disbelieve do battle for the cause of idols. So fight the minions of the devil. Lo! the devil's strategy is ever weak.\qt@no{76}}%
\qt@newcmd\qurantrans@en@dlxx{%
Hast thou not seen those unto whom it was said: Withhold your hands, establish worship and pay the poordue, but when fighting was prescribed for them behold! a party of them fear mankind even as their fear of Allah or with greater fear, and say: Our Lord! Why hast Thou ordained fighting for us? If only Thou wouldst give us respite yet a while! Say (unto them, O Muhammad): The comfort of this world is scant; the Hereafter will be better for him who wardeth off (evil); and ye will not be wronged the down upon a date-stone.\qt@no{77}}%
\qt@newcmd\qurantrans@en@dlxxi{%
Wheresoever ye may be, death will overtake you, even though ye were in lofty towers. Yet if a happy thing befalleth them they say: This is from Allah; and if an evil thing befalleth them they say: This is of thy doing (O Muhammad). Say (unto them): All is from Allah. What is amiss with these people that they come not nigh to understand a happening?\qt@no{78}}%
\qt@newcmd\qurantrans@en@dlxxii{%
Whatever of good befalleth thee (O man) it is from Allah, and whatever of ill befalleth thee it is from thyself. We have sent thee (Muhammad) as a messenger unto mankind and Allah is sufficient as Witness.\qt@no{79}}%
\qt@newcmd\qurantrans@en@dlxxiii{%
Whoso obeyeth the messenger hath obeyed Allah, and whoso turneth away: We have not sent thee as a warder over them.\qt@no{80}}%
\qt@newcmd\qurantrans@en@dlxxiv{%
And they say: (It is) obedience; but when they have gone forth from thee a party of them spend the night in planning other than what thou sayest. Allah recordeth what they plan by night. So oppose them and put thy trust in Allah. Allah is sufficient as Trustee.\qt@no{81}}%
\qt@newcmd\qurantrans@en@dlxxv{%
Will they not then ponder on the Qur'an? If it had been from other than Allah they would have found therein much incongruity.\qt@no{82}}%
\qt@newcmd\qurantrans@en@dlxxvi{%
And if any tidings, whether of safety or fear, come unto them, they noise it abroad, whereas if they had referred it to the messenger and to such of them as are in authority, those among them who are able to think out the matter would have known it. If it had not been for the grace of Allah upon you and His mercy ye would have followed Satan, save a few (of you).\qt@no{83}}%
\qt@newcmd\qurantrans@en@dlxxvii{%
So fight (O Muhammad) in the way of Allah Thou art not taxed (with the responsibility for anyone) except thyself - and urge on the believers. Peradventure Allah will restrain the might of those who disbelieve. Allah is stronger in might and stronger in inflicting punishment.\qt@no{84}}%
\qt@newcmd\qurantrans@en@dlxxviii{%
Whoso interveneth in a good cause will have the reward thereof, and whoso interveneth in an evil cause will bear the consequence thereof. Allah overseeth all things.\qt@no{85}}%
\qt@newcmd\qurantrans@en@dlxxix{%
When ye are greeted with a greeting, greet ye with a better than it or return it. Lo! Allah taketh count of all things.\qt@no{86}}%
\qt@newcmd\qurantrans@en@dlxxx{%
Allah! There is no Allah save Him. He gathereth you all unto a Day of Resurrection whereof there is no doubt. Who is more true in statement than Allah?\qt@no{87}}%
\qt@newcmd\qurantrans@en@dlxxxi{%
What aileth you that ye are become two parties regarding the hypocrites, when Allah cast them back (to disbelief) because of what they earned? Seek ye to guide him whom Allah hath sent astray? He whom Allah sendeth astray, for him thou (O MUhammad) canst not find a road.\qt@no{88}}%
\qt@newcmd\qurantrans@en@dlxxxii{%
They long that ye should disbelieve even as they disbelieve, that ye may be upon a level (with them). So choose not friends from them till they forsake their homes in the way of Allah; if they turn back (to enmity) then take them and kill them wherever ye find them, and choose no friend nor helper from among them,\qt@no{89}}%
\qt@newcmd\qurantrans@en@dlxxxiii{%
Except those who seek refuge with a people between whom and you there is a covenant, or (those who) come unto you because their hearts forbid them to make war on you or make war on their own folk. Had Allah willed He could have given them power over you so that assuredly they would have fought you. So, if they hold aloof from you and wage not war against you and offer you peace, Allah alloweth you no way against them.\qt@no{90}}%
\qt@newcmd\qurantrans@en@dlxxxiv{%
Ye will find others who desire that they should have security from you, and security from their own folk. So often as they are returned to hostility they are plunged therein. If they keep not aloof from you nor offer you peace nor hold their hands, then take them and kill them wherever ye find them. Against such We have given you clear warrant.\qt@no{91}}%
\qt@newcmd\qurantrans@en@dlxxxv{%
It is not for a believer to kill a believer unless (it be) by mistake. He who hath killed a believer by mistake must set free a believing slave, and pay the blood-money to the family of the slain, unless they remit it as a charity. If he (the victim) be of a people hostile unto you, and he is a believer, then (the penance is) to set free a believing slave. And if he cometh of a folk between whom and you there is a covenant, then the blood-money must be paid unto his folk and (also) a believing slave must be set free. And whoso hath not the wherewithal must fast two consecutive months. A penance from Allah. Allah is Knower, Wise.\qt@no{92}}%
\qt@newcmd\qurantrans@en@dlxxxvi{%
Whoso slayeth a believer of set purpose, his reward is hell for ever. Allah is wroth against him and He hath cursed him and prepared for him an awful doom.\qt@no{93}}%
\qt@newcmd\qurantrans@en@dlxxxvii{%
O ye who believe! When ye go forth (to fight) in the way of Allah, be careful to discriminate, and say not unto one who offereth you peace: ``Thou art not a believer," seeking the chance profits of this life (so that ye may despoil him). With Allah are plenteous spoils. Even thus (as he now is) were ye before; but Allah hath since then been gracious unto you. Therefore take care to discriminate. Allah is ever Informed of what ye do.\qt@no{94}}%
\qt@newcmd\qurantrans@en@dlxxxviii{%
Those of the believers who sit still, other than those who have a (disabling) hurt, are not on an equality with those who strive in the way of Allah with their wealth and lives. Allah hath conferred on those who strive with their wealth and lives a rank above the sedentary. Unto each Allah hath promised good, but He hath bestowed on those who strive a great reward above the sedentary;\qt@no{95}}%
\qt@newcmd\qurantrans@en@dlxxxix{%
Degrees of rank from Him, and forgiveness and mercy. Allah is ever Forgiving, Merciful.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dxc{%
Lo! as for those whom the angels take (in death) while they wrong themselves, (the angels) will ask: In what were ye engaged? They will say: We were oppressed in the land. (The angels) will say: Was not Allah's earth spacious that ye could have migrated therein? As for such, their habitation will be hell, an evil journey's end;\qt@no{97}}%
\qt@newcmd\qurantrans@en@dxci{%
Except the feeble among men, and the women, and the children, who are unable to devise a plan and are not shown a way.\qt@no{98}}%
\qt@newcmd\qurantrans@en@dxcii{%
As for such, it may be that Allah will pardon them. Allah is ever Clement, Forgiving.\qt@no{99}}%
\qt@newcmd\qurantrans@en@dxciii{%
Whoso migrateth for the cause of Allah will find much refuge and abundance in the earth, and whoso forsaketh his home, a fugitive unto Allah and His messenger, and death overtaketh him, his reward is then incumbent on Allah. Allah is ever Forgiving, Merciful.\qt@no{100}}%
\qt@newcmd\qurantrans@en@dxciv{%
And when ye go forth in the land, it is no sin for you to curtail (your) worship if ye fear that those who disbelieve may attack you. In truth the disbelievers are an open enemy to you.\qt@no{101}}%
\qt@newcmd\qurantrans@en@dxcv{%
And when thou (O Muhammad) art among them and arrangest (their) worship for them, let only a party of them stand with thee (to worship) and let them take their arms. Then when they have performed their prostrations let them fall to the rear and let another party come that hath not worshipped and let them worship with thee, and let them take their precaution and their arms. Those who disbelieve long for you to neglect your arms and your baggage that they may attack you once for all. It is no sin for you to lay aside your arms, if rain impedeth you or ye are sick. But take your precaution. Lo! Allah prepareth for the disbelievers shameful punishment.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dxcvi{%
When ye have performed the act of worship, remember Allah, standing, sitting and reclining. And when ye are in safety, observe proper worship. Worship at fixed times hath been enjoined on the believers.\qt@no{103}}%
\qt@newcmd\qurantrans@en@dxcvii{%
Relent not in pursuit of the enemy. If ye are suffering, lo! they suffer even as ye suffer and ye hope from Allah that for which they cannot hope. Allah is ever Knower, Wise.\qt@no{104}}%
\qt@newcmd\qurantrans@en@dxcviii{%
Lo! We reveal unto thee the Scripture with the truth, that thou mayst judge between mankind by that which Allah showeth thee. And be not thou a pleader for the treacherous;\qt@no{105}}%
\qt@newcmd\qurantrans@en@dxcix{%
And seek forgiveness of Allah. Lo! Allah is ever Forgiving, Merciful.\qt@no{106}}%
\qt@newcmd\qurantrans@en@dc{%
And plead not on behalf of (people) who deceive themselves. Lo! Allah loveth not one who is treacherous and sinful.\qt@no{107}}%
\qt@newcmd\qurantrans@en@dci{%
They seek to hide from men and seek not to hide from Allah. He is with them when by night they hold discourse displeasing unto Him. Allah ever surroundeth what they do.\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcii{%
Ho! ye are they who pleaded for them in the life of the world. But who will plead with Allah for them on the Day of Resurrection, or who will then be their defender?\qt@no{109}}%
\qt@newcmd\qurantrans@en@dciii{%
Yet whoso doeth evil or wrongeth his own soul, then seeketh pardon of Allah, will find Allah Forgiving, Merciful.\qt@no{110}}%
\qt@newcmd\qurantrans@en@dciv{%
Whoso committeth sin committeth it only against himself. Allah is ever Knower, Wise.\qt@no{111}}%
\qt@newcmd\qurantrans@en@dcv{%
And whoso committeth a delinquency or crime, then throweth (the blame) thereof upon the innocent, hath burdened himself with falsehood and a flagrant crime.\qt@no{112}}%
\qt@newcmd\qurantrans@en@dcvi{%
But for the grace of Allah upon thee (Muhammad), and His mercy, a party of them had resolved to mislead thee, but they will mislead only themselves and they will hurt thee not at all. Allah revealeth unto thee the Scripture and wisdom, and teacheth thee that which thou knewest not. The grace of Allah toward thee hath been infinite.\qt@no{113}}%
\qt@newcmd\qurantrans@en@dcvii{%
There is no good in much of their secret conferences save (in) him who enjoineth almsgiving and kindness and peace-making among the people. Whoso doeth that, seeking the good pleasure of Allah, We shall bestow on him a vast reward.\qt@no{114}}%
\qt@newcmd\qurantrans@en@dcviii{%
And whoso opposeth the messenger after the guidance (of Allah) hath been manifested unto him, and followeth other than the believer's way, We appoint for him that unto which he himself hath turned, and expose him unto hell - a hapless journey's end!\qt@no{115}}%
\qt@newcmd\qurantrans@en@dcix{%
Lo! Allah pardoneth not that partners should be ascribed unto Him. He pardoneth all save that to whom He will. Whoso ascribeth partners unto Allah hath wandered far astray.\qt@no{116}}%
\qt@newcmd\qurantrans@en@dcx{%
They invoke in His stead only females; they pray to none else than Satan, a rebel\qt@no{117}}%
\qt@newcmd\qurantrans@en@dcxi{%
Whom Allah cursed, and he said: Surely I will take of Thy bondmen an appointed portion,\qt@no{118}}%
\qt@newcmd\qurantrans@en@dcxii{%
And surely I will lead them astray, and surely I will arouse desires in them, and surely I will command them and they will cut the cattle' ears, and surely I will command them and they will change Allah's creation. Whoso chooseth Satan for a patron instead of Allah is verily a loser and his loss is manifest.\qt@no{119}}%
\qt@newcmd\qurantrans@en@dcxiii{%
He promiseth them and stirreth up desires in them, and Satan promiseth them only to beguile.\qt@no{120}}%
\qt@newcmd\qurantrans@en@dcxiv{%
For such, their habitation will be hell, and they will find no refuge therefrom.\qt@no{121}}%
\qt@newcmd\qurantrans@en@dcxv{%
But as for those who believe and do good works We shall bring them into Gardens underneath which rivers flow, wherein they will abide for ever. It is a promise from Allah in truth; and who can be more truthful than Allah in utterance?\qt@no{122}}%
\qt@newcmd\qurantrans@en@dcxvi{%
It will not be in accordance with your desires, nor the desires of the People of the Scripture. He who doeth wrong will have the recompense thereof, and will not find against Allah any protecting friend or helper.\qt@no{123}}%
\qt@newcmd\qurantrans@en@dcxvii{%
And whoso doeth good works, whether of male or female, and he (or she) is a believer, such will enter paradise and they will not be wronged the dint in a date-stone.\qt@no{124}}%
\qt@newcmd\qurantrans@en@dcxviii{%
Who is better in religion than he who surrendereth his purpose to Allah while doing good (to men) and followeth the tradition of Abraham, the upright? Allah (Himself) chose Abraham for friend.\qt@no{125}}%
\qt@newcmd\qurantrans@en@dcxix{%
Unto Allah belongeth whatsoever is in the heavens and whatsoever is in the earth. Allah ever surroundeth all things.\qt@no{126}}%
\qt@newcmd\qurantrans@en@dcxx{%
They consult thee concerning women. Say: Allah giveth you decree concerning them, and the Scripture which hath been recited unto you (giveth decree), concerning female orphans and those unto whom ye give not that which is ordained for them though ye desire to marry them, and (concerning) the weak among children, and that ye should deal justly with orphans. Whatever good ye do, lo! Allah is ever Aware of it.\qt@no{127}}%
\qt@newcmd\qurantrans@en@dcxxi{%
If a woman feareth ill treatment from her husband, or desertion, it is no sin for them twain if they make terms of peace between themselves. Peace is better. But greed hath been made present in the minds (of men). If ye do good and keep from evil, lo! Allah is ever Informed of what ye do.\qt@no{128}}%
\qt@newcmd\qurantrans@en@dcxxii{%
Ye will not be able to deal equally between (your) wives, however much ye wish (to do so). But turn not altogether away (from one), leaving her as in suspense. If ye do good and keep from evil, lo! Allah is ever Forgiving, Merciful.\qt@no{129}}%
\qt@newcmd\qurantrans@en@dcxxiii{%
But if they separate, Allah will compensate each out of His abundance. Allah is ever All-Embracing, All-Knowing.\qt@no{130}}%
\qt@newcmd\qurantrans@en@dcxxiv{%
Unto Allah belongeth whatsoever is in the heavens and whatsoever is in the earth. And We charged those who received the Scripture before you, and (We charge) you, that ye keep your duty toward Allah. And if ye disbelieve, lo! unto Allah belongeth whatsoever is in the heavens and whatsoever is in the earth, and Allah is ever Absolute, Owner of Praise.\qt@no{131}}%
\qt@newcmd\qurantrans@en@dcxxv{%
Unto Allah belongeth whatsoever is in the heavens and whatsoever is in the earth. And Allah is sufficient as Defender.\qt@no{132}}%
\qt@newcmd\qurantrans@en@dcxxvi{%
If He will, He can remove you, O people, and produce others (in your stead). Allah is Able to do that.\qt@no{133}}%
\qt@newcmd\qurantrans@en@dcxxvii{%
Whoso desireth the reward of the world, (let him know that) with Allah is the reward of the world and the Hereafter. Allah is ever Hearer, Seer.\qt@no{134}}%
\qt@newcmd\qurantrans@en@dcxxviii{%
O ye who believe! Be ye staunch in justice, witnesses for Allah, even though it be against yourselves or (your) parents or (your) kindred, whether (the case be of) a rich man or a poor man, for Allah is nearer unto both (them ye are). So follow not passion lest ye lapse (from truth) and if ye lapse or fall away, then lo! Allah is ever Informed of what ye do.\qt@no{135}}%
\qt@newcmd\qurantrans@en@dcxxix{%
O ye who believe! Believe in Allah and His messenger and the Scripture which He hath revealed unto His messenger, and the Scripture which He revealed aforetime. Whoso disbelieveth in Allah and His angels and His scriptures and His messengers and the Last Day, he verily hath wandered far astray.\qt@no{136}}%
\qt@newcmd\qurantrans@en@dcxxx{%
Lo! those who believe, then disbelieve and then (again) believe, then disbelieve, and then increase in disbelief, Allah will never pardon them, nor will He guide them unto a way.\qt@no{137}}%
\qt@newcmd\qurantrans@en@dcxxxi{%
Bear unto the hypocrites the tidings that for them there is a painful doom;\qt@no{138}}%
\qt@newcmd\qurantrans@en@dcxxxii{%
Those who chose disbelievers for their friends instead of believers! Do they look for power at their hands? Lo! all power appertaineth to Allah.\qt@no{139}}%
\qt@newcmd\qurantrans@en@dcxxxiii{%
He hath already revealed unto you in the Scripture that, when ye hear the revelations of Allah rejected and derided, (ye) sit not with them (who disbelieve and mock) until they engage in some other conversation. Lo! in that case (if ye stayed) ye would be like unto them. Lo! Allah will gather hypocrites and disbelievers, all together, into hell;\qt@no{140}}%
\qt@newcmd\qurantrans@en@dcxxxiv{%
Those who wait upon occasion in regard to you and, if a victory cometh unto you from Allah, say: Are we not with you? and if the disbelievers meet with a success say: Had we not the mastery of you, and did we not protect you from the believers? - Allah will judge between you at the Day of Resurrection, and Allah will not give the disbelievers any way (of success) against the believers.\qt@no{141}}%
\qt@newcmd\qurantrans@en@dcxxxv{%
Lo! the hypocrites seek to beguile Allah, but it is He Who beguileth them. When they stand up to worship they perform it languidly and to be seen of men, and are mindful of Allah but little;\qt@no{142}}%
\qt@newcmd\qurantrans@en@dcxxxvi{%
Swaying between this (and that), (belonging) neither to these nor to those. He whom Allah causeth to go astray, thou (O Muhammad) wilt not find a way for him:\qt@no{143}}%
\qt@newcmd\qurantrans@en@dcxxxvii{%
O ye who believe! Choose not disbelievers for (your) friends in place of believers. Would ye give Allah a clear warrant against you?\qt@no{144}}%
\qt@newcmd\qurantrans@en@dcxxxviii{%
Lo! the hypocrites (will be) in the lowest deep of the Fire, and thou wilt find no helper for them;\qt@no{145}}%
\qt@newcmd\qurantrans@en@dcxxxix{%
Save those who repent and amend and hold fast to Allah and make their religion pure for Allah (only). Those are with the believers. And Allah will bestow on the believers an immense reward.\qt@no{146}}%
\qt@newcmd\qurantrans@en@dcxl{%
What concern hath Allah for your punishment if ye are thankful (for His mercies) and believe (in Him)? Allah was ever Responsive, Aware.\qt@no{147}}%
\qt@newcmd\qurantrans@en@dcxli{%
Allah loveth not the utterance of harsh speech save by one who hath been wronged. Allah is ever Hearer, Knower.\qt@no{148}}%
\qt@newcmd\qurantrans@en@dcxlii{%
If ye do good openly or keep it secret, or forgive evil, lo! Allah is ever Forgiving, Powerful.\qt@no{149}}%
\qt@newcmd\qurantrans@en@dcxliii{%
Lo! those who disbelieve in Allah and His messengers, and seek to make distinction between Allah and His messengers, and say: We believe in some and disbelieve in others, and seek to choose a way in between;\qt@no{150}}%
\qt@newcmd\qurantrans@en@dcxliv{%
Such are disbelievers in truth; and for disbelievers We prepare a shameful doom.\qt@no{151}}%
\qt@newcmd\qurantrans@en@dcxlv{%
But those who believe in Allah and His messengers and make no distinction between any of them, unto them Allah will give their wages; and Allah was ever Forgiving, Merciful.\qt@no{152}}%
\qt@newcmd\qurantrans@en@dcxlvi{%
The people of the Scripture ask of thee that thou shouldst cause an (actual) Book to descend upon them from heaven. They asked a greater thing of Moses aforetime, for they said: Show us Allah plainly. The storm of lightning seized them for their wickedness. Then (even) after that) they chose the calf (for worship) after clear proofs (of Allah's Sovereignty) had come unto them. And We forgave them that! And We bestowed on Moses evident authority.\qt@no{153}}%
\qt@newcmd\qurantrans@en@dcxlvii{%
And We caused the Mount to tower above them at (the taking of) their covenant: and We bade them: Enter the gate, prostrate! and We bode them: Transgress not the Sabbath! and We took from them a firm covenant.\qt@no{154}}%
\qt@newcmd\qurantrans@en@dcxlviii{%
Then because of their breaking of their covenant, and their disbelieving in the revelations of Allah, and their slaying of the prophets wrongfully, and their saying: Our hearts are hardened - Nay, but Allah set a seal upon them for their disbelief, so that they believe not save a few -\qt@no{155}}%
\qt@newcmd\qurantrans@en@dcxlix{%
And because of their disbelief and of their speaking against Mary a tremendous calumny;\qt@no{156}}%
\qt@newcmd\qurantrans@en@dcl{%
And because of their saying: We slew the Messiah, Jesus son of Mary, Allah's messenger - they slew him not nor crucified him, but it appeared so unto them; and lo! those who disagree concerning it are in doubt thereof; they have no knowledge thereof save pursuit of a conjecture; they slew him not for certain.\qt@no{157}}%
\qt@newcmd\qurantrans@en@dcli{%
But Allah took him up unto Himself. Allah was ever Mighty, Wise.\qt@no{158}}%
\qt@newcmd\qurantrans@en@dclii{%
There is not one of the People of the Scripture but will believe in him before his death, and on the Day of Resurrection he will be a witness against them -\qt@no{159}}%
\qt@newcmd\qurantrans@en@dcliii{%
Because of the wrongdoing of the Jews We forbade them good things which were (before) made lawful unto them, and because of their much hindering from Allah's way,\qt@no{160}}%
\qt@newcmd\qurantrans@en@dcliv{%
And of their taking usury when they were forbidden it, and of their devouring people's wealth by false pretences, We have prepared for those of them who disbelieve a painful doom.\qt@no{161}}%
\qt@newcmd\qurantrans@en@dclv{%
But those of them who are firm in knowledge and the believers believe in that which is revealed unto thee, and that which was revealed before thee, especially the diligent in prayer and those who pay the poor-due, the believers in Allah and the Last Day. Upon these We shall bestow immense reward.\qt@no{162}}%
\qt@newcmd\qurantrans@en@dclvi{%
Lo! We inspire thee as We inspired Noah and the prophets after him, as We inspired Abraham and Ishmael and Isaac and Jacob and the tribes, and Jesus and Job and Jonah and Aaron and Solomon, and as We imparted unto David the Psalms;\qt@no{163}}%
\qt@newcmd\qurantrans@en@dclvii{%
And messengers We have mentioned unto thee before and messengers We have not mentioned unto thee; and Allah spake directly unto Moses;\qt@no{164}}%
\qt@newcmd\qurantrans@en@dclviii{%
Messengers of good cheer and of warning, in order that mankind might have no argument against Allah after the messengers. Allah was ever Mighty, Wise.\qt@no{165}}%
\qt@newcmd\qurantrans@en@dclix{%
But Allah (Himself) testifieth concerning that which He hath revealeth unto thee; in His knowledge hath He revealed it; and the angels also testify. And Allah is sufficient Witness.\qt@no{166}}%
\qt@newcmd\qurantrans@en@dclx{%
Lo! those who disbelieve and hinder (others) from the way of Allah, they verily have wandered far astray.\qt@no{167}}%
\qt@newcmd\qurantrans@en@dclxi{%
Lo! those who disbelieve and deal in wrong, Allah will never forgive them, neither will He guide them unto a road,\qt@no{168}}%
\qt@newcmd\qurantrans@en@dclxii{%
Except the road of hell, wherein they will abide for ever. And that is ever easy for Allah.\qt@no{169}}%
\qt@newcmd\qurantrans@en@dclxiii{%
O mankind! The messenger hath come unto you with the Truth from your Lord. Therefor believe; (it is) better for you. But if ye disbelieve, still, lo! unto Allah belongeth whatsoever is in the heavens and the earth. Allah is ever Knower, Wise.\qt@no{170}}%
\qt@newcmd\qurantrans@en@dclxiv{%
O People of the Scripture! Do not exaggerate in your religion nor utter aught concerning Allah save the truth. The Messiah, Jesus son of Mary, was only a messenger of Allah, and His word which He conveyed unto Mary, and a spirit from Him. So believe in Allah and His messengers, and say not ``Three" - Cease! (it is) better for you! - Allah is only One Allah. Far is it removed from His Transcendent Majesty that He should have a son. His is all that is in the heavens and all that is in the earth. And Allah is sufficient as Defender.\qt@no{171}}%
\qt@newcmd\qurantrans@en@dclxv{%
The Messiah will never scorn to be a slave unto Allah, nor will the favoured angels. Whoso scorneth His service and is proud, all such will He assemble unto Him;\qt@no{172}}%
\qt@newcmd\qurantrans@en@dclxvi{%
Then, as for those who believed and did good works, unto them will He pay their wages in full, adding unto them of His bounty; and as for those who were scornful and proud, them will He punish with a painful doom. And they will not find for them, against Allah, any protecting friend or helper.\qt@no{173}}%
\qt@newcmd\qurantrans@en@dclxvii{%
O mankind! Now hath a proof from your Lord come unto you, and We have sent down unto you a clear light;\qt@no{174}}%
\qt@newcmd\qurantrans@en@dclxviii{%
As for those who believe in Allah, and hold fast unto Him, them He will cause to enter into His mercy and grace, and will guide them unto Him by a straight road.\qt@no{175}}%
\qt@newcmd\qurantrans@en@dclxix{%
They ask thee for a pronouncement. Say: Allah hath pronounced for you concerning distant kindred. If a man die childless and he have a sister, hers is half the heritage, and he would have inherited from her had she died childless. And if there be two sisters, then theirs are two-thirds of the heritage, and if they be brethren, men and women, unto the male is the equivalent of the share of two females. Allah expoundeth unto you, so that ye err not. Allah is Knower of all things.\qt@no{176}}%
\qt@newcmd\qurantrans@en@dclxx{%
\basmalahen O ye who believe! Fulfil your indentures. The beast of cattle is made lawful unto you (for food) except that which is announced unto you (herein), game being unlawful when ye are on the pilgrimage. Lo! Allah ordaineth that which pleaseth Him.\qt@no{1}}%
\qt@newcmd\qurantrans@en@dclxxi{%
O ye who believe! Profane not Allah's monuments nor the Sacred Month nor the offerings nor the garlands, nor those repairing to the Sacred House, seeking the grace and pleasure of their Lord. But when ye have left the sacred territory, then go hunting (if ye will). And let not your hatred of a folk who (once) stopped your going to the inviolable place of worship seduce you to transgress; but help ye one another unto righteousness and pious duty. Help not one another unto sin and transgression, but keep your duty to Allah. Lo! Allah is severe in punishment.\qt@no{2}}%
\qt@newcmd\qurantrans@en@dclxxii{%
Forbidden unto you (for food) are carrion and blood and swineflesh, and that which hath been dedicated unto any other than Allah, and the strangled, and the dead through beating, and the dead through falling from a height, and that which hath been killed by (the goring of) horns, and the devoured of wild beasts, saving that which ye make lawful (by the death-stroke), and that which hath been immolated unto idols. And (forbidden is it) that ye swear by the divining arrows. This is an abomination. This day are those who disbelieve in despair of (ever harming) your religion; so fear them not, fear Me! This day have I perfected your religion for you and completed My favour unto you, and have chosen for you as religion al-Islam. Whoso is forced by hunger, not by will, to sin: (for him) lo! Allah is Forgiving, Merciful.\qt@no{3}}%
\qt@newcmd\qurantrans@en@dclxxiii{%
They ask thee (O Muhammad) what is made lawful for them. Say: (all) good things are made lawful for you. And those beasts and birds of prey which ye have trained as hounds are trained, ye teach them that which Allah taught you; so eat of that which they catch for you and mention Allah's name upon it, and observe your duty to Allah. Lo! Allah is swift to take account.\qt@no{4}}%
\qt@newcmd\qurantrans@en@dclxxiv{%
This day are (all) good things made lawful for you. The food of those who have received the Scripture is lawful for you, and your food is lawful for them. And so are the virtuous women of the believers and the virtuous women of those who received the Scripture before you (lawful for you) when ye give them their marriage portions and live with them in honour, not in fornication, nor taking them as secret concubines. Whoso denieth the faith, his work is vain and he will be among the losers in the Hereafter.\qt@no{5}}%
\qt@newcmd\qurantrans@en@dclxxv{%
O ye who believe! When ye rise up for prayer, wash you faces, and your hands up to the elbows, and lightly rub your heads and (wash) your feet up to the ankles. And if ye are unclean, purify yourselves. And if ye are sick or on a journey, or one of you cometh from the closet, or ye have had contact with women, and ye find not water, then go to clean, high ground and rub your faces and your hands with some of it. Allah would not place a burden on you, but He would purify you and would perfect His grace upon you, that ye may give thanks.\qt@no{6}}%
\qt@newcmd\qurantrans@en@dclxxvi{%
Remember Allah's grace upon you and His covenant by which He bound you when ye said: We hear and we obey; And keep your duty to Allah. Lo! He knoweth what is in the breasts (of men).\qt@no{7}}%
\qt@newcmd\qurantrans@en@dclxxvii{%
O ye who believe! Be steadfast witnesses for Allah in equity, and let not hatred of any people seduce you that ye deal not justly. Deal justly, that is nearer to your duty. Observe your duty to Allah. Lo! Allah is Informed of what ye do.\qt@no{8}}%
\qt@newcmd\qurantrans@en@dclxxviii{%
Allah hath promised those who believe and do good works: Theirs will be forgiveness and immense reward.\qt@no{9}}%
\qt@newcmd\qurantrans@en@dclxxix{%
And they who disbelieve and deny Our revelations, such are rightful owners of hell.\qt@no{10}}%
\qt@newcmd\qurantrans@en@dclxxx{%
O ye who believe! Remember Allah's favour unto you, how a people were minded to stretch out their hands against you but He withheld their hands from you; and keep your duty to Allah. In Allah let believers put their trust.\qt@no{11}}%
\qt@newcmd\qurantrans@en@dclxxxi{%
Allah made a covenant of old with the Children of Israel and We raised among them twelve chieftains, and Allah said: Lo! I am with you. If ye establish worship and pay the poor-due, and believe in My messengers and support them, and lend unto Allah a kindly loan, surely I shall remit your sins, and surely I shall bring you into Gardens underneath which rivers flow. Whoso among you disbelieveth after this will go astray from a plain road.\qt@no{12}}%
\qt@newcmd\qurantrans@en@dclxxxii{%
And because of their breaking their covenant, We have cursed them and made hard their hearts. They change words from their context and forget a part of that whereof they were admonished. Thou wilt not cease to discover treachery from all save a few of them. But bear with them and pardon them. Lo! Allah loveth the kindly.\qt@no{13}}%
\qt@newcmd\qurantrans@en@dclxxxiii{%
And with those who say: ``Lo! we are Christians," We made a covenant, but they forgot a part of that whereof they were admonished. Therefor We have stirred up enmity and hatred among them till the Day of Resurrection, when Allah will inform them of their handiwork.\qt@no{14}}%
\qt@newcmd\qurantrans@en@dclxxxiv{%
O People of the Scripture! Now hath Our messenger come unto you, expounding unto you much of that which ye used to hide in the Scripture, and forgiving much. now hath come unto you light from Allah and plain Scripture,\qt@no{15}}%
\qt@newcmd\qurantrans@en@dclxxxv{%
Whereby Allah guideth him who seeketh His good pleasure unto paths of peace. He bringeth them out of darkness unto light by His decree, and guideth them unto a straight path.\qt@no{16}}%
\qt@newcmd\qurantrans@en@dclxxxvi{%
They indeed have disbelieved who say: Lo! Allah is the Messiah, son of Mary. Say: Who then can do aught against Allah, if He had willed to destroy the Messiah son of Mary, and his mother and everyone on earth? Allah's is the Sovereignty of the heavens and the earth and all that is between them. He createth what He will. And Allah is Able to do all things.\qt@no{17}}%
\qt@newcmd\qurantrans@en@dclxxxvii{%
The Jews and Christians say: We are sons of Allah and His loved ones. Say: Why then doth He chastise you for your sins? Nay, ye are but mortals of His creating. He forgiveth whom He will, and chastiseth whom He will. Allah's is the Sovereignty of the heavens and the earth and all that is between them, and unto Him is the journeying.\qt@no{18}}%
\qt@newcmd\qurantrans@en@dclxxxviii{%
O People of the Scripture! Now hath Our messenger come unto you to make things plain unto you after an interval (of cessation) of the messengers, lest ye should say: There came not unto us a messenger of cheer nor any warner. Now hath a messenger of cheer and a warner come unto you. Allah is Able to do all things.\qt@no{19}}%
\qt@newcmd\qurantrans@en@dclxxxix{%
And (remember) when Moses said unto his people: O my people! Remember Allah's favour unto you, how He placed among you prophets, and He made you kings, and gave you that (which) He gave not to any (other) of (His) creatures.\qt@no{20}}%
\qt@newcmd\qurantrans@en@dcxc{%
O my people! Go into the holy land which Allah hath ordained for you. Turn not in flight, for surely ye turn back as losers:\qt@no{21}}%
\qt@newcmd\qurantrans@en@dcxci{%
They said: O Moses! Lo! a giant people (dwell) therein and lo! we go not in till they go forth from thence. When they go forth from thence, then we will enter (not till then).\qt@no{22}}%
\qt@newcmd\qurantrans@en@dcxcii{%
Then out spake two of those who feared (their Lord, men) unto whom Allah had been gracious: Enter in upon them by the gate, for if ye enter by it, lo! ye will be victorious. So put your trust (in Allah) if ye are indeed believers.\qt@no{23}}%
\qt@newcmd\qurantrans@en@dcxciii{%
They said: O Moses! We will never enter (the land) while they are in it. So go thou and thy Lord and fight! We will sit here.\qt@no{24}}%
\qt@newcmd\qurantrans@en@dcxciv{%
He said: My Lord! I have control of none but myself and my brother, so distinguish between us and the wrong-doing folk.\qt@no{25}}%
\qt@newcmd\qurantrans@en@dcxcv{%
(Their Lord) said: For this the land will surely be forbidden them for forty years that they will wander in the earth, bewildered. So grieve not over the wrongdoing folk.\qt@no{26}}%
\qt@newcmd\qurantrans@en@dcxcvi{%
But recite unto them with truth the tale of the two sons of Adam, how they offered each a sacrifice, and it was accepted from the one of them and it was not accepted from the other. (The one) said: I will surely kill thee. (The other) answered: Allah accepteth only from those who ward off (evil).\qt@no{27}}%
\qt@newcmd\qurantrans@en@dcxcvii{%
Even if thou stretch out thy hand against me to kill me, I shall not stretch out my hand against thee to kill thee, lo! I fear Allah, the Lord of the Worlds.\qt@no{28}}%
\qt@newcmd\qurantrans@en@dcxcviii{%
Lo! I would rather thou shouldst bear the punishment of the sin against me and thine own sin and become one of the owners of the fire. That is the reward of evil-doers.\qt@no{29}}%
\qt@newcmd\qurantrans@en@dcxcix{%
But (the other's) mind imposed on him the killing of his brother, so he slew him and became one of the losers.\qt@no{30}}%
\qt@newcmd\qurantrans@en@dcc{%
Then Allah sent a raven scratching up the ground, to show him how to hide his brother's naked corpse. He said: Woe unto me! Am I not able to be as this raven and so hide my brother's naked corpse? And he became repentant.\qt@no{31}}%
\qt@newcmd\qurantrans@en@dcci{%
For that cause We decreed for the Children of Israel that whosoever killeth a human being for other than manslaughter or corruption in the earth, it shall be as if he had killed all mankind, and whoso saveth the life of one, it shall be as if he had saved the life of all mankind. Our messengers came unto them of old with clear proofs (of Allah's Sovereignty), but afterwards lo! many of them became prodigals in the earth.\qt@no{32}}%
\qt@newcmd\qurantrans@en@dccii{%
The only reward of those who make war upon Allah and His messenger and strive after corruption in the land will be that they will be killed or crucified, or have their hands and feet on alternate sides cut off, or will be expelled out of the land. Such will be their degradation in the world, and in the Hereafter theirs will be an awful doom;\qt@no{33}}%
\qt@newcmd\qurantrans@en@dcciii{%
Save those who repent before ye overpower them. For know that Allah is Forgiving, Merciful.\qt@no{34}}%
\qt@newcmd\qurantrans@en@dcciv{%
O ye who believe! Be mindful of your duty to Allah, and seek the way of approach unto Him, and strive in His way in order that ye may succeed.\qt@no{35}}%
\qt@newcmd\qurantrans@en@dccv{%
As for those who disbelieve, lo! if all that is in the earth were theirs, and as much again therewith, to ransom them from the doom on the Day of Resurrection, it would not be accepted from them. Theirs will be a painful doom.\qt@no{36}}%
\qt@newcmd\qurantrans@en@dccvi{%
They will wish to come forth from the Fire, but they will not come forth from it. Theirs will be a lasting doom.\qt@no{37}}%
\qt@newcmd\qurantrans@en@dccvii{%
As for the thief, both male and female, cut off their hands. It is the reward of their own deeds, an exemplary punishment from Allah. Allah is Mighty, Wise.\qt@no{38}}%
\qt@newcmd\qurantrans@en@dccviii{%
But whoso repenteth after his wrongdoing and amendeth, lo! Allah will relent toward him. Lo! Allah is Forgiving, Merciful.\qt@no{39}}%
\qt@newcmd\qurantrans@en@dccix{%
Knowest thou not that unto Allah belongeth the Sovereignty of the heavens and the earth? He punisheth whom He will, and forgiveth whom He will. Allah is Able to do all things.\qt@no{40}}%
\qt@newcmd\qurantrans@en@dccx{%
O Messenger! Let not them grieve thee who vie one with another in the race to disbelief, of such as say with their mouths: ``We believe," but their hearts believe not, and of the Jews: listeners for the sake of falsehood, listeners on behalf of other folk who come not unto thee, changing words from their context and saying: If this be given unto you, receive it, but if this be not given unto you, then beware! He whom Allah doometh unto sin, thou (by thine efforts) wilt avail him naught against Allah. Those are they for whom the Will of Allah is that He cleanse not their hearts. Theirs in the world will be ignominy, and in the Hereafter an awful doom;\qt@no{41}}%
\qt@newcmd\qurantrans@en@dccxi{%
Listeners for the sake of falsehood! Greedy for illicit gain! If then they have recourse unto thee (Muhammad) judge between them or disclaim jurisdiction. If thou disclaimest jurisdiction, then they cannot harm thee at all. But if thou judgest, judge between them with equity. Lo! Allah loveth the equitable.\qt@no{42}}%
\qt@newcmd\qurantrans@en@dccxii{%
How come they unto thee for judgment when they have the Torah, wherein Allah hath delivered judgment (for them)? Yet even after that they turn away. Such (folk) are not believers.\qt@no{43}}%
\qt@newcmd\qurantrans@en@dccxiii{%
Lo! We did reveal the Torah, wherein is guidance and a light, by which the prophets who surrendered (unto Allah) judged the Jews, and the rabbis and the priests (judged) by such of Allah's Scripture as they were bidden to observe, and thereunto were they witnesses. So fear not mankind, but fear Me. And My revelations for a little gain. Whoso judgeth not by that which Allah hath revealed: such are disbelievers.\qt@no{44}}%
\qt@newcmd\qurantrans@en@dccxiv{%
And We prescribed for them therein: The life for the life, and the eye for the eye, and the nose for the nose, and the ear for the ear, and the tooth for the tooth, and for wounds retaliation. But whoso forgoeth it (in the way of charity) it shall be expiation for him. Whoso judgeth not by that which Allah hath revealed: such are wrong-doers.\qt@no{45}}%
\qt@newcmd\qurantrans@en@dccxv{%
And We caused Jesus, son of Mary, to follow in their footsteps, confirming that which was (revealed) before him in the Torah, and We bestowed on him the Gospel wherein is guidance and a light, confirming that which was (revealed) before it in the Torah - a guidance and an admonition unto those who ward off (evil).\qt@no{46}}%
\qt@newcmd\qurantrans@en@dccxvi{%
Let the People of the Gospel judge by that which Allah hath revealed therein. Whoso judgeth not by that which Allah hath revealed: such are evil-livers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@dccxvii{%
And unto thee have We revealed the Scripture with the truth, confirming whatever Scripture was before it, and a watcher over it. So judge between them by that which Allah hath revealed, and follow not their desires away from the truth which hath come unto thee. For each We have appointed a divine law and a traced-out way. Had Allah willed He could have made you one community. But that He may try you by that which He hath given you (He hath made you as ye are). So vie one with another in good works. Unto Allah ye will all return, and He will then inform you of that wherein ye differ.\qt@no{48}}%
\qt@newcmd\qurantrans@en@dccxviii{%
So judge between them by that which Allah hath revealed, and follow not their desires, but beware of them lest they seduce thee from some part of that which Allah hath revealed unto thee. And if they turn away, then know that Allah's Will is to smite them for some sin of theirs. Lo! many of mankind are evil-livers.\qt@no{49}}%
\qt@newcmd\qurantrans@en@dccxix{%
Is it a judgment of the time of (pagan) ignorance that they are seeking? Who is better than Allah for judgment to a people who have certainty (in their belief)?\qt@no{50}}%
\qt@newcmd\qurantrans@en@dccxx{%
O ye who believe! Take not the Jews and the Christians for friends. They are friends one to another. He among you who taketh them for friends is (one) of them. Lo! Allah guideth not wrongdoing folk.\qt@no{51}}%
\qt@newcmd\qurantrans@en@dccxxi{%
And thou seest those in whose heart is a disease race toward them, saying: We fear lest a change of fortune befall us. And it may happen that Allah will vouchsafe (unto thee) the victory, or a commandment from His presence. Then will they repent them of their secret thoughts.\qt@no{52}}%
\qt@newcmd\qurantrans@en@dccxxii{%
Then will the believers say (unto the people of the Scripture): are these they who swore by Allah their most binding oaths that they were surely with you? Their works have failed, and they have become the losers.\qt@no{53}}%
\qt@newcmd\qurantrans@en@dccxxiii{%
O ye who believe! Whoso of you becometh a renegade from his religion, (know that in his stead) Allah will bring a people whom He loveth and who love Him, humble toward believers, stern toward disbelievers, striving in the way of Allah, and fearing not the blame of any blamer. Such is the grace of Allah which He giveth unto whom He will. Allah is All-Embracing, All-Knowing.\qt@no{54}}%
\qt@newcmd\qurantrans@en@dccxxiv{%
Your guardian can be only Allah; and His messenger and those who believe, who establish worship and pay the poordue, and bow down (in prayer).\qt@no{55}}%
\qt@newcmd\qurantrans@en@dccxxv{%
And whoso taketh Allah and His messenger and those who believe for guardian (will know that), lo! the party of Allah, they are the victorious.\qt@no{56}}%
\qt@newcmd\qurantrans@en@dccxxvi{%
O Ye who believe! Choose not for guardians such of those who received the Scripture before you, and of the disbelievers, as make a jest and sport of your religion. But keep your duty to Allah if ye are true believers.\qt@no{57}}%
\qt@newcmd\qurantrans@en@dccxxvii{%
And when ye call to prayer they take it for a jest and sport. That is because they are a folk who understand not.\qt@no{58}}%
\qt@newcmd\qurantrans@en@dccxxviii{%
Say: O People of the Scripture! Do ye blame us for aught else than that we believe in Allah and that which is revealed unto us and that which was revealed aforetime, and because most of you are evil-livers?\qt@no{59}}%
\qt@newcmd\qurantrans@en@dccxxix{%
Shall I tell thee of a worse (case) than theirs for retribution with Allah? (Worse is the case of him) whom Allah hath cursed, him on whom His wrath hath fallen and of whose sort Allah hath turned some to apes and swine, and who serveth idols. Such are in worse plight and further astray from the plain road.\qt@no{60}}%
\qt@newcmd\qurantrans@en@dccxxx{%
When they come unto you (Muslims), they say: We believe; but they came in unbelief and they went out in the same; and Allah knoweth best what they were hiding.\qt@no{61}}%
\qt@newcmd\qurantrans@en@dccxxxi{%
And thou seest many of them vying one with another in sin and transgression and their devouring of illicit gain. Verily evil is what they do.\qt@no{62}}%
\qt@newcmd\qurantrans@en@dccxxxii{%
Why do not the rabbis and the priests forbid their evil-speaking and their devouring of illicit gain? Verily evil is their handiwork.\qt@no{63}}%
\qt@newcmd\qurantrans@en@dccxxxiii{%
The Jews say: Allah's hand is fettered. Their hands are fettered and they are accursed for saying so. Nay, but both His hands are spread out wide in bounty. He bestoweth as He will. That which hath been revealed unto thee from thy Lord is certain to increase the contumacy and disbelief of many of them, and We have cast among them enmity and hatred till the Day of Resurrection. As often as they light a fire for war, Allah extinguisheth it. Their effort is for corruption in the land, and Allah loveth not corrupters.\qt@no{64}}%
\qt@newcmd\qurantrans@en@dccxxxiv{%
If only the People of the Scripture would believe and ward off (evil), surely We should remit their sins from them and surely We should bring them into Gardens of Delight.\qt@no{65}}%
\qt@newcmd\qurantrans@en@dccxxxv{%
If they had observed the Torah and the Gospel and that which was revealed unto them from their Lord, they would surely have been nourished from above them and from beneath their feet. Among them there are people who are moderate, but many of them are of evil conduct.\qt@no{66}}%
\qt@newcmd\qurantrans@en@dccxxxvi{%
O Messenger! Make known that which hath been revealed unto thee from thy Lord, for if thou do it not, thou wilt not have conveyed His message. Allah will protect thee from mankind. Lo! Allah guideth not the disbelieving folk.\qt@no{67}}%
\qt@newcmd\qurantrans@en@dccxxxvii{%
Say O People of the Scripture! Ye have naught (of guidance) till ye observe the Torah and the Gospel and that which was revealed unto you from your Lord. That which is revealed unto thee (Muhammad) from thy Lord is certain to increase the contumacy and disbelief of many of them. But grieve not for the disbelieving folk.\qt@no{68}}%
\qt@newcmd\qurantrans@en@dccxxxviii{%
Lo! those who believe, and those who are Jews, and Sabaeans, and Christians - Whosoever believeth in Allah and the Last Day and doeth right - there shall no fear come upon them neither shall they grieve.\qt@no{69}}%
\qt@newcmd\qurantrans@en@dccxxxix{%
We made a covenant of old with the Children of Israel and We sent unto them messengers. As often as a messenger came unto them with that which their souls desired not (they became rebellious). Some (of them) they denied and some they slew.\qt@no{70}}%
\qt@newcmd\qurantrans@en@dccxl{%
They thought no harm would come of it, so they were wilfully blind and deaf. And afterward Allah turned (in mercy) toward them. Now (even after that) are many of them wilfully blind and deaf. Allah is Seer of what they do.\qt@no{71}}%
\qt@newcmd\qurantrans@en@dccxli{%
They surely disbelieve who say: Lo! Allah is the Messiah, son of Mary. The Messiah (himself) said: O Children of Israel, worship Allah, my Lord and your Lord. Lo! whoso ascribeth partners unto Allah, for him Allah hath forbidden paradise. His abode is the Fire. For evil-doers there will be no helpers.\qt@no{72}}%
\qt@newcmd\qurantrans@en@dccxlii{%
They surely disbelieve who say: Lo! Allah is the third of three; when there is no Allah save the One Allah. If they desist not from so saying a painful doom will fall on those of them who disbelieve.\qt@no{73}}%
\qt@newcmd\qurantrans@en@dccxliii{%
Will they not rather turn unto Allah and seek forgiveness of Him? For Allah is Forgiving, Merciful.\qt@no{74}}%
\qt@newcmd\qurantrans@en@dccxliv{%
The Messiah, son of Mary, was no other than a messenger, messengers (the like of whom) had passed away before him. And his mother was a saintly woman. And they both used to eat (earthly) food. See how We make the revelations clear for them, and see how they are turned away!\qt@no{75}}%
\qt@newcmd\qurantrans@en@dccxlv{%
Say: Serve ye in place of Allah that which possesseth for you neither hurt nor use? Allah it is Who is the Hearer, the Knower.\qt@no{76}}%
\qt@newcmd\qurantrans@en@dccxlvi{%
Say: O People of the Scripture! Stress not in your religion other than the truth, and follow not the vain desires of folk who erred of old and led many astray, and erred from a plain road.\qt@no{77}}%
\qt@newcmd\qurantrans@en@dccxlvii{%
Those of the Children of Israel who went astray were cursed by the tongue of David, and of Jesus, son of Mary. That was because they rebelled and used to transgress.\qt@no{78}}%
\qt@newcmd\qurantrans@en@dccxlviii{%
They restrained not one another from the wickedness they did. Verily evil was that they used to do!\qt@no{79}}%
\qt@newcmd\qurantrans@en@dccxlix{%
Thou seest many of them making friends with those who disbelieve. Surely ill for them is that which they themselves send on before them: that Allah will be wroth with them and in the doom they will abide.\qt@no{80}}%
\qt@newcmd\qurantrans@en@dccl{%
If they believed in Allah and the Prophet and that which is revealed unto him, they would not choose them for their friends. But many of them are of evil conduct.\qt@no{81}}%
\qt@newcmd\qurantrans@en@dccli{%
Thou wilt find the most vehement of mankind in hostility to those who believe (to be) the Jews and the idolaters. And thou wilt find the nearest of them in affection to those who believe (to be) those who say: Lo! We are Christians. That is because there are among them priests and monks, and because they are not proud.\qt@no{82}}%
\qt@newcmd\qurantrans@en@dcclii{%
When they listen to that which hath been revealed unto the messengers, thou seest their eyes overflow with tears because of their recognition of the Truth. They say: Our Lord, we believe. Inscribe us as among the witnesses.\qt@no{83}}%
\qt@newcmd\qurantrans@en@dccliii{%
How should we not believe in Allah and that which hath come unto us of the Truth. And (how should we not) hope that our Lord will bring us in along with righteous folk?\qt@no{84}}%
\qt@newcmd\qurantrans@en@dccliv{%
Allah hath rewarded them for that their saying - Gardens underneath which rivers flow, wherein they will abide for ever. That is the reward of the good.\qt@no{85}}%
\qt@newcmd\qurantrans@en@dcclv{%
But those who disbelieve and deny Our revelations, they are owners of hell-fire.\qt@no{86}}%
\qt@newcmd\qurantrans@en@dcclvi{%
O ye who believe! Forbid not the good things which Allah hath made lawful for you, and transgress not, Lo! Allah loveth not transgressors.\qt@no{87}}%
\qt@newcmd\qurantrans@en@dcclvii{%
Eat of that which Allah hath bestowed on you as food lawful and good, and keep your duty to Allah in Whom ye are believers.\qt@no{88}}%
\qt@newcmd\qurantrans@en@dcclviii{%
Allah will not take you to task for that which is unintentional in your oaths, but He will take you to task for the oaths which ye swear in earnest. The expiation thereof is the feeding of ten of the needy with the average of that wherewith ye feed your own folk, or the clothing of them, or the liberation of a slave, and for him who findeth not (the wherewithal to do so) then a three days' fast. This is the expiation of your oaths when ye have sworn; and keep your oaths. Thus Allah expoundeth unto you His revelations in order that ye may give thanks.\qt@no{89}}%
\qt@newcmd\qurantrans@en@dcclix{%
O ye who believe! Strong drink and games of chance and idols and divining arrows are only an infamy of Satan's handiwork. Leave it aside in order that ye may succeed.\qt@no{90}}%
\qt@newcmd\qurantrans@en@dcclx{%
Satan seeketh only to cast among you enmity and hatred by means of strong drink and games of chance, and to turn you from remembrance of Allah and from (His) worship. Will ye then have done?\qt@no{91}}%
\qt@newcmd\qurantrans@en@dcclxi{%
Obey Allah and obey the messenger, and beware! But if ye turn away, then know that the duty of Our messenger is only plain conveyance (of the message).\qt@no{92}}%
\qt@newcmd\qurantrans@en@dcclxii{%
There shall be no sin (imputed) unto those who believe and do good works for what they may have eaten (in the past). So be mindful of your duty (to Allah), and believe, and do good works; and again: be mindful of your duty, and believe; and once again: be mindful of your duty, and do right. Allah loveth the good.\qt@no{93}}%
\qt@newcmd\qurantrans@en@dcclxiii{%
O ye who believe! Allah will surely try you somewhat (in the matter) of the game which ye take with your hands and your spears, that Allah may know him who feareth Him in secret. Whoso transgresseth after this, for him there is a painful doom.\qt@no{94}}%
\qt@newcmd\qurantrans@en@dcclxiv{%
O ye who believe! Kill no wild game while ye are on the pilgrimage. Whoso of you killeth it of set purpose he shall pay its forfeit in the equivalent of that which he hath killed, of domestic animals, the judge to be two men among you known for justice, (the forfeit) to be brought as an offering to the Ka'bah; or, for expiation, he shall feed poor persons, or the equivalent thereof in fasting, that he may taste the evil consequences of his deed. Allah forgiveth whatever (of this kind) may have happened in the past, but whoso relapseth, Allah will take retribution from him. Allah is Mighty, Able to Requite (the wrong).\qt@no{95}}%
\qt@newcmd\qurantrans@en@dcclxv{%
To hunt and to eat the fish of the sea is made lawful for you, a provision for you and for seafarers; but to hunt on land is forbidden you so long as ye are on the pilgrimage. Be mindful of your duty to Allah, unto Whom ye will be gathered.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dcclxvi{%
Allah hath appointed the Ka'bah, the Sacred House, a standard for mankind, and the Sacred Month and the offerings and the garlands. That is so that ye may know that Allah knoweth whatsoever is in the heavens and whatsoever is in the earth, and that Allah is Knower of all things.\qt@no{97}}%
\qt@newcmd\qurantrans@en@dcclxvii{%
Know that Allah is severe in punishment, but that Allah (also) is Forgiving, Merciful.\qt@no{98}}%
\qt@newcmd\qurantrans@en@dcclxviii{%
The duty of the messenger is only to convey (the message). Allah knoweth what ye proclaim and what ye hide.\qt@no{99}}%
\qt@newcmd\qurantrans@en@dcclxix{%
Say: The evil and the good are not alike even though the plenty of the evil attract thee. So be mindful of your duty to Allah, O men of understanding, that ye may succeed.\qt@no{100}}%
\qt@newcmd\qurantrans@en@dcclxx{%
O ye who believe! Ask not of things which, if they were made unto you, would trouble you; but if ye ask of them when the Qur'an is being revealed, they will be made known unto you. Allah pardoneth this, for Allah is Forgiving, Clement.\qt@no{101}}%
\qt@newcmd\qurantrans@en@dcclxxi{%
A folk before you asked (for such disclosures) and then disbelieved therein.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dcclxxii{%
Allah hath not appointed anything in the nature of a Bahirah or a Sa'ibah or a Wasilah or a Hami, but those who disbelieve invent a lie against Allah. Most of them have no sense.\qt@no{103}}%
\qt@newcmd\qurantrans@en@dcclxxiii{%
And when it is said unto them: Come unto that which Allah hath revealed and unto the messenger, they say: Enough for us is that wherein we found our fathers. What! Even though their fathers had no knowledge whatsoever, and no guidance?\qt@no{104}}%
\qt@newcmd\qurantrans@en@dcclxxiv{%
O ye who believe! Ye have charge of your own souls. He who erreth cannot injure you if ye are rightly guided. Unto Allah ye will all return; and then He will inform you of what ye used to do.\qt@no{105}}%
\qt@newcmd\qurantrans@en@dcclxxv{%
O ye who believe! Let there be witnesses between you when death draweth nigh unto one of you, at the time of bequest - two witnesses, just men from among you, or two others from another tribe, in case ye are campaigning in the land and the calamity of death befall you. Ye shall empanel them both after the prayer, and, if ye doubt, they shall be made to swear by Allah (saying): We will not take a bribe, even though it were (on behalf of) a near kinsman nor will we hide the testimony of Allah, for then indeed we should be of the sinful.\qt@no{106}}%
\qt@newcmd\qurantrans@en@dcclxxvi{%
But then, if it is afterwards ascertained that both of them merit (the suspicion of) sin, let two others take their place of those nearly concerned, and let them swear by Allah, (saying): Verily our testimony is truer than their testimony and we have not transgressed (the bounds of duty), for them indeed we should be of the evil-doers.\qt@no{107}}%
\qt@newcmd\qurantrans@en@dcclxxvii{%
Thus it is more likely that they will bear true witness or fear that after their oaths the oaths (of others) will be taken. So be mindful of your duty (to Allah) and hearken. Allah guideth not the froward folk.\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcclxxviii{%
In the day when Allah gathereth together the messengers, and saith: What was your response (from mankind)? they say: We have no knowledge. Lo! Thou, only Thou art the Knower of Things Hidden,\qt@no{109}}%
\qt@newcmd\qurantrans@en@dcclxxix{%
When Allah saith: O Jesus, son of Mary! Remember My favour unto thee and unto thy mother; how I strengthened thee with the holy Spirit, so that thou spakest unto mankind in the cradle as in maturity; and how I taught thee the Scripture and Wisdom and the Torah and the Gospel; and how thou didst shape of clay as it were the likeness of a bird by My permission, and didst blow upon it and it was a bird by My permission, and thou didst heal him who was born blind and the leper by My permission; and how thou didst raise the dead by My permission; and how I restrained the Children of Israel from (harming) thee when thou camest unto them with clear proofs, and those of them who disbelieved exclaimed: This is naught else than mere magic;\qt@no{110}}%
\qt@newcmd\qurantrans@en@dcclxxx{%
And when I inspired the disciples, (saying): Believe in Me and in My messenger, they said: We believe. Bear witness that we have surrendered (unto Thee) ``we are muslims".\qt@no{111}}%
\qt@newcmd\qurantrans@en@dcclxxxi{%
When the disciples said: O Jesus, son of Mary! Is thy Lord able to send down for us a table spread with food from heaven? He said: Observe your duty to Allah, if ye are true believers.\qt@no{112}}%
\qt@newcmd\qurantrans@en@dcclxxxii{%
(They said:) We wish to eat thereof, that we may satisfy our hearts and know that thou hast spoken truth to us, and that thereof we may be witnesses.\qt@no{113}}%
\qt@newcmd\qurantrans@en@dcclxxxiii{%
Jesus, son of Mary, said: O Allah, Lord of us! Send down for us a table spread with food from heaven, that it may be a feast for us, for the first of us and for the last of us, and a sign from Thee. Give us sustenance, for Thou art the Best of Sustainers.\qt@no{114}}%
\qt@newcmd\qurantrans@en@dcclxxxiv{%
Allah said: Lo! I send it down for you. And whoso disbelieveth of you afterward, him surely will I punish with a punishment wherewith I have not punished any of (My) creatures.\qt@no{115}}%
\qt@newcmd\qurantrans@en@dcclxxxv{%
And when Allah saith: O Jesus, son of Mary! Didst thou say unto mankind: Take me and my mother for two gods beside Allah? he saith: Be glorified! It was not mine to utter that to which I had no right. If I used to say it, then Thou knewest it. Thou knowest what is in my mind, and I know not what is in Thy Mind. Lo! Thou, only Thou, art the Knower of Things Hidden?\qt@no{116}}%
\qt@newcmd\qurantrans@en@dcclxxxvi{%
I spake unto them only that which Thou commandedst me, (saying): Worship Allah, my Lord and your Lord. I was a witness of them while I dwelt among them, and when Thou tookest me Thou wast the Watcher over them. Thou art Witness over all things.\qt@no{117}}%
\qt@newcmd\qurantrans@en@dcclxxxvii{%
If Thou punish them, lo! they are Thy slaves, and if Thou forgive them (lo! they are Thy slaves). Lo! Thou, only Thou, art the Mighty, the Wise.\qt@no{118}}%
\qt@newcmd\qurantrans@en@dcclxxxviii{%
Allah saith: This is a day in which their truthfulness profiteth the truthful, for theirs are Gardens underneath which rivers flow, wherein they are secure for ever, Allah taking pleasure in them and they in Him. That is the great triumph.\qt@no{119}}%
\qt@newcmd\qurantrans@en@dcclxxxix{%
Unto Allah belongeth the Sovereignty of the heavens and the earth and whatsoever is therein, and He is Able to do all things.\qt@no{120}}%
\qt@newcmd\qurantrans@en@dccxc{%
\basmalahen Praise be to Allah, Who hath created the heavens and the earth, and hath appointed darkness and light. Yet those who disbelieve ascribe rivals unto their Lord.\qt@no{1}}%
\qt@newcmd\qurantrans@en@dccxci{%
He it is Who hath created you from clay, and hath decreed a term for you. A term is fixed with Him. Yet still ye doubt!\qt@no{2}}%
\qt@newcmd\qurantrans@en@dccxcii{%
He is Allah in the heavens and in the earth. He knoweth both your secret and your utterance, and He knoweth what ye earn.\qt@no{3}}%
\qt@newcmd\qurantrans@en@dccxciii{%
Never came there unto them a revelation of the revelations of Allah but they did turn away from it.\qt@no{4}}%
\qt@newcmd\qurantrans@en@dccxciv{%
And they denied the truth when it came unto them. But there will come unto them the tidings of that which they used to deride.\qt@no{5}}%
\qt@newcmd\qurantrans@en@dccxcv{%
See they not how many a generation We destroyed before them, whom We had established in the earth more firmly than We have established you, and We shed on them abundant showers from the sky, and made the rivers flow beneath them. Yet we destroyed them for their sins, and created after them another generation.\qt@no{6}}%
\qt@newcmd\qurantrans@en@dccxcvi{%
Had we sent down unto thee (Muhammad) (actual) writing upon parchment, so that they could feel it with their hands, those who disbelieve would have said: This is naught else than mere magic.\qt@no{7}}%
\qt@newcmd\qurantrans@en@dccxcvii{%
They say: Why hath not an angel been sent down unto him? If We sent down an angel, then the matter would be judged; no further time would be allowed them (for reflection).\qt@no{8}}%
\qt@newcmd\qurantrans@en@dccxcviii{%
Had we appointed him (Our messenger) an angel, We assuredly had made him (as) a man (that he might speak to men); and (thus) obscured for them (the truth) they (now) obscure.\qt@no{9}}%
\qt@newcmd\qurantrans@en@dccxcix{%
Messengers (of Allah) have been derided before thee, but that whereat they scoffed surrounded such of them as did deride.\qt@no{10}}%
\qt@newcmd\qurantrans@en@dccc{%
Say (unto the disbelievers): Travel in the land, and see the nature of the consequence for the rejecters!\qt@no{11}}%
\qt@newcmd\qurantrans@en@dccci{%
Say: Unto whom belongeth whatsoever is in the heavens and the earth? Say: Unto Allah. He hath prescribed for Himself mercy, that He may bring you all together to the Day of Resurrection whereof there is no doubt. Those who ruin their souls will not believe.\qt@no{12}}%
\qt@newcmd\qurantrans@en@dcccii{%
Unto Him belongeth whatsoever resteth in the night and the day. He is the Hearer, the Knower.\qt@no{13}}%
\qt@newcmd\qurantrans@en@dccciii{%
Say: Shall I choose for a protecting friend other than Allah, the Originator of the heavens and the earth, Who feedeth and is never fed? Say: I am ordered to be the first to surrender (unto Him). And be not thou (O Muhammad) of the idolaters.\qt@no{14}}%
\qt@newcmd\qurantrans@en@dccciv{%
Say: I fear, if I rebel against my Lord, the retribution of an Awful Day.\qt@no{15}}%
\qt@newcmd\qurantrans@en@dcccv{%
He from whom (such retribution) is averted on that day, (Allah) hath in truth had mercy on him. That will be the signal triumph.\qt@no{16}}%
\qt@newcmd\qurantrans@en@dcccvi{%
If Allah touch thee with affliction, there is none that can relieve therefrom save Him, and if He touch thee with good fortune (there is none that can impair it); for He is Able to do all things.\qt@no{17}}%
\qt@newcmd\qurantrans@en@dcccvii{%
He is the Omnipotent over His slaves, and He is the Wise, the Knower.\qt@no{18}}%
\qt@newcmd\qurantrans@en@dcccviii{%
Say (O Muhammad): What thing is of most weight in testimony? Say: Allah is Witness between me and you. And this Qur'an hath been inspired in me, that I may warn therewith you and whomsoever it may reach. Do ye in sooth bear witness that there are gods beside Allah? Say: I bear no such witness. Say: He is only One Allah. Lo! I am innocent of that which ye associate (with Him).\qt@no{19}}%
\qt@newcmd\qurantrans@en@dcccix{%
Those unto whom We gave the Scripture recognise (this revelation) as they recognise their sons. Those who ruin their own souls will not believe.\qt@no{20}}%
\qt@newcmd\qurantrans@en@dcccx{%
Who doth greater wrong than he who inventeth a lie against Allah or denieth His revelations? Lo! the wrongdoers will not be successful.\qt@no{21}}%
\qt@newcmd\qurantrans@en@dcccxi{%
And on the day We gather them together We shall say unto those who ascribed partners (unto Allah): Where are (now) those partners of your make-believe?\qt@no{22}}%
\qt@newcmd\qurantrans@en@dcccxii{%
Then will they have no contention save that they will say: By Allah, our Lord, we never were idolaters.\qt@no{23}}%
\qt@newcmd\qurantrans@en@dcccxiii{%
See how they lie against themselves, and (how) the thing which they devised hath failed them!\qt@no{24}}%
\qt@newcmd\qurantrans@en@dcccxiv{%
Of them are some who listen unto thee, but We have placed upon their hearts veils, lest they should understand, and in their ears a deafness. If they saw every token they would not believe therein; to the point that, when they come unto thee to argue with thee, the disbelievers say: This is naught else than fables of the men of old.\qt@no{25}}%
\qt@newcmd\qurantrans@en@dcccxv{%
And they forbid (men) from it and avoid it, and they ruin none save themselves, though they perceive not.\qt@no{26}}%
\qt@newcmd\qurantrans@en@dcccxvi{%
If thou couldst see when they are set before the Fire and say: Oh, would that we might return! Then would we not deny the revelations of our Lord but we would be of the believers!\qt@no{27}}%
\qt@newcmd\qurantrans@en@dcccxvii{%
Nay, but that hath become clear unto them which before they used to hide. And if they were sent back they would return unto that which they are forbidden. Lo! they are liars.\qt@no{28}}%
\qt@newcmd\qurantrans@en@dcccxviii{%
And they say: There is naught save our life of the world, and we shall not be raised (again).\qt@no{29}}%
\qt@newcmd\qurantrans@en@dcccxix{%
If thou couldst see when they are set before their Lord! He will say: Is not this real? They will say: Yea, verily, by our Lord! He will say: Taste now the retribution for that ye used to disbelieve.\qt@no{30}}%
\qt@newcmd\qurantrans@en@dcccxx{%
They indeed are losers who deny their meeting with Allah until, when the Hour cometh on them suddenly, they cry: Alas for us, that we neglected it! They bear upon their backs their burdens. Ah, evil is that which they bear!\qt@no{31}}%
\qt@newcmd\qurantrans@en@dcccxxi{%
Naught is the life of the world save a pastime and a sport. Better far is the abode of the Hereafter for those who keep their duty (to Allah). Have ye then no sense?\qt@no{32}}%
\qt@newcmd\qurantrans@en@dcccxxii{%
We know well how their talk grieveth thee, though in truth they deny not thee (Muhammad) but evil-doers flout the revelations of Allah.\qt@no{33}}%
\qt@newcmd\qurantrans@en@dcccxxiii{%
Messengers indeed have been denied before thee, and they were patient under the denial and the persecution till Our succour reached them. There is none to alter the decisions of Allah. Already there hath reached thee (somewhat) of the tidings of the messengers (We sent before).\qt@no{34}}%
\qt@newcmd\qurantrans@en@dcccxxiv{%
And if their aversion is grievous unto thee, then, if thou canst, seek a way down into the earth or a ladder unto the sky that thou mayst bring unto them a portent (to convince them all)! - If Allah willed, He could have brought them all together to the guidance - So be not thou among the foolish ones.\qt@no{35}}%
\qt@newcmd\qurantrans@en@dcccxxv{%
Only those can accept who hear. As for the dead, Allah will raise them up; then unto Him they will be returned.\qt@no{36}}%
\qt@newcmd\qurantrans@en@dcccxxvi{%
They say: Why hath no portent been sent down upon him from his Lord? Say: Lo! Allah is Able to send down a portent. But most of them know not.\qt@no{37}}%
\qt@newcmd\qurantrans@en@dcccxxvii{%
There is not an animal in the earth, nor a flying creature flying on two wings, but they are peoples like unto you. We have neglected nothing in the Book (of Our decrees). Then unto their Lord they will be gathered.\qt@no{38}}%
\qt@newcmd\qurantrans@en@dcccxxviii{%
Those who deny Our revelations are deaf and dumb in darkness. Whom Allah will sendeth astray, and whom He will He placeth on a straight path.\qt@no{39}}%
\qt@newcmd\qurantrans@en@dcccxxix{%
Say: Can ye see yourselves, if the punishment of Allah come upon you or the Hour come upon you, (calling upon other than Allah)? Do ye then call (for help) to any other than Allah? (Answer that) if ye are truthful.\qt@no{40}}%
\qt@newcmd\qurantrans@en@dcccxxx{%
Nay, but unto Him ye call, and He removeth that because of which ye call unto Him, if He will, and ye forget whatever partners ye ascribed unto Him.\qt@no{41}}%
\qt@newcmd\qurantrans@en@dcccxxxi{%
We have sent already unto peoples that were before thee, and We visited them with tribulation and adversity, in order that they might grow humble.\qt@no{42}}%
\qt@newcmd\qurantrans@en@dcccxxxii{%
If only, when Our disaster came on them, they had been humble! But their hearts were hardened and the devil made all that they used to do seem fair unto them!\qt@no{43}}%
\qt@newcmd\qurantrans@en@dcccxxxiii{%
Then, when they forgot that whereof they had been reminded, We opened unto them the gates of all things till, even as they were rejoicing in that which they were given, We seized them unawares, and lo! they were dumbfounded.\qt@no{44}}%
\qt@newcmd\qurantrans@en@dcccxxxiv{%
So of the people who did wrong the last remnant was cut off. Praise be to Allah, Lord of the Worlds!\qt@no{45}}%
\qt@newcmd\qurantrans@en@dcccxxxv{%
Say: Have ye imagined, if Allah should take away your hearing and your sight and seal your hearts, Who is the Allah Who could restore it to you save Allah? See how We display the revelations unto them! Yet still they turn away.\qt@no{46}}%
\qt@newcmd\qurantrans@en@dcccxxxvi{%
Say: Can ye see yourselves, if the punishment of Allah come upon you unawares or openly? Would any perish save wrongdoing folk?\qt@no{47}}%
\qt@newcmd\qurantrans@en@dcccxxxvii{%
We send not the messengers save as bearers of good news and warners. Whoso believeth and doeth right, there shall no fear come upon them neither shall they grieve.\qt@no{48}}%
\qt@newcmd\qurantrans@en@dcccxxxviii{%
But as for those who deny Our revelations, torment will afflict them for that they used to disobey.\qt@no{49}}%
\qt@newcmd\qurantrans@en@dcccxxxix{%
Say (O Muhammad, to the disbelievers): I say not unto you (that) I possess the treasures of Allah, nor that I have knowledge of the Unseen; and I say not unto you: Lo! I am an angel. I follow only that which is inspired in me. Say: Are the blind man and the seer equal? Will ye not then take thought?\qt@no{50}}%
\qt@newcmd\qurantrans@en@dcccxl{%
Warn hereby those who fear (because they know) that they will be gathered unto their Lord, for whom there is no protecting ally nor intercessor beside Him, that they may ward off (evil).\qt@no{51}}%
\qt@newcmd\qurantrans@en@dcccxli{%
Repel not those who call upon their Lord at morn and evening, seeking His Countenance. Thou art not accountable for them in aught, nor are they accountable for thee in aught, that thou shouldst repel them and be of the wrong-doers.\qt@no{52}}%
\qt@newcmd\qurantrans@en@dcccxlii{%
And even so do We try some of them by others, that they say: Are these they whom Allah favoureth among us? Is not Allah best Aware of the thanksgivers?\qt@no{53}}%
\qt@newcmd\qurantrans@en@dcccxliii{%
And when those who believe in Our revelations come unto thee, say: Peace be unto you! Your Lord hath prescribed for Himself mercy, that whoso of you doeth evil through ignorance and repenteth afterward thereof and doeth right, (for him) lo! He is Forgiving, Merciful.\qt@no{54}}%
\qt@newcmd\qurantrans@en@dcccxliv{%
Thus do We expound the revelations that the way of the unrighteous may be manifest.\qt@no{55}}%
\qt@newcmd\qurantrans@en@dcccxlv{%
Say: I am forbidden to worship those on whom ye call instead of Allah. Say: I will not follow your desires, for then should I go astray and I should not be of the rightly guided.\qt@no{56}}%
\qt@newcmd\qurantrans@en@dcccxlvi{%
Say: I am (relying) on clear proof from my Lord, while ye deny Him. I have not that for which ye are impatient. The decision is for Allah only. He telleth the truth and He is the Best of Deciders.\qt@no{57}}%
\qt@newcmd\qurantrans@en@dcccxlvii{%
Say: If I had that for which ye are impatient, then would the case (ere this) have been decided between me and you. Allah is Best Aware of the wrong-doers.\qt@no{58}}%
\qt@newcmd\qurantrans@en@dcccxlviii{%
And with Him are the keys of the Invisible. None but He knoweth them. And He knoweth what is in the land and the sea. Not a leaf falleth but He knoweth it, not a grain amid the darkness of the earth, naught of wet or dry but (it is noted) in a clear record.\qt@no{59}}%
\qt@newcmd\qurantrans@en@dcccxlix{%
He it is Who gathereth you at night and knoweth that which ye commit by day. Then He raiseth you again to life therein, that the term appointed (for you) may be accomplished. And afterward unto Him is your return. Then He will proclaim unto you what ye used to do.\qt@no{60}}%
\qt@newcmd\qurantrans@en@dcccl{%
He is the Omnipotent over His slaves. He sendeth guardians over you until, when death cometh unto one of you, Our messengers receive him, and they neglect not.\qt@no{61}}%
\qt@newcmd\qurantrans@en@dcccli{%
Then are they restored unto Allah, their Lord, the Just. Surely His is the judgment. And He is the most swift of reckoners.\qt@no{62}}%
\qt@newcmd\qurantrans@en@dccclii{%
Say: Who delivereth you from the darkness of the land and the sea? Ye call upon Him humbly and in secret, (saying): If we are delivered from this (fear) we truly will be of the thankful.\qt@no{63}}%
\qt@newcmd\qurantrans@en@dcccliii{%
Say: Allah delivereth you from this and from all affliction. Yet ye attribute partners unto Him.\qt@no{64}}%
\qt@newcmd\qurantrans@en@dcccliv{%
Say: He is able to send punishment upon you from above you or from beneath your feet, or to bewilder you with dissension and make you taste the tyranny one of another. See how We display the revelations so that they may understand.\qt@no{65}}%
\qt@newcmd\qurantrans@en@dccclv{%
Thy people (O Muhammad) have denied it, though it is the Truth. Say: I am not put in charge of you.\qt@no{66}}%
\qt@newcmd\qurantrans@en@dccclvi{%
For every announcement there is a term, and ye will come to know.\qt@no{67}}%
\qt@newcmd\qurantrans@en@dccclvii{%
And when thou seest those who meddle with Our revelations, withdraw from them until they meddle with another topic. And if the devil cause thee to forget, sit not, after the remembrance, with the congregation of wrong-doers.\qt@no{68}}%
\qt@newcmd\qurantrans@en@dccclviii{%
Those who ward off (evil) are not accountable for them in aught, but the Reminder (must be given them) that haply they (too) may ward off (evil).\qt@no{69}}%
\qt@newcmd\qurantrans@en@dccclix{%
And forsake those who take their religion for a pastime and a jest, and whom the life of the world beguileth. Remind (mankind) hereby lest a soul be destroyed by what it earneth. It hath beside Allah no protecting ally nor intercessor, and though it offer every compensation it will not be accepted from it. Those are they who perish by their own deserts. For them is drink of boiling water and a painful doom, because they disbelieved.\qt@no{70}}%
\qt@newcmd\qurantrans@en@dccclx{%
Say: Shall we cry, instead of unto Allah, unto that which neither profiteth us nor hurteth us, and shall we turn back after Allah hath guided us, like one bewildered whom the devils have infatuated in the earth, who hath companions who invite him to the guidance (saying): Come unto us? Say: Lo! the guidance of Allah is Guidance, and we are ordered to surrender to the Lord of the Worlds,\qt@no{71}}%
\qt@newcmd\qurantrans@en@dccclxi{%
And to establish worship and be dutiful to Him, and He it is unto Whom ye will be gathered.\qt@no{72}}%
\qt@newcmd\qurantrans@en@dccclxii{%
He it is Who created the heavens and the earth in truth. In the day when He saith: Be! it is. His Word is the Truth, and His will be the Sovereignty on the day when the trumpet is blown. Knower of the Invisible and the Visible, He is the Wise, the Aware.\qt@no{73}}%
\qt@newcmd\qurantrans@en@dccclxiii{%
(Remember) when Abraham said unto his father Azar: Takest thou idols for gods? Lo! I see thee and thy folk in error manifest.\qt@no{74}}%
\qt@newcmd\qurantrans@en@dccclxiv{%
Thus did We show Abraham the kingdom of the heavens and the earth that he might be of those possessing certainty:\qt@no{75}}%
\qt@newcmd\qurantrans@en@dccclxv{%
When the night grew dark upon him he beheld a star. He said: This is my Lord. But when it set, he said: I love not things that set.\qt@no{76}}%
\qt@newcmd\qurantrans@en@dccclxvi{%
And when he saw the moon uprising, he exclaimed: This is my Lord. But when it set, he said: Unless my Lord guide me, I surely shall become one of the folk who are astray.\qt@no{77}}%
\qt@newcmd\qurantrans@en@dccclxvii{%
And when he saw the sun uprising, he cried: This is my Lord! This is greater! And when it set he exclaimed: O my people! Lo! I am free from all that ye associate (with Him).\qt@no{78}}%
\qt@newcmd\qurantrans@en@dccclxviii{%
Lo! I have turned my face toward Him Who created the heavens and the earth, as one by nature upright, and I am not of the idolaters.\qt@no{79}}%
\qt@newcmd\qurantrans@en@dccclxix{%
His people argued with him. He said: Dispute ye with me concerning Allah when He hath guided me? I fear not at all that which ye set up beside Him unless my Lord willeth aught. My Lord includeth all things in His knowledge. Will ye not then remember?\qt@no{80}}%
\qt@newcmd\qurantrans@en@dccclxx{%
How should I fear that which ye set up beside Him, when ye fear not to set up beside Allah that for which He hath revealed unto you no warrant? Which of the two factions hath more right to safety? (Answer me that) if ye have knowledge.\qt@no{81}}%
\qt@newcmd\qurantrans@en@dccclxxi{%
Those who believe and obscure not their belief by wrongdoing, theirs is safety; and they are rightly guided.\qt@no{82}}%
\qt@newcmd\qurantrans@en@dccclxxii{%
That is Our argument. We gave it unto Abraham against his folk. We raise unto degrees of wisdom whom We will. Lo! thy Lord is Wise, Aware.\qt@no{83}}%
\qt@newcmd\qurantrans@en@dccclxxiii{%
And We bestowed upon him Isaac and Jacob; each of them We guided; and Noah did We guide aforetime; and of his seed (We guided) David and Solomon and Job and Joseph and Moses and Aaron. Thus do We reward the good.\qt@no{84}}%
\qt@newcmd\qurantrans@en@dccclxxiv{%
And Zachariah and John and Jesus and Elias. Each one (of them) was of the righteous.\qt@no{85}}%
\qt@newcmd\qurantrans@en@dccclxxv{%
And Ishmael and Elisha and Jonah and Lot. Each one (of them) did We prefer above (Our) creatures,\qt@no{86}}%
\qt@newcmd\qurantrans@en@dccclxxvi{%
With some of their forefathers and their offspring and their brethren; and We chose them and guided them unto a straight path.\qt@no{87}}%
\qt@newcmd\qurantrans@en@dccclxxvii{%
Such is the guidance of Allah wherewith He guideth whom He will of His bondmen. But if they had set up (for worship) aught beside Him, (all) that they did would have been vain.\qt@no{88}}%
\qt@newcmd\qurantrans@en@dccclxxviii{%
Those are they unto whom We gave the Scripture and command and prophethood. But if these disbelieve therein, then indeed We shall entrust it to a people who will not be disbelievers therein.\qt@no{89}}%
\qt@newcmd\qurantrans@en@dccclxxix{%
Those are they whom Allah guideth, so follow their guidance. Say (O Muhammad, unto mankind): I ask of you no fee for it. Lo! it is naught but a Reminder to (His) creatures.\qt@no{90}}%
\qt@newcmd\qurantrans@en@dccclxxx{%
And they measure not the power of Allah its true measure when they say: Allah hath naught revealed unto a human being. Say (unto the Jews who speak thus): Who revealed the Book which Moses brought, a light and guidance for mankind, which ye have put on parchments which ye show, but ye hide much (thereof), and (by which) ye were taught that which ye knew not yourselves nor (did) your fathers (know it)? Say: Allah. Then leave them to their play of cavilling.\qt@no{91}}%
\qt@newcmd\qurantrans@en@dccclxxxi{%
And this is a blessed Scripture which We have revealed, confirming that which (was revealed) before it, that thou mayst warn the Mother of Villages and those around her. Those who believe in the Hereafter believe herein, and they are careful of their worship.\qt@no{92}}%
\qt@newcmd\qurantrans@en@dccclxxxii{%
Who is guilty of more wrong than he who forgeth a lie against Allah, or saith: I am inspired, when he is not inspired in aught; and who saith: I will reveal the like of that which Allah hath revealed? If thou couldst see, when the wrong-doers reach the pangs of death and the angels stretch their hands out (saying): Deliver up your souls. This day ye are awarded doom of degradation for that ye spake concerning Allah other than the truth, and used to scorn His portents.\qt@no{93}}%
\qt@newcmd\qurantrans@en@dccclxxxiii{%
Now have ye come unto Us solitary as We did create you at the first, and ye have left behind you all that We bestowed upon you, and We behold not with you those your intercessors, of whom ye claimed that they possessed a share in you. Now is the bond between you severed, and that which ye presumed hath failed you.\qt@no{94}}%
\qt@newcmd\qurantrans@en@dccclxxxiv{%
Lo! Allah (it is) Who splitteth the grain of corn and the date-stone (for sprouting). He bringeth forth the living from the dead, and is the bringer-forth of the dead from the living. Such is Allah. How then are ye perverted?\qt@no{95}}%
\qt@newcmd\qurantrans@en@dccclxxxv{%
He is the Cleaver of the Daybreak, and He hath appointed the night for stillness, and the sun and the moon for reckoning. That is the measuring of the Mighty, the Wise.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dccclxxxvi{%
And He it is Who hath set for you the stars that ye may guide your course by them amid the darkness of the land and the sea. We have detailed Our revelations for a people who have knowledge.\qt@no{97}}%
\qt@newcmd\qurantrans@en@dccclxxxvii{%
And He it is Who hath produced you from a single being, and (hath given you) a habitation and a repository. We have detailed Our revelations for a people who have understanding.\qt@no{98}}%
\qt@newcmd\qurantrans@en@dccclxxxviii{%
He it is Who sendeth down water from the sky, and therewith We bring forth buds of every kind; We bring forth the green blade from which We bring forth the thick-clustered grain; and from the date-palm, from the pollen thereof, spring pendant bunches; and (We bring forth) gardens of grapes, and the olive and the pomegranate, alike and unlike. Look upon the fruit thereof, when they bear fruit, and upon its ripening. Lo! herein verily are portents for a people who believe.\qt@no{99}}%
\qt@newcmd\qurantrans@en@dccclxxxix{%
Yet they ascribe as partners unto Him the jinn, although He did create them, and impute falsely, without knowledge, sons and daughters unto Him. Glorified be He and High Exalted above (all) that they ascribe (unto Him).\qt@no{100}}%
\qt@newcmd\qurantrans@en@dcccxc{%
The Originator of the heavens and the earth! How can He have a child, when there is for Him no consort, when He created all things and is Aware of all things?\qt@no{101}}%
\qt@newcmd\qurantrans@en@dcccxci{%
Such is Allah, your Lord. There is no Allah save Him, the Creator of all things, so worship Him. And He taketh care of all things.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dcccxcii{%
Vision comprehendeth Him not, but He comprehendeth (all) vision. He is the Subtile, the Aware.\qt@no{103}}%
\qt@newcmd\qurantrans@en@dcccxciii{%
Proofs have come unto you from your Lord, so whoso seeth, it is for his own good, and whoso is blind is blind to his own hurt. And I am not a keeper over you.\qt@no{104}}%
\qt@newcmd\qurantrans@en@dcccxciv{%
Thus do We display Our revelations that they may say (unto thee, Muhammad): ``Thou hast studied," and that We may make (it) clear for people who have knowledge.\qt@no{105}}%
\qt@newcmd\qurantrans@en@dcccxcv{%
Follow that which is inspired in thee from thy Lord; there is no Allah save Him; and turn away from the idolaters.\qt@no{106}}%
\qt@newcmd\qurantrans@en@dcccxcvi{%
Had Allah willed, they had not been idolatrous. We have not set thee as a keeper over them, nor art thou responsible for them.\qt@no{107}}%
\qt@newcmd\qurantrans@en@dcccxcvii{%
Revile not those unto whom they pray beside Allah lest they wrongfully revile Allah through ignorance. Thus unto every nation have We made their deed seem fair. Then unto their Lord is their return, and He will tell them what they used to do.\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcccxcviii{%
And they swear a solemn oath by Allah that if there come unto them a portent they will believe therein. Say; Portents are with Allah and (so is) that which telleth you that if such came unto them they would not believe.\qt@no{109}}%
\qt@newcmd\qurantrans@en@dcccxcix{%
We confound their hearts and their eyes. As they believed not therein at the first, We let them wander blindly on in their contumacy.\qt@no{110}}%
\qt@newcmd\qurantrans@en@cm{%
And though We should send down the angels unto them, and the dead should speak unto them, and We should gather against them all things in array, they would not believe unless Allah so willed. Howbeit, most of them are ignorant.\qt@no{111}}%
\qt@newcmd\qurantrans@en@cmi{%
Thus have We appointed unto every prophet an adversary - devils of humankind and jinn who inspire in one another plausible discourse through guile. If thy Lord willed, they would not do so; so leave them alone with their devising;\qt@no{112}}%
\qt@newcmd\qurantrans@en@cmii{%
That the hearts of those who believe not in the Hereafter may incline thereto, and that they may take pleasure therein, and that they may earn what they are earning.\qt@no{113}}%
\qt@newcmd\qurantrans@en@cmiii{%
Shall I seek other than Allah for judge, when He it is Who hath revealed unto you (this) Scripture, fully explained? Those unto whom We gave the Scripture (aforetime) know that it is revealed from thy Lord in truth. So be not thou (O Muhammad) of the waverers.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cmiv{%
Perfected is the Word of thy Lord in truth and justice. There is naught that can change His words. He is the Hearer, the Knower.\qt@no{115}}%
\qt@newcmd\qurantrans@en@cmv{%
If thou obeyedst most of those on earth they would mislead thee far from Allah's way. They follow naught but an opinion, and they do but guess.\qt@no{116}}%
\qt@newcmd\qurantrans@en@cmvi{%
Lo! thy Lord, He knoweth best who erreth from His way; and He knoweth best (who are) the rightly guided.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cmvii{%
Eat of that over which the name of Allah hath been mentioned, if ye are believers in His revelations.\qt@no{118}}%
\qt@newcmd\qurantrans@en@cmviii{%
How should ye not eat of that over which the name of Allah hath been mentioned, when He hath explained unto you that which is forbidden unto you unless ye are compelled thereto. But lo! many are led astray by their own lusts through ignorance. Lo! thy Lord, He is Best Aware of the transgressors.\qt@no{119}}%
\qt@newcmd\qurantrans@en@cmix{%
Forsake the outwardness of sin and the inwardness thereof. Lo! those who garner sin will be awarded that which they have earned.\qt@no{120}}%
\qt@newcmd\qurantrans@en@cmx{%
And eat not of that whereon Allah's name hath not been mentioned, for lo! it is abomination. Lo! the devils do inspire their minions to dispute with you. But if ye obey them, ye will be in truth idolaters.\qt@no{121}}%
\qt@newcmd\qurantrans@en@cmxi{%
Is he who was dead and We have raised him unto life, and set for him a light wherein he walketh among men, as him whose similitude is in utter darkness whence he cannot emerge? Thus is their conduct made fairseeming for the disbelievers.\qt@no{122}}%
\qt@newcmd\qurantrans@en@cmxii{%
And thus have We made in every city great ones of its wicked ones, that they should plot therein. They do but plot against themselves, though they perceive not.\qt@no{123}}%
\qt@newcmd\qurantrans@en@cmxiii{%
And when a token cometh unto them, they say: We will not believe till we are given that which Allah's messengers are given. Allah knoweth best with whom to place His message. Humiliation from Allah and heavy punishment will smite the guilty for their scheming.\qt@no{124}}%
\qt@newcmd\qurantrans@en@cmxiv{%
And whomsoever it is Allah's will to guide, He expandeth his bosom unto the Surrender, and whomsoever it is His Will to send astray, He maketh his bosom close and narrow as if he were engaged in sheer ascent. Thus Allah layeth ignominy upon those who believe not.\qt@no{125}}%
\qt@newcmd\qurantrans@en@cmxv{%
This is the path of thy Lord, a straight path. We have detailed Our revelations for a people who take heed.\qt@no{126}}%
\qt@newcmd\qurantrans@en@cmxvi{%
For them is the abode of peace with their Lord. He will be their Protecting Friend because of what they used to do.\qt@no{127}}%
\qt@newcmd\qurantrans@en@cmxvii{%
In the day when He will gather them together (He will say): O ye assembly of the jinn! Many of humankind did ye seduce. And their adherents among humankind will say: Our Lord! We enjoyed one another, but now we have arrived at the appointed term which Thou appointedst for us. He will say: Fire is your home. Abide therein for ever, save him whom Allah willeth (to deliver). Lo! thy Lord is Wise, Aware.\qt@no{128}}%
\qt@newcmd\qurantrans@en@cmxviii{%
Thus We let some of the wrong-doers have power over others because of what they are wont to earn.\qt@no{129}}%
\qt@newcmd\qurantrans@en@cmxix{%
O ye assembly of the jinn and humankind! Came there not unto you messengers of your own who recounted unto you My tokens and warned you of the meeting of this your Day? They will say: We testify against ourselves. And the life of the world beguiled them. And they testify against themselves that they were disbelievers.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cmxx{%
This is because thy Lord destroyeth not the townships arbitrarily while their people are unconscious (of the wrong they do).\qt@no{131}}%
\qt@newcmd\qurantrans@en@cmxxi{%
For all there will be ranks from what they did. Thy Lord is not unaware of what they do.\qt@no{132}}%
\qt@newcmd\qurantrans@en@cmxxii{%
Thy Lord is the Absolute, the Lord of Mercy. If He will, He can remove you and can cause what He will to follow after you, even as He raised you from the seed of other folk.\qt@no{133}}%
\qt@newcmd\qurantrans@en@cmxxiii{%
Lo! that which ye are promised will surely come to pass, and ye cannot escape.\qt@no{134}}%
\qt@newcmd\qurantrans@en@cmxxiv{%
Say (O Muhammad): O my people! Work according to your power. Lo! I too am working. Thus ye will come to know for which of us will be the happy sequel. Lo! the wrong-doers will not be successful.\qt@no{135}}%
\qt@newcmd\qurantrans@en@cmxxv{%
They assign unto Allah, of the crops and cattle which He created, a portion, and they say: ``This is Allah's" - in their make-believe - ``and this is for (His) partners in regard to us." Thus that which (they assign) unto His partners in them reacheth not Allah and that which (they assign) unto Allah goeth to their (so-called) partners. Evil is their ordinance.\qt@no{136}}%
\qt@newcmd\qurantrans@en@cmxxvi{%
Thus have their (so-called) partners (of Allah) made the killing of their children to seem fair unto many of the idolaters, that they may ruin them and make their faith obscure for them. Had Allah willed (it otherwise), they had not done so. So leave them alone with their devices.\qt@no{137}}%
\qt@newcmd\qurantrans@en@cmxxvii{%
And they say: Such cattle and crops are forbidden. No-one is to eat of them save whom we will - in their make-believe - cattle whose backs are forbidden, cattle over which they mention not the name of Allah. (All that is) a lie against Him. He will repay them for that which they invent.\qt@no{138}}%
\qt@newcmd\qurantrans@en@cmxxviii{%
And they say: That which is in the bellies of such cattle is reserved for our males and is forbidden to our wives; but if it be born dead, then they (all) may be partakers thereof. He will reward them for their attribution (of such ordinances unto Him). Lo, He is Wise, Aware.\qt@no{139}}%
\qt@newcmd\qurantrans@en@cmxxix{%
They are losers who besottedly have slain their children without knowledge, and have forbidden that which Allah bestowed upon them, inventing a lie against Allah. They indeed have gone astray and are not guided.\qt@no{140}}%
\qt@newcmd\qurantrans@en@cmxxx{%
He it is Who produceth gardens trellised and untrellised, and the date-palm, and crops of divers flavour, and the olive and the pomegranate, like and unlike. Eat ye of the fruit thereof when it fruiteth, and pay the due thereof upon the harvest day, and be not prodigal. Lo! Allah loveth not the prodigals.\qt@no{141}}%
\qt@newcmd\qurantrans@en@cmxxxi{%
And of the cattle (He produceth) some for burdens, some for food. Eat of that which Allah hath bestowed upon you, and follow not the footsteps of the devil, for lo! he is an open foe to you.\qt@no{142}}%
\qt@newcmd\qurantrans@en@cmxxxii{%
Eight pairs: Of the sheep twain, and of the goats twain. Say: Hath He forbidden the two males or the two females, or that which the wombs of the two females contain? Expound to me (the case) with knowledge, if ye are truthful.\qt@no{143}}%
\qt@newcmd\qurantrans@en@cmxxxiii{%
And of the camels twain and of the oxen twain. Say: Hath He forbidden the two males or the two females, or that which the wombs of the two females contain; or were ye by to witness when Allah commanded you (all) this? Then who doth greater wrong than he who deviseth a lie concerning Allah, that he may lead mankind astray without knowledge. Lo! Allah guideth not wrongdoing folk.\qt@no{144}}%
\qt@newcmd\qurantrans@en@cmxxxiv{%
Say: I find not in that which is revealed unto me aught prohibited to an eater that he eat thereof, except it be carrion, or blood poured forth, or swineflesh - for that verily is foul - or the abomination which was immolated to the name of other than Allah. But whoso is compelled (thereto), neither craving nor transgressing, (for him) lo! thy Lord is Forgiving, Merciful.\qt@no{145}}%
\qt@newcmd\qurantrans@en@cmxxxv{%
Unto those who are Jews We forbade every animal with claws. And of the oxen and the sheep forbade We unto them the fat thereof save that upon the backs or the entrails, or that which is mixed with the bone. That we awarded them for their rebellion. And lo! we verily are truthful.\qt@no{146}}%
\qt@newcmd\qurantrans@en@cmxxxvi{%
So if they give the lie to thee (Muhammad), say: Your Lord is a Lord of All-Embracing Mercy, and His wrath will never be withdrawn from guilty folk.\qt@no{147}}%
\qt@newcmd\qurantrans@en@cmxxxvii{%
They who are idolaters will say: Had Allah willed, we had not ascribed (unto Him) partners neither had our fathers, nor had we forbidden aught. Thus did those who were before them give the lie (to Allah's messengers) till they tasted of the fear of Us. Say: Have ye any knowledge that ye can adduce for Us? Lo! ye follow naught but an opinion, Lo! ye do but guess.\qt@no{148}}%
\qt@newcmd\qurantrans@en@cmxxxviii{%
Say - For Allah's is the final argument - Had He willed He could indeed have guided all of you.\qt@no{149}}%
\qt@newcmd\qurantrans@en@cmxxxix{%
Say: Come, bring your witnesses who can bear witness that Allah forbade (all) this. And if they bear witness, do not thou bear witness with them. Follow thou not the whims of those who deny Our revelations, those who believe not in the Hereafter and deem (others) equal with their Lord.\qt@no{150}}%
\qt@newcmd\qurantrans@en@cmxl{%
Say: Come, I will recite unto you that which your Lord hath made a sacred duty for you: That ye ascribe no thing as partner unto Him and that ye do good to parents, and that ye slay not your children because of penury - We provide for you and for them - and that ye draw not nigh to lewd things whether open or concealed. And that ye slay not the life which Allah hath made sacred, save in the course of justice. This He hath command you, in order that ye may discern.\qt@no{151}}%
\qt@newcmd\qurantrans@en@cmxli{%
And approach not the wealth of the orphan save with that which is better, till he reach maturity. Give full measure and full weight, in justice. We task not any soul beyond its scope. And if ye give your word, do justice thereunto, even though it be (against) a kinsman; and fulfil the covenant of Allah. This He commandeth you that haply ye may remember.\qt@no{152}}%
\qt@newcmd\qurantrans@en@cmxlii{%
And (He commandeth you, saying): This is My straight path, so follow it. Follow not other ways, lest ye be parted from His way. This hath He ordained for you, that ye may ward off (evil).\qt@no{153}}%
\qt@newcmd\qurantrans@en@cmxliii{%
Again, We gave the Scripture unto Moses, complete for him who would do good, an explanation of all things, a guidance and a mercy, that they might believe in the meeting with their Lord.\qt@no{154}}%
\qt@newcmd\qurantrans@en@cmxliv{%
And this is a blessed Scripture which We have revealed. So follow it and ward off (evil), that ye may find mercy.\qt@no{155}}%
\qt@newcmd\qurantrans@en@cmxlv{%
Lest ye should say: The Scripture was revealed only to two sects before us, and we in sooth were unaware of what they read;\qt@no{156}}%
\qt@newcmd\qurantrans@en@cmxlvi{%
Or lest ye should say: If the Scripture had been revealed unto us, we surely had been better guided than are they. Now hath there come unto you a clear proof from your Lord, a guidance and mercy; and who doeth greater wrong than he who denieth the revelations of Allah, and turneth away from them? We award unto those who turn away from Our revelations an evil doom because of their aversion.\qt@no{157}}%
\qt@newcmd\qurantrans@en@cmxlvii{%
Wait they, indeed, for nothing less than that the angels should come unto them, or thy Lord should come, or there should come one of the portents from thy Lord? In the day when one of the portents from thy Lord cometh, its belief availeth naught a soul which theretofore believed not, nor in its belief earned good (by works). Say: Wait ye! Lo! We (too) are waiting.\qt@no{158}}%
\qt@newcmd\qurantrans@en@cmxlviii{%
Lo! As for those who sunder their religion and become schismatics, no concern at all hast thou with them. Their case will go to Allah, Who then will tell them what they used to do.\qt@no{159}}%
\qt@newcmd\qurantrans@en@cmxlix{%
Whoso bringeth a good deed will receive tenfold the like thereof, while whoso bringeth an ill-deed will be awarded but the like thereof; and they will not be wronged.\qt@no{160}}%
\qt@newcmd\qurantrans@en@cml{%
Say: Lo! As for me, my Lord hath guided me unto a straight path, a right religion, the community of Abraham, the upright, who was no idolater.\qt@no{161}}%
\qt@newcmd\qurantrans@en@cmli{%
Say: Lo! my worship and my sacrifice and my living and my dying are for Allah, Lord of the Worlds.\qt@no{162}}%
\qt@newcmd\qurantrans@en@cmlii{%
He hath no partner. This am I commanded, and I am first of those who surrender (unto Him).\qt@no{163}}%
\qt@newcmd\qurantrans@en@cmliii{%
Say: Shall I seek another than Allah for Lord, when He is Lord of all things? Each soul earneth only on its own account, nor doth any laden bear another's load. Then unto your Lord is your return and He will tell you that wherein ye differed.\qt@no{164}}%
\qt@newcmd\qurantrans@en@cmliv{%
He it is Who hath placed you as viceroys of the earth and hath exalted some of you in rank above others, that He may try you by (the test of) that which He hath given you. Lo! Thy Lord is swift in prosecution, and Lo! He verily is Forgiving, Merciful.\qt@no{165}}%
\qt@newcmd\qurantrans@en@cmlv{%
\basmalahen Alif. Lam. Mim. Sad.\qt@no{1}}%
\qt@newcmd\qurantrans@en@cmlvi{%
(It is) a Scripture that is revealed unto thee (Muhammad) - so let there be no heaviness in thy heart therefrom - that thou mayst warn thereby, and (it is) a Reminder unto believers.\qt@no{2}}%
\qt@newcmd\qurantrans@en@cmlvii{%
(Saying): Follow that which is sent down unto you from your Lord, and follow no protecting friends beside Him. Little do ye recollect!\qt@no{3}}%
\qt@newcmd\qurantrans@en@cmlviii{%
How many a township have We destroyed! As a raid by night, or while they slept at noon, Our terror came unto them.\qt@no{4}}%
\qt@newcmd\qurantrans@en@cmlix{%
No plea had they, when Our terror came unto them, save that they said: Lo! We were wrong-doers.\qt@no{5}}%
\qt@newcmd\qurantrans@en@cmlx{%
Then verily We shall question those unto whom (Our message) hath been sent, and verily We shall question the messengers.\qt@no{6}}%
\qt@newcmd\qurantrans@en@cmlxi{%
Then verily We shall narrate unto them (the event) with knowledge, for We were not absent (when it came to pass).\qt@no{7}}%
\qt@newcmd\qurantrans@en@cmlxii{%
The weighing on that day is the true (weighing). As for those whose scale is heavy, they are the successful.\qt@no{8}}%
\qt@newcmd\qurantrans@en@cmlxiii{%
And as for those whose scale is light: those are they who lose their souls because they used to wrong Our revelations.\qt@no{9}}%
\qt@newcmd\qurantrans@en@cmlxiv{%
And We have given you (mankind) power in the earth, and appointed for you therein livelihoods. Little give ye thanks!\qt@no{10}}%
\qt@newcmd\qurantrans@en@cmlxv{%
And We created you, then fashioned you, then told the angels: Fall ye prostrate before Adam! And they fell prostrate, all save Iblis, who was not of those who make prostration.\qt@no{11}}%
\qt@newcmd\qurantrans@en@cmlxvi{%
He said: What hindered thee that thou didst not fall prostrate when I bade thee? (Iblis) said: I am better than him. Thou createdst me of fire while him Thou didst create of mud.\qt@no{12}}%
\qt@newcmd\qurantrans@en@cmlxvii{%
He said: Then go down hence! It is not for thee to show pride here, so go forth! Lo! thou art of those degraded.\qt@no{13}}%
\qt@newcmd\qurantrans@en@cmlxviii{%
He said: Reprieve me till the day when they are raised (from the dead).\qt@no{14}}%
\qt@newcmd\qurantrans@en@cmlxix{%
He said: Lo! thou art of those reprieved.\qt@no{15}}%
\qt@newcmd\qurantrans@en@cmlxx{%
He said: Now, because Thou hast sent me astray, verily I shall lurk in ambush for them on Thy Right Path.\qt@no{16}}%
\qt@newcmd\qurantrans@en@cmlxxi{%
Then I shall come upon them from before them and from behind them and from their right hands and from their left hands, and Thou wilt not find most of them beholden (unto Thee).\qt@no{17}}%
\qt@newcmd\qurantrans@en@cmlxxii{%
He said: Go forth from hence, degraded, banished. As for such of them as follow thee, surely I will fill hell with all of you.\qt@no{18}}%
\qt@newcmd\qurantrans@en@cmlxxiii{%
And (unto man): O Adam! Dwell thou and thy wife in the Garden and eat from whence ye will, but come not nigh this tree lest ye become wrong-doers.\qt@no{19}}%
\qt@newcmd\qurantrans@en@cmlxxiv{%
Then Satan whispered to them that he might manifest unto them that which was hidden from them of their shame, and he said: Your Lord forbade you from this tree only lest ye should become angels or become of the immortals.\qt@no{20}}%
\qt@newcmd\qurantrans@en@cmlxxv{%
And he swore unto them (saying): Lo! I am a sincere adviser unto you.\qt@no{21}}%
\qt@newcmd\qurantrans@en@cmlxxvi{%
Thus did he lead them on with guile. And when they tasted of the tree their shame was manifest to them and they began to hide (by heaping) on themselves some of the leaves of the Garden. And their Lord called them, (saying): Did I not forbid you from that tree and tell you: Lo! Satan is an open enemy to you?\qt@no{22}}%
\qt@newcmd\qurantrans@en@cmlxxvii{%
They said: Our Lord! We have wronged ourselves. If thou forgive us not and have not mercy on us, surely we are of the lost!\qt@no{23}}%
\qt@newcmd\qurantrans@en@cmlxxviii{%
He said: Go down (from hence), one of you a foe unto the other. There will be for you on earth a habitation and provision for a while.\qt@no{24}}%
\qt@newcmd\qurantrans@en@cmlxxix{%
He said: There shall ye live, and there shall ye die, and thence shall ye be brought forth.\qt@no{25}}%
\qt@newcmd\qurantrans@en@cmlxxx{%
O Children of Adam! We have revealed unto you raiment to conceal your shame, and splendid vesture, but the raiment of restraint from evil, that is best. This is of the revelations of Allah, that they may remember.\qt@no{26}}%
\qt@newcmd\qurantrans@en@cmlxxxi{%
O Children of Adam! Let not Satan seduce you as he caused your (first) parents to go forth from the Garden and tore off from them their robe (of innocence) that he might manifest their shame to them. Lo! he seeth you, he and his tribe, from whence ye see him not. Lo! We have made the devils protecting friends for those who believe not.\qt@no{27}}%
\qt@newcmd\qurantrans@en@cmlxxxii{%
And when they do some lewdness they say: We found our fathers doing it and Allah hath enjoined it on us. Say: Allah, verily, enjoineth not lewdness. Tell ye concerning Allah that which ye know not?\qt@no{28}}%
\qt@newcmd\qurantrans@en@cmlxxxiii{%
Say: My Lord enjoineth justice. And set your faces upright (toward Him) at every place of worship and call upon Him, making religion pure for Him (only). As He brought you into being, so return ye (unto Him).\qt@no{29}}%
\qt@newcmd\qurantrans@en@cmlxxxiv{%
A party hath He led aright, while error hath just hold over (another) party, for lo! they choose the devils for protecting supporters instead of Allah and deem that they are rightly guided.\qt@no{30}}%
\qt@newcmd\qurantrans@en@cmlxxxv{%
O Children of Adam! Look to your adornment at every place of worship, and eat and drink, but be not prodigal. Lo! He loveth not the prodigals.\qt@no{31}}%
\qt@newcmd\qurantrans@en@cmlxxxvi{%
Say: Who hath forbidden the adornment of Allah which He hath brought forth for His bondmen, and the good things of His providing? Say: Such, on the Day of Resurrection, will be only for those who believed during the life of the world. Thus do we detail Our revelations for people who have knowledge.\qt@no{32}}%
\qt@newcmd\qurantrans@en@cmlxxxvii{%
Say: My Lord forbiddeth only indecencies, such of them as are apparent and such as are within, and sin and wrongful oppression, and that ye associate with Allah that for which no warrant hath been revealed, and that ye tell concerning Allah that which ye know not.\qt@no{33}}%
\qt@newcmd\qurantrans@en@cmlxxxviii{%
And every nation hath its term, and when its term cometh, they cannot put it off an hour nor yet advance (it).\qt@no{34}}%
\qt@newcmd\qurantrans@en@cmlxxxix{%
O Children of Adam! When messengers of your own come unto you who narrate unto you My revelations, then whosoever refraineth from evil and amendeth - there shall no fear come upon them neither shall they grieve.\qt@no{35}}%
\qt@newcmd\qurantrans@en@cmxc{%
But they who deny Our revelations and scorn them - each are rightful owners of the Fire; they will abide therein.\qt@no{36}}%
\qt@newcmd\qurantrans@en@cmxci{%
Who doeth greater wrong than he who inventeth a lie concerning Allah or denieth Our tokens. (For such) their appointed portion of the Book (of destiny) reacheth them till, when Our messengers come to gather them, they say: Where (now) is that to which ye cried beside Allah? They say: They have departed from us. And they testify against themselves that they were disbelievers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@cmxcii{%
He saith: Enter into the Fire among nations of the jinn and humankind who passed away before you. Every time a nation entereth, it curseth its sister (nation) till, when they have all been made to follow one another thither, the last of them saith unto the first of them: Our Lord! These led us astray, so give them double torment of the Fire. He saith: For each one there is double (torment), but ye know not.\qt@no{38}}%
\qt@newcmd\qurantrans@en@cmxciii{%
And the first of them saith unto the last of them: Ye were no whit better than us, so taste the doom for what ye used to earn.\qt@no{39}}%
\qt@newcmd\qurantrans@en@cmxciv{%
Lo! they who deny Our revelations and scorn them, for them the gates of heaven will nor be opened not will they enter the Garden until the camel goeth through the needle's eye. Thus do We requite the guilty.\qt@no{40}}%
\qt@newcmd\qurantrans@en@cmxcv{%
Theirs will be a bed of hell, and over them coverings (of hell). Thus do We requite wrong-doers.\qt@no{41}}%
\qt@newcmd\qurantrans@en@cmxcvi{%
But (as for) those who believe and do good works - We tax not any soul beyond its scope - Such are rightful owners of the Garden. They abide therein.\qt@no{42}}%
\qt@newcmd\qurantrans@en@cmxcvii{%
And We remove whatever rancour may be in their hearts. Rivers flow beneath them. And they say: The praise to Allah, Who hath guided us to this. We could not truly have been led aright if Allah had not guided us. Verily the messengers of our Lord did bring the Truth. And it is cried unto them: This is the Garden. Ye inherit it for what ye used to do.\qt@no{43}}%
\qt@newcmd\qurantrans@en@cmxcviii{%
And the dwellers of the Garden cry unto the dwellers of the Fire: We have found that which our Lord promised us (to be) the Truth. Have ye (too) found that which your Lord promised the Truth? They say: Yea, verily. And a crier in between them crieth: The curse of Allah is on evil-doers,\qt@no{44}}%
\qt@newcmd\qurantrans@en@cmxcix{%
Who debar (men) from the path of Allah and would have it crooked, and who are disbelievers in the Last Day.\qt@no{45}}%
\qt@newcmd\qurantrans@en@m{%
Between them is a veil. And on the Heights are men who know them all by their marks. And they call unto the dwellers of the Garden: Peace be unto you! They enter it not although they hope (to enter).\qt@no{46}}%
\qt@newcmd\qurantrans@en@mi{%
And when their eyes are turned toward the dwellers of the Fire, they say: Our Lord! Place us not with the wrong-doing folk.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mii{%
And the dwellers on the Heights call unto men whom they know by their marks, (saying): What did your multitude and that in which ye took your pride avail you?\qt@no{48}}%
\qt@newcmd\qurantrans@en@miii{%
Are these they of whom ye swore that Allah would not show them mercy? (Unto them it hath been said): Enter the Garden. No fear shall come upon you nor is it ye who will grieve.\qt@no{49}}%
\qt@newcmd\qurantrans@en@miv{%
And the dwellers of the Fire cry out unto the dwellers of the Garden: Pour on us some water or some wherewith Allah hath provided you. They say: Lo! Allah hath forbidden both to disbelievers (in His guidance),\qt@no{50}}%
\qt@newcmd\qurantrans@en@mv{%
Who took their religion for a sport and pastime, and whom the life of the world beguiled. So this day We have forgotten them even as they forgot the meeting of this their Day and as they used to deny Our tokens.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mvi{%
Verily We have brought them a Scripture which We expounded with knowledge, a guidance and a mercy for a people who believe.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mvii{%
Await they aught save the fulfilment thereof? On the day when the fulfilment thereof cometh, those who were before forgetful thereof will say: The messengers of our Lord did bring the Truth! Have we any intercessors, that they may intercede for us? Or can we be returned (to life on earth), that we may act otherwise than we used to act? They have lost their souls, and that which they devised hath failed them.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mviii{%
Lo! your Lord is Allah Who created the heavens and the earth in six Days, then mounted He the Throne. He covereth the night with the day, which is in haste to follow it, and hath made the sun and the moon and the stars subservient by His command. His verily is all creation and commandment. Blessed be Allah, the Lord of the Worlds!\qt@no{54}}%
\qt@newcmd\qurantrans@en@mix{%
(O mankind!) Call upon your Lord humbly and in secret. Lo! He loveth not aggressors.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mx{%
Work not confusion in the earth after the fair ordering (thereof). and call on Him in fear and hope. Lo! the mercy of Allah is nigh unto the good.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mxi{%
And He it is Who sendeth the winds as tidings heralding His mercy, till, when they bear a cloud heavy (with rain), We lead it to a dead land, and then cause water to descend thereon and thereby bring forth fruits of every kind. Thus bring We forth the dead. Haply ye may remember.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mxii{%
As for the good land, its vegetation cometh forth by permission of its Lord; while as for that which is bad, only the useless cometh forth (from it). Thus do We recount the tokens for people who give thanks.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mxiii{%
We sent Noah (of old) unto his people, and he said: O my people! Serve Allah. Ye have no other Allah save Him. Lo! I fear for you the retribution of an Awful Day.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mxiv{%
The chieftains of his people said: Lo! we see thee surely in plain error.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mxv{%
He said: O my people! There is no error in me, but I am a messenger from the Lord of the Worlds.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mxvi{%
I convey unto you the messages of my Lord and give good counsel unto you, and know from Allah that which ye know not.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mxvii{%
Marvel ye that there should come unto you a Reminder from your Lord by means of a man among you, that he may warn you, and that ye may keep from evil, and that haply ye may find mercy.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mxviii{%
But they denied him, so We saved him and those with him in the ship, and We drowned those who denied Our tokens. Lo! they were blind folk.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mxix{%
And unto (the tribe of) A'ad (We sent) their brother, Hud. He said: O my people! Serve Allah. Ye have no other Allah save Him. Will ye not ward off (evil)?\qt@no{65}}%
\qt@newcmd\qurantrans@en@mxx{%
The chieftains of his people, who were disbelieving, said: Lo! we surely see thee in foolishness, and lo! we deem thee of the liars.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mxxi{%
He said: O my people! There is no foolishness in me, but I am a messenger from the Lord of the Worlds.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mxxii{%
I convey unto you the messages of my Lord and am for you a true adviser.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mxxiii{%
Marvel ye that there should come unto you a Reminder from your Lord by means of a man among you, that he may warn you? Remember how He made you viceroys after Noah's folk, and gave you growth of stature. Remember (all) the bounties of your Lord, that haply ye may be successful.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mxxiv{%
They said: Hast come unto us that we should serve Allah alone, and forsake what our fathers worshipped? Then bring upon us that wherewith thou threatenest us if thou art of the truthful!\qt@no{70}}%
\qt@newcmd\qurantrans@en@mxxv{%
He said: Terror and wrath from your Lord have already fallen on you. Would ye wrangle with me over names which ye have named, ye and your fathers, for which no warrant from Allah hath been revealed? Then await (the consequence), lo! I (also) am of those awaiting (it).\qt@no{71}}%
\qt@newcmd\qurantrans@en@mxxvi{%
And We saved him and those with him by a mercy from Us, and We cut the root of those who denied Our revelations and were not believers.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mxxvii{%
And to (the tribe of) Thamud (We sent) their brother Salih. He said: O my people! Serve Allah. Ye have no other Allah save Him. A wonder from your Lord hath come unto you. Lo! this is the camel of Allah, a token unto you; so let her feed in Allah's earth, and touch her not with hurt lest painful torment seize you.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mxxviii{%
And remember how He made you viceroys after A'ad and gave you station in the earth. Ye choose castles in the plains and hew the mountains into dwellings. So remember (all) the bounties of Allah and do not evil, making mischief in the earth.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mxxix{%
The chieftains of his people, who were scornful, said unto those whom they despised, unto such of them as believed: Know ye that Salih is one sent from his Lord? They said: Lo! In that wherewith he hath been sent we are believers.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mxxx{%
Those who were scornful said: Lo! in that which ye believe we are disbelievers.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mxxxi{%
So they hamstrung the she-camel, and they flouted the commandment of their Lord, and they said: O Salih! Bring upon us that thou threatenest if thou art indeed of those sent (from Allah).\qt@no{77}}%
\qt@newcmd\qurantrans@en@mxxxii{%
So the earthquake seized them, and morning found them prostrate in their dwelling-place.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mxxxiii{%
And (Salih) turned from them and said: O my people! I delivered my Lord's message unto you and gave you good advice, but ye love not good advisers.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mxxxiv{%
And Lot! (Remember) when he said unto his folk: Will ye commit abomination such as no creature ever did before you?\qt@no{80}}%
\qt@newcmd\qurantrans@en@mxxxv{%
Lo! ye come with lust unto men instead of women. Nay, but ye are wanton folk.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mxxxvi{%
And the answer of his people was only that they said (one to another): Turn them out of your township. They are folk, forsooth, who keep pure.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mxxxvii{%
And We rescued him and his household, save his wife, who was of those who stayed behind.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mxxxviii{%
And We rained a rain upon them. See now the nature of the consequence of evil-doers!\qt@no{84}}%
\qt@newcmd\qurantrans@en@mxxxix{%
And unto Midian (We sent) their brother, Shu'eyb. He said: O my people! Serve Allah. Ye have no other Allah save Him. Lo! a clear proof hath come unto you from your Lord; so give full measure and full weight and wrong not mankind in their goods, and work not confusion in the earth after the fair ordering thereof. That will be better for you, if ye are believers.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mxl{%
Lurk not on every road to threaten (wayfarers), and to turn away from Allah's path him who believeth in Him, and to seek to make it crooked. And remember, when ye were but few, how He did multiply you. And see the nature of the consequence for the corrupters!\qt@no{86}}%
\qt@newcmd\qurantrans@en@mxli{%
And if there is a party of you which believeth in that wherewith I have been sent, and there is a party which believeth not, then have patience until Allah judge between us. He is the Best of all who deal in judgment.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mxlii{%
The chieftains of his people, who were scornful, said: Surely we will drive thee out, O Shu'eyb, and those who believe with thee, from our township, unless ye return to our religion. He said: Even though we hate it?\qt@no{88}}%
\qt@newcmd\qurantrans@en@mxliii{%
We should have invented a lie against Allah if we returned to your religion after Allah hath rescued us from it. It is not for us to return to it unless Allah our Lord should (so) will. Our Lord comprehendeth all things in knowledge. In Allah do we put our trust. Our Lord! Decide with truth between us and our folk, for Thou art the best of those who make decision.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mxliv{%
But the chieftains of his people, who were disbelieving, said: If ye follow Shu'eyb, then truly ye shall be the losers.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mxlv{%
So the earthquake seized them and morning found them prostrate in their dwelling-place.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mxlvi{%
Those who denied Shu'eyb became as though they had not dwelt there. Those who denied Shu'eyb, they were the losers.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mxlvii{%
So he turned from them and said: O my people! I delivered my Lord's messages unto you and gave you good advice; then how can I sorrow for a people that rejected (truth)?\qt@no{93}}%
\qt@newcmd\qurantrans@en@mxlviii{%
And We sent no prophet unto any township but We did afflict its folk with tribulation and adversity that haply they might grow humble.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mxlix{%
Then changed We the evil plight for good till they grew affluent and said: Tribulation and distress did touch our fathers. Then We seized them unawares, when they perceived not.\qt@no{95}}%
\qt@newcmd\qurantrans@en@ml{%
And if the people of the townships had believed and kept from evil, surely We should have opened for them blessings from the sky and from the earth. But (unto every messenger) they gave the lie, and so We seized them on account of what they used to earn.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mli{%
Are the people of the townships then secure from the coming of Our wrath upon them as a night-raid while they sleep?\qt@no{97}}%
\qt@newcmd\qurantrans@en@mlii{%
Or are the people of the townships then secure from the coming of Our wrath upon them in the daytime while they play?\qt@no{98}}%
\qt@newcmd\qurantrans@en@mliii{%
Are they then secure from Allah's scheme? None deemeth himself secure from Allah's scheme save folk that perish.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mliv{%
Is it not an indication to those who inherit the land after its people (who thus reaped the consequence of evil-doing) that, if We will, We can smite them for their sins and print upon their hearts so that they hear not?\qt@no{100}}%
\qt@newcmd\qurantrans@en@mlv{%
Such were the townships. We relate some tidings of them unto thee (Muhammad). Their messengers verily came unto them with clear proofs (of Allah's Sovereignty), but they could not believe because they had before denied. Thus doth Allah print upon the hearts of disbelievers (that they hear not).\qt@no{101}}%
\qt@newcmd\qurantrans@en@mlvi{%
We found no (loyalty to any) covenant in most of them. Nay, most of them We found wrong-doers.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mlvii{%
Then, after them, We sent Moses with our tokens unto Pharaoh and his chiefs, but they repelled them. Now, see the nature of the consequence for the corrupters!\qt@no{103}}%
\qt@newcmd\qurantrans@en@mlviii{%
Moses said: O Pharaoh! Lo! I am a messenger from the Lord of the Worlds,\qt@no{104}}%
\qt@newcmd\qurantrans@en@mlix{%
Approved upon condition that I speak concerning Allah nothing but the truth. I come unto you (lords of Egypt) with a clear proof from your Lord. So let the Children of Israel go with me.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mlx{%
(Pharaoh) said: If thou comest with a token, then produce it, if thou art of those who speak the truth.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mlxi{%
Then he flung down his staff and lo! it was a serpent manifest;\qt@no{107}}%
\qt@newcmd\qurantrans@en@mlxii{%
And he drew forth his hand (from his bosom), and lo! it was white for the beholders.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mlxiii{%
The chiefs of Pharaoh's people said: Lo! this is some knowing wizard,\qt@no{109}}%
\qt@newcmd\qurantrans@en@mlxiv{%
Who would expel you from your land. Now what do ye advise?\qt@no{110}}%
\qt@newcmd\qurantrans@en@mlxv{%
They said (unto Pharaoh): Put him off (a while) - him and his brother - and send into the cities summoners,\qt@no{111}}%
\qt@newcmd\qurantrans@en@mlxvi{%
To bring each knowing wizard unto thee.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mlxvii{%
And the wizards came to Pharaoh, saying: Surely there will be a reward for us if we are victors.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mlxviii{%
He answered: Yes, and surely ye shall be of those brought near (to me).\qt@no{114}}%
\qt@newcmd\qurantrans@en@mlxix{%
They said: O Moses! Either throw (first) or let us be the first throwers?\qt@no{115}}%
\qt@newcmd\qurantrans@en@mlxx{%
He said: Throw! And when they threw they cast a spell upon the people's eyes, and overawed them, and produced a mighty spell.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mlxxi{%
And We inspired Moses (saying): Throw thy staff! And lo! it swallowed up their lying show.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mlxxii{%
Thus was the Truth vindicated and that which they were doing was made vain.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mlxxiii{%
Thus were they there defeated and brought low.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mlxxiv{%
And the wizards fell down prostrate,\qt@no{120}}%
\qt@newcmd\qurantrans@en@mlxxv{%
Crying: We believe in the Lord of the Worlds,\qt@no{121}}%
\qt@newcmd\qurantrans@en@mlxxvi{%
The Lord of Moses and Aaron.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mlxxvii{%
Pharaoh said: Ye believe in Him before I give you leave! Lo! this is the plot that ye have plotted in the city that ye may drive its people hence. But ye shall come to know!\qt@no{123}}%
\qt@newcmd\qurantrans@en@mlxxviii{%
Surely I shall have your hands and feet cut off upon alternate sides. Then I shall crucify you every one.\qt@no{124}}%
\qt@newcmd\qurantrans@en@mlxxix{%
They said: Lo! We are about to return unto our Lord!\qt@no{125}}%
\qt@newcmd\qurantrans@en@mlxxx{%
Thou takest vengeance on us only forasmuch as we believed the tokens of our Lord when they came unto us. Our Lord! Vouchsafe unto us steadfastness and make us die as men who have surrendered (unto Thee).\qt@no{126}}%
\qt@newcmd\qurantrans@en@mlxxxi{%
The chiefs of Pharaoh's people said: (O King), wilt thou suffer Moses and his people to make mischief in the land, and flout thee and thy gods? He said: We will slay their sons and spare their women, for lo! we are in power over them.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mlxxxii{%
And Moses said unto his people: Seek help in Allah and endure. Lo! the earth is Allah's. He giveth it for an inheritance to whom He will. And lo! the sequel is for those who keep their duty (unto Him).\qt@no{128}}%
\qt@newcmd\qurantrans@en@mlxxxiii{%
They said: We suffered hurt before thou camest unto us, and since thou hast come unto us. He said: It may be that your Lord is going to destroy your adversary and make you viceroys in the earth, that He may see how ye behave.\qt@no{129}}%
\qt@newcmd\qurantrans@en@mlxxxiv{%
And we straitened Pharaoh's folk with famine and dearth of fruits, that peradventure they might heed.\qt@no{130}}%
\qt@newcmd\qurantrans@en@mlxxxv{%
But whenever good befell them, they said: This is ours; and whenever evil smote them they ascribed it to the evil auspices of Moses and those with him. Surely their evil auspice was only with Allah. But most of them knew not.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mlxxxvi{%
And they said: Whatever portent thou bringest wherewith to bewitch us, we shall not put faith in thee.\qt@no{132}}%
\qt@newcmd\qurantrans@en@mlxxxvii{%
So We sent against them the flood and the locusts and the vermin and the frogs and the blood - a succession of clear signs. But they were arrogant and became a guilty folk.\qt@no{133}}%
\qt@newcmd\qurantrans@en@mlxxxviii{%
And when the terror fell on them they cried: O Moses! Pray for us unto thy Lord, because He hath a covenant with thee. If thou removest the terror from us we verily will trust thee and will let the Children of Israel go with thee.\qt@no{134}}%
\qt@newcmd\qurantrans@en@mlxxxix{%
But when We did remove from them the terror for a term which they must reach, behold! they broke their covenant.\qt@no{135}}%
\qt@newcmd\qurantrans@en@mxc{%
Therefore We took retribution from them; therefore We drowned them in the sea: because they denied Our revelations and were heedless of them.\qt@no{136}}%
\qt@newcmd\qurantrans@en@mxci{%
And We caused the folk who were despised to inherit the eastern parts of the land and the western parts thereof which We had blessed. And the fair word of thy Lord was fulfilled for the Children of Israel because of their endurance; and We annihilated (all) that Pharaoh and his folk had done and that they had contrived.\qt@no{137}}%
\qt@newcmd\qurantrans@en@mxcii{%
And We brought the Children of Israel across the sea, and they came unto a people who were given up to idols which they had. They said: O Moses! Make for us a god even as they have gods. He said: Lo! ye are a folk who know not.\qt@no{138}}%
\qt@newcmd\qurantrans@en@mxciii{%
Lo! as for these, their way will be destroyed and all that they are doing is in vain.\qt@no{139}}%
\qt@newcmd\qurantrans@en@mxciv{%
He said: Shall I seek for you a god other than Allah when He hath favoured you above (all) creatures?\qt@no{140}}%
\qt@newcmd\qurantrans@en@mxcv{%
And (remember) when We did deliver you from Pharaoh's folk who were afflicting you with dreadful torment, slaughtering your sons and sparing your women. That was a tremendous trial from your Lord.\qt@no{141}}%
\qt@newcmd\qurantrans@en@mxcvi{%
And when We did appoint for Moses thirty nights (of solitude), and added to them ten, and he completed the whole time appointed by his Lord of forty nights; and Moses said unto his brother, Aaron: Take my place among the people. Do right, and follow not the way of mischief-makers.\qt@no{142}}%
\qt@newcmd\qurantrans@en@mxcvii{%
And when Moses came to Our appointed tryst and his Lord had spoken unto him, he said: My Lord! Show me (Thy Self), that I may gaze upon Thee. He said: Thou wilt not see Me, but gaze upon the mountain! If it stand still in its place, then thou wilt see Me. And when his Lord revealed (His) glory to the mountain He sent it crashing down. And Moses fell down senseless. And when he woke he said: Glory unto Thee! I turn unto Thee repentant, and I am the first of (true) believers.\qt@no{143}}%
\qt@newcmd\qurantrans@en@mxcviii{%
He said: O Moses! I have preferred thee above mankind by My messages and by My speaking (unto thee). So hold that which I have given thee, and be among the thankful.\qt@no{144}}%
\qt@newcmd\qurantrans@en@mxcix{%
And We wrote for him, upon the tablets, the lesson to be drawn from all things and the explanation of all things, then (bade him): Hold it fast; and command thy people (saying): Take the better (course made clear) therein. I shall show thee the abode of evil-livers.\qt@no{145}}%
\qt@newcmd\qurantrans@en@mc{%
I shall turn away from My revelations those who magnify themselves wrongfully in the earth, and if they see each token believe it not, and if they see the way of righteousness choose it nor for (their) way, and if they see the way of error choose if for (their) way. That is because they deny Our revelations and are used to disregard them.\qt@no{146}}%
\qt@newcmd\qurantrans@en@mci{%
Those who deny Our revelations and the meeting of the Hereafter, their works are fruitless. Are they requited aught save what they used to do?\qt@no{147}}%
\qt@newcmd\qurantrans@en@mcii{%
And the folk of Moses, after (he left them), chose a calf (for worship), (made) out of their ornaments, of saffron hue, which gave a lowing sound. Saw they not that it spake not unto them nor guided them to any way? They chose it, and became wrong-doers.\qt@no{148}}%
\qt@newcmd\qurantrans@en@mciii{%
And when they feared the consequences thereof and saw that they had gone astray, they said: Unless our Lord have mercy on us and forgive us, we verily are of the lost.\qt@no{149}}%
\qt@newcmd\qurantrans@en@mciv{%
And when Moses returned unto his people, angry and grieved, he said: Evil is that (course) which ye took after I had left you. Would ye hasten on the judgment of your Lord? And he cast down the tablets, and he seized his brother by the head, dragging him toward him. He said: Son of my mother! Lo! the folk did judge me weak and almost killed me. Oh, make not mine enemies to triumph over me and place me not among the evil-doers.\qt@no{150}}%
\qt@newcmd\qurantrans@en@mcv{%
He said: My Lord! Have mercy on me and on my brother; bring us into Thy mercy, Thou the Most Merciful of all who show mercy.\qt@no{151}}%
\qt@newcmd\qurantrans@en@mcvi{%
Lo! Those who chose the calf (for worship), terror from their Lord and humiliation will come upon them in the life of the world. Thus do We requite those who invent a lie.\qt@no{152}}%
\qt@newcmd\qurantrans@en@mcvii{%
But those who do ill-deeds and afterward repent and believe - lo! for them, afterward, Allah is Forgiving, Merciful.\qt@no{153}}%
\qt@newcmd\qurantrans@en@mcviii{%
Then, when the anger of Moses abated, he took up the tablets, and in their inscription there was guidance and mercy for all those who fear their Lord.\qt@no{154}}%
\qt@newcmd\qurantrans@en@mcix{%
And Moses chose of his people seventy men for Our appointed tryst and, when the trembling came on them, he said: My Lord! If Thou hadst willed Thou hadst destroyed them long before, and me with them. Wilt thou destroy us for that which the ignorant among us did? It is but Thy trial (of us). Thou sendest whom Thou wilt astray and guidest whom Thou wilt: Thou art our Protecting Friend, therefore forgive us and have mercy on us, Thou, the Best of all who show forgiveness.\qt@no{155}}%
\qt@newcmd\qurantrans@en@mcx{%
And ordain for us in this world that which is good, and in the Hereafter (that which is good), Lo! We have turned unto Thee. He said: I smite with My punishment whom I will, and My mercy embraceth all things, therefore I shall ordain it for those who ward off (evil) and pay the poor-due, and those who believe Our revelations;\qt@no{156}}%
\qt@newcmd\qurantrans@en@mcxi{%
Those who follow the messenger, the Prophet who can neither read nor write, whom they will find described in the Torah and the Gospel (which are) with them. He will enjoin on them that which is right and forbid them that which is wrong. He will make lawful for them all good things and prohibit for them only the foul; and he will relieve them of their burden and the fetters that they used to wear. Then those who believe in him, and honour him, and help him, and follow the light which is sent down with him: they are the successful.\qt@no{157}}%
\qt@newcmd\qurantrans@en@mcxii{%
Say (O Muhammad): O mankind! Lo! I am the messenger of Allah to you all - (the messenger of) Him unto Whom belongeth the Sovereignty of the heavens and the earth. There is no Allah save Him. He quickeneth and He giveth death. So believe in Allah and His messenger, the Prophet who can neither read nor write, who believeth in Allah and in His Words, and follow him that haply ye may be led aright.\qt@no{158}}%
\qt@newcmd\qurantrans@en@mcxiii{%
And of Moses' folk there is a community who lead with truth and establish justice therewith.\qt@no{159}}%
\qt@newcmd\qurantrans@en@mcxiv{%
We divided them into twelve tribes, nations; and We inspired Moses, when his people asked him for water, saying: Smite with thy staff the rock! And there gushed forth therefrom twelve springs, so that each tribe knew their drinking-place. And we caused the white cloud to overshadow them and sent down for them the manna and the quails (saying): Eat of the good things wherewith we have provided you. They wronged Us not, but they were wont to wrong themselves.\qt@no{160}}%
\qt@newcmd\qurantrans@en@mcxv{%
And when it was said unto them: Dwell in this township and eat therefrom whence ye will, and say ``Repentance," and enter the gate prostrate; We shall forgive you your sins; We shall increase (reward) for the right-doers.\qt@no{161}}%
\qt@newcmd\qurantrans@en@mcxvi{%
But those of them who did wrong changed the word which had been told them for another saying, and We sent down upon them wrath from heaven for their wrongdoing.\qt@no{162}}%
\qt@newcmd\qurantrans@en@mcxvii{%
Ask them (O Muhammad) of the township that was by the sea, how they did break the Sabbath, how their big fish came unto them visibly upon their Sabbath day and on a day when they did not keep Sabbath came they not unto them. Thus did We try them for that they were evil-livers.\qt@no{163}}%
\qt@newcmd\qurantrans@en@mcxviii{%
And when a community among them said: Why preach ye to a folk whom Allah is about to destroy or punish with an awful doom, they said: In order to be free from guilt before your Lord, and that haply they may ward off (evil).\qt@no{164}}%
\qt@newcmd\qurantrans@en@mcxix{%
And when they forgot that whereof they had been reminded, We rescued those who forbade wrong, and visited those who did wrong with dreadful punishment because they were evil-livers.\qt@no{165}}%
\qt@newcmd\qurantrans@en@mcxx{%
So when they took pride in that which they had been forbidden, We said unto them: Be ye apes despised and loathed!\qt@no{166}}%
\qt@newcmd\qurantrans@en@mcxxi{%
And (remember) when thy Lord proclaimed that He would raise against them till the Day of Resurrection those who would lay on them a cruel torment. Lo! verily thy Lord is swift in prosecution and lo! verily He is Forgiving, Merciful.\qt@no{167}}%
\qt@newcmd\qurantrans@en@mcxxii{%
And We have sundered them in the earth as (separate) nations. Some of them are righteous, and some far from that. And We have tried them with good things and evil things that haply they might return.\qt@no{168}}%
\qt@newcmd\qurantrans@en@mcxxiii{%
And a generation hath succeeded them who inherited the scriptures. They grasp the goods of this low life (as the price of evil-doing) and say: It will be forgiven us. And if there came to them (again) the offer of the like, they would accept it (and would sin again). Hath not the covenant of the Scripture been taken on their behalf that they should not speak aught concerning Allah save the truth? And they have studied that which is therein. And the abode of the Hereafter is better, for those who ward off (evil). Have ye then no sense?\qt@no{169}}%
\qt@newcmd\qurantrans@en@mcxxiv{%
And as for those who make (men) keep the Scripture, and establish worship - lo! We squander not the wages of reformers.\qt@no{170}}%
\qt@newcmd\qurantrans@en@mcxxv{%
And when We shook the Mount above them as it were a covering, and they supposed that it was going to fall upon them (and We said): Hold fast that which We have given you, and remember that which is therein, that ye may ward off (evil).\qt@no{171}}%
\qt@newcmd\qurantrans@en@mcxxvi{%
And (remember) when thy Lord brought forth from the Children of Adam, from their reins, their seed, and made them testify of themselves, (saying): Am I not your Lord? They said: Yea, verily. We testify. (That was) lest ye should say at the Day of Resurrection: Lo! of this we were unaware;\qt@no{172}}%
\qt@newcmd\qurantrans@en@mcxxvii{%
Or lest ye should say: (It is) only (that) our fathers ascribed partners to Allah of old and we were (their) seed after them. Wilt Thou destroy us on account of that which those who follow falsehood did?\qt@no{173}}%
\qt@newcmd\qurantrans@en@mcxxviii{%
Thus we detail the revelations, that haply they may return.\qt@no{174}}%
\qt@newcmd\qurantrans@en@mcxxix{%
Recite unto them the tale of him to whom We gave Our revelations, but he sloughed them off, so Satan overtook him and he became of those who lead astray.\qt@no{175}}%
\qt@newcmd\qurantrans@en@mcxxx{%
And had We willed We could have raised him by their means, but he clung to the earth and followed his own lust. Therefor his likeness is as the likeness of a dog: if thou attackest him he panteth with his tongue out, and if thou leavest him he panteth with his tongue out. Such is the likeness of the people who deny Our revelations. Narrate unto them the history (of the men of old), that haply they may take thought.\qt@no{176}}%
\qt@newcmd\qurantrans@en@mcxxxi{%
Evil as an example are the folk who denied Our revelations, and were wont to wrong themselves.\qt@no{177}}%
\qt@newcmd\qurantrans@en@mcxxxii{%
He whom Allah leadeth, he indeed is led aright, while he whom Allah sendeth astray - they indeed are losers.\qt@no{178}}%
\qt@newcmd\qurantrans@en@mcxxxiii{%
Already have We urged unto hell many of the jinn and humankind, having hearts wherewith they understand not, and having eyes wherewith they see not, and having ears wherewith they hear not. These are as the cattle - nay, but they are worse! These are the neglectful.\qt@no{179}}%
\qt@newcmd\qurantrans@en@mcxxxiv{%
Allah's are the fairest names. Invoke Him by them. And leave the company of those who blaspheme His names. They will be requited what they do.\qt@no{180}}%
\qt@newcmd\qurantrans@en@mcxxxv{%
And of those whom We created there is a nation who guide with the Truth and establish justice therewith.\qt@no{181}}%
\qt@newcmd\qurantrans@en@mcxxxvi{%
And those who deny Our revelations - step by step We lead them on from whence they know not.\qt@no{182}}%
\qt@newcmd\qurantrans@en@mcxxxvii{%
I give them rein (for) lo! My scheme is strong.\qt@no{183}}%
\qt@newcmd\qurantrans@en@mcxxxviii{%
Have they not bethought them (that) there is no madness in their comrade? He is but a plain warner.\qt@no{184}}%
\qt@newcmd\qurantrans@en@mcxxxix{%
Have they not considered the dominion of the heavens and the earth, and what things Allah hath created, and that it may be that their own term draweth nigh? In what fact after this will they believe?\qt@no{185}}%
\qt@newcmd\qurantrans@en@mcxl{%
Those whom Allah sendeth astray, there is no guide for them. He leaveth them to wander blindly on in their contumacy.\qt@no{186}}%
\qt@newcmd\qurantrans@en@mcxli{%
They ask thee of the (destined) Hour, when will it come to port. Say: Knowledge thereof is with my Lord only. He alone will manifest it at its proper time. It is heavy in the heavens and the earth. It cometh not to you save unawares. They question thee as if thou couldst be well informed thereof. Say: Knowledge thereof is with Allah only, but most of mankind know not.\qt@no{187}}%
\qt@newcmd\qurantrans@en@mcxlii{%
Say: For myself I have no power to benefit, nor power to hurt, save that which Allah willeth. Had I knowledge of the Unseen, I should have abundance of wealth, and adversity would not touch me. I am but a warner, and a bearer of good tidings unto folk who believe.\qt@no{188}}%
\qt@newcmd\qurantrans@en@mcxliii{%
He it is Who did create you from a single soul, and therefrom did make his mate that he might take rest in her. And when he covered her she bore a light burden, and she passed (unnoticed) with it, but when it became heavy they cried unto Allah, their Lord, saying: If thou givest unto us aright we shall be of the thankful.\qt@no{189}}%
\qt@newcmd\qurantrans@en@mcxliv{%
But when He gave unto them aright, they ascribed unto Him partners in respect of that which He had given them. High is He Exalted above all that they associate (with Him).\qt@no{190}}%
\qt@newcmd\qurantrans@en@mcxlv{%
Attribute they as partners to Allah those who created naught, but are themselves created,\qt@no{191}}%
\qt@newcmd\qurantrans@en@mcxlvi{%
And cannot give them help, nor can they help themselves?\qt@no{192}}%
\qt@newcmd\qurantrans@en@mcxlvii{%
And if ye call them to the Guidance, they follow you not. Whether ye call them or are silent is all one for you.\qt@no{193}}%
\qt@newcmd\qurantrans@en@mcxlviii{%
Lo! those on whom ye call beside Allah are slaves like unto you. Call on them now, and let them answer you, if ye are truthful!\qt@no{194}}%
\qt@newcmd\qurantrans@en@mcxlix{%
Have they feet wherewith they walk, or have they hands wherewith they hold, or have they eyes wherewith they see, or have they ears wherewith they hear? Say: Call upon your (so-called) partners (of Allah), and then contrive against me, spare me not!\qt@no{195}}%
\qt@newcmd\qurantrans@en@mcl{%
Lo! my Protecting Friend is Allah Who revealeth the Scripture. He befriendeth the righteous.\qt@no{196}}%
\qt@newcmd\qurantrans@en@mcli{%
They on whom ye call beside Him have no power to help you, nor can they help you, nor can they help themselves.\qt@no{197}}%
\qt@newcmd\qurantrans@en@mclii{%
And if ye (Muslims) call them to the guidance they hear not; and thou (Muhammad) seest them looking toward thee, but they see not.\qt@no{198}}%
\qt@newcmd\qurantrans@en@mcliii{%
Keep to forgiveness (O Muhammad), and enjoin kindness, and turn away from the ignorant.\qt@no{199}}%
\qt@newcmd\qurantrans@en@mcliv{%
And if a slander from the devil wound thee, then seek refuge in Allah. Lo! He is Hearer, Knower.\qt@no{200}}%
\qt@newcmd\qurantrans@en@mclv{%
Lo! those who ward off (evil), when a glamour from the devil troubleth them, they do but remember (Allah's Guidance) and behold them seers!\qt@no{201}}%
\qt@newcmd\qurantrans@en@mclvi{%
Their brethren plunge them further into error and cease not.\qt@no{202}}%
\qt@newcmd\qurantrans@en@mclvii{%
And when thou bringest not a verse for them they say: Why hast thou not chosen it? Say: I follow only that which is inspired in me from my Lord. This (Qur'an) is insight from your Lord, and a guidance and a mercy for a people that believe.\qt@no{203}}%
\qt@newcmd\qurantrans@en@mclviii{%
And when the Qur'an is recited, give ear to it and pay heed, that ye may obtain mercy.\qt@no{204}}%
\qt@newcmd\qurantrans@en@mclix{%
And do thou (O Muhammad) remember thy Lord within thyself humbly and with awe, below thy breath, at morn and evening. And be not thou of the neglectful.\qt@no{205}}%
\qt@newcmd\qurantrans@en@mclx{%
Lo! those who are with thy Lord are not too proud to do Him service, but they praise Him and prostrate before Him.\qt@no{206}}%
\qt@newcmd\qurantrans@en@mclxi{%
\basmalahen They ask thee (O Muhammad) of the spoils of war. Say: The spoils of war belong to Allah and the messenger, so keep your duty to Allah, and adjust the matter of your difference, and obey Allah and His messenger, if ye are (true) believers.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mclxii{%
They only are the (true) believers whose hearts feel fear when Allah is mentioned, and when His revelations are recited unto them they increase their faith, and who trust in their Lord;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mclxiii{%
Who establish worship and spend of that We have bestowed on them.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mclxiv{%
Those are they who are in truth believers. For them are grades (of honour) with their Lord, and pardon, and a bountiful provision.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mclxv{%
Even as thy Lord caused thee (Muhammad) to go forth from thy home with the Truth, and lo! a party of the believers were averse (to it).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mclxvi{%
Disputing with thee of the Truth after it had been made manifest, as if they were being driven to death visible.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mclxvii{%
And when Allah promised you one of the two bands (of the enemy) that it should be yours, and ye longed that other than the armed one might be yours. And Allah willed that He should cause the Truth to triumph by His words, and cut the root of the disbelievers;\qt@no{7}}%
\qt@newcmd\qurantrans@en@mclxviii{%
That He might cause the Truth to triumph and bring vanity to naught, however much the guilty might oppose;\qt@no{8}}%
\qt@newcmd\qurantrans@en@mclxix{%
When ye sought help of your Lord and He answered you (saying): I will help you with a thousand of the angels, rank on rank.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mclxx{%
Allah appointed it only as good tidings, and that your hearts thereby might be at rest. Victory cometh only by the help of Allah. Lo! Allah is Mighty, Wise.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mclxxi{%
When He made the slumber fall upon you as a reassurance from him and sent down water from the sky upon you, that thereby He might purify you, and remove from you the fear of Satan, and make strong your hearts and firm (your) feet thereby.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mclxxii{%
When thy Lord inspired the angels, (saying): I am with you. So make those who believe stand firm. I will throw fear into the hearts of those who disbelieve. Then smite the necks and smite of them each finger.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mclxxiii{%
That is because they opposed Allah and His messenger. Whoso opposeth Allah and His messenger, (for him) lo! Allah is severe in punishment.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mclxxiv{%
That (is the award), so taste it, and (know) that for disbelievers is the torment of the Fire.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mclxxv{%
O ye who believe! When ye meet those who disbelieve in battle, turn not your backs to them.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mclxxvi{%
Whoso on that day turneth his back to them, unless manoeuvring for battle or intent to join a company, he truly hath incurred wrath from Allah, and his habitation will be hell, a hapless journey's end.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mclxxvii{%
Ye (Muslims) slew them not, but Allah slew them. And thou (Muhammad) threwest not when thou didst throw, but Allah threw, that He might test the believers by a fair test from Him. Lo! Allah is Hearer, Knower.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mclxxviii{%
That (is the case); and (know) that Allah (it is) Who maketh weak the plan of disbelievers.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mclxxix{%
(O Qureysh!) If ye sought a judgment, now hath the judgment come unto you. And if ye cease (from persecuting the believers) it will be better for you, but if ye return (to the attack) We also shall return. And your host will avail you naught, however numerous it be, and (know) that Allah is with the believers (in His Guidance).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mclxxx{%
O ye who believe! Obey Allah and His messenger, and turn not away from him when ye hear (him speak).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mclxxxi{%
Be not as those who say, we hear, and they hear not.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mclxxxii{%
Lo! the worst of beasts in Allah's sight are the deaf, the dumb, who have no sense.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mclxxxiii{%
Had Allah known of any good in them He would have made them hear, but had He made them hear they would have turned away, averse.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mclxxxiv{%
O ye who believe! Obey Allah, and the messenger when He calleth you to that which quickeneth you, and know that Allah cometh in between the man and his own heart, and that He it is unto Whom ye will be gathered.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mclxxxv{%
And guard yourselves against a chastisement which cannot fall exclusively on those of you who are wrong-doers, and know that Allah is severe in punishment.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mclxxxvi{%
And remember, when ye were few and reckoned feeble in the land, and were in fear lest men should extirpate you, how He gave you refuge, and strengthened you with His help, and made provision of good things for you, that haply ye might be thankful.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mclxxxvii{%
O ye who believe! Betray not Allah and His messenger, nor knowingly betray your trusts.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mclxxxviii{%
And know that your possessions and your children are a test, and that with Allah is immense reward.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mclxxxix{%
O ye who believe! If ye keep your duty to Allah, He will give you discrimination (between right and wrong) and will rid you of your evil thoughts and deeds, and will forgive you. Allah is of Infinite Bounty.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcxc{%
And when those who disbelieve plot against thee (O Muhammad) to wound thee fatally, or to kill thee or to drive thee forth; they plot, but Allah (also) plotteth; and Allah is the best of plotters.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcxci{%
And when Our revelations are recited unto them they say: We have heard. If we wish we can speak the like of this. Lo! this is naught but fables of the men of old.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcxcii{%
And when they said: O Allah! If this be indeed the truth from Thee, then rain down stones on us or bring on us some painful doom!\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcxciii{%
But Allah would not punish them while thou wast with them, nor will He punish them while they seek forgiveness.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcxciv{%
What (plea) have they that Allah should not punish them, when they debar (His servants) from the Inviolable Place of Worship, though they are not its fitting guardians. Its fitting guardians are those only who keep their duty to Allah. But most of them know not.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcxcv{%
And their worship at the (holy) House is naught but whistling and hand-clapping. Therefore (it is said unto them): Taste of the doom because ye disbelieve.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcxcvi{%
Lo! those who disbelieve spend their wealth in order that they may debar (men) from the way of Allah. They will spend it, then it will become an anguish for them, then they will be conquered. And those who disbelieve will be gathered unto hell,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcxcvii{%
That Allah may separate the wicked from the good, The wicked will He place piece upon piece, and heap them all together, and consign them unto hell. Such verily are the losers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcxcviii{%
Tell those who disbelieve that if they cease (from persecution of believers) that which is past will be forgiven them; but if they return (thereto) then the example of the men of old hath already gone (before them, for a warning).\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcxcix{%
And fight them until persecution is no more, and religion is all for Allah. But if they cease, then lo! Allah is Seer of what they do.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcc{%
And if they turn away, then know that Allah is your Befriender - a Transcendent Patron, a Transcendent Helper!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcci{%
And know that whatever ye take as spoils of war, lo! a fifth thereof is for Allah, and for the messenger and for the kinsman (who hath need) and orphans and the needy and the wayfarer, if ye believe in Allah and that which We revealed unto Our slave on the Day of Discrimination, the day when the two armies met. And Allah is Able to do all things.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mccii{%
When ye were on the near bank (of the valley) and they were on the yonder bank, and the caravan was below you (on the coast plain). And had ye trysted to meet one another ye surely would have failed to keep the tryst, but (it happened, as it did, without the forethought of either of you) that Allah might conclude a thing that must be done; that he who perished (on that day) might perish by a clear proof (of His Sovereignty) and he who survived might survive by a clear proof (of His Sovereignty). Lo! Allah in truth is Hearer, Knower.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcciii{%
When Allah showed them unto thee (O Muhammad) in thy dream as few in number, and if He had shown them to thee as many, ye (Muslims) would have faltered and would have quarrelled over the affair. But Allah saved (you). Lo! He knoweth what is in the breasts (of men).\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcciv{%
And when He made you (Muslims), when ye met (them), see them with your eyes as few, and lessened you in their eyes, (it was) that Allah might conclude a thing that must be done. Unto Allah all things are brought back.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mccv{%
O ye who believe! When ye meet an army, hold firm and think of Allah much, that ye may be successful.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mccvi{%
And obey Allah and His messenger, and dispute not one with another lest ye falter and your strength depart from you; but be steadfast! Lo! Allah is with the steadfast.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mccvii{%
Be not as those who came forth from their dwellings boastfully and to be seen of men, and debar (men) from the way of Allah, while Allah is surrounding all they do.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mccviii{%
And when Satan made their deeds seem fair to them and said: No-one of mankind can conquer you this day, for I am your protector. But when the armies came in sight of one another, he took flight, saying: Lo! I am guiltless of you. Lo! I see that which ye see not. Lo! I fear Allah. And Allah is severe in punishment.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mccix{%
When the hypocrites and those in whose hearts is a disease said: Their religion hath deluded these. Whoso putteth his trust in Allah (will find that) lo! Allah is Mighty, Wise.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mccx{%
If thou couldst see how the angels receive those who disbelieve, smiting faces and their backs and (saying): Taste the punishment of burning!\qt@no{50}}%
\qt@newcmd\qurantrans@en@mccxi{%
This is for that which your own hands have sent before (to the Judgment), and (know) that Allah is not a tyrant to His slaves.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mccxii{%
(Their way is) as the way of Pharaoh's folk and those before them; they disbelieved the revelations of Allah, and Allah took them in their sins. Lo! Allah is Strong, severe in punishment.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mccxiii{%
That is because Allah never changeth the grace He hath bestowed on any people until they first change that which is in their hearts, and (that is) because Allah is Hearer, Knower.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mccxiv{%
(Their way is) as the way of Pharaoh's folk and those before them; they denied the revelations of their Lord, so We destroyed them in their sins. And We drowned the folk of Pharaoh. All were evil-doers.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mccxv{%
Lo! the worst of beasts in Allah's sight are the ungrateful who will not believe.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mccxvi{%
Those of them with whom thou madest a treaty, and then at every opportunity they break their treaty, and they keep not duty (to Allah).\qt@no{56}}%
\qt@newcmd\qurantrans@en@mccxvii{%
If thou comest on them in the war, deal with them so as to strike fear in those who are behind them, that haply they may remember.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mccxviii{%
And if thou fearest treachery from any folk, then throw back to them (their treaty) fairly. Lo! Allah loveth not the treacherous.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mccxix{%
And let not those who disbelieve suppose that they can outstrip (Allah's Purpose). Lo! they cannot escape.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mccxx{%
Make ready for them all thou canst of (armed) force and of horses tethered, that thereby ye may dismay the enemy of Allah and your enemy, and others beside them whom ye know not. Allah knoweth them. Whatsoever ye spend in the way of Allah it will be repaid to you in full, and ye will not be wronged.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mccxxi{%
And if they incline to peace, incline thou also to it, and trust in Allah. Lo! He, even He, is the Hearer, the Knower.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mccxxii{%
And if they would deceive thee, then lo! Allah is Sufficient for thee. He it is Who supporteth thee with His help and with the believers,\qt@no{62}}%
\qt@newcmd\qurantrans@en@mccxxiii{%
And (as for the believers) hath attuned their hearts. If thou hadst spent all that is in the earth thou couldst not have attuned their hearts, but Allah hath attuned them. Lo! He is Mighty, Wise.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mccxxiv{%
O Prophet! Allah is Sufficient for thee and those who follow thee of the believers.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mccxxv{%
O Prophet! Exhort the believers to fight. If there be of you twenty steadfast they shall overcome two hundred, and if there be of you a hundred (steadfast) they shall overcome a thousand of those who disbelieve, because they (the disbelievers) are a folk without intelligence.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mccxxvi{%
Now hath Allah lightened your burden, for He knoweth that there is weakness in you. So if there be of you a steadfast hundred they shall overcome two hundred, and if there be of you a thousand (steadfast) they shall overcome two thousand by permission of Allah. Allah is with the steadfast.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mccxxvii{%
It is not for any prophet to have captives until he hath made slaughter in the land. Ye desire the lure of this world and Allah desireth (for you) the Hereafter, and Allah is Mighty, Wise.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mccxxviii{%
Had it not been for an ordinance of Allah which had gone before, an awful doom had come upon you on account of what ye took.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mccxxix{%
Now enjoy what ye have won, as lawful and good, and keep your duty to Allah. Lo! Allah is Forgiving, Merciful.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mccxxx{%
O Prophet! Say unto those captives who are in your hands: If Allah knoweth any good in your hearts He will give you better than that which hath been taken from you, and will forgive you. Lo! Allah is Forgiving, Merciful.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mccxxxi{%
And if they would betray thee, they betrayed Allah before, and He gave (thee) power over them. Allah is Knower, Wise.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mccxxxii{%
Lo! those who believed and left their homes and strove with their wealth and their lives for the cause of Allah, and those who took them in and helped them: these are protecting friends one of another. And those who believed but did not leave their homes, ye have no duty to protect them till they leave their homes; but if they seek help from you in the matter of religion then it is your duty to help (them) except against a folk between whom and you there is a treaty. Allah is Seer of what ye do.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mccxxxiii{%
And those who disbelieve are protectors one of another - If ye do not so, there will be confusion in the land, and great corruption.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mccxxxiv{%
Those who believed and left their homes and strove for the cause of Allah, and those who took them in and helped them - these are the believers in truth. For them is pardon, and bountiful provision.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mccxxxv{%
And those who afterwards believed and left their homes and strove along with you, they are of you; and those who are akin are nearer one to another in the ordinance of Allah. Lo! Allah is Knower of all things.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mccxxxvi{%
\basmalahen Freedom from obligation (is proclaimed) from Allah and His messenger toward those of the idolaters with whom ye made a treaty.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mccxxxvii{%
Travel freely in the land four months, and know that ye cannot escape Allah and that Allah will confound the disbelievers (in His Guidance).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mccxxxviii{%
And a proclamation from Allah and His messenger to all men on the day of the Greater Pilgrimage that Allah is free from obligation to the idolaters, and (so is) His messenger. So, if ye repent, it will be better for you; but if ye are averse, then know that ye cannot escape Allah. Give tidings (O Muhammad) of a painful doom to those who disbelieve,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mccxxxix{%
Excepting those of the idolaters with whom ye (Muslims) have a treaty, and who have since abated nothing of your right nor have supported anyone against you. (As for these), fulfil their treaty to them till their term. Lo! Allah loveth those who keep their duty (unto Him).\qt@no{4}}%
\qt@newcmd\qurantrans@en@mccxl{%
Then, when the sacred months have passed, slay the idolaters wherever ye find them, and take them (captive), and besiege them, and prepare for them each ambush. But if they repent and establish worship and pay the poor-due, then leave their way free. Lo! Allah is Forgiving, Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mccxli{%
And if anyone of the idolaters seeketh thy protection (O Muhammad), then protect him so that he may hear the Word of Allah, and afterward convey him to his place of safety. That is because they are a folk who know not.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mccxlii{%
How can there be a treaty with Allah and with His messenger for the idolaters save those with whom ye made a treaty at the Inviolable Place of Worship? So long as they are true to you, be true to them. Lo! Allah loveth those who keep their duty.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mccxliii{%
How (can there be any treaty for the others) when, if they have the upper hand of you, they regard not pact nor honour in respect of you? They satisfy you with their mouths the while their hearts refuse. And most of them are wrongdoers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mccxliv{%
They have purchased with the revelations of Allah a little gain, so they debar (men) from His way. Lo! evil is that which they are wont to do.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mccxlv{%
And they observe toward a believer neither pact nor honour. These are they who are transgressors.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mccxlvi{%
But if they repent and establish worship and pay the poor-due, then are they your brethren in religion. We detail Our revelations for a people who have knowledge.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mccxlvii{%
And if they break their pledges after their treaty (hath been made with you) and assail your religion, then fight the heads of disbelief - Lo! they have no binding oaths - in order that they may desist.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mccxlviii{%
Will ye not fight a folk who broke their solemn pledges, and purposed to drive out the messenger and did attack you first? What! Fear ye them? Now Allah hath more right that ye should fear Him, if ye are believers\qt@no{13}}%
\qt@newcmd\qurantrans@en@mccxlix{%
Fight them! Allah will chastise them at your hands, and He will lay them low and give you victory over them, and He will heal the breasts of folk who are believers.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mccl{%
And He will remove the anger of their hearts. Allah relenteth toward whom He will. Allah is Knower, Wise.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mccli{%
Or deemed ye that ye would be left (in peace) when Allah yet knoweth not those of you who strive, choosing for familiar none save Allah and His messenger and the believers? Allah is Informed of what ye do.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcclii{%
It is not for the idolaters to tend Allah's sanctuaries, bearing witness against themselves of disbelief. As for such, their works are vain and in the Fire they will abide.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mccliii{%
He only shall tend Allah's sanctuaries who believeth in Allah and the Last Day and observeth proper worship and payeth the poor-due and feareth none save Allah. For such (only) is it possible that they can be of the rightly guided.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mccliv{%
Count ye the slaking of a pilgrim's thirst and tendance of the Inviolable Place of Worship as (equal to the worth of) him who believeth in Allah and the Last Day, and striveth in the way of Allah? They are not equal in the sight of Allah. Allah guideth not wrongdoing folk.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcclv{%
Those who believe, and have left their homes and striven with their wealth and their lives in Allah's way are of much greater worth in Allah's sight. These are they who are triumphant.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcclvi{%
Their Lord giveth them good tidings of mercy from Him, and acceptance, and Gardens where enduring pleasure will be theirs;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcclvii{%
There they will abide for ever. Lo! with Allah there is immense reward.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcclviii{%
O ye who believe! Choose not your fathers nor your brethren for friends if they take pleasure in disbelief rather than faith. Whoso of you taketh them for friends, such are wrong-doers.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcclix{%
Say: If your fathers, and your sons, and your brethren, and your wives, and your tribe, and the wealth ye have acquired, and merchandise for which ye fear that there will no sale, and dwellings ye desire are dearer to you than Allah and His messenger and striving in His way: then wait till Allah bringeth His command to pass. Allah guideth not wrongdoing folk.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcclx{%
Allah hath given you victory on many fields and on the day of Huneyn, when ye exulted in your multitude but it availed you naught, and the earth, vast as it is, was straitened for you; then ye turned back in flight;\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcclxi{%
Then Allah sent His peace of reassurance down upon His messenger and upon the believers, and sent down hosts ye could not see, and punished those who disbelieved. Such is the reward of disbelievers.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcclxii{%
Then afterward Allah will relent toward whom He will; for Allah is Forgiving, Merciful.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcclxiii{%
O ye who believe! The idolaters only are unclean. So let them not come near the Inviolable Place of Worship after this their year. If ye fear poverty (from the loss of their merchandise) Allah shall preserve you of His bounty if He will. Lo! Allah is Knower, Wise.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcclxiv{%
Fight against such of those who have been given the Scripture as believe not in Allah nor the Last Day, and forbid not that which Allah hath forbidden by His messenger, and follow not the Religion of Truth, until they pay the tribute readily, being brought low.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcclxv{%
And the Jews say: Ezra is the son of Allah, and the Christians say: The Messiah is the son of Allah. That is their saying with their mouths. They imitate the saying of those who disbelieved of old. Allah (Himself) fighteth against them. How perverse are they!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcclxvi{%
They have taken as lords beside Allah their rabbis and their monks and the Messiah son of Mary, when they were bidden to worship only One Allah. There is no Allah save Him. Be He Glorified from all that they ascribe as partner (unto Him)!\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcclxvii{%
Fain would they put out the light of Allah with their mouths, but Allah disdaineth (aught) save that He shall perfect His light, however much the disbelievers are averse.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcclxviii{%
He it is Who hath sent His messenger with the guidance and the Religion of Truth, that He may cause it to prevail over all religion, however much the idolaters may be averse.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcclxix{%
O ye who believe! Lo! many of the (Jewish) rabbis and the (Christian) monks devour the wealth of mankind wantonly and debar (men) from the way of Allah. They who hoard up gold and silver and spend it not in the way of Allah, unto them give tidings (O Muhammad) of a painful doom,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcclxx{%
On the day when it will (all) be heated in the fire of hell, and their foreheads and their flanks and their backs will be branded therewith (and it will be said unto them): Here is that which ye hoarded for yourselves. Now taste of what ye used to hoard.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcclxxi{%
Lo! the number of the months with Allah is twelve months by Allah's ordinance in the day that He created the heavens and the earth. Four of them are sacred: that is the right religion. So wrong not yourselves in them. And wage war on all of the idolaters as they are waging war on all of you. And know that Allah is with those who keep their duty (unto Him).\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcclxxii{%
Postponement (of a sacred month) is only an excess of disbelief whereby those who disbelieve are misled; they allow it one year and forbid it (another) year, that they may make up the number of the months which Allah hath hallowed, so that they allow that which Allah hath forbidden. The evil of their deeds is made fairseeming unto them. Allah guideth not the disbelieving folk.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcclxxiii{%
O ye who believe! What aileth you that when it is said unto you: Go forth in the way of Allah, ye are bowed down to the ground with heaviness. Take ye pleasure in the life of the world rather than in the Hereafter? The comfort of the life of the world is but little in the Hereafter.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcclxxiv{%
If ye go not forth He will afflict you with a painful doom, and will choose instead of you a folk other than you. Ye cannot harm Him at all. Allah is Able to do all things.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcclxxv{%
If ye help him not, still Allah helped him when those who disbelieve drove him forth, the second of two; when they two were in the cave, when he said unto his comrade: Grieve not. Lo! Allah is with us. Then Allah caused His peace of reassurance to descend upon him and supported him with hosts ye cannot see, and made the word of those who disbelieved the nethermost, while Allah's Word it was that became the uppermost. Allah is Mighty, Wise.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcclxxvi{%
Go forth, light-armed and heavy-armed, and strive with your wealth and your lives in the way of Allah! That is best for you if ye but knew.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcclxxvii{%
Had it been a near adventure and an easy journey they had followed thee, but the distance seemed too far for them. Yet will they swear by Allah (saying): If we had been able we would surely have set out with you. They destroy their souls, and Allah knoweth that they verily are liars.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcclxxviii{%
Allah forgive thee (O Muhammad)! Wherefor didst thou grant them leave ere those who told the truth were manifest to thee and thou didst know the liars?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcclxxix{%
Those who believe in Allah and the Last Day ask no leave of thee lest they should strive with their wealth and their lives. Allah is Aware of those who keep their duty (unto Him).\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcclxxx{%
They alone ask leave of thee who believe not in Allah and the Last Day, and whose hearts feel doubt, so in their doubt they waver.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcclxxxi{%
And if they had wished to go forth they would assuredly have made ready some equipment, but Allah was averse to their being sent forth and held them back and it was said (unto them): Sit ye with the sedentary!\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcclxxxii{%
Had they gone forth among you they had added to you naught save trouble and had hurried to and fro among you, seeking to cause sedition among you; and among you there are some who would have listened to them. Allah is Aware of evil-doers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcclxxxiii{%
Aforetime they sought to cause sedition and raised difficulties for thee till the Truth came and the decree of Allah was made manifest, though they were loth.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcclxxxiv{%
Of them is he who saith: Grant me leave (to stay at home) and tempt me not. Surely it is into temptation that they (thus) have fallen. Lo! hell verily is all around the disbelievers.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcclxxxv{%
If good befalleth thee (O Muhammad) it afflicteth them, and if calamity befalleth thee, they say: We took precaution, and they turn away well pleased.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcclxxxvi{%
Say: Naught befalleth us save that which Allah hath decreed for us. He is our Protecting Friend. In Allah let believers put their trust!\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcclxxxvii{%
Say: Can ye await for us aught save one of two good things (death or victory in Allah's way)? while we await for you that Allah will afflict you with a doom from Him or at our hands. Await then! Lo! We are awaiting with you.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcclxxxviii{%
Say: Pay (your contribution), willingly or unwillingly, it will not be accepted from you. Lo! ye were ever froward folk.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcclxxxix{%
And naught preventeth that their contributions should be accepted from them save that they have disbelieved in Allah and in His messenger, and they come not to worship save as idlers, and pay not (their contribution) save reluctantly.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mccxc{%
So let not their riches nor their children please thee (O Muhammad). Allah thereby intendeth but to punish them in the life of the world and that their souls shall pass away while they are disbelievers.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mccxci{%
And they swear by Allah that they are in truth of you, when they are not of you, but they are folk who are afraid.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mccxcii{%
Had they but found a refuge, or caverns, or a place to enter, they surely had resorted thither swift as runaways.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mccxciii{%
And of them is he who defameth thee in the matter of the alms. If they are given thereof they are content, and if they are not given thereof, behold! they are enraged.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mccxciv{%
(How much more seemly) had they been content with that which Allah and His messenger had given them and had said: Allah sufficeth us. Allah will give us of His bounty, and (also) His messenger. Unto Allah we are suppliants.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mccxcv{%
The alms are only for the poor and the needy, and those who collect them, and those whose hearts are to be reconciled, and to free the captives and the debtors, and for the cause of Allah, and (for) the wayfarer; a duty imposed by Allah. Allah is Knower, Wise.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mccxcvi{%
And of them are those who vex the Prophet and say: He is only a hearer. Say: A hearer of good for you, who believeth in Allah and is true to the believers, and a mercy for such of you as believe. Those who vex the messenger of Allah, for them there is a painful doom.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mccxcvii{%
They swear by Allah to you (Muslims) to please you, but Allah, with His messenger, hath more right that they should please Him if they are believers.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mccxcviii{%
Know they not that whoso opposeth Allah and His messenger, his verily is fire of hell, to abide therein? That is the extreme abasement.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mccxcix{%
The hypocrites fear lest a surah should be revealed concerning them, proclaiming what is in their hearts. Say: Scoff (your fill)! Lo! Allah is disclosing what ye fear.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mccc{%
And if thou ask them (O Muhammad) they will say: We did but talk and jest. Say: Was it at Allah and His revelations and His messenger that ye did scoff?\qt@no{65}}%
\qt@newcmd\qurantrans@en@mccci{%
Make no excuse. Ye have disbelieved after your (confession of) belief. If We forgive a party of you, a party of you We shall punish because they have been guilty.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcccii{%
The hypocrites, both men and women, proceed one from another. They enjoin the wrong, and they forbid the right, and they withhold their hands (from spending for the cause of Allah). They forget Allah, so He hath forgotten them. Lo! the hypocrites, they are the transgressors.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mccciii{%
Allah promiseth the hypocrites, both men and women, and the disbelievers fire of hell for their abode. It will suffice them. Allah curseth them, and theirs is lasting torment.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mccciv{%
Even as those before you who were mightier than you in strength, and more affluent than you in wealth and children. They enjoyed their lot awhile, so ye enjoy your lot awhile even as those before you did enjoy their lot awhile. And ye prate even as they prated. Such are they whose works have perished in the world and the Hereafter. Such are they who are the losers.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcccv{%
Hath not the fame of those before them reached them - the folk of Noah, A'ad, Thamud, the folk of Abraham, the dwellers of Midian and the disasters (which befell them)? Their messengers (from Allah) came unto them with proofs (of Allah's Sovereignty). So Allah surely wronged them not, but they did wrong themselves.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcccvi{%
And the believers, men and women, are protecting friends one of another; they enjoin the right and forbid the wrong, and they establish worship and they pay the poor-due, and they obey Allah and His messenger. As for these, Allah will have mercy on them. Lo! Allah is Mighty, Wise.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcccvii{%
Allah promiseth to the believers, men and women, Gardens underneath which rivers flow, wherein they will abide - blessed dwellings in Gardens of Eden. And - greater (far)! - acceptance from Allah. That is the supreme triumph.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcccviii{%
O Prophet! Strive against the disbelievers and the hypocrites! Be harsh with them. Their ultimate abode is hell, a hapless journey's end.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcccix{%
They swear by Allah that they said nothing (wrong), yet they did say the word of disbelief, and did disbelieve after their Surrender (to Allah). And they purposed that which they could not attain, and they sought revenge only that Allah by His messenger should enrich them of His bounty. If they repent it will be better for them; and if they turn away, Allah will afflict them with a painful doom in the world and the Hereafter, and they have no protecting friend nor helper in the earth.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcccx{%
And of them is he who made a covenant with Allah (saying): If He give us of His bounty we will give alms and become of the righteous.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcccxi{%
Yet when He gave them of His bounty, they hoarded it and turned away, averse;\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcccxii{%
So He hath made the consequence (to be) hypocrisy in their hearts until the day when they shall meet Him, because they broke their word to Allah that they promised Him, and because they lied.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcccxiii{%
Know they not that Allah knoweth both their secret and the thought that they confide, and that Allah is the Knower of Things Hidden?\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcccxiv{%
Those who point at such of the believers as give the alms willingly and such as can find naught to give but their endeavours, and deride them - Allah (Himself) derideth them. Theirs will be a painful doom.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcccxv{%
Ask forgiveness for them (O Muhammad), or ask not forgiveness for them; though thou ask forgiveness for them seventy times Allah will not forgive them. That is because they disbelieved in Allah and His messenger, and Allah guideth not wrongdoing folk.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcccxvi{%
Those who were left behind rejoiced at sitting still behind the messenger of Allah, and were averse to striving with their wealth and their lives in Allah's way. And they said: Go not forth in the heat! Say: The fire of hell is more intense of heat, if they but understood.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcccxvii{%
Then let them laugh a little: they will weep much, as the reward of what they used to earn.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcccxviii{%
If Allah bring thee back (from the campaign) unto a party of them and they ask of thee leave to go out (to fight), then say unto them: Ye shall never more go out with me nor fight with me against a foe. Ye were content with sitting still the first time. So sit still, with the useless.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcccxix{%
And never (O Muhammad) pray for one of them who dieth, nor stand by his grave. Lo! they disbelieved in Allah and His messenger, and they died while they were evil-doers.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcccxx{%
Let not their wealth nor their children please thee! Allah purposeth only to punish them thereby in the world, and that their souls shall pass away while they are disbelievers.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcccxxi{%
And when a surah is revealed (which saith): Believe in Allah and strive along with His messenger, the men of wealth among them still ask leave of thee and say: Suffer us to be with those who sit (at home).\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcccxxii{%
They are content that they should be with the useless and their hearts are sealed, so that they apprehend not.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcccxxiii{%
But the messenger and those who believe with him strive with their wealth and their lives. Such are they for whom are the good things. Such are they who are the successful.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcccxxiv{%
Allah hath made ready for them Gardens underneath which rivers flow, wherein they will abide. That is the supreme triumph.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcccxxv{%
And those among the wandering Arabs who had an excuse came in order that permission might be granted them. And those who lied to Allah and His messenger sat at home. A painful doom will fall on those of them who disbelieve.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcccxxvi{%
Not unto the weak nor unto the sick nor unto those who can find naught to spend is any fault (to be imputed though they stay at home) if they are true to Allah and His messenger. Not unto the good is there any road (of blame). Allah is Forgiving, Merciful.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcccxxvii{%
Nor unto those whom, when they came to thee (asking) that thou shouldst mount them, thou didst tell: I cannot find whereon to mount you. They turned back with eyes flowing with tears, for sorrow that they could not find the means to spend.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcccxxviii{%
The road (of blame) is only against those who ask for leave of thee (to stay at home) when they are rich. They are content to be with the useless. Allah hath sealed their hearts so that they know not.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcccxxix{%
They will make excuse to you (Muslims) when ye return unto them. Say: Make no excuse, for we shall not believe you. Allah hath told us tidings of you. Allah and His messenger will see your conduct, and then ye will be brought back unto Him Who knoweth the Invisible as well as the Visible, and He will tell you what ye used to do.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcccxxx{%
They will swear by Allah unto you, when ye return unto them, that ye may let them be. Let them be, for lo! they are unclean, and their abode is hell as the reward for what they used to earn.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcccxxxi{%
They swear unto you, that ye may accept them. Though ye accept them. Allah verily accepteth not wrongdoing folk.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcccxxxii{%
The wandering Arabs are more hard in disbelief and hypocrisy, and more likely to be ignorant of the limits which Allah hath revealed unto His messenger. And Allah is Knower, Wise.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcccxxxiii{%
And of the wandering Arabs there is he who taketh that which he expendeth (for the cause of Allah) as a loss, and awaiteth (evil) turns of fortune for you (that he may be rid of it). The evil turn of fortune will be theirs. Allah is Hearer, Knower.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcccxxxiv{%
And of the wandering Arabs there is he who believeth in Allah and the Last Day, and taketh that which he expendeth and also the prayers of the messenger as acceptable offerings in the sight of Allah. Lo! verily it is an acceptable offering for them. Allah will bring them into His mercy. Lo! Allah is Forgiving, Merciful.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcccxxxv{%
And the first to lead the way, of the Muhajirin and the Ansar, and those who followed them in goodness - Allah is well pleased with them and they are well pleased with Him, and He hath made ready for them Gardens underneath which rivers flow, wherein they will abide for ever. That is the supreme triumph.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mcccxxxvi{%
And among those around you of the wandering Arabs there are hypocrites, and among the townspeople of Al-Madinah (there are some who) persist in hypocrisy whom thou (O Muhammad) knowest not. We, We know them, and We shall chastise them twice; then they will be relegated to a painful doom.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mcccxxxvii{%
And (there are) others who have acknowledged their faults. They mixed a righteous action with another that was bad. It may be that Allah will relent toward them. Lo! Allah is Forgiving, Merciful.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mcccxxxviii{%
Take alms of their wealth, wherewith thou mayst purify them and mayst make them grow, and pray for them. Lo! thy prayer is an assuagement for them. Allah is Hearer, Knower.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mcccxxxix{%
Know they not that Allah is He Who accepteth repentance from His bondmen and taketh the alms, and that Allah is He Who is the Relenting, the Merciful.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mcccxl{%
And say (unto them): Act! Allah will behold your actions, and (so will) His messenger and the believers, and ye will be brought back to the Knower of the Invisible and the Visible, and He will tell you what ye used to do.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mcccxli{%
And (there are) others who await Allah's decree, whether He will punish them or will forgive them. Allah is Knower, Wise.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mcccxlii{%
And as for those who chose a place of worship out of opposition and disbelief, and in order to cause dissent among the believers, and as an outpost for those who warred against Allah and His messenger aforetime, they will surely swear: We purposed naught save good. Allah beareth witness that they verily are liars.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mcccxliii{%
Never stand (to pray) there. A place of worship which was found upon duty (to Allah) from the first day is more worthy that thou shouldst stand (to pray) therein, wherein are men who love to purify themselves. Allah loveth the purifiers.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mcccxliv{%
Is he who founded his building upon duty to Allah and His good pleasure better; or he who founded his building on the brink of a crumbling, overhanging precipice so that it toppled with him into the fire of hell? Allah guideth not wrongdoing folk.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mcccxlv{%
The building which they built will never cease to be a misgiving in their hearts unless their hearts be torn to pieces. Allah is Knower, Wise.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mcccxlvi{%
Lo! Allah hath bought from the believers their lives and their wealth because the Garden will be theirs: they shall fight in the way of Allah and shall slay and be slain. It is a promise which is binding on Him in the Torah and the Gospel and the Qur'an. Who fulfilleth His covenant better than Allah? Rejoice then in your bargain that ye have made, for that is the supreme triumph.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mcccxlvii{%
(Triumphant) are those who turn repentant (to Allah), those who serve (Him), those who praise (Him), those who fast, those who bow down, those who fall prostrate (in worship), those who enjoin the right and who forbid the wrong and those who keep the limits (ordained) of Allah - And give glad tidings to believers!\qt@no{112}}%
\qt@newcmd\qurantrans@en@mcccxlviii{%
It is not for the Prophet, and those who believe, to pray for the forgiveness of idolaters even though they may be near of kin (to them) after it hath become clear that they are people of hell-fire.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mcccxlix{%
The prayer of Abraham for the forgiveness of his father was only because of a promise he had promised him, but when it had become clear unto him that he (his father) was an enemy to Allah he (Abraham) disowned him. Lo! Abraham was soft of heart, long-suffering.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mcccl{%
It was never Allah's (part) that He should send a folk astray after He had guided them until He had made clear unto them what they should avoid. Lo! Allah is Aware of all things.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mcccli{%
Lo! Allah! Unto Him belongeth the Sovereignty of the heavens and the earth. He quickeneth and He giveth death. And ye have, instead of Allah, no protecting friend nor helper.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mccclii{%
Allah hath turned in mercy to the Prophet, and to the Muhajirin and the Ansar who followed him in the hour of hardship. After the hearts of a party of them had almost swerved aside, then turned He unto them in mercy. Lo! He is Full of Pity, Merciful for them.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mcccliii{%
And to the three also (did He turn in mercy) who were left behind, when the earth, vast as it is, was straitened for them, and their own souls were straitened for them till they bethought them that there is no refuge from Allah save toward Him. Then turned He unto them in mercy that they (too) might turn (repentant unto Him). Lo! Allah! He is the Relenting, the Merciful.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mcccliv{%
O ye who believe! Be careful of your duty to Allah, and be with the truthful.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mccclv{%
It is not for the townsfolk of Al-Madinah and for those around them of the wandering Arabs so stay behind the messenger of Allah and prefer their lives to his life. That is because neither thirst nor toil nor hunger afflicteth them in the way of Allah, nor step they any step that angereth the disbelievers, nor gain they from the enemy a gain, but a good deed is recorded for them therefor. Lo! Allah loseth not the wages of the good.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mccclvi{%
Nor spend they any spending, small or great, nor do they cross a valley, but it is recorded for them, that Allah may repay them the best of what they used to do.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mccclvii{%
And the believers should not all go out to fight. Of every troop of them, a party only should go forth, that they (who are left behind) may gain sound knowledge in religion, and that they may warn their folk when they return to them, so that they may beware.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mccclviii{%
O ye who believe! Fight those of the disbelievers who are near to you, and let them find harshness in you, and know that Allah is with those who keep their duty (unto Him).\qt@no{123}}%
\qt@newcmd\qurantrans@en@mccclix{%
And whenever a surah is revealed there are some of them who say: Which one of you hath thus increased in faith? As for those who believe, it hath increased them in faith and they rejoice (therefor).\qt@no{124}}%
\qt@newcmd\qurantrans@en@mccclx{%
But as for those in whose hearts is disease, it only addeth wickedness to their wickedness, and they die while they are disbelievers.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mccclxi{%
See they not that they are tested once or twice in every year? Still they turn not in repentance, neither pay they heed.\qt@no{126}}%
\qt@newcmd\qurantrans@en@mccclxii{%
And whenever a surah is revealed, they look one at another (as who should say): Doth anybody see you? Then they turn away. Allah turneth away their hearts because they are a folk who understand not.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mccclxiii{%
There hath come unto you a messenger, (one) of yourselves, unto whom aught that ye are overburdened is grievous, full of concern for you, for the believers full of pity, merciful.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mccclxiv{%
Now, if they turn away (O Muhammad) say: Allah sufficeth me. There is no Allah save Him. In Him have I put my trust, and He is Lord of the Tremendous Throne.\qt@no{129}}%
\qt@newcmd\qurantrans@en@mccclxv{%
\basmalahen Alif. Lam. Ra. These are verses of the Wise Scripture.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mccclxvi{%
Is it a wonder for mankind that We have inspired a man among them, saying: Warn mankind and bring unto those who believe the good tidings that they have a sure footing with their Lord? The disbelievers say: Lo! this is a mere wizard.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mccclxvii{%
Lo! your Lord is Allah Who created the heavens and the earth in six Days, then He established Himself upon the Throne, directing all things. There is no intercessor (with Him) save after His permission. That is Allah, your Lord, so worship Him. Oh, will ye not remind?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mccclxviii{%
Unto Him is the return of all of you; it is a promise of Allah in truth. Lo! He produceth creation, then reproduceth it, that He may reward those who believe and do good works with equity; while, as for those who disbelieve, theirs will be a boiling drink and painful doom because they disbelieved.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mccclxix{%
He it is Who appointed the sun a splendour and the moon a light, and measured for her stages, that ye might know the number of the years, and the reckoning. Allah created not (all) that save in truth. He detaileth the revelations for people who have knowledge.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mccclxx{%
Lo! in the difference of day and night and all that Allah hath created in the heavens and the earth are portents, verily, for folk who ward off (evil).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mccclxxi{%
Lo! those who expect not the meeting with Us but desire the life of the world and feel secure therein, and those who are neglectful of Our revelations,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mccclxxii{%
Their home will be the Fire because of what they used to earn.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mccclxxiii{%
Lo! those who believe and do good works, their Lord guideth them by their faith. Rivers will flow beneath them in the Gardens of Delight,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mccclxxiv{%
Their prayer therein will be: Glory be to Thee, O Allah! and their greeting therein will be: Peace. And the conclusion of their prayer will be: Praise be to Allah, Lord of the Worlds!\qt@no{10}}%
\qt@newcmd\qurantrans@en@mccclxxv{%
If Allah were to hasten on for men the ill (that they have earned) as they would hasten on the good, their respite would already have expired. But We suffer those who look not for the meeting with Us to wander blindly on in their contumacy.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mccclxxvi{%
And if misfortune touch a man he crieth unto Us, (while reclining) on his side, or sitting or standing, but when We have relieved him of the misfortune he goeth his way as though he had not cried unto Us because of a misfortune that afflicted him. Thus is what they do made (seeming) fair unto the prodigal.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mccclxxvii{%
We destroyed the generations before you when they did wrong; and their messengers (from Allah) came unto them with clear proofs (of His Sovereignty) but they would not believe. Thus do We reward the guilty folk.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mccclxxviii{%
Then We appointed you viceroys in the earth after them, that We might see how ye behave.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mccclxxix{%
And when Our clear revelations are recited unto them, they who look not for the meeting with Us say: Bring a Lecture other than this, or change it. Say (O Muhammad): It is not for me to change it of my accord. I only follow that which is inspired in me. Lo! if I disobey my Lord I fear the retribution of an awful Day.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mccclxxx{%
Say: If Allah had so willed I should not have recited it to you nor would He have made it known to you. I dwelt among you a whole lifetime before it (came to me). Have ye then no sense?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mccclxxxi{%
Who doeth greater wrong than he who inventeth a lie concerning Allah and denieth His revelations? Lo! the guilty never are successful.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mccclxxxii{%
They worship beside Allah that which neither hurteth them nor profiteth them, and they say: These are our intercessors with Allah. Say: Would ye inform Allah of (something) that He knoweth not in the heavens or in the earth? Praised be He and High Exalted above all that ye associate (with Him)!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mccclxxxiii{%
Mankind were but one community; then they differed; and had it not been for a word that had already gone forth from thy Lord it had been judged between them in respect of that wherein they differ.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mccclxxxiv{%
And they will say: If only a portent were sent down upon him from his Lord! Then say, (O Muhammad): The Unseen belongeth to Allah. So wait! Lo! I am waiting with you.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mccclxxxv{%
And when We cause mankind to taste of mercy after some adversity which had afflicted them, behold! they have some plot against Our revelations. Say: Allah is more swift in plotting. Lo! Our messengers write down that which ye plot.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mccclxxxvi{%
He it is Who maketh you to go on the land and the sea till, when ye are in the ships and they sail with them with a fair breeze and they are glad therein, a storm-wind reacheth them and the wave cometh unto them from every side and they deem that they are overwhelmed therein; (then) they cry unto Allah, making their faith pure for Him only: If Thou deliver us from this, we truly will be of the thankful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mccclxxxvii{%
Yet when He hath delivered them, behold! they rebel in the earth wrongfully. O mankind! Your rebellion is only against yourselves. (Ye have) enjoyment of the life of the world; then unto Us is your return and We shall proclaim unto you what ye used to do.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mccclxxxviii{%
The similitude of the life of the world is only as water which We send down from the sky, then the earth's growth of that which men and cattle eat mingleth with it till, when the earth hath taken on her ornaments and is embellished, and her people deem that they are masters of her, Our commandment cometh by night or by day and We make it as reaped corn as if it had not flourished yesterday. Thus do we expound the revelations for people who reflect.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mccclxxxix{%
And Allah summoneth to the abode of peace, and leadeth whom He will to a straight path.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcccxc{%
For those who do good is the best (reward) and more (thereto). Neither dust nor ignominy cometh near their faces. Such are rightful owners of the Garden; they will abide therein.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcccxci{%
And those who earn ill-deeds, (for them) requital of each ill-deed by the like thereof; and ignominy overtaketh them - They have no protector from Allah - as if their faces had been covered with a cloak of darkest night. Such are rightful owners of the Fire; they will abide therein.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcccxcii{%
On the day when We gather them all together, then We say unto those who ascribed partners (unto Us): Stand back, ye and your (pretended) partners (of Allah)! And We separate them, the one from the other, and their (pretended) partners say: It was not us ye worshipped.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcccxciii{%
Allah sufficeth as a witness between us and you, that we were unaware of your worship.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcccxciv{%
There doth every soul experience that which it did aforetime, and they are returned unto Allah, their rightful Lord, and that which they used to invent hath failed them.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcccxcv{%
Say (unto them, O Muhammad): Who provideth for you from the sky and the earth, or Who owneth hearing and sight; and Who bringeth forth the living from the dead and bringeth forth the dead from the living; and Who directeth the course? They will say: Allah. Then say: Will ye not then keep your duty (unto Him)?\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcccxcvi{%
Such then is Allah, your rightful Lord. After the Truth what is there saving error? How then are ye turned away!\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcccxcvii{%
Thus is the Word of thy Lord justified concerning those who do wrong: that they believe not.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcccxcviii{%
Say: Is there of your partners (whom ye ascribe unto Allah) one that produceth Creation and then reproduceth it? Say: Allah produceth Creation, then reproduceth it. How then, are ye misled!\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcccxcix{%
Say: Is there of your partners (whom ye ascribe unto Allah) one that leadeth to the Truth? Say: Allah leadeth to the Truth. Is He Who leadeth to the Truth more deserving that He should be followed, or he who findeth not the way unless he (himself) be guided. What aileth you? How judge ye?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcd{%
Most of them follow not but conjecture. Assuredly conjecture can by no means take the place of truth. Lo! Allah is Aware of what they do.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcdi{%
And this Qur'an is not such as could ever be invented in despite of Allah; but it is a confirmation of that which was before it and an exposition of that which is decreed for mankind - Therein is no doubt - from the Lord of the Worlds.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcdii{%
Or say they: He hath invented it? Say: Then bring a surah like unto it, and call (for help) on all ye can besides Allah, if ye are truthful.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcdiii{%
Nay, but they denied that, the knowledge whereof they could not compass, and whereof the interpretation (in events) hath not yet come unto them. Even so did those before them deny. Then see what was the consequence for the wrong-doers!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcdiv{%
And of them is he who believeth therein, and of them is he who believeth not therein, and thy Lord is Best Aware of the corrupters.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcdv{%
And if they deny thee, say: Unto me my work, and unto you your work. Ye are innocent of what I do, and I am innocent of what ye do.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcdvi{%
And of them are some who listen unto thee. But canst thou make the deaf to hear even though they apprehend not?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcdvii{%
And of them is he who looketh toward thee. But canst thou guide the blind even though they see not?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcdviii{%
Lo! Allah wrongeth not mankind in aught; but mankind wrong themselves.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcdix{%
And on the day when He shall gather them together, (when it will seem) as though they had tarried but an hour of the day, recognising one another, those will verily have perished who denied the meeting with Allah and were not guided.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcdx{%
Whether We let thee (O Muhammad) behold something of that which We promise them or (whether We) cause thee to die, still unto Us is their return, and Allah, moreover, is Witness over what they do.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcdxi{%
And for every nation there is a messenger. And when their messenger cometh (on the Day of Judgment) it will be judged between them fairly, and they will not be wronged.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcdxii{%
And they say: When will this promise be fulfilled, if ye are truthful?\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcdxiii{%
Say: I have no power to hurt or benefit myself, save that which Allah willeth. For every nation there is an appointed time. When their time cometh, then they cannot put it off an hour, nor hasten (it).\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcdxiv{%
Say: Have ye thought: When His doom cometh unto you as a raid by night, or in the (busy) day; what is there of it that the guilty ones desire to hasten?\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcdxv{%
Is it (only) then, when it hath befallen you, that ye will believe? What! (Believe) now, when (until now) ye have been hastening it on (through disbelief)?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcdxvi{%
Then will it be said unto those who dealt unjustly Taste the torment of eternity. Are ye requited aught save what ye used to earn?\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcdxvii{%
And they ask thee to inform them (saying): Is it true? Say: Yea, by my Lord, verily it is true, and ye cannot escape.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcdxviii{%
And if each soul that doeth wrong had all that is in the earth it would seek to ransom itself therewith; and they will feel remorse within them, when they see the doom. But it hath been judged between them fairly and they are not wronged.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mcdxix{%
Lo! verily all that is in the heavens and the earth is Allah's. Lo! verily Allah's promise is true. But most of them know not.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mcdxx{%
He quickeneth and giveth death, and unto Him ye will be returned.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mcdxxi{%
O mankind! There hath come unto you an exhortation from your Lord, a balm for that which is in the breasts, a guidance and a mercy for believers.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mcdxxii{%
Say: In the bounty of Allah and in His mercy: therein let them rejoice. It is better than what they hoard.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mcdxxiii{%
Say: Have ye considered what provision Allah hath sent down for you, how ye have made of it lawful and unlawful? Hath Allah permitted you, or do ye invent a lie concerning Allah?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mcdxxiv{%
And what think those who invent a lie concerning Allah (will be their plight) upon the Day of Resurrection? Lo! Allah truly is Bountiful toward mankind, but most of them give not thanks.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mcdxxv{%
And thou (Muhammad) art not occupied with any business and thou recitest not a Lecture from this (Scripture), and ye (mankind) perform no act, but We are Witness of you when ye are engaged therein. And not an atom's weight in the earth or in the sky escapeth your Lord, nor what is less than that or greater than that, but it is (written) in a clear Book.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mcdxxvi{%
Lo! verily the friends of Allah are (those) on whom fear (cometh) not, nor do they grieve?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mcdxxvii{%
Those who believe and keep their duty (to Allah).\qt@no{63}}%
\qt@newcmd\qurantrans@en@mcdxxviii{%
Theirs are good tidings in the life of the world and in the Hereafter - There is no changing the Words of Allah - that is the Supreme Triumph.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mcdxxix{%
And let not their speech grieve thee (O Muhammad). Lo! power belongeth wholly to Allah. He is the Hearer, the Knower.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mcdxxx{%
Lo! is it not unto Allah that belongeth whosoever is in the heavens and whosoever is in the earth? Those who follow aught instead of Allah follow not (His) partners. They follow only a conjecture, and they do but guess.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcdxxxi{%
He it is Who hath appointed for you the night that ye should rest therein and the day giving sight. Lo! herein verily are portents for a folk that heed.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mcdxxxii{%
They say: Allah hath taken (unto Him) a son - Glorified be He! He hath no needs! His is all that is in the heavens and all that is in the earth. Ye have no warrant for this. Tell ye concerning Allah that which ye know not?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mcdxxxiii{%
Say: Verily those who invent a lie concerning Allah will not succeed.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcdxxxiv{%
This world's portion (will be theirs), then unto Us is their return. Then We make them taste a dreadful doom because they used to disbelieve.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcdxxxv{%
Recite unto them the story of Noah, when he told his people: O my people! If my sojourn (here) and my reminding you by Allah's revelations are an offence unto you, in Allah have I put my trust, so decide upon your course of action you and your partners. Let not your course of action be in doubt for you. Then have at me, give me no respite.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcdxxxvi{%
But if ye are averse I have asked of you no wage. My wage is the concern of Allah only, and I am commanded to be of those who surrender (unto Him).\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcdxxxvii{%
But they denied him, so We saved him and those with him in the ship, and made them viceroys (in the earth), while We drowned those who denied Our revelations. See then the nature of the consequence for those who had been warned.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcdxxxviii{%
Then, after him, We sent messengers unto their folk, and they brought them clear proofs. But they were not ready to believe in that which they before denied. Thus print We on the hearts of the transgressors.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcdxxxix{%
Then, after them, We sent Moses and Aaron unto Pharaoh and his chiefs with Our revelations, but they were arrogant and were a guilty folk.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcdxl{%
And when the Truth from Our presence came unto them, they said: Lo! this is mere magic.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcdxli{%
Moses said: Speak ye (so) of the Truth when it hath come unto you? Is this magic? Now magicians thrive not.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcdxlii{%
They said: Hast thou come unto us to pervert us from that (faith) in which we found our fathers, and that you two may own the place of greatness in the land? We will not believe you two.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcdxliii{%
And Pharaoh said: Bring every cunning wizard unto me.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcdxliv{%
And when the wizards came, Moses said unto them: Cast your cast!\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcdxlv{%
And when they had cast, Moses said: That which ye have brought is magic. Lo! Allah will make it vain. Lo! Allah upholdeth not the work of mischief-makers.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcdxlvi{%
And Allah will vindicate the Truth by His words, however much the guilty be averse.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcdxlvii{%
But none trusted Moses, save some scions of his people, (and they were) in fear of Pharaoh and their chiefs, that he would persecute them. Lo! Pharaoh was verily a tyrant in the land, and lo! he verily was of the wanton.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcdxlviii{%
And Moses said: O my people! If ye have believed in Allah then put trust in Him, if ye have indeed surrendered (unto Him)!\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcdxlix{%
They said: In Allah we put trust. Our Lord! Oh, make us not a lure for the wrongdoing folk;\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcdl{%
And, of Thy mercy, save us from the folk that disbelieve.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcdli{%
And We inspired Moses and his brother, (saying): Appoint houses for your people in Egypt and make your houses oratories, and establish worship. And give good news to the believers.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcdlii{%
And Moses said: Our Lord! Lo! Thou hast given Pharaoh and his chiefs splendour and riches in the life of the world, Our Lord! that they may lead men astray from Thy way. Our Lord! Destroy their riches and harden their hearts so that they believe not till they see the painful doom.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcdliii{%
He said: Your prayer is heard. Do ye twain keep to the straight path, and follow not the road of those who have no knowledge.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcdliv{%
And We brought the Children of Israel across the sea, and Pharaoh with his hosts pursued them in rebellion and transgression, till, when the (fate of) drowning overtook him, he exclaimed: I believe that there is no Allah save Him in Whom the Children of Israel believe, and I am of those who surrender (unto Him).\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcdlv{%
What! Now! When hitherto thou hast rebelled and been of the wrong-doers?\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcdlvi{%
But this day We save thee in thy body that thou mayst be a portent for those after thee. Lo! most of mankind are heedless of Our portents.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcdlvii{%
And We verily did allot unto the Children of Israel a fixed abode, and did provide them with good things; and they differed not until the knowledge came unto them. Lo! thy Lord will judge between them on the Day of Resurrection concerning that wherein they used to differ.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcdlviii{%
And if thou (Muhammad) art in doubt concerning that which We reveal unto thee, then question those who read the Scripture (that was) before thee. Verily the Truth from thy Lord hath come unto thee. So be not thou of the waverers.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcdlix{%
And be not thou of those who deny the revelations of Allah, for then wert thou of the losers.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcdlx{%
Lo! those for whom the word of thy Lord (concerning sinners) hath effect will not believe,\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcdlxi{%
Though every token come unto them, till they see the painful doom.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcdlxii{%
If only there had been a community (of all those that were destroyed of old) that believed and profited by its belief as did the folk of Jonah! When they believed We drew off from them the torment of disgrace in the life of the world and gave them comfort for a while.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcdlxiii{%
And if thy Lord willed, all who are in the earth would have believed together. Wouldst thou (Muhammad) compel men until they are believers?\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcdlxiv{%
It is not for any soul to believe save by the permission of Allah. He hath set uncleanness upon those who have no sense.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mcdlxv{%
Say: Behold what is in the heavens and the earth! But revelations and warnings avail not folk who will not believe.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mcdlxvi{%
What expect they save the like of the days of those who passed away before them? Say: Expect then! I am with you among the expectant.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mcdlxvii{%
Then shall We save Our messengers and the believers, in like manner (as of old). It is incumbent upon Us to save believers.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mcdlxviii{%
Say (O Muhammad): O mankind! If ye are in doubt of my religion, then (know that) I worship not those whom ye worship instead of Allah, but I worship Allah Who causeth you to die, and I have been commanded to be of the believers.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mcdlxix{%
And, (O Muhammad) set thy purpose resolutely for religion, as a man by nature upright, and be not of those who ascribe partners (to Allah).\qt@no{105}}%
\qt@newcmd\qurantrans@en@mcdlxx{%
And cry not, beside Allah, unto that which cannot profit thee nor hurt thee, for if thou didst so then wert thou of the wrong-doers.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mcdlxxi{%
If Allah afflicteth thee with some hurt, there is none who can remove it save Him; and if He desireth good for thee, there is none who can repel His bounty. He striketh with it whom He will of his bondmen. He is the Forgiving, the Merciful.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mcdlxxii{%
Say: O mankind! Now hath the Truth from your Lord come unto you. So whosoever is guided, is guided only for (the good of) his soul, and whosoever erreth erreth only against it. And I am not a warder over you.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mcdlxxiii{%
And (O Muhammad) follow that which is inspired in thee, and forbear until Allah give judgment. And He is the Best of Judges.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mcdlxxiv{%
\basmalahen Alif. Lam. Ra. (This is) a Scripture the revelations whereof are perfected and then expounded. (It cometh) from One Wise, Informed,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mcdlxxv{%
(Saying): Serve none but Allah. Lo! I am unto you from Him a warner and a bringer of good tidings.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mcdlxxvi{%
And (bidding you): Ask pardon of your Lord and turn to Him repentant. He will cause you to enjoy a fair estate until a time appointed. He giveth His bounty unto every bountiful one. But if ye turn away, lo! (then) I fear for you the retribution of an awful Day.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mcdlxxvii{%
Unto Allah is your return, and He is Able to do all things.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mcdlxxviii{%
Lo! now they fold up their breasts that they may hide (their thoughts) from Him. At the very moment when they cover themselves with their clothing, Allah knoweth that which they keep hidden and that which they proclaim. Lo! He is Aware of what is in the breasts (of men).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mcdlxxix{%
And there is not a beast in the earth but the sustenance thereof dependeth on Allah. He knoweth its habitation and its repository. All is in a clear Record.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mcdlxxx{%
And He it is Who created the heavens and the earth in six Days - and His Throne was upon the water - that He might try you, which of you is best in conduct. Yet if thou (O Muhammad) sayest: Lo! ye will be raised again after death! those who disbelieve will surely say: This is naught but mere magic.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mcdlxxxi{%
And if We delay for them the doom until a reckoned time, they will surely say: What withholdeth it? Verily on the day when it cometh unto them, it cannot be averted from them, and that which they derided will surround them.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mcdlxxxii{%
And if we cause man to taste some mercy from Us and afterward withdraw it from him, lo! he is despairing, thankless.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mcdlxxxiii{%
And if We cause him to taste grace after some misfortune that had befallen him, he saith: The ills have gone from me. Lo! he is exultant, boastful;\qt@no{10}}%
\qt@newcmd\qurantrans@en@mcdlxxxiv{%
Save those who persevere and do good works. Theirs will be forgiveness and a great reward.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mcdlxxxv{%
A likely thing, that thou wouldst forsake aught of that which hath been revealed unto thee, and that thy breast should be straitened for it, because they say: Why hath not a treasure been sent down for him, or an angel come with him? Thou art but a warner, and Allah is in charge of all things.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mcdlxxxvi{%
Or they say: He hath invented it. Say: Then bring ten surahs, the like thereof, invented, and call on everyone ye can beside Allah, if ye are truthful!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mcdlxxxvii{%
And if they answer not your prayer, then know that it is revealed only in the knowledge of Allah; and that there is no Allah save Him. Will ye then be (of) those who surrender?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mcdlxxxviii{%
Whoso desireth the life of the world and its pomp, We shall repay them their deeds herein, and therein they will not be wronged.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mcdlxxxix{%
Those are they for whom is naught in the Hereafter save the Fire. (All) that they contrive here is vain and (all) that they are wont to do is fruitless.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcdxc{%
Is he (to be counted equal with them) who relieth on a clear proof from his Lord, and a witness from Him reciteth it, and before it was the Book of Moses, an example and a mercy? Such believe therein, and whoso disbelieveth therein of the clans, the Fire is his appointed place. So be not thou in doubt concerning it. Lo! it is the Truth from thy Lord; but most of mankind believe not.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mcdxci{%
Who doeth greater wrong than he who inventeth a lie concerning Allah? Such will be brought before their Lord, and the witnesses will say: These are they who lied concerning their Lord. Now the curse of Allah is upon wrong-doers,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mcdxcii{%
Who debar (men) from the way of Allah and would have it crooked, and who are disbelievers in the Hereafter.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcdxciii{%
Such will not escape in the earth, nor have they any protecting friends beside Allah. For them the torment will be double. They could not bear to hear, and they used not to see.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcdxciv{%
Such are they who have lost their souls, and that which they used to invent hath failed them.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcdxcv{%
Assuredly in the Hereafter they will be the greatest losers.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcdxcvi{%
Lo! those who believe and do good works and humble themselves before their Lord: such are rightful owners of the Garden; they will abide therein.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcdxcvii{%
The similitude of the two parties is as the blind and the deaf and the seer and the hearer. Are they equal in similitude? Will ye not then be admonished?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcdxcviii{%
And We sent Noah unto his folk (and he said): Lo! I am a plain warner unto you.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcdxcix{%
That ye serve none, save Allah. Lo! I fear for you the retribution of a painful Day.\qt@no{26}}%
\qt@newcmd\qurantrans@en@md{%
The chieftains of his folk, who disbelieved, said: We see thee but a mortal like us, and we see not that any follow thee save the most abject among us, without reflection. We behold in you no merit above us - nay, we deem you liars.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdi{%
He said: O my people! Bethink you, if I rely on a clear proof from my Lord and there hath come unto me a mercy from His presence, and it hath been made obscure to you, can we compel you to accept it when ye are averse thereto?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdii{%
And O my people! I ask of you no wealth therefor. My reward is the concern only of Allah, and I am not going to thrust away those who believe - Lo! they have to meet their Lord! - but I see you a folk that are ignorant.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdiii{%
And, O my people! who would deliver me from Allah if I thrust them away? Will ye not then reflect?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdiv{%
I say not unto you: ``I have the treasures of Allah" nor ``I have knowledge of the Unseen," nor say I: ``Lo! I am an angel!" Nor say I unto those whom your eyes scorn that Allah will not give them good - Allah knoweth best what is in their hearts - Lo! then indeed I should be of the wrong-doers.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdv{%
They said: O Noah! Thou hast disputed with us and multiplied disputation with us; now bring upon us that wherewith thou threatenest us, if thou art of the truthful.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdvi{%
He said: Only Allah will bring it upon you if He will, and ye can by no means escape.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdvii{%
My counsel will not profit you if I were minded to advise you, if Allah's will is to keep you astray. He is your Lord and unto Him ye will be brought back.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdviii{%
Or say they (again): He hath invented it? Say: If I have invented it, upon me be my crimes, but I am innocent of (all) that ye commit.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdix{%
And it was inspired in Noah, (saying): No-one of thy folk will believe save him who hath believed already. Be not distressed because of what they do.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdx{%
Build the ship under Our eyes and by Our inspiration, and speak not unto Me on behalf of those who do wrong. Lo! they will be drowned.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdxi{%
And he was building the ship, and every time that chieftains of his people passed him, they made mock of him. He said: Though ye make mock of Us, yet We mock at you even as ye mock;\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdxii{%
And ye shall know to whom a punishment that will confound him cometh, and upon whom a lasting doom will fall.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdxiii{%
(Thus it was) till, when Our commandment came to pass and the oven gushed forth water, We said: Load therein two of every kind, a pair (the male and female), and thy household, save him against whom the word hath gone forth already, and those who believe. And but a few were they who believed with him.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdxiv{%
And he said: Embark therein! In the name of Allah be its course and its mooring. Lo! my Lord is Forgiving, Merciful.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdxv{%
And it sailed with them amid waves like mountains, and Noah cried unto his son - and he was standing aloof - O my son! Come ride with us, and be not with the disbelievers.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdxvi{%
He said: I shall betake me to some mountain that will save me from the water. (Noah) said: This day there is none that saveth from the commandment of Allah save him on whom He hath had mercy. And the wave came in between them, so he was among the drowned.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdxvii{%
And it was said: O earth! Swallow thy water and, O sky! be cleared of clouds! And the water was made to subside. And the commandment was fulfilled. And it (the ship) came to rest upon (the mount) Al-Judi and it was said: A far removal for wrongdoing folk!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdxviii{%
And Noah cried unto his Lord and said: My Lord! Lo! my son is of my household! Surely Thy promise is the truth and Thou are the Most Just of Judges.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdxix{%
He said: O Noah! Lo! he is not of thy household; lo! he is of evil conduct, so ask not of Me that whereof thou hast no knowledge. I admonish thee lest thou be among the ignorant.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdxx{%
He said: My Lord! Lo! in Thee do I seek refuge (from the sin) that I should ask of Thee that whereof I have no knowledge. Unless Thou forgive me and have mercy on me I shall be among the lost.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdxxi{%
It was said (unto him): O Noah! Go thou down (from the mountain) with peace from Us and blessings upon thee and some nations (that will spring) from those with thee. (There will be other) nations unto whom We shall give enjoyment a long while and then a painful doom from Us will overtake them.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdxxii{%
This is of the tidings of the Unseen which We inspire in thee (Muhammad). Thou thyself knewest it not, nor did thy folk (know it) before this. Then have patience. Lo! the sequel is for those who ward off (evil).\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdxxiii{%
And unto (the tribe of) A'ad (We sent) their brother, Hud. He said: O my people! Serve Allah! Ye have no other Allah save Him. Lo! ye do but invent.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdxxiv{%
O my people! I ask of you no reward for it. Lo! my reward is the concern only of Him Who made me. Have ye then no sense?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdxxv{%
And, O my people! Ask forgiveness of your Lord, then turn unto Him repentant; He will cause the sky to rain abundance on you and will add unto you strength to your strength. Turn not away, guilty!\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdxxvi{%
They said: O Hud! Thou hast brought us no clear proof and we are not going to forsake our gods on thy (mere) saying, and we are not believers in thee.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdxxvii{%
We say naught save that one of our gods hath possessed thee in an evil way. He said: I call Allah to witness, and do ye (too) bear witness, that I am innocent of (all) that ye ascribe as partners (to Allah)\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdxxviii{%
Beside Him. So (try to) circumvent me, all of you, give me no respite.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdxxix{%
Lo! I have put my trust in Allah, my Lord and your Lord. Not an animal but He doth grasp it by the forelock! Lo! my Lord is on a straight path.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdxxx{%
And if ye turn away, still I have conveyed unto you that wherewith I was sent unto you, and my Lord will set in place of you a folk other than you. Ye cannot injure Him at all. Lo! my Lord is Guardian over all things.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdxxxi{%
And when Our commandment came to pass We saved Hud and those who believed with him by a mercy from Us; We saved them from a harsh doom.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdxxxii{%
And such were A'ad. They denied the revelations of their Lord and flouted His messengers and followed the command of every froward potentate.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdxxxiii{%
And a curse was made to follow them in the world and on the Day of Resurrection. Lo! A'ad disbelieved in their Lord. A far removal for A'ad, the folk of Hud!\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdxxxiv{%
And unto (the tribe of) Thamud (We sent) their brother Salih. He said: O my people! Serve Allah, Ye have no other Allah save Him. He brought you forth from the earth and hath made you husband it. So ask forgiveness of Him and turn unto Him repentant. Lo! my Lord is Nigh, Responsive.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdxxxv{%
They said: O Salih! Thou hast been among us hitherto as that wherein our hope was placed. Dost thou ask us not to worship what our fathers worshipped? Lo! we verily are in grave doubt concerning that to which thou callest us.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdxxxvi{%
He said: O my people! Bethink you: if I am (acting) on clear proof from my Lord and there hath come unto me a mercy from Him, who will save me from Allah if I disobey Him? Ye would add to me naught save perdition.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdxxxvii{%
O my people! This is the camel of Allah, a token unto you, so suffer her to feed in Allah's earth, and touch her not with harm lest a near torment seize you.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdxxxviii{%
But they hamstrung her, and then he said: Enjoy life in your dwelling-place three days! This is a threat that will not be belied.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdxxxix{%
So, when Our commandment came to pass, We saved Salih, and those who believed with him, by a mercy from Us, from the ignominy of that day. Lo, thy Lord! He is the Strong, the Mighty.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdxl{%
And the (awful) Cry overtook those who did wrong, so that morning found them prostrate in their dwellings,\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdxli{%
As though they had not dwelt there. Lo! Thamud disbelieved in their Lord. A far removal for Thamud!\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdxlii{%
And Our messengers cam unto Abraham with good news. They said: Peace! He answered: Peace! and delayed not to bring a roasted calf.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdxliii{%
And when he saw their hands reached not to it, he mistrusted them and conceived a fear of them. They said: Fear not! Lo! we are sent unto the folk of Lot.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdxliv{%
And his wife, standing by laughed when We gave her good tidings (of the birth) of Isaac, and, after Isaac, of Jacob.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdxlv{%
She said: Oh woe is me! Shall I bear a child when I am an old woman, and this my husband is an old man? Lo! this is a strange thing!\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdxlvi{%
They said: Wonderest thou at the commandment of Allah? The mercy of Allah and His blessings be upon you, O people of the house! Lo! He is Owner of Praise, Owner of Glory!\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdxlvii{%
And when the awe departed from Abraham, and the glad news reached him, he pleaded with Us on behalf of the folk of Lot.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdxlviii{%
Lo! Abraham was mild, imploring, penitent.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdxlix{%
(It was said) O Abraham! Forsake this! Lo! thy Lord's commandment hath gone forth, and lo! there cometh unto them a doom which cannot be repelled.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdl{%
And when Our messengers came unto Lot, he was distressed and knew not how to protect them. He said: This is a distressful day.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdli{%
And his people came unto him, running towards him - and before then they used to commit abominations - He said: O my people! Here are my daughters! They are purer for you. Beware of Allah, and degrade me not in (the person of) my guests. Is there not among you any upright man?\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdlii{%
They said: Well thou knowest that we have no right to thy daughters, and well thou knowest what we want.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdliii{%
He said: Would that I had strength to resist you or had some strong support (among you)!\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdliv{%
(The messengers) said: O Lot! Lo! we are messengers of thy Lord; they shall not reach thee. So travel with thy people in a part of the night, and let not one of you turn round - (all) save thy wife. Lo! that which smiteth them will smite her (also). Lo! their tryst is (for) the morning. Is not the morning nigh?\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdlv{%
So when Our commandment came to pass We overthrew (that township) and rained upon it stones of clay, one after another,\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdlvi{%
Marked with fire in the providence of thy Lord (for the destruction of the wicked). And they are never far from the wrong-doers.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdlvii{%
And unto Midian (We sent) their brother Shu'eyb. He said: O my people! Serve Allah. Ye have no other Allah save Him! And give not short measure and short weight. Lo! I see you well-to-do, and lo! I fear for you the doom of a besetting Day.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdlviii{%
O my people! Give full measure and full weight in justice, and wrong not people in respect of their goods. And do not evil in the earth, causing corruption.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdlix{%
That which Allah leaveth with you is better for you if ye are believers; and I am not a keeper over you.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdlx{%
They said: O Shu'eyb! Doth thy way of prayer command thee that we should forsake that which our fathers (used to) worship, or that we (should leave off) doing what we will with our own property. Lo! thou art the mild, the guide to right behaviour.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdlxi{%
He said: O my people! Bethink you: if I am (acting) on a clear proof from my Lord and He sustaineth me with fair sustenance from Him (how can I concede aught to you)? I desire not to do behind your backs that which I ask you not to do. I desire naught save reform so far as I am able. My welfare is only in Allah. In Him I trust and unto Him I turn (repentant).\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdlxii{%
And, O my people! Let not the schism with me cause you to sin so that there befall you that which befell the folk of Noah and the folk of Hud, and the folk of Salih; and the folk of Lot are not far off from you.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdlxiii{%
Ask pardon of your Lord and then turn unto Him (repentant). Lo! my Lord is Merciful, Loving.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdlxiv{%
They said: O Shu'eyb! We understand not much of that thou tellest, and lo! we do behold thee weak among us. But for thy family, we should have stoned thee, for thou art not strong against us.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdlxv{%
He said: O my people! Is my family more to be honoured by you than Allah? and ye put Him behind you, neglected! Lo! my Lord surroundeth what ye do.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdlxvi{%
And, O my people! Act according to your power, lo! I (too) am acting. Ye will soon know on whom there cometh a doom that will abase him, and who it is that lieth. And watch! Lo! I am a watcher with you.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdlxvii{%
And when Our commandment came to pass We saved Shu'eyb and those who believed with him by a mercy from Us; and the (Awful) Cry seized those who did injustice, and morning found them prostrate in their dwellings,\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdlxviii{%
As though they had not dwelt there. A far removal for Midian, even as Thamud had been removed afar!\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdlxix{%
And verily We sent Moses with Our revelations and a clear warrant\qt@no{96}}%
\qt@newcmd\qurantrans@en@mdlxx{%
Unto Pharaoh and his chiefs, but they did follow the command of Pharaoh, and the command of Pharaoh was no right guide.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mdlxxi{%
He will go before his people on the Day of Resurrection and will lead them to the Fire for watering-place. Ah, hapless is the watering-place (whither they are) led.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mdlxxii{%
A curse is made to follow them in the world and on the Day of Resurrection. Hapless is the gift (that will be) given (them).\qt@no{99}}%
\qt@newcmd\qurantrans@en@mdlxxiii{%
That is (something) of the tidings of the townships (which were destroyed of old). We relate it unto thee (Muhammad). Some of them are standing and some (already) reaped.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mdlxxiv{%
We wronged them not, but they did wrong themselves; and their gods on whom they call beside Allah availed them naught when came thy Lord's command; they added to them naught save ruin.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mdlxxv{%
Even thus is the grasp of thy Lord when He graspeth the townships while they are doing wrong. Lo! His grasp is painful, very strong.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mdlxxvi{%
Lo! herein verily there is a portent for those who fear the doom of the Hereafter. That is a day unto which mankind will be gathered, and that is a day that will be witnessed.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mdlxxvii{%
And We defer it only to a term already reckoned.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mdlxxviii{%
On the day when it cometh no soul will speak except by His permission; some among them will be wretched, (others) glad.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mdlxxix{%
As for those who will be wretched (on that day) they will be in the Fire; sighing and wailing will be their portion therein,\qt@no{106}}%
\qt@newcmd\qurantrans@en@mdlxxx{%
Abiding there so long as the heavens and the earth endure save for that which thy Lord willeth. Lo! thy Lord is Doer of what He will.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mdlxxxi{%
And as for those who will be glad (that day) they will be in the Garden, abiding there so long as the heavens and the earth endure save for that which thy Lord willeth: a gift unfailing.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mdlxxxii{%
So be not thou in doubt concerning that which these (folk) worship. They worship only as their fathers worshipped aforetime. Lo! we shall pay them their whole due unabated.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mdlxxxiii{%
And we verily gave unto Moses the Scripture, and there was strife thereupon; and had it not been for a Word that had already gone forth from thy Lord, the case would have been judged between them, and lo! they are in grave doubt concerning it.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mdlxxxiv{%
And lo! unto each thy Lord will verily repay his works in full. Lo! He is Informed of what they do.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mdlxxxv{%
So tread thou the straight path as thou art commanded, and those who turn (unto Allah) with thee, and transgress not. Lo! He is Seer of what ye do.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mdlxxxvi{%
And incline not toward those who do wrong lest the Fire touch you, and ye have no protecting friends against Allah, and afterward ye would not be helped.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mdlxxxvii{%
Establish worship at the two ends of the day and in some watches of the night. Lo! good deeds annul ill-deeds. This is reminder for the mindful.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mdlxxxviii{%
And have patience, (O Muhammad), for lo! Allah loseth not the wages of the good.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mdlxxxix{%
If only there had been among the generations before you men possessing a remnant (of good sense) to warn (their people) from corruption in the earth, as did a few of those whom We saved from them! The wrong-doers followed that by which they were made sapless, and were guilty.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mdxc{%
In truth thy Lord destroyed not the townships tyrannously while their folk were doing right.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mdxci{%
And if thy Lord had willed, He verily would have made mankind one nation, yet they cease not differing,\qt@no{118}}%
\qt@newcmd\qurantrans@en@mdxcii{%
Save him on whom thy Lord hath mercy; and for that He did create them. And the Word of thy Lord hath been fulfilled: Verily I shall fill hell with the jinn and mankind together.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mdxciii{%
And all that We relate unto thee of the story of the messengers is in order that thereby We may make firm thy heart. And herein hath come unto thee the Truth and an exhortation and a reminder for believers.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mdxciv{%
And say unto those who believe not: Act according to your power. Lo! We (too) are acting.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mdxcv{%
And wait! Lo! We (too) are waiting.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mdxcvi{%
And Allah's is the Invisible of the heavens and the earth, and unto Him the whole matter will be returned. So worship Him and put thy trust in Him. Lo! thy Lord is not unaware of what ye (mortals) do.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mdxcvii{%
\basmalahen Alif. Lam. Ra. These are verse of the Scripture that maketh plain.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdxcviii{%
Lo! We have revealed it, a Lecture in Arabic, that ye may understand.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdxcix{%
We narrate unto thee (Muhammad) the best of narratives in that We have inspired in thee this Qur'an, though aforetime thou wast of the heedless.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdc{%
When Joseph said unto his father: O my father! Lo! I saw in a dream eleven planets and the sun and the moon, I saw them prostrating themselves unto me.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdci{%
He said: O my dear son! Tell not thy brethren of thy vision, lest they plot a plot against thee. Lo! Satan is for man an open foe.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcii{%
Thus thy Lord will prefer thee and will teach thee the interpretation of events, and will perfect His grace upon thee and upon the family of Jacob as He perfected it upon thy forefathers, Abraham and Isaac. Lo! thy Lord is Knower, Wise.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdciii{%
Verily in Joseph and his brethren are signs (of Allah's Sovereignty) for the inquiring.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdciv{%
When they said: Verily Joseph and his brother are dearer to our father than we are, many though we be. Lo! our father is in plain aberration.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcv{%
(One said): Kill Joseph or cast him to some (other) land, so that your father's favour may be all for you, and (that) ye may afterward be righteous folk.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcvi{%
One among them said: Kill not Joseph but, if ye must be doing, fling him into the depth of the pit; some caravan will find him.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcvii{%
They said: O our father! Why wilt thou not trust us with Joseph, when lo! we are good friends to him?\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcviii{%
Send him with us to-morrow that he may enjoy himself and play. And lo! we shall take good care of him.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcix{%
He said: Lo! in truth it saddens me that ye should take him with you, and I fear less the wolf devour him while ye are heedless of him.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcx{%
They said: If the wolf should devour him when we are (so strong) a band, then surely we should have already perished.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcxi{%
Then, when they led him off, and were of one mind that they should place him in the depth of the pit, We inspired in him: Thou wilt tell them of this deed of theirs when they know (thee) not.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcxii{%
And they came weeping to their father in the evening.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcxiii{%
Saying: O our father! We went racing one with another, and left Joseph by our things, and the wolf devoured him, and thou believest not our saying even when we speak the truth.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcxiv{%
And they came with false blood on his shirt. He said: Nay, but your minds have beguiled you into something. (My course is) comely patience. And Allah it is Whose help is to be sought in that (predicament) which ye describe.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcxv{%
And there came a caravan, and they sent their waterdrawer. He let down his pail (into the pit). He said: Good luck! Here is a youth. And they hid him as a treasure, and Allah was Aware of what they did.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcxvi{%
And they sold him for a low price, a number of silver coins; and they attached no value to him.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcxvii{%
And he of Egypt who purchased him said unto his wife: Receive him honourably. Perchance he may prove useful to us or we may adopt him as a son. Thus we established Joseph in the land that We might teach him the interpretation of events. And Allah was predominant in His career, but most of mankind know not.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcxviii{%
And And when he reached his prime We gave him wisdom and knowledge. Thus We reward the good.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcxix{%
And she, in whose house he was, asked of him an evil act. She bolted the doors and said: Come! He said: I seek refuge in Allah! Lo! he is my lord, who hath treated me honourably. Lo! wrong-doers never prosper.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcxx{%
She verily desired him, and he would have desired her if it had not been that he saw the argument of his Lord. Thus it was, that We might ward off from him evil and lewdness. Lo! he was of Our chosen slaves.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcxxi{%
And they raced with one another to the door, and she tore his shirt from behind, and they met her lord and master at the door. She said: What shall be his reward, who wisheth evil to thy folk, save prison or a painful doom?\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcxxii{%
(Joseph) said: She it was who asked of me an evil act. And a witness of her own folk testified: If his shirt is torn from before, then she speaketh truth and he is of the liars.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcxxiii{%
And if his shirt is torn from behind, then she hath lied and he is of the truthful.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcxxiv{%
So when he saw his shirt torn from behind, he said: Lo! this is of the guile of you women. Lo! the guile of you is very great.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcxxv{%
O Joseph! Turn away from this, and thou, (O woman), ask forgiveness for thy sin. Lo! thou art of the faulty.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcxxvi{%
And women in the city said: The ruler's wife is asking of her slave-boy an ill-deed. Indeed he has smitten her to the heart with love. We behold her in plain aberration.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcxxvii{%
And when she heard of their sly talk, she sent to them and prepared for them a cushioned couch (to lie on at the feast) and gave to every one of them a knife and said (to Joseph): Come out unto them! And when they saw him they exalted him and cut their hands, exclaiming: Allah Blameless! This is no a human being. This is not other than some gracious angel.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcxxviii{%
She said: This is he on whose account ye blamed me. I asked of him an evil act, but he proved continent, but if he do not my behest he verily shall be imprisoned, and verily shall be of those brought low.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcxxix{%
He said: O my Lord! Prison is more dear than that unto which they urge me, and if Thou fend not off their wiles from me I shall incline unto them and become of the foolish.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcxxx{%
So his Lord heard his prayer and fended off their wiles from him. Lo! He is Hearer, Knower.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcxxxi{%
And it seemed good to them (the men-folk) after they had seen the signs (of his innocence) to imprison him for a time.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcxxxii{%
And two young men went to prison with him. One of them said: I dreamed that I was pressing wine. The other said: I dreamed that I was carrying upon my head bread whereof the birds were eating. Announce unto us the interpretation, for we see thee of those good (at interpretation).\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcxxxiii{%
He said: The food which ye are given (daily) shall not come unto you but I shall tell you the interpretation ere it cometh unto you. This is of that which my Lord hath taught me. Lo! I have forsaken the religion of folk who believe not in Allah and are disbelievers in the Hereafter.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcxxxiv{%
And I have followed the religion of my fathers, Abraham and Isaac and Jacob. It never was for us to attribute aught as partner to Allah. This is of the bounty of Allah unto us (the seed of Abraham) and unto mankind; but most men give not thanks.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcxxxv{%
O my fellow-prisoners! Are divers lords better, or Allah the One, Almighty?\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdcxxxvi{%
Those whom ye worship beside Him are but names which ye have named, ye and your fathers. Allah hath revealed no sanction for them. The decision rests with Allah only, Who hath commanded you that ye worship none save Him. This is the right religion, but most men know not.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdcxxxvii{%
O my two fellow-prisoners! As for one of you, he will pour out wine for his lord to drink; and as for the other, he will be crucified so that the birds will eat from his head. Thus is the case judged concerning which ye did inquire.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdcxxxviii{%
And he said unto him of the twain who he knew would be released: Mention me in the presence of thy lord. But Satan caused him to forget to mention it to his lord, so he (Joseph) stayed in prison for some years.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdcxxxix{%
And the king said: Lo! I saw in a dream seven fat kine which seven lean were eating, and seven green ears of corn and other (seven) dry. O notables! Expound for me my vision, if ye can interpret dreams.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdcxl{%
They answered: Jumbled dreams! And we are not knowing in the interpretation of dreams.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdcxli{%
And he of the two who was released, and (now) at length remembered, said: I am going to announce unto you the interpretation, therefore send me forth.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdcxlii{%
(And when he came to Joseph in the prison, he exclaimed): Joseph! O thou truthful one! Expound for us the seven fat kine which seven lean were eating and the seven green ears of corn and other (seven) dry, that I may return unto the people, so that they may know.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdcxliii{%
He said: Ye shall sow seven years as usual, but that which ye reap, leave it in the ear, all save a little which ye eat.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdcxliv{%
Then after that will come seven hard years which will devour all that ye have prepared for them, save a little of that which ye have stored.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdcxlv{%
Then, after that, will come a year when the people will have plenteous crops and when they will press (wine and oil).\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdcxlvi{%
And the king said: Bring him unto me. And when the messenger came unto him, he (Joseph) said: Return unto thy lord and ask him what was the case of the women who cut their hands. Lo! my Lord knoweth their guile.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdcxlvii{%
He (the king) (then sent for those women and) said: What happened when ye asked an evil act of Joseph? They answered: Allah Blameless! We know no evil of him. Said the wife of the ruler: Now the truth is out. I asked of him an evil act, and he is surely of the truthful.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcxlviii{%
(Then Joseph said: I asked for) this, that he (my lord) may know that I betrayed him not in secret, and that surely Allah guideth not the snare of the betrayers.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdcxlix{%
I do not exculpate myself. Lo! the (human) soul enjoineth unto evil, save that whereon my Lord hath mercy. Lo! my Lord is Forgiving, Merciful.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdcl{%
And the king said: Bring him unto me that I may attach him to my person. And when he had talked with him he said: Lo! thou art to-day in our presence established and trusted.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdcli{%
He said: Set me over the storehouses of the land. Lo! I am a skilled custodian.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdclii{%
Thus gave We power to Joseph in the land. He was the owner of it where he pleased. We reach with Our mercy whom We will. We lose not the reward of the good.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdcliii{%
And the reward of the Hereafter is better, for those who believe and ward off (evil).\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdcliv{%
And Joseph's brethren came and presented themselves before him, and he knew them but they knew him not.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdclv{%
And when he provided them with their provision he said: Bring unto me a brother of yours from your father. See ye not that I fill up the measure and I am the best of hosts?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdclvi{%
And if ye bring him not unto me, then there shall be no measure for you with me, nor shall ye draw near.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdclvii{%
They said: We will try to win him from his father: that we will surely do.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdclviii{%
He said unto his young men: Place their merchandise in their saddlebags, so that they may know it when they go back to their folk, and so will come again.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdclix{%
So when they went back to their father they said: O our father! The measure is denied us, so send with us our brother that we may obtain the measure, surely we will guard him well.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdclx{%
He said: Can I entrust him to you save as I entrusted his brother to you aforetime? Allah is better at guarding, and He is the Most Merciful of those who show mercy.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdclxi{%
And when they opened their belongings they discovered that their merchandise had been returned to them. They said: O our father! What (more) can we ask? Here is our merchandise returned to us. We shall get provision for our folk and guard our brother, and we shall have the extra measure of a camel (load). This (that we bring now) is a light measure.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdclxii{%
He said: I will not send him with you till ye give me an undertaking in the name of Allah that ye will bring him back to me, unless ye are surrounded. And when they gave him their undertaking he said: Allah is the Warden over what we say.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdclxiii{%
And he said: O my sons! Go not in by one gate; go in by different gates. I can naught avail you as against Allah. Lo! the decision rests with Allah only. In Him do I put my trust, and in Him let all the trusting put their trust.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdclxiv{%
And when they entered in the manner which their father had enjoined, it would have naught availed them as against Allah; it was but a need of Jacob's soul which he thus satisfied; and lo! he was a lord of knowledge because We had taught him; but most of mankind know not.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdclxv{%
And when they went in before Joseph, he took his brother unto him, saying: Lo! I, even I, am thy brother, therefore sorrow not for what they did.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdclxvi{%
And when he provided them with their provision, he put the drinking-cup in his brother's saddlebag, and then a crier cried: O camel-riders! Lo! ye are surely thieves!\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdclxvii{%
They cried, coming toward them: What is it ye have lost?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdclxviii{%
They said: We have lost the king's cup, and he who bringeth it shall have a camel-load, and I (said Joseph) am answerable for it.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdclxix{%
They said: By Allah, well ye know we came not to do evil in the land, and are no thieves.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdclxx{%
They said: And what shall be the penalty for it, if ye prove liars?\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdclxxi{%
They said: The penalty for it! He in whose bag (the cup) is found, he is the penalty for it. Thus we requite wrong-doers.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdclxxii{%
Then he (Joseph) began the search with their bags before his brother's bag, then he produced it from his brother's bag. Thus did We contrive for Joseph. He could not have taken his brother according to the king's law unless Allah willed. We raise by grades (of mercy) whom We will, and over every lord of knowledge there is one more knowing.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdclxxiii{%
They said: If he stealeth, a brother of his stole before. But Joseph kept it secret in his soul and revealed it not unto them. He said (within himself): Ye are in worse case, and Allah knoweth best (the truth of) that which ye allege.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdclxxiv{%
They said: O ruler of the land! Lo! he hath a very aged father, so take one of us instead of him. Lo! we behold thee of those who do kindness.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdclxxv{%
He said: Allah forbid that we should seize save him with whom we found our property; then truly we should be wrong-doers.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdclxxvi{%
So, When they despaired of (moving) him, they conferred together apart. The eldest of them said: Know ye not how your father took an undertaking from you in Allah's name and how ye failed in the case of Joseph aforetime? Therefore I shall not go forth from the land until my father giveth leave or Allah judgeth for me. He is the Best of Judges.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdclxxvii{%
Return unto your father and say: O our father! Lo! thy son hath stolen. We testify only to that which we know; we are not guardians of the Unseen.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdclxxviii{%
Ask the township where we were, and the caravan with which we travelled hither. Lo! we speak the truth.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdclxxix{%
(And when they came unto their father and had spoken thus to him) he said: Nay, but your minds have beguiled you into something. (My course is) comely patience! It may be that Allah will bring them all unto me. Lo! He, only He, is the Knower, the Wise.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdclxxx{%
And he turned away from them and said: Alas, my grief for Joseph! And his eyes were whitened with the sorrow that he was suppressing.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdclxxxi{%
They said: By Allah, thou wilt never cease remembering Joseph till thy health is ruined or thou art of those who perish!\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdclxxxii{%
He said: I expose my distress and anguish only unto Allah, and I know from Allah that which ye know not.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdclxxxiii{%
Go, O my sons, and ascertain concerning Joseph and his brother, and despair not of the Spirit of Allah. Lo! none despaireth of the Spirit of Allah save disbelieving folk.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdclxxxiv{%
And when they came (again) before him (Joseph) they said: O ruler! Misfortune hath touched us and our folk, and we bring but poor merchandise, so fill for us the measure and be charitable unto us. Lo! Allah will requite the charitable,\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdclxxxv{%
He said: Know ye what ye did unto Joseph and his brother in your ignorance?\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdclxxxvi{%
They said: Is it indeed thou who art Joseph? He said: I am Joseph and this is my brother. Allah hath shown us favour. Lo! he who wardeth off (evil) and endureth (findeth favour); for lo! Allah loseth not the wages of the kindly.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdclxxxvii{%
They said: By Allah, verily Allah hath preferred thee above us, and we were indeed sinful.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdclxxxviii{%
He said: Have no fear this day! May Allah forgive you, and He is the Most Merciful of those who show mercy.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdclxxxix{%
Go with this shirt of mine and lay it on my father's face, he will become (again) a seer; and come to me with all your folk.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdcxc{%
When the caravan departed their father had said: Truly I am conscious of the breath of Joseph, though ye call me dotard.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdcxci{%
(Those around him) said: By Allah, lo! thou art in thine old aberration.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdcxcii{%
Then, when the bearer of glad tidings came, he laid it on his face and he became a seer once more. He said: Said I not unto you that I know from Allah that which ye know not?\qt@no{96}}%
\qt@newcmd\qurantrans@en@mdcxciii{%
They said: O our father! Ask forgiveness of our sins for us, for lo! we were sinful.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mdcxciv{%
He said: I shall ask forgiveness for you of my Lord. Lo! He is the Forgiving, the Merciful.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mdcxcv{%
And when they came in before Joseph, he took his parents unto him, and said: Come into Egypt safe, if Allah will!\qt@no{99}}%
\qt@newcmd\qurantrans@en@mdcxcvi{%
And he placed his parents on the dais and they fell down before him prostrate, and he said: O my father! This is the interpretation of my dream of old. My Lord hath made it true, and He hath shown me kindness, since He took me out of the prison and hath brought you from the desert after Satan had made strife between me and my brethren. Lo! my Lord is tender unto whom He will. He is the Knower, the Wise.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mdcxcvii{%
O my Lord! Thou hast given me (something) of sovereignty and hast taught me (something) of the interpretation of events - Creator of the heavens and the earth! Thou art my Protecting Guardian in the world and the Hereafter. Make me to die muslim (unto Thee), and join me to the righteous.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mdcxcviii{%
This is of the tidings of the Unseen which We inspire in thee (Muhammad). Thou wast not present with them when they fixed their plan and they were scheming.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mdcxcix{%
And though thou try much, most men will not believe.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mdcc{%
Thou askest them no fee for it. It is naught else than a reminder unto the peoples.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mdcci{%
How many a portent is there in the heavens and the earth which they pass by with face averted!\qt@no{105}}%
\qt@newcmd\qurantrans@en@mdccii{%
And most of them believe not in Allah except that they attribute partners (unto Him).\qt@no{106}}%
\qt@newcmd\qurantrans@en@mdcciii{%
Deem they themselves secure from the coming on them of a pall of Allah's punishment, or the coming of the Hour suddenly while they are unaware?\qt@no{107}}%
\qt@newcmd\qurantrans@en@mdcciv{%
Say: This is my Way: I call on Allah with sure knowledge. I and whosoever followeth me - Glory be to Allah! - and I am not of the idolaters.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mdccv{%
We sent not before thee (any messengers) save men whom We inspired from among the folk of the townships - Have they not travelled in the land and seen the nature of the consequence for those who were before them? And verily the abode of the Hereafter, for those who ward off (evil), is best. Have ye then no sense? -\qt@no{109}}%
\qt@newcmd\qurantrans@en@mdccvi{%
Till, when the messengers despaired and thought that they were denied, then came unto them Our help, and whom We would was saved. And Our wrath cannot be warded from the guilty.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mdccvii{%
In their history verily there is a lesson for men of understanding. It is no invented story but a confirmation of the existing (Scripture) and a detailed explanation of everything, and a guidance and a mercy for folk who believe.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mdccviii{%
\basmalahen Alif. Lam. Mim. Ra. These are verses of the Scripture. That which is revealed unto thee from thy Lord is the Truth, but most of mankind believe not.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdccix{%
Allah it is Who raised up the heavens without visible supports, then mounted the Throne, and compelled the sun and the moon to be of service, each runneth unto an appointed term; He ordereth the course; He detaileth the revelations, that haply ye may be certain of the meeting with your Lord.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdccx{%
And He it is Who spread out the earth and placed therein firm hills and flowing streams, and of all fruits He placed therein two spouses (male and female). He covereth the night with the day. Lo! herein verily are portents for people who take thought.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdccxi{%
And in the Earth are neighbouring tracts, vineyards and ploughed lands, and date-palms, like and unlike, which are watered with one water. And we have made some of them to excel others in fruit. Lo! herein verily are portents for people who have sense.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdccxii{%
And if thou wonderest, then wondrous is their saying: When we are dust, are we then forsooth (to be raised) in a new creation? Such are they who disbelieve in their Lord; such have carcans on their necks; such are rightful owners of the Fire, they will abide therein.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdccxiii{%
And they bid thee hasten on the evil rather than the good, when exemplary punishments have indeed occurred before them. But lo! thy Lord is rich in pardon for mankind despite their wrong, and lo! thy Lord is strong in punishment.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdccxiv{%
Those who disbelieve say: If only some portent were sent down upon him from his Lord! Thou art a warner only, and for every folk a guide.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdccxv{%
Allah knoweth that which every female beareth and that which the wombs absorb and that which they grow. And everything with Him is measured.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdccxvi{%
He is the Knower of the Invisible and the Visible, the Great, the High Exalted.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdccxvii{%
Alike of you is he who hideth the saying and he who noiseth it abroad, he who lurketh in the night and he who goeth freely in the daytime.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdccxviii{%
For him are angels ranged before him and behind him, who guard him by Allah's command. Lo! Allah changeth not the condition of a folk until they (first) change that which is in their hearts; and if Allah willeth misfortune for a folk there is none that can repel it, nor have they a defender beside Him.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdccxix{%
He it is Who showeth you the lightning, a fear and a hope, and raiseth the heavy clouds.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdccxx{%
The thunder hymneth His praise and (so do) the angels for awe of Him. He launcheth the thunderbolts and smiteth with them whom He will while they dispute (in doubt) concerning Allah, and He is mighty in wrath.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdccxxi{%
Unto Him is the real prayer. Those unto whom they pray beside Allah respond to them not at all, save as (is the response to) one who stretcheth forth his hands toward water (asking) that it may come unto his mouth, and it will never reach it. The prayer of disbelievers goeth (far) astray.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdccxxii{%
And unto Allah falleth prostrate whosoever is in the heavens and the earth, willingly or unwillingly, as do their shadows in the morning and the evening hours.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdccxxiii{%
Say (O Muhammad): Who is Lord of the heavens and the earth? Say: Allah. Say: Take ye then (others) beside Him for protectors, which, even for themselves, have neither benefit nor hurt? Say: Is the blind man equal to the seer, or is darkness equal to light? Or assign they unto Allah partners who created the like of His creation so that the creation (which they made and His creation) seemed alike to them? Say: Allah is the Creator of all things, and He is the One, the Almighty.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdccxxiv{%
He sendeth down water from the sky, so that valleys flow according to their measure, and the flood beareth (on its surface) swelling foam - from that which they smelt in the fire in order to make ornaments and tools riseth a foam like unto it - thus Allah coineth (the similitude of) the true and the false. Then, as for the foam, it passeth away as scum upon the banks, while, as for that which is of use to mankind, it remaineth in the earth. Thus Allah coineth the similitudes.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdccxxv{%
For those who answered Allah's call is bliss; and for those who answered not His call, if they had all that is in the earth, and therewith the like thereof, they would proffer it as ransom. Such will have a woeful reckoning, and their habitation will be hell, a dire abode.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdccxxvi{%
Is he who knoweth that what is revealed unto thee from thy Lord is the truth like him who is blind? But only men of understanding heed;\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdccxxvii{%
Such as keep the pact of Allah, and break not the covenant;\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdccxxviii{%
Such as unite that which Allah hath commandeth should be joined, and fear their Lord, and dread a woeful reckoning;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdccxxix{%
Such as persevere in seeking their Lord's Countenance and are regular in prayer and spend of that which We bestow upon them secretly and openly, and overcome evil with good. Theirs will be the sequel of the (heavenly) Home,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdccxxx{%
Gardens of Eden which they enter, along with all who do right of their fathers and their helpmeets and their seed. The angels enter unto them from every gate,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdccxxxi{%
(Saying): Peace be unto you because ye persevered. Ah, passing sweet will be the sequel of the (heavenly) Home.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdccxxxii{%
And those who break the covenant of Allah after ratifying it, and sever that which Allah hath commanded should be joined, and make mischief in the earth: theirs is the curse and theirs the ill abode.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdccxxxiii{%
Allah enlargeth livelihood for whom He will, and straiteneth (it for whom He will); and they rejoice in the life of the world, whereas the life of the world is but brief comfort as compared with the Hereafter.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdccxxxiv{%
Those who disbelieve say: If only a portent were sent down upon him from his Lord! Say: Lo! Allah sendeth whom He will astray, and guideth unto Himself all who turn (unto Him),\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdccxxxv{%
Who have believed and whose hearts have rest in the remembrance of Allah. Verily in the remembrance of Allah do hearts find rest!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdccxxxvi{%
Those who believe and do right: Joy is for them, and bliss (their) journey's end.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdccxxxvii{%
Thus We send thee (O Muhammad) unto a nation, before whom other nations have passed away, that thou mayst recite unto them that which We have inspired in thee, while they are disbelievers in the Beneficent. Say: He is my Lord; there is no Allah save Him. In Him do I put my trust and unto Him is my recourse.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdccxxxviii{%
Had it been possible for a Lecture to cause the mountains to move, or the earth to be torn asunder, or the dead to speak, (this Qur'an would have done so). Nay, but Allah's is the whole command. Do not those who believe know that, had Allah willed, He could have guided all mankind? As for those who disbelieve, disaster ceaseth not to strike them because of what they do, or it dwelleth near their home until the threat of Allah come to pass. Lo! Allah faileth not to keep the tryst.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdccxxxix{%
And verily messengers (of Allah) were mocked before thee, but long I bore with those who disbelieved. At length I seized them, and how (awful) was My punishment!\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdccxl{%
Is He Who is aware of the deserts of every soul (as he who is aware of nothing)? Yet they ascribe unto Allah partners. Say: Name them. Is it that ye would inform Him of something which He knoweth not in the earth? Or is it but a way of speaking? Nay but their contrivance is made seeming fair for those who disbelieve and they are kept from the right road. He whom Allah sendeth astray, for him there is no guide.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdccxli{%
For them is torment in the life of the world, and verily the doom of the Hereafter is more painful, and they have no defender from Allah.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdccxlii{%
A similitude of the Garden which is promised unto those who keep their duty (to Allah): Underneath it rivers flow; its food is everlasting, and its shade; this is the reward of those who keep their duty, while the reward of disbelievers is the Fire.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdccxliii{%
Those unto whom We gave the Scripture rejoice in that which is revealed unto thee. And of the clans there are who deny some of it. Say: I am commanded only that I serve Allah and ascribe unto Him no partner. Unto Him I cry, and unto Him is my return.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdccxliv{%
Thus have We revealed it, a decisive utterance in Arabic; and if thou shouldst follow their desires after that which hath come unto thee of knowledge, then truly wouldst thou have from Allah no protecting friend nor defender.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdccxlv{%
And verily We sent messengers (to mankind) before thee, and We appointed for them wives and offspring, and it was not (given) to any messenger that he should bring a portent save by Allah's leave. For everything there is a time prescribed.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdccxlvi{%
Allah effaceth what He will, and establisheth (what He will), and with Him is the source of ordinance.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdccxlvii{%
Whether We let thee see something of that which We have promised them, or make thee die (before its happening), thine is but conveyance (of the message). Ours the reckoning.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdccxlviii{%
See they not how we aim to the land, reducing it of its outlying parts? (When) Allah doometh there is none that can postpone His doom, and He is swift at reckoning.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdccxlix{%
Those who were before them plotted; but all plotting is Allah's. He knoweth that which each soul earneth. The disbelievers will come to know for whom will be the sequel of the (heavenly) Home.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdccl{%
They who disbelieve say: Thou art no messenger (of Allah). Say: Allah, and whosoever hath knowledge of the Scripture, is sufficient witness between me and you.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdccli{%
\basmalahen Alif. Lam. Ra. (This is) a Scripture which We have revealed unto thee (Muhammad) that thereby thou mayst bring forth mankind from darkness unto light, by the permission of their Lord, unto the path of the Mighty, the Owner of Praise,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdcclii{%
Allah, unto Whom belongeth whatsoever is in the heavens and whatsoever is in the earth. and woe unto the disbelievers from an awful doom;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdccliii{%
Those who love the life of the world more than the Hereafter, and debar (men) from the way of Allah and would have it crooked: such are far astray.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdccliv{%
And We never sent a messenger save with the language of his folk, that he might make (the message) clear for them. Then Allah sendeth whom He will astray, and guideth whom He will. He is the Mighty, the Wise.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdcclv{%
We verily sent Moses with Our revelations, saying: Bring thy people forth from darkness unto light. And remind them of the days of Allah. Lo! therein are revelations for each steadfast, thankful (heart).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcclvi{%
And (remind them) how Moses said unto his people: Remember Allah's favour unto you when He delivered you from Pharaoh's folk who were afflicting you with dreadful torment, and were slaying your sons and sparing your women; that was a tremendous trial from your Lord.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdcclvii{%
And when your Lord proclaimed: If ye give thanks, I will give you more; but if ye are thankless, lo! My punishment is dire.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdcclviii{%
And Moses said: Though ye and all who are in the earth prove thankless, lo! Allah verily is Absolute, Owner of Praise.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcclix{%
Hath not the history of those before you reached you: the folk of Noah, and (the tribes of) A'ad and Thamud, and those after them? None save Allah knoweth them. Their messengers came unto them with clear proofs, but they thrust their hands into their mouths, and said: Lo! we disbelieve in that wherewith ye have been sent, and lo! we are in grave doubt concerning that to which ye call us.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcclx{%
Their messengers said: Can there be doubt concerning Allah, the Creator of the heavens and the earth? He calleth you that He may forgive you your sins and reprieve you unto an appointed term. They said: Ye are but mortals like us, who would fain turn us away from what our fathers used to worship. Then bring some clear warrant.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcclxi{%
Their messengers said unto them: We are but mortals like you, but Allah giveth grace unto whom He will of His slaves. It is not ours to bring you a warrant unless by the permission of Allah. In Allah let believers put their trust!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcclxii{%
How should we not put our trust in Allah when He hath shown us our ways? We surely will endure the hurt ye do us. In Allah let the trusting put their trust.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcclxiii{%
And those who disbelieved said unto their messengers: Verily we will drive you out from our land, unless ye return to our religion. Then their Lord inspired them, (saying): Verily we shall destroy the wrong-doers,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcclxiv{%
And verily We shall make you to dwell in the land after them. This is for him who feareth My Majesty and feareth My threats.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcclxv{%
And they sought help (from their Lord) and every froward potentate was bought to naught;\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcclxvi{%
Hell is before him, and he is made to drink a festering water,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcclxvii{%
Which he sippeth but can hardly swallow, and death cometh unto him from every side while yet he cannot die, and before him is a harsh doom.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcclxviii{%
A similitude of those who disbelieve in their Lord: Their works are as ashes which the wind bloweth hard upon a stormy day. They have no control of aught that they have earned. That is the extreme failure.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcclxix{%
Hast thou not seen that Allah hath created the heavens and the earth with truth? If He will, He can remove you and bring (in) some new creation;\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcclxx{%
And that is no great matter for Allah.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcclxxi{%
They all come forth unto their Lord. Then those who were despised say unto those who were scornful: We were unto you a following, can ye then avert from us aught of Allah's doom? They say: Had Allah guided us, we should have guided you. Whether we rage or patiently endure is (now) all one for us; we have no place of refuge.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcclxxii{%
And Satan saith, when the matter hath been decided: Lo! Allah promised you a promise of truth; and I promised you, then failed you. And I had no power over you save that I called unto you and ye obeyed me. So blame not, but blame yourselves. I cannot help you, nor can ye help me, Lo! I disbelieved in that which ye before ascribed to me. Lo! for wrong-doers is a painful doom.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcclxxiii{%
And those who believed and did good works are made to enter Gardens underneath which rivers flow, therein abiding by permission of their Lord, their greeting therein: Peace!\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcclxxiv{%
Seest thou not how Allah coineth a similitude: A goodly saying, as a goodly tree, its root set firm, its branches reaching into heaven,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcclxxv{%
Giving its fruit at every season by permission of its Lord? Allah coineth the similitudes for mankind in order that they may reflect.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcclxxvi{%
And the similitude of a bad saying is as a bad tree, uprooted from upon the earth, possessing no stability.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcclxxvii{%
Allah confirmeth those who believe by a firm saying in the life of the world and in the Hereafter, and Allah sendeth wrong-doers astray. And Allah doeth what He will.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcclxxviii{%
Hast thou not seen those who gave the grace of Allah in exchange for thanklessness and led their people down to the Abode of Loss,\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcclxxix{%
(Even to) hell? They are exposed thereto. A hapless end!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcclxxx{%
And they set up rivals to Allah that they may mislead (men) from His way. Say: Enjoy life (while ye may) for lo! your journey's end will be the Fire.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcclxxxi{%
Tell My bondmen who believe to establish worship and spend of that which We have given them, secretly and publicly, before a day cometh wherein there will be neither traffick nor befriending.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcclxxxii{%
Allah is He Who created the heavens and the earth, and causeth water to descend from the sky, thereby producing fruits as food for you, and maketh the ships to be of service unto you, that they may run upon the sea at His command, and hath made of service unto you the rivers;\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcclxxxiii{%
And maketh the sun and the moon, constant in their courses, to be of service unto you, and hath made of service unto you the night and the day.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcclxxxiv{%
And He giveth you of all ye ask of Him, and if ye would count the bounty of Allah ye cannot reckon it. Lo! man is verily a wrong-doer, an ingrate.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcclxxxv{%
And when Abraham said: My Lord! Make safe this territory, and preserve me and my sons from serving idols.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcclxxxvi{%
My Lord! Lo! they have led many of mankind astray. But whoso followeth me, he verily is of me. And whoso disobeyeth me - Still Thou art Forgiving, Merciful.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcclxxxvii{%
Our Lord! Lo! I have settled some of my posterity in an uncultivable valley near unto Thy holy House, our Lord! that they may establish proper worship; so incline some hearts of men that they may yearn toward them, and provide Thou them with fruits in order that they may be thankful.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcclxxxviii{%
Our Lord! Lo! Thou knowest that which we hide and that which we proclaim. Nothing in the earth or in the heaven is hidden from Allah.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcclxxxix{%
Praise be to Allah Who hath given me, in my old age, Ishmael and Isaac! Lo! my Lord is indeed the Hearer of Prayer.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdccxc{%
My Lord! Make me to establish proper worship, and some of my posterity (also); our Lord! and accept my prayer.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdccxci{%
Our Lord! Forgive me and my parents and believers on the day when the account is cast.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdccxcii{%
Deem not that Allah is unaware of what the wicked do. He but giveth them a respite till a day when eyes will stare (in terror),\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdccxciii{%
As they come hurrying on in fear, their heads upraised, their gaze returning not to them, and their hearts as air.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdccxciv{%
And warn mankind of a day when the doom will come upon them, and those who did wrong will say: Our Lord! Reprieve us for a little while. We will obey Thy call and will follow the messengers. (It will be answered): Did ye not swear before that there would be no end for you?\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdccxcv{%
And (have ye not) dwelt in the dwellings of those who wronged themselves (of old) and (hath it not) become plain to you how We dealt with them and made examples for you?\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdccxcvi{%
Verily they have plotted their plot, and their plot is with Allah, though their plot were one whereby the mountains should be moved.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdccxcvii{%
So think not that Allah will fail to keep His promise to His messengers. Lo! Allah is Mighty, Able to Requite (the wrong).\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdccxcviii{%
On the day when the earth will be changed to other than the earth, and the heavens (also will be changed) and they will come forth unto Allah, the One, the Almighty,\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdccxcix{%
Thou wilt see the guilty on that day linked together in chains,\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdccc{%
Their raiment of pitch, and the Fire covering their faces,\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdccci{%
That Allah may repay each soul what it hath earned. Lo! Allah is swift at reckoning.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcccii{%
This is a clear message for mankind in order that they may be warned thereby, and that they may know that He is only One Allah, and that men of understanding may take heed.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdccciii{%
\basmalahen Alif. Lam. Ra. These are verses of the Scripture and a plain Reading.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdccciv{%
It may be that those who disbelieve wish ardently that they were Muslims.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdcccv{%
Let them eat and enjoy life, and let (false) hope beguile them. They will come to know!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdcccvi{%
And We destroyed no township but there was a known decree for it.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdcccvii{%
No nation can outstrip its term nor can they lag behind.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcccviii{%
And they say: O thou unto whom the Reminder is revealed, lo! thou art indeed a madman!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdcccix{%
Why bringest thou not angels unto us, if thou art of the truthful?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdcccx{%
We send not down the angels save with the Fact, and in that case (the disbelievers) would not be tolerated.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcccxi{%
Lo! We, even We, reveal the Reminder, and lo! We verily are its Guardian.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcccxii{%
We verily sent (messengers) before thee among the factions of the men of old.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcccxiii{%
And never came there unto them a messenger but they did mock him.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcccxiv{%
Thus do We make it traverse the hearts of the guilty:\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcccxv{%
They believe not therein, though the example of the men of old hath gone before.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcccxvi{%
And even if We opened unto them a gate of heaven and they kept mounting through it,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcccxvii{%
They would say: Our sight is wrong - nay, but we are folk bewitched.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcccxviii{%
And verily in the heaven we have set mansions of the stars, and We have beautified it for beholders.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcccxix{%
And We have guarded it from every outcast devil,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcccxx{%
Save him who stealeth the hearing, and them doth a clear flame pursue.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcccxxi{%
And the earth have We spread out, and placed therein firm hills, and caused each seemly thing to grow therein.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcccxxii{%
And we have given unto you livelihoods therein, and unto those for whom ye provide not.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcccxxiii{%
And there is not a thing but with Us are the stores thereof. And we send it not down save in appointed measure.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcccxxiv{%
And We send the winds fertilising, and cause water to descend from the sky, and give it you to drink. It is not ye who are the holders of the store thereof.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcccxxv{%
Lo! and it is We, even We, Who quicken and give death, and We are the Inheritor.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcccxxvi{%
And verily We know the eager among you and verily We know the laggards.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcccxxvii{%
Lo! thy Lord will gather them together. Lo! He is Wise, Aware.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcccxxviii{%
Verily We created man of potter's clay of black mud altered,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcccxxix{%
And the jinn did We create aforetime of essential fire.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcccxxx{%
And (remember) when thy Lord said unto the angels: Lo! I am creating a mortal out of potter's clay of black mud altered,\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcccxxxi{%
So, when I have made him and have breathed into him of My Spirit, do ye fall down, prostrating yourselves unto him.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcccxxxii{%
So the angels fell prostrate, all of them together\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcccxxxiii{%
Save Iblis. He refused to be among the prostrate.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcccxxxiv{%
He said: O Iblis! What aileth thee that thou art not among the prostrate?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcccxxxv{%
He said: I am not one to prostrate myself unto a mortal whom Thou hast created out of potter's clay of black mud altered!\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcccxxxvi{%
He said: Then go thou forth from hence, for lo! thou art outcast.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcccxxxvii{%
And lo! the curse shall be upon thee till the Day of Judgment.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcccxxxviii{%
He said: My Lord! Reprieve me till the day when they are raised.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcccxxxix{%
He said: Then lo! thou art of those reprieved\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcccxl{%
Till the Day of appointed time.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcccxli{%
He said: My Lord! Because Thou hast sent me astray, I verily shall adorn the path of error for them in the earth, and shall mislead them every one,\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdcccxlii{%
Save such of them as are Thy perfectly devoted slaves.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdcccxliii{%
He said: This is a right course incumbent upon Me:\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdcccxliv{%
Lo! as for My slaves, thou hast no power over any of them save such of the froward as follow thee,\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdcccxlv{%
And lo! for all such, hell will be the promised place.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdcccxlvi{%
It hath seven gates, and each gate hath an appointed portion.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdcccxlvii{%
Lo! those who ward off (evil) are among gardens and watersprings.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdcccxlviii{%
(And it is said unto them): Enter them in peace, secure.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdcccxlix{%
And We remove whatever rancour may be in their breasts. As brethren, face to face, (they rest) on couches raised.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdcccl{%
Toil cometh not unto them there, nor will they be expelled from thence.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdcccli{%
Announce, (O Muhammad) unto My slaves that verily I am the Forgiving, the Merciful,\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdccclii{%
And that My doom is the dolorous doom.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdcccliii{%
And tell them of Abraham's guests,\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcccliv{%
(How) when they came in unto him, and said: Peace. He said: Lo! we are afraid of you.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdccclv{%
They said: Be not afraid! Lo! we bring thee good tidings of a boy possessing wisdom.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdccclvi{%
He said: Bring ye me good tidings (of a son) when old age hath overtaken me? Of what then can ye bring good tidings?\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdccclvii{%
They said: We bring thee good tidings in truth. So be not thou of the despairing.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdccclviii{%
He said: And who despaireth of the mercy of his Lord save those who are astray?\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdccclix{%
He said: And afterward what is your business, O ye messengers (of Allah)?\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdccclx{%
They said: We have been sent unto a guilty folk,\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdccclxi{%
(All) save the family of Lot. Them we shall deliver every one,\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdccclxii{%
Except his wife, of whom We had decreed that she should be of those who stay behind.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdccclxiii{%
And when the messengers came unto the family of Lot,\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdccclxiv{%
He said: Lo! ye are folk unknown (to me).\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdccclxv{%
They said: Nay, but we bring thee that concerning which they keep disputing,\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdccclxvi{%
And bring thee the Truth, and lo! we are truth-tellers.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdccclxvii{%
So travel with thy household in a portion of the night, and follow thou their backs. Let none of you turn round, but go whither ye are commanded.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdccclxviii{%
And We made plain the case to him, that the root of them (who did wrong) was to be cut at early morn.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdccclxix{%
And the people of the city came, rejoicing at the news (of new arrivals).\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdccclxx{%
He said: Lo! they are my guests. Affront me not!\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdccclxxi{%
And keep your duty to Allah, and shame me not!\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdccclxxii{%
They said; Have we not forbidden you from (entertaining) anyone?\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdccclxxiii{%
He said: Here are my daughters, if ye must be doing (so).\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdccclxxiv{%
By thy life (O Muhammad) they moved blindly in the frenzy of approaching death.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdccclxxv{%
Then the (Awful) Cry overtook them at the sunrise.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdccclxxvi{%
And We utterly confounded them, and We rained upon them stones of heated clay.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdccclxxvii{%
Lo! therein verily are portents for those who read the signs.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdccclxxviii{%
And lo! it is upon a road still uneffaced.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdccclxxix{%
Lo! therein is indeed a portent for believers.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdccclxxx{%
And the dwellers in the wood indeed were evil-doers.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdccclxxxi{%
So we took vengeance on them; and lo! they both are on a high-road plain to see.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdccclxxxii{%
And the dwellers in Al-Hijr denied (Our) messengers.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdccclxxxiii{%
And we gave them Our revelations, but they were averse to them.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdccclxxxiv{%
And they used to hew out dwellings from the hills, (wherein they dwelt) secure.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdccclxxxv{%
But the (Awful) Cry overtook them at the morning hour,\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdccclxxxvi{%
And that which they were wont to count as gain availed them not.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdccclxxxvii{%
We created not the heavens and the earth and all that is between them save with truth, and lo! the Hour is surely coming. So forgive, (O Muhammad), with a gracious forgiveness.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdccclxxxviii{%
Lo! Thy Lord! He is the All-Wise Creator.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdccclxxxix{%
We have given thee seven of the oft-repeated (verses) and the great Qur'an.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdcccxc{%
Strain not thine eyes toward that which We cause some wedded pairs among them to enjoin, and be not grieved on their account, and lower thy wing (in tenderness) for the believers.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdcccxci{%
And say: Lo! I, even I, am a plain warner,\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdcccxcii{%
Such as We send down for those who make division,\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdcccxciii{%
Those who break the Qur'an into parts.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdcccxciv{%
Them, by thy Lord, We shall question, every one,\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdcccxcv{%
Of what they used to do.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdcccxcvi{%
So proclaim that which thou art commanded, and withdraw from the idolaters.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdcccxcvii{%
Lo! We defend thee from the scoffers,\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdcccxcviii{%
Who set some other god along with Allah. But they will come to know.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mdcccxcix{%
Well know We that thy bosom is oppressed by what they say,\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcm{%
But hymn the praise of thy Lord, and be of those who make prostration (unto Him).\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcmi{%
And serve thy Lord till the Inevitable cometh unto thee.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcmii{%
\basmalahen The commandment of Allah will come to pass, so seek not ye to hasten it. Glorified and Exalted be He above all that they associate (with Him).\qt@no{1}}%
\qt@newcmd\qurantrans@en@mcmiii{%
He sendeth down the angels with the Spirit of His command unto whom He will of His bondmen, (saying): Warn mankind that there is no Allah save Me, so keep your duty unto Me.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mcmiv{%
He hath created the heavens and the earth with truth. High be He Exalted above all that they associate (with Him).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mcmv{%
He hath created man from a drop of fluid, yet behold! he is an open opponent.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mcmvi{%
And the cattle hath He created, whence ye have warm clothing and uses, and whereof ye eat;\qt@no{5}}%
\qt@newcmd\qurantrans@en@mcmvii{%
And wherein is beauty for you, when ye bring them home, and when ye take them out to pasture.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mcmviii{%
And they bear your loads for you unto a land ye could not reach save with great trouble to yourselves. Lo! your Lord is Full of Pity, Merciful.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mcmix{%
And horses and mules and asses (hath He created) that ye may ride them, and for ornament. And He createth that which ye know not.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mcmx{%
And Allah's is the direction of the way, and some (roads) go not straight. And had He willed He would have led you all aright.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mcmxi{%
He it is Who sendeth down water from the sky, whence ye have drink, and whence are trees on which ye send your beasts to pasture.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mcmxii{%
Therewith He causeth crops to grow for you, and the olive and the date-palm and grapes and all kinds of fruit. Lo! herein is indeed a portent for people who reflect.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mcmxiii{%
And He hath constrained the night and the day and the sun and the moon to be of service unto you, and the stars are made subservient by His command. Lo! herein indeed are portents for people who have sense.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mcmxiv{%
And whatsoever He hath created for you in the earth of divers hues, lo! therein is indeed a portent for people who take heed.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mcmxv{%
And He it is Who hath constrained the sea to be of service that ye eat fresh meat from thence, and bring forth from thence ornaments which ye wear. And thou seest the ships ploughing it that ye (mankind) may seek of His bounty and that haply ye may give thanks.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mcmxvi{%
And He hath cast into the earth firm hills that it quake not with you, and streams and roads that ye may find a way.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mcmxvii{%
And landmarks (too), and by the star they find a way.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcmxviii{%
Is He then Who createth as him who createth not? Will ye not then remember?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mcmxix{%
And if ye would count the favour of Allah ye cannot reckon it. Lo! Allah is indeed Forgiving, Merciful.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mcmxx{%
And Allah knoweth that which ye keep hidden and that which ye proclaim.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcmxxi{%
Those unto whom they cry beside Allah created naught, but are themselves created.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcmxxii{%
(They are) dead, not living. And they know not when they will be raised.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcmxxiii{%
Your Allah is One Allah. But as for those who believe not in the Hereafter their hearts refuse to know, for they are proud.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcmxxiv{%
Assuredly Allah knoweth that which they keep hidden and that which they proclaim. Lo! He loveth not the proud.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcmxxv{%
And when it is said unto them: What hath your Lord revealed? they say: (Mere) fables of the men of old,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcmxxvi{%
That they may bear their burdens undiminished on the Day of Resurrection, with somewhat of the burdens of those whom they mislead without knowledge. Ah! evil is that which they bear!\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcmxxvii{%
Those before them plotted, so Allah struck at the foundations of their building, and then the roof fell down upon them from above them, and the doom came on them whence they knew not;\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcmxxviii{%
Then on the Day of Resurrection He will disgrace them and will say: Where are My partners, for whose sake ye opposed (My guidance)? Those who have been given knowledge will say: Disgrace this day and evil are upon the disbelievers,\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcmxxix{%
Whom the angels cause to die while they are wronging themselves. Then will they make full submission (saying): We used not to do any wrong. Nay! Surely Allah is Knower of what ye used to do.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcmxxx{%
So enter the gates of hell, to dwell therein for ever. Woeful indeed will be the lodging of the arrogant.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcmxxxi{%
And it is said unto those who ward off (evil): What hath your Lord revealed? They say: Good. For those who do good in this world there is a good (reward) and the home of the Hereafter will be better. Pleasant indeed will be the home of those who ward off (evil) -\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcmxxxii{%
Gardens of Eden which they enter, underneath which rivers flow, wherein they have what they will. Thus Allah repayeth those who ward off (evil),\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcmxxxiii{%
Those whom the angels cause to die (when they are) good. They say: Peace be unto you! Enter the Garden because of what ye used to do.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcmxxxiv{%
Await they aught say that the angels should come unto them or thy Lord's command should come to pass? Even so did those before them. Allah wronged them not, but they did wrong themselves,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcmxxxv{%
So that the evils of what they did smote them, and that which they used to mock surrounded them.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcmxxxvi{%
And the idolaters say: Had Allah willed, we had not worshipped aught beside Him, we and our fathers, nor had we forbidden aught without (command from) Him. Even so did those before them. Are the messengers charged with aught save plain conveyance (of the message)?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcmxxxvii{%
And verily We have raised in every nation a messenger, (proclaiming): Serve Allah and shun false gods. Then some of them (there were) whom Allah guided, and some of them (there were) upon whom error had just hold. Do but travel in the land and see the nature of the consequence for the deniers!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcmxxxviii{%
Even if thou (O Muhammad) desirest their right guidance, still Allah assuredly will not guide him who misleadeth. Such have no helpers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcmxxxix{%
And they swear by Allah their most binding oaths (that) Allah will not raise up him who dieth. Nay, but it is a promise (binding) upon Him in truth, but most of mankind know not,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcmxl{%
That He may explain unto them that wherein they differ, and that those who disbelieved may know that they were liars.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcmxli{%
And Our word unto a thing, when We intend it, is only that We say unto it: Be! and it is.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcmxlii{%
And those who became fugitives for the cause of Allah after they had been oppressed, We verily shall give them goodly lodging in the world, and surely the reward of the Hereafter is greater, if they but knew;\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcmxliii{%
Such as are steadfast and put their trust in Allah.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcmxliv{%
And We sent not (as Our messengers) before thee other than men whom We inspired - Ask the followers of the Remembrance if ye know not! -\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcmxlv{%
With clear proofs and writings; and We have revealed unto thee the Remembrance that thou mayst explain to mankind that which hath been revealed for them, and that haply they may reflect.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcmxlvi{%
Are they who plan ill-deeds then secure that Allah will not cause the earth to swallow them, or that the doom will not come on them whence they know not?\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcmxlvii{%
Or that He will not seize them in their going to and fro so that there be no escape for them?\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcmxlviii{%
Or that He will not seize them with a gradual wasting? Lo! thy Lord is indeed Full of Pity, Merciful.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcmxlix{%
Have they not observed all things that Allah hath created, how their shadows incline to the right and to the left, making prostration unto Allah, and they are lowly?\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcml{%
And unto Allah maketh prostration whatsoever is in the heavens and whatsoever is in the earth of living creatures, and the angels (also) and they are not proud.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcmli{%
They fear their Lord above them, and do what they are bidden.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcmlii{%
Allah hath said: Choose not two gods. There is only One Allah. So of Me, Me only, be in awe.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcmliii{%
Unto Him belongeth whatsoever is in the heavens and the earth, and religion is His for ever. Will ye then fear any other than Allah?\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcmliv{%
And whatever of comfort ye enjoy, it is from Allah. Then, when misfortune reacheth you, unto Him ye cry for help.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcmlv{%
And afterward, when He hath rid you of the misfortune, behold! a set of you attribute partners to their Lord,\qt@no{54}}%
\qt@newcmd\qurantrans@en@mcmlvi{%
So as to deny that which We have given them. Then enjoy life (while ye may), for ye will come to know.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mcmlvii{%
And they assign a portion of that which We have given them unto what they know not. By Allah! but ye will indeed be asked concerning (all) that ye used to invent.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mcmlviii{%
And they assign unto Allah daughters - Be He Glorified! - and unto themselves what they desire;\qt@no{57}}%
\qt@newcmd\qurantrans@en@mcmlix{%
When if one of them receiveth tidings of the birth of a female, his face remaineth darkened, and he is wroth inwardly.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mcmlx{%
He hideth himself from the folk because of the evil of that whereof he hath had tidings, (asking himself): Shall he keep it in contempt, or bury it beneath the dust. Verily evil is their judgment.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mcmlxi{%
For those who believe not in the Hereafter is an evil similitude, and Allah's is the Sublime Similitude. He is the Mighty, the Wise.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mcmlxii{%
If Allah were to take mankind to task for their wrong-doing, he would not leave hereon a living creature, but He reprieveth them to an appointed term, and when their term cometh they cannot put (it) off an hour nor (yet) advance (it).\qt@no{61}}%
\qt@newcmd\qurantrans@en@mcmlxiii{%
And they assign unto Allah that which they (themselves) dislike, and their tongues expound the lie that the better portion will be theirs. Assuredly theirs will be the Fire, and they will be abandoned.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mcmlxiv{%
By Allah, We verily sent messengers unto the nations before thee, but the devil made their deeds fairseeming unto them. So he is their patron this day, and theirs will be a painful doom.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mcmlxv{%
And We have revealed the Scripture unto thee only that thou mayst explain unto them that wherein they differ, and (as) a guidance and a mercy for a people who believe.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mcmlxvi{%
Allah sendeth down water from the sky and therewith reviveth the earth after her death. Lo! herein is indeed a portent for a folk who hear.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mcmlxvii{%
And lo! in the cattle there is a lesson for you. We give you to drink of that which is in their bellies, from betwixt the refuse and the blood, pure milk palatable to the drinkers.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcmlxviii{%
And of the fruits of the date-palm, and grapes, whence ye derive strong drink and (also) good nourishment. Lo! therein is indeed a portent for people who have sense.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mcmlxix{%
And thy Lord inspired the bee, saying: Choose thou habitations in the hills and in the trees and in that which they thatch;\qt@no{68}}%
\qt@newcmd\qurantrans@en@mcmlxx{%
Then eat of all fruits, and follow the ways of thy Lord, made smooth (for thee). There cometh forth from their bellies a drink divers of hues, wherein is healing for mankind. Lo! herein is indeed a portent for people who reflect.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcmlxxi{%
And Allah createth you, then causeth you to die, and among you is he who is brought back to the most abject stage of life, so that he knoweth nothing after (having had) knowledge. Lo! Allah is Knower, Powerful.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcmlxxii{%
And Allah hath favoured some of you above others in provision. Now those who are more favoured will by no means hand over their provision to those (slaves) whom their right hands possess, so that they may be equal with them in respect thereof. Is it then the grace of Allah that they deny?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcmlxxiii{%
And Allah hath given you wives of your own kind, and hath given you, from your wives, sons and grandsons, and hath made provision of good things for you. Is it then in vanity that they believe and in the grace of Allah that they disbelieve?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcmlxxiv{%
And they worship beside Allah that which owneth no provision whatsoever for them from the heavens or the earth, nor have they (whom they worship) any power.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcmlxxv{%
So coin not similitudes for Allah. Lo! Allah knoweth; ye know not.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcmlxxvi{%
Allah coineth a similitude: (on the one hand) a (mere) chattel slave, who hath control of nothing, and (on the other hand) one on whom we have bestowed a fair provision from Us, and he spendeth thereof secretly and openly. Are they equal? Praise be to Allah! But most of them know not.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcmlxxvii{%
And Allah coineth a similitude: Two men, one of them dumb, having control of nothing, and he is a burden on his owner; whithersoever he directeth him to go, he bringeth no good. Is he equal with one who enjoineth justice and followeth a straight path (of conduct)?\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcmlxxviii{%
And unto Allah belongeth the Unseen of the heavens and the earth, and the matter of the Hour (of Doom) is but as a twinkling of the eye, or it is nearer still. Lo! Allah is Able to do all things.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcmlxxix{%
And Allah brought you forth from the wombs of your mothers knowing nothing, and gave you hearing and sight and hearts that haply ye might give thanks.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcmlxxx{%
Have they not seen the birds obedient in mid-air? None holdeth them save Allah. Lo! herein, verily, are portents for a people who believe.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcmlxxxi{%
And Allah hath given you in your houses an abode, and hath given you (also), of the hides of cattle, houses which ye find light (to carry) on the day of migration and on the day of pitching camp; and of their wool and their fur and their hair, caparison and comfort for a while.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcmlxxxii{%
And Allah hath given you, of that which He hath created, shelter from the sun; and hath given you places of refuge in the mountains, and hath given you coats to ward off the heat from you, and coats (of armour) to save you from your own foolhardiness. Thus doth He perfect His favour unto you, in order that ye may surrender (unto Him).\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcmlxxxiii{%
Then, if they turn away, thy duty (O Muhammad) is but plain conveyance (of the message).\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcmlxxxiv{%
They know the favour of Allah and then deny it. Most of them are ingrates.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcmlxxxv{%
And (bethink you of) the day when we raise up of every nation a witness, then there is no leave for disbelievers, nor are they allowed to make amends.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcmlxxxvi{%
And when those who did wrong behold the doom, it will not be made light for them, nor will they be reprieved.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcmlxxxvii{%
And when those who ascribed partners to Allah behold those partners of theirs, they will say: Our Lord! these are our partners unto whom we used to cry instead of Thee. But they will fling to them the saying: Lo! ye verily are liars!\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcmlxxxviii{%
And they proffer unto Allah submission on that day, and all that they used to invent hath failed them.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcmlxxxix{%
For those who disbelieve and debar (men) from the way of Allah, We add doom to doom because they wrought corruption,\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcmxc{%
And (bethink you of) the day when We raise in every nation a witness against them of their own folk, and We bring thee (Muhammad) as a witness against these. And We reveal the Scripture unto thee as an exposition of all things, and a guidance and a mercy and good tidings for those who have surrendered (to Allah).\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcmxci{%
Lo! Allah enjoineth justice and kindness, and giving to kinsfolk, and forbiddeth lewdness and abomination and wickedness. He exhorteth you in order that ye may take heed.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcmxcii{%
Fulfil the covenant of Allah when ye have covenanted, and break not your oaths after the asseveration of them, and after ye have made Allah surety over you. Lo! Allah knoweth what ye do.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcmxciii{%
And be not like unto her who unravelleth the thread, after she hath made it strong, to thin filaments, making your oaths a deceit between you because of a nation being more numerous than (another) nation. Allah only trieth you thereby, and He verily will explain to you on the Day of Resurrection that wherein ye differed.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcmxciv{%
Had Allah willed He could have made you (all) one nation, but He sendeth whom He will astray and guideth whom He will, and ye will indeed be asked of what ye used to do.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcmxcv{%
Make not your oaths a deceit between you, lest a foot should slip after being firmly planted and ye should taste evil forasmuch as ye debarred (men) from the way of Allah, and yours should be an awful doom.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcmxcvi{%
And purchase not a small gain at the price of Allah's covenant. Lo! that which Allah hath is better for you, if ye did but know.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcmxcvii{%
That which ye have wasteth away, and that which Allah hath remaineth. And verily We shall pay those who are steadfast a recompense in proportion to the best of what they used to do.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcmxcviii{%
Whosoever doeth right, whether male or female, and is a believer, him verily we shall quicken with good life, and We shall pay them a recompense in proportion to the best of what they used to do.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcmxcix{%
And when thou recitest the Qur'an, seek refuge in Allah from Satan the outcast.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mm{%
Lo! he hath no power over those who believe and put trust in their Lord.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmi{%
His power is only over those who make a friend of him, and those who ascribe partners unto Him (Allah).\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmii{%
And when We put a revelation in place of (another) revelation, - and Allah knoweth best what He revealeth - they say: Lo! thou art but inventing. Most of them know not.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmiii{%
Say: The holy Spirit hath delivered it from thy Lord with truth, that it may confirm (the faith of) those who believe, and as guidance and good tidings for those who have surrendered (to Allah).\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmiv{%
And We know well that they say: Only a man teacheth him. The speech of him at whom they falsely hint is outlandish, and this is clear Arabic speech.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmv{%
Lo! those who disbelieve the revelations of Allah, Allah guideth them not and theirs will be a painful doom.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmvi{%
Only they invent falsehood who believe not Allah's revelations, and (only) they are the liars.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmvii{%
Whoso disbelieveth in Allah after his belief - save him who is forced thereto and whose heart is still content with the Faith - but whoso findeth ease in disbelief: On them is wrath from Allah. Theirs will be an awful doom.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmviii{%
That is because they have chosen the life of the world rather than the Hereafter, and because Allah guideth not the disbelieving folk.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmix{%
Such are they whose hearts and ears and eyes Allah hath sealed. And such are the heedless.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmx{%
Assuredly in the Hereafter they are the losers.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmxi{%
Then lo! thy Lord - for those who became fugitives after they had been persecuted, and then fought and were steadfast - lo! thy Lord afterward is (for them) indeed Forgiving, Merciful.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmxii{%
On the Day when every soul will come pleading for itself, and every soul will be repaid what it did, and they will not be wronged.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmxiii{%
Allah coineth a similitude: a township that dwelt secure and well content, its provision coming to it in abundance from every side, but it disbelieved in Allah's favours, so Allah made it experience the garb of dearth and fear because of what they used to do.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmxiv{%
And verily there had come unto them a messenger from among them, but they had denied him, and so the torment seized them while they were wrong-doers.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmxv{%
So eat of the lawful and good food which Allah hath provided for you, and thank the bounty of your Lord if it is Him ye serve.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmxvi{%
He hath forbidden for you only carrion and blood and swineflesh and that which hath been immolated in the name of any other than Allah; but he who is driven thereto, neither craving nor transgressing, lo! then Allah is Forgiving, Merciful.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmxvii{%
And speak not, concerning that which your own tongues qualify (as clean or unclean), the falsehood: ``This is lawful, and this is forbidden," so that ye invent a lie against Allah. Lo! those who invent a lie against Allah will not succeed.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmxviii{%
A brief enjoyment (will be theirs); and theirs a painful doom.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmxix{%
And unto those who are Jews We have forbidden that which We have already related unto thee. And We wronged them not, but they were wont to wrong themselves.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmxx{%
Then lo! thy Lord - for those who do evil in ignorance and afterward repent and amend - lo! (for them) thy Lord is afterward indeed Forgiving, Merciful.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmxxi{%
Lo! Abraham was a nation obedient to Allah, by nature upright, and he was not of the idolaters;\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmxxii{%
Thankful for His bounties; He chose him and He guided him unto a straight path.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmxxiii{%
And We gave him good in the world, and in the Hereafter he is among the righteous.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmxxiv{%
And afterward We inspired thee (Muhammad, saying): Follow the religion of Abraham, as one by nature upright. He was not of the idolaters.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmxxv{%
The Sabbath was appointed only for those who differed concerning it, and lo! thy Lord will judge between them on the Day of Resurrection concerning that wherein they used to differ.\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmxxvi{%
Call unto the way of thy Lord with wisdom and fair exhortation, and reason with them in the better way. Lo! thy Lord is Best Aware of him who strayeth from His way, and He is Best Aware of those who go aright.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmxxvii{%
If ye punish, then punish with the like of that wherewith ye were afflicted. But if ye endure patiently, verily it is better for the patient.\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmxxviii{%
Endure thou patiently (O Muhammad). Thine endurance is only by (the help of) Allah. Grieve not for them, and be not in distress because of that which they devise.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmxxix{%
Lo! Allah is with those who keep their duty unto Him and those who are doers of good.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmxxx{%
\basmalahen Glorified be He Who carried His servant by night from the Inviolable Place of Worship to the Far distant place of worship the neighbourhood whereof We have blessed, that We might show him of Our tokens! Lo! He, only He, is the Hearer, the Seer.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmxxxi{%
We gave unto Moses the Scripture, and We appointed it a guidance for the children of Israel, saying: Choose no guardian beside Me.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmxxxii{%
(They were) the seed of those whom We carried (in the ship) along with Noah. Lo! he was a grateful slave.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmxxxiii{%
And We decreed for the Children of Israel in the Scripture: Ye verily will work corruption in the earth twice, and ye will become great tyrants.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmxxxiv{%
So when the time for the first of the two came, We roused against you slaves of Ours of great might who ravaged (your) country, and it was a threat performed.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmxxxv{%
Then we gave you once again your turn against them, and We aided you with wealth and children and made you more in soldiery.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmxxxvi{%
(Saying): If ye do good, ye do good for your own souls, and if ye do evil, it is for them (in like manner). So, when the time for the second (of the judgments) came (We roused against you others of Our slaves) to ravage you, and to enter the Temple even as they entered it the first time, and to lay waste all that they conquered with an utter wasting.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmxxxvii{%
It may be that your Lord will have mercy on you, but if ye repeat (the crime) We shall repeat (the punishment), and We have appointed hell a dungeon for the disbelievers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmxxxviii{%
Lo! this Qur'an guideth unto that which is straightest, and giveth tidings unto the believers who do good works that theirs will be a great reward.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmxxxix{%
And that those who believe not in the Hereafter, for them We have prepared a painful doom.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmxl{%
Man prayeth for evil as he prayeth for good; for man was ever hasty.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmxli{%
And We appoint the night and the day two portents. Then We make dark the portent of the night, and We make the portent of the day sight-giving, that ye may seek bounty from your Lord, and that ye may know the computation of the years, and the reckoning; and everything have We expounded with a clear expounding.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmxlii{%
And every man's augury have We fastened to his own neck, and We shall bring forth for him on the Day of Resurrection a book which he will find wide open.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmxliii{%
(And it will be said unto him): Read thy Book. Thy soul sufficeth as reckoner against thee this day.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmxliv{%
Whosoever goeth right, it is only for (the good of) his own soul that he goeth right, and whosoever erreth, erreth only to its hurt. No laden soul can bear another's load, We never punish until we have sent a messenger.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmxlv{%
And when We would destroy a township We send commandment to its folk who live at ease, and afterward they commit abomination therein, and so the Word (of doom) hath effect for it, and we annihilate it with complete annihilation.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmxlvi{%
How many generations have We destroyed since Noah! And Allah sufficeth as Knower and Beholder of the sins of His slaves.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmxlvii{%
Whoso desireth that (life) which hasteneth away, We hasten for him therein what We will for whom We please. And afterward We have appointed for him hell; he will endure the heat thereof, condemned, rejected.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmxlviii{%
And whoso desireth the Hereafter and striveth for it with the effort necessary, being a believer; for such, their effort findeth favour (with their Lord).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmxlix{%
Each do We supply, both these and those, from the bounty of thy Lord. And the bounty of thy Lord can never be walled up.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mml{%
See how We prefer one of them above another, and verily the Hereafter will be greater in degrees and greater in preferment.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmli{%
Set not up with Allah any other god (O man) lest thou sit down reproved, forsaken.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmlii{%
Thy Lord hath decreed, that ye worship none save Him, and (that ye show) kindness to parents. If one of them or both of them attain old age with thee, say not ``Fie" unto them nor repulse them, but speak unto them a gracious word.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmliii{%
And lower unto them the wing of submission through mercy, and say: My Lord! Have mercy on them both as they did care for me when I was little.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmliv{%
Your Lord is Best Aware of what is in your minds. If ye are righteous, then lo! He was ever Forgiving unto those who turn (unto Him).\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmlv{%
Give the kinsman his due, and the needy, and the wayfarer, and squander not (thy wealth) in wantonness.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmlvi{%
Lo! the squanderers were ever brothers of the devils, and the devil was ever an ingrate to his Lord.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmlvii{%
But if thou turn away from them, seeking mercy from thy Lord, for which thou hopest, then speak unto them a reasonable word.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmlviii{%
And let not thy hand be chained to thy neck nor open it with a complete opening, lest thou sit down rebuked, denuded.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmlix{%
Lo! thy Lord enlargeth the provision for whom He will, and straiteneth (it for whom He will). Lo, He was ever Knower, Seer of His slaves.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmlx{%
Slay not your children, fearing a fall to poverty, We shall provide for them and for you. Lo! the slaying of them is great sin.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmlxi{%
And come not near unto adultery. Lo! it is an abomination and an evil way.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmlxii{%
And slay not the life which Allah hath forbidden save with right. Whoso is slain wrongfully, We have given power unto his heir, but let him not commit excess in slaying. Lo! he will be helped.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmlxiii{%
Come not near the wealth of the orphan save with that which is better till he come to strength; and keep the covenant. Lo! of the covenant it will be asked.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmlxiv{%
Fill the measure when ye measure, and weigh with a right balance; that is meet, and better in the end.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmlxv{%
(O man), follow not that whereof thou hast no knowledge. Lo! the hearing and the sight and the heart - of each of these it will be asked.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmlxvi{%
And walk not in the earth exultant. Lo! thou canst not rend the earth, nor canst thou stretch to the height of the hills.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmlxvii{%
The evil of all that is hateful in the sight of thy Lord.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmlxviii{%
This is (part) of that wisdom wherewith thy Lord hath inspired thee (O Muhammad). And set not up with Allah any other god, lest thou be cast into hell, reproved, abandoned.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmlxix{%
Hath your Lord then distinguished you (O men of Makka) by giving you sons, and hath chosen for Himself females from among the angels? Lo! verily ye speak an awful word!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmlxx{%
We verily have displayed (Our warnings) in this Qur'an that they may take heed, but it increaseth them in naught save aversion.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmlxxi{%
Say (O Muhammad, to the disbelievers): If there were other gods along with Him, as they say, then had they sought a way against the Lord of the Throne.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmlxxii{%
Glorified is He, and High Exalted above what they say!\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmlxxiii{%
The seven heavens and the earth and all that is therein praise Him, and there is not a thing but hymneth His praise; but ye understand not their praise. Lo! He is ever Clement, Forgiving.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmlxxiv{%
And when thou recitest the Qur'an we place between thee and those who believe not in the Hereafter a hidden barrier;\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmlxxv{%
And We place upon their hearts veils lest they should understand it, and in their ears a deafness; and when thou makest mention of thy Lord alone in the Qur'an, they turn their backs in aversion.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmlxxvi{%
We are Best Aware of what they wish to hear when they give ear to thee and when they take secret counsel, when the evil-doers say: Ye follow but a man bewitched.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmlxxvii{%
See what similitudes they coin for thee, and thus are all astray, and cannot find a road!\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmlxxviii{%
And they say: When we are bones and fragments, shall we forsooth, be raised up as a new creation?\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmlxxix{%
Say: Be ye stones or iron\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmlxxx{%
Or some created thing that is yet greater in your thoughts! Then they will say: Who shall bring us back (to life). Say: He Who created you at the first. Then will they shake their heads at thee, and say: When will it be? Say: It will perhaps be soon;\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmlxxxi{%
A day when He will call you and ye will answer with His praise, and ye will think that ye have tarried but a little while.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmlxxxii{%
Tell My bondmen to speak that which is kindlier. Lo! the devil soweth discord among them. Lo! the devil is for man an open foe.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmlxxxiii{%
Your Lord is Best Aware of you. If He will, He will have mercy on you, or if He will, He will punish you. We have not sent thee (O Muhammad) as a warden over them.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmlxxxiv{%
And thy Lord is Best Aware of all who are in the heavens and the earth. And we preferred some of the prophets above others, and unto David We gave the Psalms.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmlxxxv{%
Say: Cry unto those (saints and angels) whom ye assume (to be gods) beside Him, yet they have no power to rid you of misfortune nor to change.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmlxxxvi{%
Those unto whom they cry seek the way of approach to their Lord, which of them shall be the nearest; they hope for His mercy and they fear His doom. Lo! the doom of thy Lord is to be shunned.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmlxxxvii{%
There is not a township but We shall destroy it ere the Day of Resurrection, or punish it with dire punishment. That is set forth in the Book (of Our decrees).\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmlxxxviii{%
Naught hindereth Us from sending portents save that the folk of old denied them. And We gave Thamud the she-camel - a clear portent save to warn.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmlxxxix{%
And (it was a warning) when we told thee: Lo! thy Lord encompasseth mankind, and We appointed the sight which We showed thee as an ordeal for mankind, and (likewise) the Accursed Tree in the Qur'an. We warn them, but it increaseth them in naught save gross impiety.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmxc{%
And when We said unto the angels: Fall down prostrate before Adam and they fell prostrate all save Iblis, he said: Shall I fall prostrate before that which Thou hast created of clay?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmxci{%
He said: Seest Thou this (creature) whom Thou hast honoured above me, if Thou give me grace until the Day of Resurrection I verily will seize his seed, save but a few.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmxcii{%
He said: Go, and whosoever of them followeth thee - lo! hell will be your payment, ample payment.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmxciii{%
And excite any of them whom thou canst with thy voice, and urge thy horse and foot against them, and be a partner in their wealth and children, and promise them. Satan promiseth them only to deceive.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmxciv{%
Lo! My (faithful) bondmen - over them thou hast no power, and thy Lord sufficeth as (their) guardian.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmxcv{%
(O mankind), your Lord is He Who driveth for you the ship upon the sea that ye may seek of His bounty. Lo! He was ever Merciful toward you.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmxcvi{%
And when harm toucheth you upon the sea, all unto whom ye cry (for succour) fail save Him (alone), but when He bringeth you safe to land, ye turn away, for man was ever thankless.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmxcvii{%
Feel ye then secure that He will not cause a slope of the land to engulf you, or send a sand-storm upon you, and then ye will find that ye have no protector?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmxcviii{%
Or feel ye secure that He will not return you to that (plight) a second time, and send against you a hurricane of wind and drown you for your thanklessness, and then ye will not find therein that ye have any avenger against Us?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmxcix{%
Verily we have honoured the Children of Adam. We carry them on the land and the sea, and have made provision of good things for them, and have preferred them above many of those whom We created with a marked preferment.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmc{%
On the day when We shall summon all men with their record, whoso is given his book in his right hand - such will read their book and they will not be wronged a shred.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmci{%
Whoso is blind here will be blind in the Hereafter, and yet further from the road.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcii{%
And they indeed strove hard to beguile thee (Muhammad) away from that wherewith We have inspired thee, that thou shouldst invent other than it against Us; and then would they have accepted thee as a friend.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmciii{%
And if We had not made thee wholly firm thou mightest almost have inclined unto them a little.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmciv{%
Then had we made thee taste a double (punishment) of living and a double (punishment) of dying, then hadst thou found no helper against Us.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcv{%
And they indeed wished to scare thee from the land that they might drive thee forth from thence, and then they would have stayed (there) but a little after thee.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcvi{%
(Such was Our) method in the case of those whom We sent before thee (to mankind), and thou wilt not find for Our method aught of power to change.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcvii{%
Establish worship at the going down of the sun until the dark of night, and (the recital of) the Qur'an at dawn. Lo! (the recital of) the Qur'an at dawn is ever witnessed.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcviii{%
And some part of the night awake for it, a largess for thee. It may be that thy Lord will raise thee to a praised estate.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcix{%
And say: My Lord! Cause me to come in with a firm incoming and to go out with a firm outgoing. And give me from Thy presence a sustaining Power.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcx{%
And say: Truth hath come and falsehood hath vanished away. Lo! falsehood is ever bound to vanish.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcxi{%
And We reveal of the Qur'an that which is a healing and a mercy for believers though it increase the evil-doers in naught save ruin.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcxii{%
And when We make life pleasant unto man, he turneth away and is averse; and when ill toucheth him he is in despair.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcxiii{%
Say: Each one doth according to his rule of conduct, and thy Lord is Best Aware of him whose way is right.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcxiv{%
They are asking thee concerning the Spirit. Say: The Spirit is by command of my Lord, and of knowledge ye have been vouchsafed but little.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcxv{%
And if We willed We could withdraw that which We have revealed unto thee, then wouldst thou find no guardian for thee against Us in respect thereof.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcxvi{%
(It is naught) save mercy from thy Lord. Lo! His kindness unto thee was ever great.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcxvii{%
Say: Verily, though mankind and the jinn should assemble to produce the like of this Qur'an, they could not produce the like thereof though they were helpers one of another.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcxviii{%
And verily We have displayed for mankind in this Qur'an all kind of similitudes, but most of mankind refuse aught save disbelief.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcxix{%
And they say: We will not put faith in thee till thou cause a spring to gush forth from the earth for us;\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcxx{%
Or thou have a garden of date-palms and grapes, and cause rivers to gush forth therein abundantly;\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcxxi{%
Or thou cause the heaven to fall upon us piecemeal, as thou hast pretended, or bring Allah and the angels as a warrant;\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcxxii{%
Or thou have a house of gold; or thou ascend up into heaven, and even then we will put no faith in thine ascension till thou bring down for us a book that we can read. Say (O Muhammad): My Lord be Glorified! Am I aught save a mortal messenger?\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcxxiii{%
And naught prevented mankind from believing when the guidance came unto them save that they said: Hath Allah sent a mortal as (His) messenger?\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcxxiv{%
Say: If there were in the earth angels walking secure, We had sent down for them from heaven an angel as messenger.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcxxv{%
Say: Allah sufficeth for a witness between me and you. Lo! He is Knower, Seer of His slaves.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcxxvi{%
And he whom Allah guideth, he is led aright; while, as for him whom He sendeth astray, for them thou wilt find no protecting friends beside Him, and We shall assemble them on the Day of Resurrection on their faces, blind, dumb and deaf; their habitation will be hell; whenever it abateth, We increase the flame for them.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcxxvii{%
That is their reward because they disbelieved Our revelations and said: When we are bones and fragments shall we, forsooth, be raised up as a new creation?\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcxxviii{%
Have they not seen that Allah Who created the heavens and the earth is Able to create the like of them, and hath appointed for them an end whereof there is no doubt? But the wrong-doers refuse aught save disbelief.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmcxxix{%
Say (unto them): If ye possessed the treasures of the mercy of my Lord, ye would surely hold them back for fear of spending, for man was ever grudging.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmcxxx{%
And verily We gave unto Moses nine tokens, clear proofs (of Allah's Sovereignty). Do but ask the Children of Israel how he came unto them, then Pharaoh said unto him: Lo! I deem thee one bewitched, O Moses.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmcxxxi{%
He said: In truth thou knowest that none sent down these (portents) save the Lord of the heavens and the earth as proofs, and lo! (for my part) I deem thee lost, O Pharaoh.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmcxxxii{%
And he wished to scare them from the land, but We drowned him and those with him, all together.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmcxxxiii{%
And We said unto the Children of Israel after him: Dwell in the land; but when the promise of the Hereafter cometh to pass We shall bring you as a crowd gathered out of various nations.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmcxxxiv{%
With truth have We sent it down, and with truth hath it descended. And We have sent thee as naught else save a bearer of good tidings and a warner.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmcxxxv{%
And (it is) a Qur'an that We have divided, that thou mayst recite it unto mankind at intervals, and We have revealed it by (successive) revelation.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmcxxxvi{%
Say: Believe therein or believe not, lo! those who were given knowledge before it, when it is read unto them, fall down prostrate on their faces, adoring,\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmcxxxvii{%
Saying: Glory to our Lord! Verily the promise of our Lord must be fulfilled.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmcxxxviii{%
They fall down on their faces, weeping, and it increaseth humility in them.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmcxxxix{%
Say (unto mankind): Cry unto Allah, or cry unto the Beneficent, unto whichsoever ye cry (it is the same). His are the most beautiful names. And thou (Muhammad), be not loud-voiced in thy worship nor yet silent therein, but follow a way between.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmcxl{%
And say: Praise be to Allah, Who hath not taken unto Himself a son, and Who hath no partner in the Sovereignty, nor hath He any protecting friend through dependence. And magnify Him with all magnificence.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmcxli{%
\basmalahen Praise be to Allah Who hath revealed the Scripture unto His slave, and hath not placed therein any crookedness,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcxlii{%
(But hath made it) straight, to give warning of stern punishment from Him, and to bring unto the believers who do good works the news that theirs will be a fair reward,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcxliii{%
Wherein they will abide for ever;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcxliv{%
And to warn those who say: Allah hath chosen a son,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcxlv{%
(A thing) whereof they have no knowledge, nor (had) their fathers, Dreadful is the word that cometh out of their mouths. They speak naught but a lie.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcxlvi{%
Yet it may be, if they believe not in this statement, that thou (Muhammad) wilt torment thy soul with grief over their footsteps.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcxlvii{%
Lo! We have placed all that is on the earth as an ornament thereof that We may try them: which of them is best in conduct.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcxlviii{%
And lo! We shall make all that is thereon a barren mound.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcxlix{%
Or deemest thou that the People of the Cave and the Inscription are a wonder among Our portents?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcl{%
When the young men fled for refuge to the Cave and said: Our Lord! Give us mercy from Thy presence, and shape for us right conduct in our plight.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcli{%
Then We sealed up their hearing in the Cave for a number of years.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmclii{%
And afterward We raised them up that We might know which of the two parties would best calculate the time that they had tarried.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcliii{%
We narrate unto thee their story with truth. Lo! they were young men who believed in their Lord, and We increased them in guidance.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcliv{%
And We made firm their hearts when they stood forth and said: Our Lord is the Lord of the heavens and the earth. We cry unto no Allah beside Him, for then should we utter an enormity.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmclv{%
These, our people, have chosen (other) gods beside Him though they bring no clear warrant (vouchsafed) to them. And who doth greater wrong than he who inventeth a lie concerning Allah?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmclvi{%
And when ye withdraw from them and that which they worship except Allah, then seek refuge in the Cave; your Lord will spread for you of His mercy and will prepare for you a pillow in your plight.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmclvii{%
And thou mightest have seen the sun when it rose move away from their cave to the right, and when it set go past them on the left, and they were in the cleft thereof. That was (one) of the portents of Allah. He whom Allah guideth, he indeed is led aright, and he whom He sendeth astray, for him thou wilt not find a guiding friend.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmclviii{%
And thou wouldst have deemed them waking though they were asleep, and We caused them to turn over to the right and the left, and their dog stretching out his paws on the threshold. If thou hadst observed them closely thou hadst assuredly turned away from them in flight, and hadst been filled with awe of them.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmclix{%
And in like manner We awakened them that they might question one another. A speaker from among them said: How long have ye tarried? They said: We have tarried a day or some part of a day, (Others) said: Your Lord best knoweth what ye have tarried. Now send one of you with this your silver coin unto the city, and let him see what food is purest there and bring you a supply thereof. Let him be courteous and let no man know of you.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmclx{%
For they, if they should come to know of you, will stone you or turn you back to their religion; then ye will never prosper.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmclxi{%
And in like manner We disclosed them (to the people of the city) that they might know that the promise of Allah is true, and that, as for the Hour, there is no doubt concerning it. When (the people of the city) disputed of their case among themselves, they said: Build over them a building; their Lord knoweth best concerning them. Those who won their point said: We verily shall build a place of worship over them.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmclxii{%
(Some) will say: They were three, their dog the fourth, and (some) say: Five, their dog the sixth, guessing at random; and (some) say: Seven, and their dog the eighth. Say (O Muhammad): My Lord is Best Aware of their number. None knoweth them save a few. So contend not concerning them except with an outward contending, and ask not any of them to pronounce concerning them.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmclxiii{%
And say not of anything: Lo! I shall do that tomorrow,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmclxiv{%
Except if Allah will. And remember thy Lord when thou forgettest, and say: It may be that my Lord guideth me unto a nearer way of truth than this.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmclxv{%
And (it is said) they tarried in their Cave three hundred years and add nine.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmclxvi{%
Say: Allah is Best Aware how long they tarried. His is the Invisible of the heavens and the earth. How clear of sight is He and keen of hearing! They have no protecting friend beside Him, and He maketh none to share in His government.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmclxvii{%
And recite that which hath been revealed unto thee of the Scripture of thy Lord. There is none who can change His words, and thou wilt find no refuge beside Him.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmclxviii{%
Restrain thyself along with those who cry unto their Lord at morn and evening, seeking His Countenance; and let not thine eyes overlook them, desiring the pomp of the life of the world; and obey not him whose heart We have made heedless of Our remembrance, who followeth his own lust and whose case hath been abandoned.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmclxix{%
Say: (It is) the truth from the Lord of you (all). Then whosoever will, let him believe, and whosoever will, let him disbelieve. Lo! We have prepared for disbelievers Fire. Its tent encloseth them. If they ask for showers, they will be showered with water like to molten lead which burneth the faces. Calamitous the drink and ill the resting-place!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmclxx{%
Lo! as for those who believe and do good works - Lo! We suffer not the reward of one whose work is goodly to be lost.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmclxxi{%
As for such, theirs will be Gardens of Eden, wherein rivers flow beneath them; therein they will be given armlets of gold and will wear green robes of finest silk and gold embroidery, reclining upon throne therein. Blest the reward, and fair the resting-place!\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmclxxii{%
Coin for them a similitude: Two men, unto one of whom We had assigned two gardens of grapes, and We had surrounded both with date-palms and had put between them tillage.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmclxxiii{%
Each of the gardens gave its fruit and withheld naught thereof. And We caused a river to gush forth therein.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmclxxiv{%
And he had fruit. And he said unto his comrade, when he spake with him: I am more than thee in wealth, and stronger in respect of men.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmclxxv{%
And he went into his garden, while he (thus) wronged himself. He said: I think not that all this will ever perish.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmclxxvi{%
I think not that the Hour will ever come, and if indeed I am brought back unto my Lord I surely shall find better than this as a resort.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmclxxvii{%
His comrade, when he (thus) spake with him, exclaimed: Disbelievest thou in Him Who created thee of dust, then of a drop (of seed), and then fashioned thee a man?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmclxxviii{%
But He is Allah, my Lord, and I ascribe unto my Lord no partner.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmclxxix{%
If only, when thou enteredst thy garden, thou hadst said: That which Allah willeth (will come to pass)! There is no strength save in Allah! Though thou seest me as less than thee in wealth and children,\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmclxxx{%
Yet it may be that my Lord will give me better than thy garden, and will send on it a bolt from heaven, and some morning it will be a smooth hillside,\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmclxxxi{%
Or some morning the water thereof will be lost in the earth so that thou canst not make search for it.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmclxxxii{%
And his fruit was beset (with destruction). Then began he to wring his hands for all that he had spent upon it, when (now) it was all ruined on its trellises, and to say: Would that I had ascribed no partner to my Lord!\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmclxxxiii{%
And he had no troop of men to help him as against Allah, nor could he save himself.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmclxxxiv{%
In this case is protection only from Allah, the True, He is Best for reward, and best for consequence.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmclxxxv{%
And coin for them the similitude of the life of the world as water which We send down from the sky, and the vegetation of the earth mingleth with it and then becometh dry twigs that the winds scatter. Allah is able to do all things.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmclxxxvi{%
Wealth and children are an ornament of the life of the world. But the good deeds which endure are better in thy Lord's sight for reward, and better in respect of hope.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmclxxxvii{%
And (bethink you of) the Day when we remove the hills and ye see the earth emerging, and We gather them together so as to leave not one of them behind.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmclxxxviii{%
And they are set before thy Lord in ranks (and it is said unto them): Now verily have ye come unto Us as We created you at the first. But ye thought that We had set no tryst for you.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmclxxxix{%
And the Book is placed, and thou seest the guilty fearful of that which is therein, and they say: What kind of a Book is this that leaveth not a small thing nor a great thing but hath counted it! And they find all that they did confronting them, and thy Lord wrongeth no-one.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcxc{%
And (remember) when We said unto the angels: Fall prostrate before Adam, and they fell prostrate, all save Iblis. He was of the jinn, so he rebelled against his Lord's command. Will ye choose him and his seed for your protecting friends instead of Me, when they are an enemy unto you? Calamitous is the exchange for evil-doers.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcxci{%
I made them not to witness the creation of the heavens and the earth, nor their own creation; nor choose I misleaders for (My) helpers.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcxcii{%
And (be mindful of) the Day when He will say: Call those partners of Mine whom ye pretended. Then they will cry unto them, but they will not hear their prayer, and We shall set a gulf of doom between them.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcxciii{%
And the guilty behold the Fire and know that they are about to fall therein, and they find no way of escape thence.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcxciv{%
And verily We have displayed for mankind in this Qur'an all manner of similitudes, but man is more than anything contentious.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcxcv{%
And naught hindereth mankind from believing when the guidance cometh unto them, and from asking forgiveness of their Lord unless (it be that they wish) that the judgment of the men of old should come upon them or (that) they should be confronted with the Doom.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcxcvi{%
We send not the messengers save as bearers of good news and warners. Those who disbelieve contend with falsehood in order to refute the Truth thereby. And they take Our revelations and that wherewith they are threatened as a jest.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcxcvii{%
And who doth greater wrong than he who hath been reminded of the revelations of his Lord, yet turneth away from them and forgetteth what his hands send forward (to the Judgment)? Lo! on their hearts We have placed coverings so that they understand not, and in their ears a deafness. And though thou call them to the guidance, in that case they can never be led aright.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcxcviii{%
Thy Lord is the Forgiver, Full of Mercy. If He took them to task (now) for what they earn, He would hasten on the doom for them; but theirs is an appointed term from which they will find no escape.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcxcix{%
And (all) those townships! We destroyed them when they did wrong, and We appointed a fixed time for their destruction.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcc{%
And when Moses said unto his servant: I will not give up until I reach the point where the two rivers meet, though I march on for ages.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcci{%
And when they reached the point where the two met, they forgot their fish, and it took its way into the waters, being free.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmccii{%
And when they had gone further, he said unto his servant: Bring us our breakfast. Verily we have found fatigue in this our journey.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcciii{%
He said: Didst thou see, when we took refuge on the rock, and I forgot the fish - and none but Satan caused me to forget to mention it - it took its way into the waters by a marvel.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcciv{%
He said: This is that which we have been seeking. So they retraced their steps again.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmccv{%
Then found they one of Our slaves, unto whom We had given mercy from Us, and had taught him knowledge from Our presence.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmccvi{%
Moses said unto him: May I follow thee, to the end that thou mayst teach me right conduct of that which thou hast been taught?\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmccvii{%
He said: Lo! thou canst not bear with me.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmccviii{%
How canst thou bear with that whereof thou canst not compass any knowledge?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmccix{%
He said: Allah willing, thou shalt find me patient and I shall not in aught gainsay thee.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmccx{%
He said: Well, if thou go with me, ask me not concerning aught till I myself make mention of it unto thee.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmccxi{%
So they twain set out till, when they were in the ship, he made a hole therein. (Moses) said: Hast thou made a hole therein to drown the folk thereof? Thou verily hast done a dreadful thing.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmccxii{%
He said: Did I not tell thee that thou couldst not bear with me?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmccxiii{%
(Moses) said: Be not wroth with me that I forgot, and be not hard upon me for my fault.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmccxiv{%
So they twain journeyed on till, when they met a lad, he slew him. (Moses) said: What! Hast thou slain an innocent soul who hath slain no man? Verily thou hast done a horrid thing.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmccxv{%
He said: Did I not tell thee that thou couldst not bear with me?\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmccxvi{%
(Moses) said: If I ask thee after this concerning aught, keep not company with me. Thou hast received an excuse from me.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmccxvii{%
So they twain journeyed on till, when they came unto the folk of a certain township, they asked its folk for food, but they refused to make them guests. And they found therein a wall upon the point of falling into ruin, and he repaired it. (Moses) said: If thou hadst wished, thou couldst have taken payment for it.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmccxviii{%
He said: This is the parting between thee and me! I will announce unto thee the interpretation of that thou couldst not bear with patience.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmccxix{%
As for the ship, it belonged to poor people working on the river, and I wished to mar it, for there was a king behind them who is taking every ship by force.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmccxx{%
And as for the lad, his parents were believers and we feared lest he should oppress them by rebellion and disbelief.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmccxxi{%
And we intended that their Lord should change him for them for one better in purity and nearer to mercy.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmccxxii{%
And as for the wall, it belonged to two orphan boys in the city, and there was beneath it a treasure belonging to them, and their father had been righteous, and thy Lord intended that they should come to their full strength and should bring forth their treasure as a mercy from their Lord; and I did it not upon my own command. Such is the interpretation of that wherewith thou couldst not bear.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmccxxiii{%
They will ask thee of Dhu'l-Qarneyn. Say: I shall recite unto you a remembrance of him.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmccxxiv{%
Lo! We made him strong in the land and gave him unto every thing a road.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmccxxv{%
And he followed a road\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmccxxvi{%
Till, when he reached the setting-place of the sun, he found it setting in a muddy spring, and found a people thereabout. We said: O Dhu'l-Qarneyn! Either punish or show them kindness.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmccxxvii{%
He said: As for him who doeth wrong, we shall punish him, and then he will be brought back unto his Lord, Who will punish him with awful punishment!\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmccxxviii{%
But as for him who believeth and doeth right, good will be his reward, and We shall speak unto him a mild command.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmccxxix{%
Then he followed a road\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmccxxx{%
Till, when he reached the rising-place of the sun, he found it rising on a people for whom We had appointed no shelter therefrom.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmccxxxi{%
So (it was). And We knew all concerning him.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmccxxxii{%
Then he followed a road\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmccxxxiii{%
Till, when he came between the two mountains, he found upon their hither side a folk that scarce could understand a saying.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmccxxxiv{%
They said: O Dhu'l-Qarneyn! Lo! Gog and Magog are spoiling the land. So may we pay thee tribute on condition that thou set a barrier between us and them?\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmccxxxv{%
He said: That wherein my Lord hath established me is better (than your tribute). Do but help me with strength (of men), I will set between you and them a bank.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmccxxxvi{%
Give me pieces of iron - till, when he had levelled up (the gap) between the cliffs, he said: Blow! - till, when he had made it a fire, he said: Bring me molten copper to pour thereon.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmccxxxvii{%
And (Gog and Magog) were not able to surmount, nor could they pierce (it).\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmccxxxviii{%
He said: This is a mercy from my Lord; but when the promise of my Lord cometh to pass, He will lay it low, for the promise of my Lord is true.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmccxxxix{%
And on that day we shall let some of them surge against others, and the Trumpet will be blown. Then We shall gather them together in one gathering.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmccxl{%
On that day we shall present hell to the disbelievers, plain to view,\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmccxli{%
Those whose eyes were hoodwinked from My reminder, and who could not bear to hear.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmccxlii{%
Do the disbelievers reckon that they can choose My bondmen as protecting friends beside Me? Lo! We have prepared hell as a welcome for the disbelievers.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmccxliii{%
Say: Shall We inform you who will be the greatest losers by their works?\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmccxliv{%
Those whose effort goeth astray in the life of the world, and yet they reckon that they do good work.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmccxlv{%
Those are they who disbelieve in the revelations of their Lord and in the meeting with Him. Therefor their works are vain, and on the Day of Resurrection We assign no weight to them.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmccxlvi{%
That is their reward: hell, because they disbelieved, and made a jest of Our revelations and Our messengers.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmccxlvii{%
Lo! those who believe and do good works, theirs are the Gardens of Paradise for welcome,\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmccxlviii{%
Wherein they will abide, with no desire to be removed from thence.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmccxlix{%
Say: Though the sea became ink for the Words of my Lord, verily the sea would be used up before the words of my Lord were exhausted, even though We brought the like thereof to help.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmccl{%
Say: I am only a mortal like you. My Lord inspireth in me that your Allah is only One Allah. And whoever hopeth for the meeting with his Lord, let him do righteous work, and make none sharer of the worship due unto his Lord.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmccli{%
\basmalahen Kaf. Ha. Ya. A'in. Sad.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcclii{%
A mention of the mercy of thy Lord unto His servant Zachariah.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmccliii{%
When he cried unto his Lord a cry in secret,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmccliv{%
Saying: My Lord! Lo! the bones of me wax feeble and my head is shining with grey hair, and I have never been unblest in prayer to Thee, my Lord.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcclv{%
Lo! I fear my kinsfolk after me, since my wife is barren. Oh, give me from Thy presence a successor\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcclvi{%
Who shall inherit of me and inherit (also) of the house of Jacob. And make him, my Lord, acceptable (unto Thee).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcclvii{%
(It was said unto him): O Zachariah! Lo! We bring thee tidings of a son whose name is John; we have given the same name to none before (him).\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcclviii{%
He said: My Lord! How can I have a son when my wife is barren and I have reached infirm old age?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcclix{%
He said: So (it will be). Thy Lord saith: It is easy for Me, even as I created thee before, when thou wast naught.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcclx{%
He said: My Lord! Appoint for me some token. He said: Thy token is that thou, with no bodily defect, shalt not speak unto mankind three nights.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcclxi{%
Then he came forth unto his people from the sanctuary, and signified to them: Glorify your Lord at break of day and fall of night.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcclxii{%
(And it was said unto his son): O John! Hold fast the Scripture. And we gave him wisdom when a child,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcclxiii{%
And compassion from Our presence, and purity; and he was devout,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcclxiv{%
And dutiful toward his parents. And he was not arrogant, rebellious.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcclxv{%
Peace on him the day he was born, and the day he dieth and the day he shall be raised alive!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcclxvi{%
And make mention of Mary in the Scripture, when she had withdrawn from her people to a chamber looking East,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmcclxvii{%
And had chosen seclusion from them. Then We sent unto her Our Spirit and it assumed for her the likeness of a perfect man.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmcclxviii{%
She said: Lo! I seek refuge in the Beneficent One from thee, if thou art Allah-fearing.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmcclxix{%
He said: I am only a messenger of thy Lord, that I may bestow on thee a faultless son.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmcclxx{%
She said: How can I have a son when no mortal hath touched me, neither have I been unchaste?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmcclxxi{%
He said: So (it will be). Thy Lord saith: It is easy for Me. And (it will be) that We may make of him a revelation for mankind and a mercy from Us, and it is a thing ordained.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmcclxxii{%
And she conceived him, and she withdrew with him to a far place.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmcclxxiii{%
And the pangs of childbirth drove her unto the trunk of the palm-tree. She said: Oh, would that I had died ere this and had become a thing of naught, forgotten!\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmcclxxiv{%
Then (one) cried unto her from below her, saying: Grieve not! Thy Lord hath placed a rivulet beneath thee,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmcclxxv{%
And shake the trunk of the palm-tree toward thee, thou wilt cause ripe dates to fall upon thee.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmcclxxvi{%
So eat and drink and be consoled. And if thou meetest any mortal, say: Lo! I have vowed a fast unto the Beneficent, and may not speak this day to any mortal.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmcclxxvii{%
Then she brought him to her own folk, carrying him. They said: O Mary! Thou hast come with an amazing thing.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmcclxxviii{%
O sister of Aaron! Thy father was not a wicked man nor was thy mother a harlot.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmcclxxix{%
Then she pointed to him. They said: How can we talk to one who is in the cradle, a young boy?\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmcclxxx{%
He spake: Lo! I am the slave of Allah. He hath given me the Scripture and hath appointed me a Prophet,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmcclxxxi{%
And hath made me blessed wheresoever I may be, and hath enjoined upon me prayer and almsgiving so long as I remain alive,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmcclxxxii{%
And (hath made me) dutiful toward her who bore me, and hath not made me arrogant, unblest.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmcclxxxiii{%
Peace on me the day I was born, and the day I die, and the day I shall be raised alive!\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmcclxxxiv{%
Such was Jesus, son of Mary: (this is) a statement of the truth concerning which they doubt.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmcclxxxv{%
It befitteth not (the Majesty of) Allah that He should take unto Himself a son. Glory be to Him! When He decreeth a thing, He saith unto it only: Be! and it is.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmcclxxxvi{%
And lo! Allah is my Lord and your Lord. So serve Him. That is the right path.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmcclxxxvii{%
The sects among them differ: but woe unto the disbelievers from the meeting of an awful Day.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmcclxxxviii{%
See and hear them on the Day they come unto Us! yet the evil-doers are to-day in error manifest.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmcclxxxix{%
And warn them of the Day of anguish when the case hath been decided. Now they are in a state of carelessness, and they believe not.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmccxc{%
Lo! We, only We, inherit the earth and all who are thereon, and unto Us they are returned.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmccxci{%
And make mention (O Muhammad) in the Scripture of Abraham. Lo! he was a saint, a prophet.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmccxcii{%
When he said unto his father: O my father! Why worshippest thou that which heareth not nor seeth, nor can in aught avail thee?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmccxciii{%
O my father! Lo! there hath come unto me of knowledge that which came not unto thee. So follow me, and I will lead thee on a right path.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmccxciv{%
O my father! Serve not the devil. Lo! the devil is a rebel unto the Beneficent.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmccxcv{%
O my father! Lo! I fear lest a punishment from the Beneficent overtake thee so that thou become a comrade of the devil.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmccxcvi{%
He said: Rejectest thou my gods, O Abraham? If thou cease not, I shall surely stone thee. Depart from me a long while!\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmccxcvii{%
He said: Peace be unto thee! I shall ask forgiveness of my Lord for thee. Lo! He was ever gracious unto me.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmccxcviii{%
I shall withdraw from you and that unto which ye pray beside Allah, and I shall pray unto my Lord. It may be that, in prayer unto my Lord, I shall not be unblest.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmccxcix{%
So, when he had withdrawn from them and that which they were worshipping beside Allah, We gave him Isaac and Jacob. Each of them We made a prophet.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmccc{%
And we gave them of Our mercy, and assigned to them a high and true renown.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmccci{%
And make mention in the Scripture of Moses. Lo! he was chosen, and he was a messenger (of Allah), a prophet.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcccii{%
We called him from the right slope of the Mount, and brought him nigh in communion.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmccciii{%
And We bestowed upon him of Our mercy his brother Aaron, a prophet (likewise).\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmccciv{%
And make mention in the Scripture of Ishmael. Lo! he was a keeper of his promise, and he was a messenger (of Allah), a prophet.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcccv{%
He enjoined upon his people worship and almsgiving, and was acceptable in the sight of his Lord.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcccvi{%
And make mention in the Scripture of Idris. Lo! he was a saint, a prophet;\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcccvii{%
And We raised him to high station.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcccviii{%
These are they unto whom Allah showed favour from among the prophets, of the seed of Adam and of those whom We carried (in the ship) with Noah, and of the seed of Abraham and Israel, and from among those whom We guided and chose. When the revelations of the Beneficent were recited unto them, they fell down, adoring and weeping.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcccix{%
Now there hath succeeded them a later generation whom have ruined worship and have followed lusts. But they will meet deception.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcccx{%
Save him who shall repent and believe and do right. Such will enter the Garden, and they will not be wronged in aught -\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcccxi{%
Gardens of Eden, which the Beneficent hath promised to His slaves in the unseen. Lo! His promise is ever sure of fulfilment -\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcccxii{%
They hear therein no idle talk, but only Peace; and therein they have food for morn and evening.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcccxiii{%
Such is the Garden which We cause the devout among Our bondmen to inherit.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcccxiv{%
We (angels) come not down save by commandment of thy Lord. Unto Him belongeth all that is before us and all that is behind us and all that is between those two, and thy Lord was never forgetful -\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcccxv{%
Lord of the heavens and the earth and all that is between them! Therefor, worship thou Him and be thou steadfast in His service. Knowest thou one that can be named along with Him?\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcccxvi{%
And man saith: When I am dead, shall I forsooth be brought forth alive?\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcccxvii{%
Doth not man remember that We created him before, when he was naught?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcccxviii{%
And, by thy Lord, verily We shall assemble them and the devils, then We shall bring them, crouching, around hell.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcccxix{%
Then We shall pluck out from every sect whichever of them was most stubborn in rebellion to the Beneficent.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcccxx{%
And surely We are Best Aware of those most worthy to be burned therein.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcccxxi{%
There is not one of you but shall approach it. That is a fixed ordinance of thy Lord.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcccxxii{%
Then We shall rescue those who kept from evil, and leave the evil-doers crouching there.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcccxxiii{%
And when Our clear revelations are recited unto them, those who disbelieve say unto those who believe: Which of the two parties (yours or ours) is better in position, and more imposing as an army?\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcccxxiv{%
How many a generation have We destroyed before them, who were more imposing in respect of gear and outward seeming!\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcccxxv{%
Say: As for him who is in error, the Beneficent will verily prolong his span of life until, when they behold that which they were promised, whether it be punishment (in the world), or the Hour (of doom), they will know who is worse in position and who is weaker as an army.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcccxxvi{%
Allah increaseth in right guidance those who walk aright, and the good deeds which endure are better in thy Lord's sight for reward, and better for resort.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcccxxvii{%
Hast thou seen him who disbelieveth in Our revelations and saith: Assuredly I shall be given wealth and children?\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcccxxviii{%
Hath he perused the Unseen, or hath he made a pact with the Beneficent?\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcccxxix{%
Nay, but We shall record that which he saith and prolong for him a span of torment.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcccxxx{%
And We shall inherit from him that whereof he spake, and he will come unto Us, alone (without his wealth and children).\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcccxxxi{%
And they have chosen (other) gods beside Allah that they may be a power for them.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcccxxxii{%
Nay, but they will deny their worship of them, and become opponents unto them.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcccxxxiii{%
Seest thou not that We have set the devils on the disbelievers to confound them with confusion?\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcccxxxiv{%
So make no haste against them (O Muhammad). We do but number unto them a sum (of days).\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcccxxxv{%
On the day when We shall gather the righteous unto the Beneficent, a goodly company.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcccxxxvi{%
And drive the guilty unto hell, a weary herd,\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcccxxxvii{%
They will have no power of intercession, save him who hath made a covenant with his Lord.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcccxxxviii{%
And they say: The Beneficent hath taken unto Himself a son.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcccxxxix{%
Assuredly ye utter a disastrous thing\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcccxl{%
Whereby almost the heavens are torn, and the earth is split asunder and the mountains fall in ruins,\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcccxli{%
That ye ascribe unto the Beneficent a son,\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcccxlii{%
When it is not meet for (the Majesty of) the Beneficent that He should choose a son.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcccxliii{%
There is none in the heavens and the earth but cometh unto the Beneficent as a slave.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcccxliv{%
Verily He knoweth them and numbereth them with (right) numbering.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcccxlv{%
And each one of them will come unto Him on the Day of Resurrection, alone.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcccxlvi{%
Lo! those who believe and do good works, the Beneficent will appoint for them love.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcccxlvii{%
And We make (this Scripture) easy in thy tongue, (O Muhammad) only that thou mayst bear good tidings therewith unto those who ward off (evil), and warn therewith the froward folk.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcccxlviii{%
And how many a generation before them have We destroyed! Canst thou (Muhammad) see a single man of them, or hear from them the slightest sound?\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcccxlix{%
\basmalahen Ta. Ha.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcccl{%
We have not revealed unto thee (Muhammad) this Qur'an that thou shouldst be distressed,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcccli{%
But as a reminder unto him who feareth,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmccclii{%
A revelation from Him Who created the earth and the high heavens,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcccliii{%
The Beneficent One, Who is established on the Throne.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcccliv{%
Unto Him belongeth whatsoever is in the heavens and whatsoever is in the earth, and whatsoever is between them, and whatsoever is beneath the sod.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmccclv{%
And if thou speakest aloud, then lo! He knoweth the secret (thought) and (that which is yet) more hidden.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmccclvi{%
Allah! There is no Allah save Him. His are the most beautiful names.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmccclvii{%
Hath there come unto thee the story of Moses?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmccclviii{%
When he saw a fire and said unto his folk: Lo! Wait! I see a fire afar off. Peradventure I may bring you a brand therefrom or may find guidance at the fire.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmccclix{%
And when he reached it, he was called by name: O Moses!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmccclx{%
Lo! I, even I, am thy Lord, So take off thy shoes, for lo! thou art in the holy valley of Tuwa.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmccclxi{%
And I have chosen thee, so hearken unto that which is inspired.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmccclxii{%
Lo! I, even I, am Allah, There is no Allah save Me. So serve Me and establish worship for My remembrance.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmccclxiii{%
Lo! the Hour is surely coming. But I will to keep it hidden, that every soul may be rewarded for that which it striveth (to achieve).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmccclxiv{%
Therefor, let not him turn thee aside from (the thought of) it who believeth not therein but followeth his own desire, lest thou perish.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmccclxv{%
And what is that in thy right hand, O Moses?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmccclxvi{%
He said: This is my staff whereon I lean, and wherewith I bear down branches for my sheep, and wherein I find other uses.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmccclxvii{%
He said: Cast it down, O Moses!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmccclxviii{%
So he cast it down, and lo! it was a serpent, gliding.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmccclxix{%
He said: Grasp it and fear not. We shall return it to its former state.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmccclxx{%
And thrust thy hand within thine armpit, it will come forth white without hurt. (That will be) another token.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmccclxxi{%
That We may show thee (some) of Our greater portents,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmccclxxii{%
Go thou unto Pharaoh! Lo! he hath transgressed (the bounds).\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmccclxxiii{%
(Moses) said: My Lord! relieve my mind\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmccclxxiv{%
And ease my task for me;\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmccclxxv{%
And loose a knot from my tongue,\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmccclxxvi{%
That they may understand my saying.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmccclxxvii{%
Appoint for me a henchman from my folk,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmccclxxviii{%
Aaron, my brother.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmccclxxix{%
Confirm my strength with him\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmccclxxx{%
And let him share my task,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmccclxxxi{%
That we may glorify Thee much\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmccclxxxii{%
And much remember Thee.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmccclxxxiii{%
Lo! Thou art ever Seeing us.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmccclxxxiv{%
He said: Thou art granted thy request, O Moses.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmccclxxxv{%
And indeed, another time, already We have shown thee favour,\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmccclxxxvi{%
When we inspired in thy mother that which is inspired,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmccclxxxvii{%
Saying: Throw him into the ark, and throw it into the river, then the river shall throw it on to the bank, and there an enemy to Me and an enemy to him shall take him. And I endued thee with love from Me that thou mightest be trained according to My will,\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmccclxxxviii{%
When thy sister went and said: Shall I show you one who will nurse him? and we restored thee to thy mother that her eyes might be refreshed and might not sorrow. And thou didst kill a man and We delivered thee from great distress, and tried thee with a heavy trial. And thou didst tarry years among the folk of Midian. Then camest thou (hither) by (My) providence, O Moses,\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmccclxxxix{%
And I have attached thee to Myself.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmcccxc{%
Go, thou and thy brother, with My tokens, and be not faint in remembrance of Me.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmcccxci{%
Go, both of you, unto Pharaoh. Lo! he hath transgressed (the bounds).\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmcccxcii{%
And speak unto him a gentle word, that peradventure he may heed or fear.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcccxciii{%
They said: Our Lord! Lo! we fear that he may be beforehand with us or that he may play the tyrant.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcccxciv{%
He said: Fear not. Lo! I am with you twain, Hearing and Seeing.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcccxcv{%
So go ye unto him and say: Lo! we are two messengers of thy Lord. So let the children of Israel go with us, and torment them not. We bring thee a token from thy Lord. And peace will be for him who followeth right guidance.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcccxcvi{%
Lo! it hath been revealed unto us that the doom will be for him who denieth and turneth away.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcccxcvii{%
(Pharaoh) said: Who then is the Lord of you twain, O Moses?\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcccxcviii{%
He said: Our Lord is He Who gave unto everything its nature, then guided it aright.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcccxcix{%
He said: What then is the state of the generations of old?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcd{%
He said: The knowledge thereof is with my Lord in a Record. My Lord neither erreth nor forgetteth,\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcdi{%
Who hath appointed the earth as a bed and hath threaded roads for you therein and hath sent down water from the sky and thereby We have brought forth divers kinds of vegetation,\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcdii{%
(Saying): Eat ye and feed your cattle. Lo! herein verily are portents for men of thought.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcdiii{%
Thereof We created you, and thereunto We return you, and thence We bring you forth a second time.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcdiv{%
And We verily did show him all Our tokens, but he denied them and refused.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcdv{%
He said: Hast come to drive us out from our land by thy magic, O Moses?\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcdvi{%
But we surely can produce for thee magic the like thereof; so appoint a tryst between us and you, which neither we nor thou shall fail to keep, at a place convenient (to us both).\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcdvii{%
(Moses) said: Your tryst shall be the day of the feast, and let the people assemble when the sun hath risen high.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcdviii{%
Then Pharaoh went and gathered his strength, then came (to the appointed tryst).\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcdix{%
Moses said unto them: Woe unto you! Invent not a lie against Allah, lest He extirpate you by some punishment. He who lieth faileth miserably.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcdx{%
Then they debated one with another what they must do, and they kept their counsel secret.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcdxi{%
They said: Lo! these are two wizards who would drive you out from your country by their magic, and destroy your best traditions;\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcdxii{%
So arrange your plan, and come in battle line. Whoso is uppermost this day will be indeed successful.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcdxiii{%
They said: O Moses! Either throw first, or let us be the first to throw?\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcdxiv{%
He said: Nay, do ye throw! Then lo! their cords and their staves, by their magic, appeared to him as though they ran.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcdxv{%
And Moses conceived a fear in his mind.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcdxvi{%
We said: Fear not! Lo! thou art the higher.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcdxvii{%
Throw that which is in thy right hand! It will eat up that which they have made. Lo! that which they have made is but a wizard's artifice, and a wizard shall not be successful to whatever point (of skill) he may attain.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcdxviii{%
Then the wizards were (all) flung down prostrate, crying: We believe in the Lord of Aaron and Moses.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcdxix{%
(Pharaoh) said: Ye put faith in him before I give you leave. Lo! he is your chief who taught you magic. Now surely I shall cut off your hands and your feet alternately, and I shall crucify you on the trunks of palm trees, and ye shall know for certain which of us hath sterner and more lasting punishment.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcdxx{%
They said: We choose thee not above the clear proofs that have come unto us, and above Him Who created us. So decree what thou wilt decree. Thou wilt end for us only this life of the world.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcdxxi{%
Lo! we believe in our Lord, that He may forgive us our sins and the magic unto which thou didst force us. Allah is better and more lasting.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcdxxii{%
Lo! whoso cometh guilty unto his Lord, verily for him is hell. There he will neither die nor live.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcdxxiii{%
But whoso cometh unto Him a believer, having done good works, for such are the high stations;\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcdxxiv{%
Gardens of Eden underneath which rivers flow, wherein they will abide for ever. That is the reward of him who groweth.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcdxxv{%
And verily We inspired Moses, saying: Take away My slaves by night and strike for them a dry path in the sea, fearing not to be overtaken, neither being afraid (of the sea).\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcdxxvi{%
Then Pharaoh followed them with his hosts and there covered them that which did cover them of the sea.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcdxxvii{%
And Pharaoh led his folk astray, he did not guide them.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcdxxviii{%
O Children of Israel! We delivered you from your enemy, and we made a covenant with you on the holy mountain's side, and sent down on you the manna and the quails,\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcdxxix{%
(Saying): Eat of the good things wherewith We have provided you, and transgress not in respect thereof lest My wrath come upon you: and he on whom My wrath cometh, he is lost indeed.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcdxxx{%
And lo! verily I am Forgiving toward him who repenteth and believeth and doeth good, and afterward walketh aright.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcdxxxi{%
And (it was said): What hath made thee hasten from thy folk, O Moses?\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcdxxxii{%
He said: They are close upon my track. I hastened unto Thee, my Lord, that Thou mightest be well pleased.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcdxxxiii{%
He said: Lo! We have tried thy folk in thine absence, and As-Samiri hath misled them.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcdxxxiv{%
Then Moses went back unto his folk, angry and sad. He said: O my people! Hath not your Lord promised you a fair promise? Did the time appointed then appear too long for you, or did ye wish that wrath from your Lord should come upon you, that ye broke tryst with me?\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcdxxxv{%
They said: We broke not tryst with thee of our own will, but we were laden with burdens of ornaments of the folk, then cast them (in the fire), for thus As-Samiri proposed.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcdxxxvi{%
Then he produced for them a calf, of saffron hue, which gave forth a lowing sound. And they cried: This is your god and the god of Moses, but he hath forgotten.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcdxxxvii{%
See they not, then, that it returneth no saying unto them and possesseth for them neither hurt nor use?\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcdxxxviii{%
And Aaron indeed had told them beforehand: O my people! Ye are but being seduced therewith, for lo! your Lord is the Beneficent, so follow me and obey my order.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcdxxxix{%
They said: We shall by no means cease to be its votaries till Moses return unto us.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcdxl{%
He (Moses) said: O Aaron! What held thee back when thou didst see them gone astray,\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcdxli{%
That thou followedst me not? Hast thou then disobeyed my order?\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcdxlii{%
He said: O son of my mother! Clutch not my beard nor my head! I feared lest thou shouldst say: Thou hast caused division among the Children of Israel, and hast not waited for my word.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcdxliii{%
(Moses) said: And what hast thou to say, O Samiri?\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcdxliv{%
He said: I perceived what they perceive not, so I seized a handful from the footsteps of the messenger, and then threw it in. Thus my soul commended to me.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcdxlv{%
(Moses) said: Then go! and lo! in this life it is for thee to say: Touch me not! and lo! there is for thee a tryst thou canst not break. Now look upon thy god of which thou hast remained a votary. Verily we will burn it and will scatter its dust over the sea.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcdxlvi{%
Your Allah is only Allah, than Whom there is no other Allah. He embraceth all things in His knowledge.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcdxlvii{%
Thus relate We unto thee (Muhammad) some tidings of that which happened of old, and We have given thee from Our presence a reminder.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmcdxlviii{%
Whoso turneth away from it, he verily will bear a burden on the Day of Resurrection,\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmcdxlix{%
Abiding under it - an evil burden for them on the Day of Resurrection,\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmcdl{%
The day when the Trumpet is blown. On that day we assemble the guilty white-eyed (with terror),\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmcdli{%
Murmuring among themselves: Ye have tarried but ten (days).\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmcdlii{%
We are Best Aware of what they utter when their best in conduct say: Ye have tarried but a day.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmcdliii{%
They will ask thee of the mountains (on that day). Say: My Lord will break them into scattered dust.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmcdliv{%
And leave it as an empty plain,\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmcdlv{%
Wherein thou seest neither curve nor ruggedness.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmcdlvi{%
On that day they follow the summoner who deceiveth not, and voices are hushed for the Beneficent, and thou hearest but a faint murmur.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmcdlvii{%
On that day no intercession availeth save (that of) him unto whom the Beneficent hath given leave and whose word He accepteth.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmcdlviii{%
He knoweth (all) that is before them and (all) that is behind them, while they cannot compass it in knowledge.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmcdlix{%
And faces humble themselves before the Living, the Eternal. And he who beareth (a burden of) wrongdoing is indeed a failure (on that day).\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmcdlx{%
And he who hath done some good works, being a believer, he feareth not injustice nor begrudging (of his wage).\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmcdlxi{%
Thus we have revealed it as a Lecture in Arabic, and have displayed therein certain threats, that peradventure they may keep from evil or that it may cause them to take heed.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmcdlxii{%
Then exalted be Allah, the True King! And hasten not (O Muhammad) with the Qur'an ere its revelation hath been perfected unto thee, and say: My Lord! Increase me in knowledge.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmcdlxiii{%
And verily We made a covenant of old with Adam, but he forgot, and We found no constancy in him.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmcdlxiv{%
And when We said unto the angels: Fall prostrate before Adam, they fell prostrate (all) save Iblis; he refused.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmcdlxv{%
Therefor we said: O Adam! This is an enemy unto thee and unto thy wife, so let him not drive you both out of the Garden so that thou come to toil.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmcdlxvi{%
It is (vouchsafed) unto thee that thou hungerest not therein nor art naked,\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmcdlxvii{%
And that thou thirstest not therein nor art exposed to the sun's heat.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmcdlxviii{%
But the devil whispered to him, saying: O Adam! Shall I show thee the tree of immortality and power that wasteth not away?\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmcdlxix{%
Then they twain ate thereof, so that their shame became apparent unto them, and they began to hide by heaping on themselves some of the leaves of the Garden. And Adam disobeyed his Lord, so went astray.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmcdlxx{%
Then his Lord chose him, and relented toward him, and guided him.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmcdlxxi{%
He said: Go down hence, both of you, one of you a foe unto the other. But when there come unto you from Me a guidance, then whoso followeth My guidance, he will not go astray nor come to grief.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmcdlxxii{%
But he who turneth away from remembrance of Me, his will be a narrow life, and I shall bring him blind to the assembly on the Day of Resurrection.\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmcdlxxiii{%
He will say: My Lord! Wherefor hast Thou gathered me (hither) blind, when I was wont to see?\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmcdlxxiv{%
He will say: So (it must be). Our revelations came unto thee but thou didst forget them. In like manner thou art forgotten this Day.\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmcdlxxv{%
Thus do We reward him who is prodigal and believeth not the revelations of his Lord; and verily the doom of the Hereafter will be sterner and more lasting.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmcdlxxvi{%
Is it not a guidance for them (to know) how many a generation We destroyed before them, amid whose dwellings they walk? Lo! therein verily are signs for men of thought.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmcdlxxvii{%
And but for a decree that had already gone forth from thy Lord, and a term already fixed, the judgment would have been inevitable (in this world).\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmcdlxxviii{%
Therefor (O Muhammad), bear with what they say, and celebrate the praise of thy Lord ere the rising of the sun and ere the going down thereof. And glorify Him some hours of the night and at the two ends of the day, that thou mayst find acceptance.\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmcdlxxix{%
And strain not thine eyes toward that which We cause some wedded pairs among them to enjoy, the flower of the life of the world, that We may try them thereby. The provision of thy Lord is better and more lasting.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmcdlxxx{%
And enjoin upon thy people worship, and be constant therein. We ask not of thee a provision: We provided for thee. And the sequel is for righteousness.\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmcdlxxxi{%
And they say: If only he would bring us a miracle from his Lord! Hath there not come unto them the proof of what is in the former scriptures?\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmcdlxxxii{%
And if we had destroyed them with some punishment before it, they would assuredly have said: Our Lord! If only Thou hadst sent unto us a messenger, so that we might have followed Thy revelations before we were (thus) humbled and disgraced!\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmcdlxxxiii{%
Say: Each is awaiting; so await ye! Ye will come to know who are the owners of the path of equity, and who is right.\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmcdlxxxiv{%
\basmalahen Their reckoning draweth nigh for mankind, while they turn away in heedlessness.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcdlxxxv{%
Never cometh there unto them a new reminder from their Lord but they listen to it while they play,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcdlxxxvi{%
With hearts preoccupied. And they confer in secret. The wrong-doers say: Is this other than a mortal like you? Will ye then succumb to magic when ye see (it)?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcdlxxxvii{%
He saith: My Lord knoweth what is spoken in the heaven and the earth. He is the Hearer, the Knower.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcdlxxxviii{%
Nay, say they, (these are but) muddled dreams; nay, he hath but invented it; nay, he is but a poet. Let him bring us a portent even as those of old (who were Allah's messengers) were sent (with portents).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcdlxxxix{%
Not a township believed of those which We destroyed before them (though We sent them portents): would they then believe?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcdxc{%
And We sent not (as Our messengers) before thee other than men, whom We inspired. Ask the followers of the Reminder if ye know not?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcdxci{%
We gave them not bodies that would not eat food, nor were they immortals.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcdxcii{%
Then we fulfilled the promise unto them. So we delivered them and whom We would, and We destroyed the prodigals.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcdxciii{%
Now We have revealed unto you a Scripture wherein is your Reminder. Have ye then no sense?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcdxciv{%
How many a community that dealt unjustly have We shattered, and raised up after them another folk!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcdxcv{%
And, when they felt Our might, behold them fleeing from it!\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcdxcvi{%
(But it was said unto them): Flee not, but return to that (existence) which emasculated you and to your dwellings, that ye may be questioned.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcdxcvii{%
They cried: Alas for us! we were wrong-doers.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcdxcviii{%
And this their crying ceased not till We made them as reaped corn, extinct.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcdxcix{%
We created not the heaven and the earth and all that is between them in play.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmd{%
If We had wished to find a pastime, We could have found it in Our presence - if We ever did.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdi{%
Nay, but We hurl the true against the false, and it doth break its head and lo! it vanisheth. And yours will be woe for that which ye ascribe (unto Him).\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdii{%
Unto Him belongeth whosoever is in the heavens and the earth. And those who dwell in His presence are not too proud to worship Him, nor do they weary;\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdiii{%
They glorify (Him) night and day; they flag not.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdiv{%
Or have they chosen gods from the earth who raise the dead?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdv{%
If there were therein gods beside Allah, then verily both (the heavens and the earth) had been disordered. Glorified be Allah, the Lord of the Throne, from all that they ascribe (unto Him).\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdvi{%
He will not be questioned as to that which He doeth, but they will be questioned.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdvii{%
Or have they chosen other gods beside Him? say: Bring your proof (of their godhead). This is the Reminder of those with me and those before me, but most of them know not the Truth and so they are averse.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdviii{%
And We sent no messenger before thee but We inspired him, (saying): There is no Allah save Me (Allah), so worship Me.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdix{%
And they say: The Beneficent hath taken unto Himself a son. Be He Glorified! Nay, but (those whom they call sons) are honoured slaves;\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdx{%
They speak not until He hath spoken, and they act by His command.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdxi{%
He knoweth what is before them and what is behind them, and they cannot intercede except for him whom He accepteth, and they quake for awe of Him.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdxii{%
And one of them who should say: Lo! I am a god beside Him, that one We should repay with hell. Thus We Repay wrong-doers.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdxiii{%
Have not those who disbelieve known that the heavens and the earth were of one piece, then We parted them, and we made every living thing of water? Will they not then believe?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdxiv{%
And We have placed in the earth firm hills lest it quake with them, and We have placed therein ravines as roads that haply they may find their way.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdxv{%
And we have made the sky a roof withheld (from them). Yet they turn away from its portents.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdxvi{%
And He it is Who created the night and the day, and the sun and the moon. They float, each in an orbit.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdxvii{%
We appointed immortality for no mortal before thee. What! if thou diest, can they be immortal!\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdxviii{%
Every soul must taste of death, and We try you with evil and with good, for ordeal. And unto Us ye will be returned.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdxix{%
And when those who disbelieve behold thee, they but choose thee out for mockery, (saying): Is this he who maketh mention of your gods? And they would deny all mention of the Beneficent.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdxx{%
Man is made of haste. I shall show you My portents, but ask Me not to hasten.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdxxi{%
And they say: When will this promise (be fulfilled), if ye are truthful?\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdxxii{%
If those who disbelieved but knew the time when they will not be able to drive off the fire from their faces and from their backs, and they will not be helped!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdxxiii{%
Nay, but it will come upon them unawares so that it will stupefy them, and they will be unable to repel it, neither will they be reprieved.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdxxiv{%
Messengers before thee, indeed, were mocked, but that whereat they mocked surrounded those who scoffed at them.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdxxv{%
Say: Who guardeth you in the night or in the day from the Beneficent? Nay, but they turn away from mention of their Lord!\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdxxvi{%
Or have they gods who can shield them from Us? They cannot help themselves nor can they be defended from Us.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdxxvii{%
Nay, but We gave these and their fathers ease until life grew long for them. See they not how we aim to the land, reducing it of its outlying parts? Can they then be the victors?\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdxxviii{%
Say (O Muhammad, unto mankind): I warn you only by the Inspiration. But the deaf hear not the call when they are warned.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdxxix{%
And if a breath of thy Lord's punishment were to touch them, they assuredly would say: Alas for us! Lo! we were wrong-doers.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdxxx{%
And We set a just balance for the Day of Resurrection so that no soul is wronged in aught. Though it be of the weight of a grain of mustard seed, We bring it. And We suffice for reckoners.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdxxxi{%
And We verily gave Moses and Aaron the Criterion (of right and wrong) and a light and a Reminder for those who keep from evil,\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdxxxii{%
Those who fear their Lord in secret and who dread the Hour (of doom).\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdxxxiii{%
This is a blessed Reminder that we have revealed: Will ye then reject it?\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdxxxiv{%
And We verily gave Abraham of old his proper course, and We were Aware of him,\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdxxxv{%
When he said unto his father and his folk: What are these images unto which ye pay devotion?\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdxxxvi{%
They said: We found our fathers worshippers of them.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdxxxvii{%
He said: Verily ye and your fathers were in plain error.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdxxxviii{%
They said: Bringest thou unto us the truth, or art thou some jester?\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdxxxix{%
He said: Nay, but your Lord is the Lord of the heavens and the earth, Who created them; and I am of those who testify unto that.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdxl{%
And, by Allah, I shall circumvent your idols after ye have gone away and turned your backs.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdxli{%
Then he reduced them to fragments, all save the chief of them, that haply they might have recourse to it.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdxlii{%
They said: Who hath done this to our gods? Surely it must be some evil-doer.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdxliii{%
They said: We heard a youth make mention of them, who is called Abraham.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdxliv{%
They said: Then bring him (hither) before the people's eyes that they may testify.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdxlv{%
They said: Is it thou who hast done this to our gods, O Abraham?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdxlvi{%
He said: But this, their chief hath done it. So question them, if they can speak.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdxlvii{%
Then gathered they apart and said: Lo! ye yourselves are the wrong-doers.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdxlviii{%
And they were utterly confounded, and they said: Well thou knowest that these speak not.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdxlix{%
He said: Worship ye then instead of Allah that which cannot profit you at all, nor harm you?\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdl{%
Fie on you and all that ye worship instead of Allah! Have ye then no sense?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdli{%
They cried: Burn him and stand by your gods, if ye will be doing.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdlii{%
We said: O fire, be coolness and peace for Abraham,\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdliii{%
And they wished to set a snare for him, but We made them the greater losers.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdliv{%
And We rescued him and Lot (and brought them) to the land which We have blessed for (all) peoples.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdlv{%
And We bestowed upon him Isaac, and Jacob as a grandson. Each of them We made righteous.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdlvi{%
And We made them chiefs who guide by Our command, and We inspired in them the doing of good deeds and the right establishment of worship and the giving of alms, and they were worshippers of Us (alone).\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdlvii{%
And unto Lot we gave judgment and knowledge, and We delivered him from the community that did abominations. Lo! they were folk of evil, lewd.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdlviii{%
And We brought him in unto Our mercy. Lo! he was of the righteous.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdlix{%
And Noah, when he cried of old, We heard his prayer and saved him and his household from the great affliction.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdlx{%
And delivered him from the people who denied Our revelations. Lo! they were folk of evil, therefor did We drown them all.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdlxi{%
And David and Solomon, when they gave judgment concerning the field, when people's sheep had strayed and browsed therein by night; and We were witnesses to their judgment.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdlxii{%
And We made Solomon to understand (the case); and unto each of them We gave judgment and knowledge. And we subdued the hills and the birds to hymn (His) praise along with David. We were the doers (thereof).\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmdlxiii{%
And We taught him the art of making garments (of mail) to protect you in your daring. Are ye then thankful?\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmdlxiv{%
And unto Solomon (We subdued) the wind in its raging. It set by his command toward the land which We had blessed. And of everything We are Aware.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmdlxv{%
And of the evil ones (subdued We unto him) some who dived (for pearls) for him and did other work, and We were warders unto them.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmdlxvi{%
And Job, when he cried unto his Lord, (saying): Lo! adversity afflicteth me, and Thou art Most Merciful of all who show mercy.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmdlxvii{%
Then We heard his prayer and removed that adversity from which he suffered, and We gave him his household (that he had lost) and the like thereof along with them, a mercy from Our store, and a remembrance for the worshippers;\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmdlxviii{%
And (mention) Ishmael, and Idris, and Dhu'l-Kifl. All were of the steadfast.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmdlxix{%
And We brought them in unto Our mercy. Lo! they are among the righteous.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmdlxx{%
And (mention) Dhu'n-Nun, when he went off in anger and deemed that We had no power over him, but he cried out in the darkness, saying: There is no Allah save Thee. Be Thou Glorified! Lo! I have been a wrong-doer.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmdlxxi{%
Then we heard his prayer and saved him from the anguish. Thus we save believers.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmdlxxii{%
And Zachariah, when he cried unto his Lord: My Lord! Leave me not childless, though Thou art the Best of inheritors.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmdlxxiii{%
Then We heard his prayer, and bestowed upon him John, and adjusted his wife (to bear a child) for him. Lo! they used to vie one with the other in good deeds, and they cried unto Us in longing and in fear, and were submissive unto Us.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmdlxxiv{%
And she who was chaste, therefor We breathed into her (something) of Our Spirit and made her and her son a token for (all) peoples.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmdlxxv{%
Lo! this, your religion, is one religion, and I am your Lord, so worship Me.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmdlxxvi{%
And they have broken their religion (into fragments) among them, (yet) all are returning unto Us.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmdlxxvii{%
Then whoso doeth some good works and is a believer, there will be no rejection of his effort. Lo! We record (it) for him.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmdlxxviii{%
And there is a ban upon any community which We have destroyed: that they shall not return.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmdlxxix{%
Until, when Gog and Magog are let loose, and they hasten out of every mound,\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmdlxxx{%
And the True Promise draweth nigh; then behold them, staring wide (in terror), the eyes of those who disbelieve! (They say): Alas for us! We (lived) in forgetfulness of this. Ah, but we were wrong-doers!\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmdlxxxi{%
Lo! ye (idolaters) and that which ye worship beside Allah are fuel of hell. Thereunto ye will come.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmdlxxxii{%
If these had been gods they would not have come thither, but all will abide therein.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmdlxxxiii{%
Therein wailing is their portion, and therein they hear not.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmdlxxxiv{%
Lo! those unto whom kindness hath gone forth before from Us, they will be far removed from thence.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmdlxxxv{%
They will not hear the slightest sound thereof, while they abide in that which their souls desire.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmdlxxxvi{%
The Supreme Horror will not grieve them, and the angels will welcome them, (saying): This is your Day which ye were promised;\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmdlxxxvii{%
The Day when We shall roll up the heavens as a recorder rolleth up a written scroll. As We began the first creation, We shall repeat it. (It is) a promise (binding) upon Us. Lo! We are to perform it.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmdlxxxviii{%
And verily we have written in the Scripture, after the Reminder: My righteous slaves will inherit the earth:\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmdlxxxix{%
Lo! there is a plain statement for folk who are devout.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmdxc{%
We sent thee not save as a mercy for the peoples.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmdxci{%
Say: It is only inspired in me that your Allah is One Allah. Will ye then surrender (unto Him)?\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmdxcii{%
But if they are averse, then say: I have warned you all alike, although I know not whether nigh or far is that which ye are promised.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmdxciii{%
Lo! He knoweth that which is said openly, and that which ye conceal.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmdxciv{%
And I know not but that this may be a trial for you, and enjoyment for a while.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmdxcv{%
He saith: My Lord! Judge Thou with truth. Our Lord is the Beneficent, Whose help is to be implored against that which ye ascribe (unto Him).\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmdxcvi{%
\basmalahen O mankind! Fear your Lord. Lo! the earthquake of the Hour (of Doom) is a tremendous thing.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdxcvii{%
On the day when ye behold it, every nursing mother will forget her nursling and every pregnant one will be delivered of her burden, and thou (Muhammad) wilt see mankind as drunken, yet they will not be drunken, but the Doom of Allah will be strong (upon them).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdxcviii{%
Among mankind is he who disputeth concerning Allah without knowledge, and followeth each froward devil;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdxcix{%
For him it is decreed that whoso taketh him for friend, he verily will mislead him and will guide him to the punishment of the Flame.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdc{%
O mankind! if ye are in doubt concerning the Resurrection, then lo! We have created you from dust, then from a drop of seed, then from a clot, then from a little lump of flesh shapely and shapeless, that We may make (it) clear for you. And We cause what We will to remain in the wombs for an appointed time, and afterward We bring you forth as infants, then (give you growth) that ye attain your full strength. And among you there is he who dieth (young), and among you there is he who is brought back to the most abject time of life, so that, after knowledge, he knoweth naught. And thou (Muhammad) seest the earth barren, but when We send down water thereon, it doth thrill and swell and put forth every lovely kind (of growth).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdci{%
That is because Allah, He is the Truth and because He quickeneth the dead, and because He is Able to do all things;\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdcii{%
And because the Hour will come, there is no doubt thereof; and because Allah will raise those who are in the graves.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdciii{%
And among mankind is he who disputeth concerning Allah without knowledge or guidance or a scripture giving light,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdciv{%
Turning away in pride to beguile (men) from the way of Allah. For him in this world is ignominy, and on the Day of Resurrection We make him taste the doom of burning.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdcv{%
(And unto him it will be said): This is for that which thy two hands have sent before, and because Allah is no oppressor of His slaves.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdcvi{%
And among mankind is he who worshippeth Allah upon a narrow marge so that if good befalleth him he is content therewith, but if a trial befalleth him, he falleth away utterly. He loseth both the world and the Hereafter. That is the sheer loss.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdcvii{%
He calleth, beside Allah, unto that which hurteth him not nor benefiteth him. That is the far error.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdcviii{%
He calleth unto him whose harm is nearer than his benefit; verily an evil patron and verily an evil friend!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdcix{%
Lo! Allah causeth those who believe and do good works to enter Gardens underneath which rivers flow. Lo! Allah doth what He intendeth.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdcx{%
Whoso is wont to think (through envy) that Allah will not give him (Muhammad) victory in the world and the Hereafter (and is enraged at the thought of his victory), let him stretch a rope up to the roof (of his dwelling), and let him hang himself. Then let him see whether his strategy dispelleth that whereat he rageth!.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdcxi{%
Thus We reveal it as plain revelations, and verily Allah guideth whom He will.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcxii{%
Lo! those who believe (this revelation), and those who are Jews, and the Sabaeans and the Christians and the Magians and the idolaters - Lo! Allah will decide between them on the Day of Resurrection. Lo! Allah is Witness over all things.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcxiii{%
Hast thou not seen that unto Allah payeth adoration whosoever is in the heavens and whosoever is in the earth, and the sun, and the moon, and the stars, and the hills, and the trees, and the beasts, and many of mankind, while there are many unto whom the doom is justly due. He whom Allah scorneth, there is none to give him honour. Lo! Allah doeth what He will.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcxiv{%
These twain (the believers and the disbelievers) are two opponents who contend concerning their Lord. But as for those who disbelieve, garments of fire will be cut out for them; boiling fluid will be poured down on their heads,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcxv{%
Whereby that which is in their bellies, and their skins too, will be melted;\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcxvi{%
And for them are hooked rods of iron.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcxvii{%
Whenever, in their anguish, they would go forth from thence they are driven back therein and (it is said unto them): Taste the doom of burning.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcxviii{%
Lo! Allah will cause those who believe and do good works to enter Gardens underneath which rivers flow, wherein they will be allowed armlets of gold, and pearls, and their raiment therein will be silk.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcxix{%
They are guided unto gentle speech; they are guided unto the path of the Glorious One.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcxx{%
Lo! those who disbelieve and bar (men) from the way of Allah and from the Inviolable Place of Worship, which We have appointed for mankind together, the dweller therein and the nomad: whosoever seeketh wrongful partiality therein, him We shall cause to taste a painful doom.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcxxi{%
And (remember) when We prepared for Abraham the place of the (holy) House, saying: Ascribe thou no thing as partner unto Me, and purify My House for those who make the round (thereof) and those who stand and those who bow and make prostration.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcxxii{%
And proclaim unto mankind the pilgrimage. They will come unto thee on foot and on every lean camel; they will come from every deep ravine,\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcxxiii{%
That they may witness things that are of benefit to them, and mention the name of Allah on appointed days over the beast of cattle that He hath bestowed upon them. Then eat thereof and feed therewith the poor unfortunate.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdcxxiv{%
Then let them make an end of their unkemptness and pay their vows and go around the ancient House.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcxxv{%
That (is the command). And whoso magnifieth the sacred things of Allah, it will be well for him in the sight of his Lord. The cattle are lawful unto you save that which hath been told you. So shun the filth of idols, and shun lying speech,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcxxvi{%
Turning unto Allah (only), not ascribing partners unto Him; for whoso ascribeth partners unto Allah, it is as if he had fallen from the sky and the birds had snatched him or the wind had blown him to a far-off place.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdcxxvii{%
That (is the command). And whoso magnifieth the offerings consecrated to Allah, it surely is from devotion of the hearts,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdcxxviii{%
Therein are benefits for you for an appointed term; and afterward they are brought for sacrifice unto the ancient House.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdcxxix{%
And for every nation have We appointed a ritual, that they may mention the name of Allah over the beast of cattle that He hath given them for food; and your god is One God, therefor surrender unto Him. And give good tidings (O Muhammad) to the humble,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcxxx{%
Whose hearts fear when Allah is mentioned, and the patient of whatever may befall them, and those who establish worship and who spend of that We have bestowed on them.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcxxxi{%
And the camels! We have appointed them among the ceremonies of Allah. Therein ye have much good. So mention the name of Allah over them when they are drawn up in lines. Then when their flanks fall (dead), eat thereof and feed the beggar and the suppliant. Thus have We made them subject unto you, that haply ye may give thanks.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcxxxii{%
Their flesh and their food reach not Allah, but the devotion from you reacheth Him. Thus have We made them subject unto you that ye may magnify Allah that He hath guided you. And give good tidings (O Muhammad) to the good.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcxxxiii{%
Lo! Allah defendeth those who are true. Lo! Allah loveth not each treacherous ingrate.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcxxxiv{%
Sanction is given unto those who fight because they have been wronged; and Allah is indeed Able to give them victory;\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcxxxv{%
Those who have been driven from their homes unjustly only because they said: Our Lord is Allah - For had it not been for Allah's repelling some men by means of others, cloisters and churches and oratories and mosques, wherein the name of Allah is oft mentioned, would assuredly have been pulled down. Verily Allah helpeth one who helpeth Him. Lo! Allah is Strong, Almighty -\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcxxxvi{%
Those who, if We give them power in the land, establish worship and pay the poor-due and enjoin kindness and forbid iniquity. And Allah's is the sequel of events.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcxxxvii{%
If they deny thee (Muhammad), even so the folk of Noah, and (the tribes of) A'ad and Thamud, before thee, denied (Our messengers);\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcxxxviii{%
And the folk of Abraham and the folk of Lot;\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcxxxix{%
(And) the dwellers in Midian. And Moses was denied; but I indulged the disbelievers a long while, then I seized them, and how (terrible) was My abhorrence!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdcxl{%
How many a township have We destroyed while it was sinful, so that it lieth (to this day) in ruins, and (how many) a deserted well and lofty tower!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdcxli{%
Have they not travelled in the land, and have they hearts wherewith to feel and ears wherewith to hear? For indeed it is not the eyes that grow blind, but it is the hearts, which are within the bosoms, that grow blind.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdcxlii{%
And they will bid thee hasten on the Doom, and Allah faileth not His promise, but lo! a Day with Allah is as a thousand years of what ye reckon.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdcxliii{%
And how many a township did I suffer long though it was sinful! Then I grasped it. Unto Me is the return.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdcxliv{%
Say: O mankind! I am only a plain warner unto you.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdcxlv{%
Those who believe and do good works, for them is pardon and a rich provision;\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdcxlvi{%
While those who strive to thwart Our revelations, such are rightful owners of the Fire.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdcxlvii{%
Never sent We a messenger or a prophet before thee but when He recited (the message) Satan proposed (opposition) in respect of that which he recited thereof. But Allah abolisheth that which Satan proposeth. Then Allah establisheth His revelations. Allah is Knower, Wise;\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdcxlviii{%
That He may make that which the devil proposeth a temptation for those in whose hearts is a disease, and those whose hearts are hardened - Lo! the evil-doers are in open schism -\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdcxlix{%
And that those who have been given knowledge may know that it is the truth from thy Lord, so that they may believe therein and their hearts may submit humbly unto Him. Lo! Allah verily is guiding those who believe unto a right path.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdcl{%
And those who disbelieve will not cease to be in doubt thereof until the Hour come upon them unawares, or there come unto them the doom of a disastrous day.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdcli{%
The Sovereignty on that day will be Allah's, He will judge between them. Then those who believed and did good works will be in Gardens of Delight,\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdclii{%
While those who disbelieved and denied Our revelations, for them will be a shameful doom.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdcliii{%
Those who fled their homes for the cause of Allah and then were slain or died, Allah verily will provide for them a good provision. Lo! Allah, He verily is Best of all who make provision.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdcliv{%
Assuredly He will cause them to enter by an entry that they will love. Lo! Allah verily is Knower, Indulgent.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdclv{%
That (is so). And whoso hath retaliated with the like of that which he was made to suffer and then hath (again) been wronged, Allah will succour him. Lo! Allah verily is Mild, Forgiving.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdclvi{%
That is because Allah maketh the night to pass into the day and maketh the day to pass into the night, and because Allah is Hearer, Seer.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdclvii{%
That is because Allah, He is the True, and that whereon they call instead of Him, it is the false, and because Allah, He is the High, the Great.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdclviii{%
Seest thou not how Allah sendeth down water from the sky and then the earth becometh green upon the morrow? Lo! Allah is Subtile, Aware.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdclix{%
Unto Him belongeth all that is in the heavens and all that is in the earth. Lo! Allah, He verily is the Absolute, the Owner of Praise.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdclx{%
Hast thou not seen how Allah hath made all that is in the earth subservient unto you? And the ship runneth upon the sea by His command, and He holdeth back the heaven from falling on the earth unless by His leave. Lo! Allah is, for mankind, Full of Pity, Merciful.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdclxi{%
And He it is Who gave you life, then He will cause you to die, and then will give you life (again). Lo! man is verily an ingrate.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdclxii{%
Unto each nation have We given sacred rites which they are to perform; so let them not dispute with thee of the matter, but summon thou unto thy Lord. Lo! thou indeed followest right guidance.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdclxiii{%
And if they wrangle with thee, say: Allah is Best Aware of what ye do.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdclxiv{%
Allah will judge between you on the Day of Resurrection concerning that wherein ye used to differ.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdclxv{%
Hast thou not known that Allah knoweth all that is in the heaven and the earth? Lo! it is in a record. Lo! that is easy for Allah.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdclxvi{%
And they worship instead of Allah that for which He hath sent down no warrant, and that whereof they have no knowledge. For evil-doers there is no helper.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdclxvii{%
And when Our revelations are recited unto them, thou knowest the denial in the faces of those who disbelieve; they all but attack those who recite Our revelations unto them. Say: Shall I proclaim unto you worse than that? The Fire! Allah hath promised it for those who disbelieve. A hapless journey's end!\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdclxviii{%
O mankind! A similitude is coined, so pay ye heed to it: Lo! those on whom ye call beside Allah will never create a fly though they combine together for the purpose. And if the fly took something from them, they could not rescue it from it. So weak are (both) the seeker and the sought!\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdclxix{%
They measure not Allah His rightful measure. Lo! Allah is Strong, Almighty.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdclxx{%
Allah chooseth from the angels messengers, and (also) from mankind. Lo! Allah is Hearer, Seer.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdclxxi{%
He knoweth all that is before them and all that is behind them, and unto Allah all things are returned. $$A\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdclxxii{%
O ye who believe! Bow down and prostrate yourselves, and worship your Lord, and do good, that haply ye may prosper.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdclxxiii{%
And strive for Allah with the endeavour which is His right. He hath chosen you and hath not laid upon you in religion any hardship; the faith of your father Abraham (is yours). He hath named you Muslims of old time and in this (Scripture), that the messenger may be a witness against you, and that ye may be witnesses against mankind. So establish worship, pay the poor-due, and hold fast to Allah. He is your Protecting friend. A blessed Patron and a blessed Helper!\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdclxxiv{%
\basmalahen Successful indeed are the believers\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdclxxv{%
Who are humble in their prayers,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdclxxvi{%
And who shun vain conversation,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdclxxvii{%
And who are payers of the poor-due;\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdclxxviii{%
And who guard their modesty -\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdclxxix{%
Save from their wives or the (slaves) that their right hands possess, for then they are not blameworthy,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdclxxx{%
But whoso craveth beyond that, such are transgressors -\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdclxxxi{%
And who are shepherds of their pledge and their covenant,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdclxxxii{%
And who pay heed to their prayers.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdclxxxiii{%
These are the heirs\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdclxxxiv{%
Who will inherit paradise. There they will abide.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdclxxxv{%
Verily We created man from a product of wet earth;\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdclxxxvi{%
Then placed him as a drop (of seed) in a safe lodging;\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdclxxxvii{%
Then fashioned We the drop a clot, then fashioned We the clot a little lump, then fashioned We the little lump bones, then clothed the bones with flesh, and then produced it as another creation. So blessed be Allah, the Best of creators!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdclxxxviii{%
Then lo! after that ye surely die.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdclxxxix{%
Then lo! on the Day of Resurrection ye are raised (again).\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcxc{%
And We have created above you seven paths, and We are never unmindful of creation.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcxci{%
And we send down from the sky water in measure, and We give it lodging in the earth, and lo! We are Able to withdraw it.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcxcii{%
Then We produce for you therewith gardens of date-palms and grapes, wherein is much fruit for you and whereof ye eat;\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcxciii{%
And a tree that springeth forth from Mount Sinai that groweth oil and relish for the eaters.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcxciv{%
And lo! in the cattle there is verily a lesson for you. We give you to drink of that which is in their bellies, and many uses have ye in them, and of them do ye eat;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcxcv{%
And on them and on the ship ye are carried.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcxcvi{%
And We verily sent Noah unto his folk, and he said: O my people! Serve Allah. Ye have no other Allah save Him. Will ye not ward off (evil)?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcxcvii{%
But the chieftains of his folk, who disbelieved, said: This is only a mortal like you who would make himself superior to you. Had Allah willed, He surely could have sent down angels. We heard not of this in the case of our fathers of old.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcxcviii{%
He is only a man in whom is a madness, so watch him for a while.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcxcix{%
He said: My Lord! Help me because they deny me.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcc{%
Then We inspired in him, saying: Make the ship under Our eyes and Our inspiration. Then, when Our command cometh and the oven gusheth water, introduce therein of every (kind) two spouses, and thy household save him thereof against whom the Word hath already gone forth. And plead not with Me on behalf of those who have done wrong. Lo! they will be drowned.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcci{%
And when thou art on board the ship, thou and whoso is with thee, then say: Praise be to Allah Who hath saved us from the wrongdoing folk!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdccii{%
And say: My Lord! Cause me to land at a blessed landing-place, for Thou art Best of all who bring to land.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcciii{%
Lo! herein verily are portents, for lo! We are ever putting (mankind) to the test.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcciv{%
Then, after them, We brought forth another generation;\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdccv{%
And we sent among them a messenger of their own, saying: Serve Allah, Ye have no other Allah save Him. Will ye not ward off (evil)?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdccvi{%
And the chieftains of his folk, who disbelieved and denied the meeting of the Hereafter, and whom We had made soft in the life of the world, said: This is only a mortal like you, who eateth of that whereof ye eat and drinketh of that ye drink.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdccvii{%
If ye were to obey a mortal like yourselves, then, lo! ye surely would be losers.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdccviii{%
Doth he promise you that you, when ye are dead and have become dust and bones, will (again) be brought forth?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdccix{%
Begone, begone, with that which ye are promised!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdccx{%
There is naught but our life of the world; we die and we live, and we shall not be raised (again).\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdccxi{%
He is only a man who hath invented a lie about Allah. We are not going to put faith in him.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdccxii{%
He said: My Lord! Help me because they deny me.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdccxiii{%
He said: In a little while they surely will become repentant.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdccxiv{%
So the (Awful) Cry overtook them rightfully, and We made them like as wreckage (that a torrent hurleth). A far removal for wrongdoing folk!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdccxv{%
Then after them We brought forth other generations.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdccxvi{%
No nation can outstrip its term, nor yet postpone it.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdccxvii{%
Then We sent our messengers one after another. Whenever its messenger came unto a nation they denied him; so We caused them to follow one another (to disaster) and We made them bywords. A far removal for folk who believe not!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdccxviii{%
Then We sent Moses and his brother Aaron with Our tokens and a clear warrant\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdccxix{%
Unto Pharaoh and his chiefs, but they scorned (them) and they were despotic folk.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdccxx{%
And they said: Shall we put faith in two mortals like ourselves, and whose folk are servile unto us?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdccxxi{%
So they denied them, and became of those who were destroyed.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdccxxii{%
And We verily gave Moses the Scripture, that haply they might go aright.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdccxxiii{%
And We made the son of Mary and his mother a portent, and We gave them refuge on a height, a place of flocks and watersprings.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdccxxiv{%
O ye messengers! Eat of the good things, and do right. Lo! I am Aware of what ye do.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdccxxv{%
And lo! this your religion is one religion and I am your Lord, so keep your duty unto Me.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdccxxvi{%
But they (mankind) have broken their religion among them into sects, each group rejoicing in its tenets.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdccxxvii{%
So leave them in their error till a time.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdccxxviii{%
Think they that in the wealth and sons wherewith We provide them\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdccxxix{%
We hasten unto them with good things? Nay, but they perceive not.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdccxxx{%
Lo! those who go in awe for fear of their Lord.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdccxxxi{%
And those who believe in the revelations of their Lord,\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdccxxxii{%
And those who ascribe not partners unto their Lord,\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdccxxxiii{%
And those who give that which they give with hearts afraid because they are about to return unto their Lord,\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdccxxxiv{%
These race for the good things, and they shall win them in the race.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdccxxxv{%
And we task not any soul beyond its scope, and with Us is a Record which speaketh the truth, and they will not be wronged.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdccxxxvi{%
Nay, but their hearts are in ignorance of this (Qur'an), and they have other works, besides, which they are doing;\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdccxxxvii{%
Till when We grasp their luxurious ones with the punishment, behold! they supplicate.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdccxxxviii{%
Supplicate not this day! Assuredly ye will not be helped by Us.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdccxxxix{%
My revelations were recited unto you, but ye used to turn back on your heels,\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdccxl{%
In scorn thereof. Nightly did ye rave together.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdccxli{%
Have they not pondered the Word, or hath that come unto them which came not unto their fathers of old?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdccxlii{%
Or know they not their messenger, and so reject him?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdccxliii{%
Or say they: There is a madness in him? Nay, but he bringeth them the Truth; and most of them are haters of the Truth.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdccxliv{%
And if the Truth had followed their desires, verily the heavens and the earth and whosoever is therein had been corrupted. Nay, We have brought them their Reminder, but from their Reminder they now turn away.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdccxlv{%
Or dost thou ask of them (O Muhammad) any tribute? But the bounty of thy Lord is better, for He is Best of all who make provision.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdccxlvi{%
And lo! thou summonest them indeed unto a straight path.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdccxlvii{%
And lo! those who believe not in the Hereafter are indeed astray from the path.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdccxlviii{%
Though We had mercy on them and relieved them of the harm afflicting them, they still would wander blindly on in their contumacy.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdccxlix{%
Already have We grasped them with punishment, but they humble not themselves unto their Lord, nor do they pray,\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdccl{%
Until, when We open for them the gate of extreme punishment, behold! they are aghast thereat.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdccli{%
He it is Who hath created for you ears and eyes and hearts. Small thanks give ye!\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdcclii{%
And He it is Who hath sown you broadcast in the earth, and unto Him ye will be gathered.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmdccliii{%
And He it is Who giveth life and causeth death, and His is the difference of night and day. Have ye then no sense?\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmdccliv{%
Nay, but they say the like of that which said the men of old;\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmdcclv{%
They say: When we are dead and have become (mere) dust and bones, shall we then, forsooth, be raised again?\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmdcclvi{%
We were already promised this, we and our forefathers. Lo! this is naught but fables of the men of old.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmdcclvii{%
Say: Unto Whom (belongeth) the earth and whosoever is therein, if ye have knowledge?\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmdcclviii{%
They will say: Unto Allah. Say: Will ye not then remember?\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmdcclix{%
Say: Who is Lord of the seven heavens, and Lord of the Tremendous Throne?\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmdcclx{%
They will say: Unto Allah (all that belongeth). Say: Will ye not then keep duty (unto Him)?\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmdcclxi{%
Say: In Whose hand is the dominion over all things and He protecteth, while against Him there is no protection, if ye have knowledge?\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmdcclxii{%
They will say: Unto Allah (all that belongeth). Say: How then are ye bewitched?\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmdcclxiii{%
Nay, but We have brought them the Truth, and lo! they are liars.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmdcclxiv{%
Allah hath not chosen any son, nor is there any god along with Him; else would each god have assuredly championed that which he created, and some of them would assuredly have overcome others. Glorified be Allah above all that they allege.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmdcclxv{%
Knower of the Invisible and the Visible! and Exalted be He over all that they ascribe as partners (unto Him)!\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmdcclxvi{%
Say: My Lord! If Thou shouldst show me that which they are promised.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmdcclxvii{%
My Lord! then set me not among the wrongdoing folk.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmdcclxviii{%
And verily We are Able to show thee that which We have promised them.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmdcclxix{%
Repel evil with that which is better. We are Best Aware of that which they allege.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmdcclxx{%
And say: My Lord! I seek refuge in Thee from suggestions of the evil ones,\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmdcclxxi{%
And I seek refuge in Thee, my Lord, lest they be present with me,\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmdcclxxii{%
Until, when death cometh unto one of them, he saith: My Lord! Send me back,\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmdcclxxiii{%
That I may do right in that which I have left behind! But nay! It is but a word that he speaketh; and behind them is a barrier until the day when they are raised.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmdcclxxiv{%
And when the trumpet is blown there will be no kinship among them that day, nor will they ask of one another.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmdcclxxv{%
Then those whose scales are heavy, they are the successful.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmdcclxxvi{%
And those whose scales are light are those who lose their souls, in hell abiding.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmdcclxxvii{%
The fire burneth their faces, and they are glum therein.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmdcclxxviii{%
(It will be said): Were not My revelations recited unto you, and then ye used to deny them?\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmdcclxxix{%
They will say: Our Lord! Our evil fortune conquered us, and we were erring folk.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmdcclxxx{%
Our Lord! Oh, bring us forth from hence! If we return (to evil) then indeed we shall be wrong-doers.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmdcclxxxi{%
He saith: Begone therein, and speak not unto Me.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmdcclxxxii{%
Lo! there was a party of My slaves who said: Our Lord! We believe, therefor forgive us and have mercy on us for Thou art Best of all who show mercy;\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmdcclxxxiii{%
But ye chose them for a laughing-stock until they caused you to forget remembrance of Me, while ye laughed at them.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmdcclxxxiv{%
Lo! I have rewarded them this day forasmuch as they were steadfast in that they, even they, are the triumphant.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmdcclxxxv{%
He will say: How long tarried ye in the earth, counting by years?\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmdcclxxxvi{%
They will say: We tarried by a day or part of a day. Ask of those who keep count!\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmdcclxxxvii{%
He will say: Ye tarried but a little if ye only knew.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmdcclxxxviii{%
Deemed ye then that We had created you for naught, and that ye would not be returned unto Us?\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmdcclxxxix{%
Now Allah be Exalted, the True King! There is no Allah save Him, the Lord of the Throne of Grace.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmdccxc{%
He who crieth unto any other god along with Allah hath no proof thereof. His reckoning is only with his Lord. Lo! disbelievers will not be successful.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmdccxci{%
And (O Muhammad) say: My Lord! Forgive and have mercy, for Thou art Best of all who show mercy.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmdccxcii{%
\basmalahen (Here is) a surah which We have revealed and enjoined, and wherein We have revealed plain tokens, that haply ye may take heed.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdccxciii{%
The adulterer and the adulteress, scourge ye each one of them (with) a hundred stripes. And let not pity for the twain withhold you from obedience to Allah, if ye believe in Allah and the Last Day. And let a party of believers witness their punishment.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdccxciv{%
The adulterer shall not marry save an adulteress or an idolatress, and the adulteress none shall marry save an adulterer or an idolater. All that is forbidden unto believers.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdccxcv{%
And those who accuse honourable women but bring not four witnesses, scourge them (with) eighty stripes and never (afterward) accept their testimony - They indeed are evil-doers -\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdccxcvi{%
Save those who afterward repent and make amends. (For such) lo! Allah is Forgiving, Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdccxcvii{%
As for those who accuse their wives but have no witnesses except themselves; let the testimony of one of them be four testimonies, (swearing) by Allah that he is of those who speak the truth;\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdccxcviii{%
And yet a fifth, invoking the curse of Allah on him if he is of those who lie.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdccxcix{%
And it shall avert the punishment from her if she bear witness before Allah four times that the thing he saith is indeed false,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdccc{%
And a fifth (time) that the wrath of Allah be upon her if he speaketh truth.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdccci{%
And had it not been for the grace of Allah and His mercy unto you, and that Allah is Clement, Wise, (ye had been undone).\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdcccii{%
Lo! they who spread the slander are a gang among you. Deem it not a bad thing for you; nay, it is good for you. Unto every man of them (will be paid) that which he hath earned of the sin; and as for him among them who had the greater share therein, his will be an awful doom.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdccciii{%
Why did not the believers, men and women, when ye heard it, think good of their own own folk, and say: It is a manifest untruth?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdccciv{%
Why did they not produce four witnesses? Since they produce not witnesses, they verily are liars in the sight of Allah.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdcccv{%
Had it not been for the grace of Allah and His mercy unto you in the world and the Hereafter an awful doom had overtaken you for that whereof ye murmured.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdcccvi{%
When ye welcomed it with your tongues, and uttered with your mouths that whereof ye had no knowledge, ye counted it a trifle. In the sight of Allah it is very great.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdcccvii{%
Wherefor, when ye heard it, said ye not: It is not for us to speak of this. Glory be to Thee (O Allah)! This is awful calumny.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcccviii{%
Allah admonisheth you that ye repeat not the like thereof ever, if ye are (in truth) believers.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcccix{%
And He expoundeth unto you the revelations. Allah is Knower, Wise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcccx{%
Lo! those who love that slander should be spread concerning those who believe, theirs will be a painful punishment in the world and the Hereafter. Allah knoweth. Ye know not.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcccxi{%
Had it not been for the grace of Allah and His mercy unto you, and that Allah is Clement, Merciful, (ye had been undone).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcccxii{%
O ye who believe! Follow not the footsteps of the devil. Unto whomsoever followeth the footsteps of the devil, lo! he commandeth filthiness and wrong. Had it not been for the grace of Allah and His mercy unto you, not one of you would ever have grown pure. But Allah causeth whom He will to grow. And Allah is Hearer, Knower.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcccxiii{%
And let not those who possess dignity and ease among you swear not to give to the near of kin and to the needy, and to fugitives for the cause of Allah. Let them forgive and show indulgence. Yearn ye not that Allah may forgive you? Allah is Forgiving, Merciful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcccxiv{%
Lo! as for those who traduce virtuous, believing women (who are) careless, cursed are they in the world and the Hereafter. Theirs will be an awful doom\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcccxv{%
On the day when their tongues and their hands and their feet testify against them as to what they used to do,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcccxvi{%
On that day Allah will pay them their just due, and they will know that Allah, He is the Manifest Truth.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcccxvii{%
Vile women are for vile men, and vile men for vile women. Good women are for good men, and good men for good women; such are innocent of that which people say: For them is pardon and a bountiful provision.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcccxviii{%
O ye who believe! Enter not houses other than your own without first announcing your presence and invoking peace upon the folk thereof. That is better for you, that ye may be heedful.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcccxix{%
And if ye find no-one therein, still enter not until permission hath been given. And if it be said unto you: Go away again, then go away, for it is purer for you. Allah knoweth what ye do.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdcccxx{%
(It is) no sin for you to enter uninhabited houses wherein is comfort for you. Allah knoweth what ye proclaim and what ye hide.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcccxxi{%
Tell the believing men to lower their gaze and be modest. That is purer for them. Lo! Allah is aware of what they do.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcccxxii{%
And tell the believing women to lower their gaze and be modest, and to display of their adornment only that which is apparent, and to draw their veils over their bosoms, and not to reveal their adornment save to their own husbands or fathers or husbands' fathers, or their sons or their husbands' sons, or their brothers or their brothers' sons or sisters' sons, or their women, or their slaves, or male attendants who lack vigour, or children who know naught of women's nakedness. And let them not stamp their feet so as to reveal what they hide of their adornment. And turn unto Allah together, O believers, in order that ye may succeed.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdcccxxiii{%
And marry such of you as are solitary and the pious of your slaves and maid-servants. If they be poor, Allah will enrich them of His bounty. Allah is of ample means, Aware.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdcccxxiv{%
And let those who cannot find a match keep chaste till Allah give them independence by His grace. And such of your slaves as seek a writing (of emancipation), write it for them if ye are aware of aught of good in them, and bestow upon them of the wealth of Allah which He hath bestowed upon you. Force not your slave-girls to whoredom that ye may seek enjoyment of the life of the world, if they would preserve their chastity. And if one force them, then (unto them), after their compulsion, lo! Allah will be Forgiving, Merciful.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdcccxxv{%
And verily We have sent down for you revelations that make plain, and the example of those who passed away before you. An admonition unto those who ward off (evil).\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcccxxvi{%
Allah is the Light of the heavens and the earth. The similitude of His light is as a niche wherein is a lamp. The lamp is in a glass. The glass is as it were a shining star. (This lamp is) kindled from a blessed tree, an olive neither of the East nor of the West, whose oil would almost glow forth (of itself) though no fire touched it. Light upon light. Allah guideth unto His light whom He will. And Allah speaketh to mankind in allegories, for Allah is Knower of all things.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcccxxvii{%
(This lamp is found) in houses which Allah hath allowed to be exalted and that His name shall be remembered therein. Therein do offer praise to Him at morn and evening.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcccxxviii{%
Men whom neither merchandise nor sale beguileth from remembrance of Allah and constancy in prayer and paying to the poor their due; who fear a day when hearts and eyeballs will be overturned;\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcccxxix{%
That Allah may reward them with the best of what they did, and increase reward for them of His bounty. Allah giveth blessings without stint to whom He will.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcccxxx{%
As for those who disbelieve, their deeds are as a mirage in a desert. The thirsty one supposeth it to be water till he cometh unto it and findeth it naught, and findeth, in the place thereof, Allah Who payeth him his due; and Allah is swift at reckoning.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcccxxxi{%
Or as darkness on a vast, abysmal sea. There covereth him a wave, above which is a wave, above which is a cloud. Layer upon layer of darkness. When he holdeth out his hand he scarce can see it. And he for whom Allah hath not appointed light, for him there is no light.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcccxxxii{%
Hast thou not seen that Allah, He it is Whom all who are in the heavens and the earth praise, and the birds in their flight? Of each He knoweth verily the worship and the praise; and Allah is Aware of what they do.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcccxxxiii{%
And unto Allah belongeth the Sovereignty of the heavens and the earth, and unto Allah is the journeying.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcccxxxiv{%
Hast thou not seen how Allah wafteth the clouds, then gathereth them, then maketh them layers, and thou seest the rain come forth from between them; He sendeth down from the heaven mountains wherein is hail, and smiteth therewith whom He will, and averteth it from whom He will. The flashing of His lightning all but snatcheth away the sight.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcccxxxv{%
Allah causeth the revolution of the day and the night. Lo! herein is indeed a lesson for those who see.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdcccxxxvi{%
Allah hath created every animal of water. Of them is (a kind) that goeth upon its belly and (a kind) that goeth upon two legs and (a kind) that goeth upon four. Allah createth what He will. Lo! Allah is Able to do all things.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdcccxxxvii{%
Verily We have sent down revelations and explained them. Allah guideth whom He will unto a straight path.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdcccxxxviii{%
And they say: We believe in Allah and the messenger, and we obey; then after that a faction of them turn away. Such are not believers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdcccxxxix{%
And when they appeal unto Allah and His messenger to judge between them, lo! a faction of them are averse;\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdcccxl{%
But if right had been with them they would have come unto him willingly.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdcccxli{%
Is there in their hearts a disease, or have they doubts, or fear they lest Allah and His messenger should wrong them in judgment? Nay, but such are evil-doers.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdcccxlii{%
The saying of (all true) believers when they appeal unto Allah and His messenger to judge between them is only that they say: We hear and we obey. And such are the successful.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdcccxliii{%
He who obeyeth Allah and His messenger, and feareth Allah, and keepeth duty (unto Him): such indeed are the victorious.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdcccxliv{%
They swear by Allah solemnly that, if thou order them, they will go forth. Say: Swear not; known obedience (is better). Lo! Allah is Informed of what ye do.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdcccxlv{%
Say: Obey Allah and obey the messenger. But if ye turn away, then (it is) for him (to do) only that wherewith he hath been charged, and for you (to do) only that wherewith ye have been charged. If ye obey him, ye will go aright. But the messenger hath no other charge than to convey (the message) plainly.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdcccxlvi{%
Allah hath promised such of you as believe and do good work that He will surely make them to succeed (the present rulers) in the earth even as He caused those who were before them to succeed (others); and that He will surely establish for them their religion which He hath approved for them, and will give them in exchange safety after their fear. They serve Me. They ascribe no thing as partner unto Me. Those who disbelieve henceforth, they are the miscreants.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdcccxlvii{%
Establish worship and pay the poor-due and obey the messenger, that haply ye may find mercy.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdcccxlviii{%
Think not that the disbelievers can escape in the land. Fire will be their home - a hapless journey's end!\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdcccxlix{%
O ye who believe! Let your slaves, and those of you who have not come to puberty, ask leave of you at three times (before they come into your presence): Before the prayer of dawn, and when ye lay aside your raiment for the heat of noon, and after the prayer of night. Three times of privacy for you. It is no sin for them or for you at other times, when some of you go round attendant upon others (if they come into your presence without leave). Thus Allah maketh clear the revelations for you. Allah is Knower, Wise.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdcccl{%
And when the children among you come to puberty then let them ask leave even as those before them used to ask it. Thus Allah maketh clear His revelations for you. Allah is Knower, Wise.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdcccli{%
As for women past child-bearing, who have no hope of marriage, it is no sin for them if they discard their (outer) clothing in such a way as not to show adornment. But to refrain is better for them. Allah is Hearer, Knower.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdccclii{%
No blame is there upon the blind nor any blame upon the lame nor any blame upon the sick nor on yourselves if ye eat from your houses, or the houses of your fathers, or the houses of your mothers, or the houses of your brothers, or the houses of your sisters, or the houses of your fathers' brothers, or the houses of your fathers' sisters, or the houses of your mothers' brothers, or the houses of your mothers' sisters, or (from that) whereof ye hold the keys, or (from the house) of a friend. No sin shall it be for you whether ye eat together or apart. But when ye enter houses, salute one another with a greeting from Allah, blessed and sweet. Thus Allah maketh clear His revelations for you, that haply ye may understand.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdcccliii{%
They only are the true believers who believe in Allah and His messenger and, when they are with him on some common errand, go not away until they have asked leave of him. Lo! those who ask leave of thee, those are they who believe in Allah and His messenger. So, if they ask thy leave for some affair of theirs, give leave to whom thou wilt of them, and ask for them forgiveness of Allah. Lo! Allah is Forgiving, Merciful.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdcccliv{%
Make not the calling of the messenger among you as your calling one of another. Allah knoweth those of you who steal away, hiding themselves. And let those who conspire to evade orders beware lest grief or painful punishment befall them.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdccclv{%
Lo! verily unto Allah belongeth whatsoever is in the heavens and the earth. He knoweth your condition. And (He knoweth) the Day when they are returned unto Him so that He may inform them of what they did. Allah is Knower of all things.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdccclvi{%
\basmalahen Blessed is He Who hath revealed unto His slave the Criterion (of right and wrong), that he may be a warner to the peoples.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdccclvii{%
He unto Whom belongeth the Sovereignty of the heavens and the earth, He hath chosen no son nor hath He any partner in the Sovereignty. He hath created everything and hath meted out for it a measure.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdccclviii{%
Yet they choose beside Him other gods who create naught but are themselves created, and possess not hurt nor profit for themselves, and possess not death nor life, nor power to raise the dead.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdccclix{%
Those who disbelieve say: This is naught but a lie that he hath invented, and other folk have helped him with it, so that they have produced a slander and a lie.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdccclx{%
And they say: Fables of the men of old which he hath had written down so that they are dictated to him morn and evening.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdccclxi{%
Say (unto them, O Muhammad): He who knoweth the secret of the heavens and the earth hath revealed it. Lo! He ever is Forgiving, Merciful.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdccclxii{%
And they say: What aileth this messenger (of Allah) that he eateth food and walketh in the markets? Why is not an angel sent down unto him, to be a warner with him.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdccclxiii{%
Or (why is not) treasure thrown down unto him, or why hath he not a paradise from whence to eat? And the evil-doers say: Ye are but following a man bewitched.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdccclxiv{%
See how they coin similitudes for thee, so that they are all astray and cannot find a road!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdccclxv{%
Blessed is He Who, if He will, will assign thee better than (all) that - Gardens underneath which rivers flow - and will assign thee mansions.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdccclxvi{%
Nay, but they deny (the coming of) the Hour, and for those who deny (the coming of) the Hour We have prepared a flame.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdccclxvii{%
When it seeth them from afar, they hear the crackling and the roar thereof.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdccclxviii{%
And when they are flung into a narrow place thereof, chained together, they pray for destruction there.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdccclxix{%
Pray not that day for one destruction, but pray for many destructions!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdccclxx{%
Say: Is that (doom) better or the Garden of Immortality which is promised unto those who ward off (evil)? It will be their reward and journey's end.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdccclxxi{%
Therein abiding, they have all that they desire. It is for thy Lord a promise that must be fulfilled.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdccclxxii{%
And on the day when He will assemble them and that which they worship instead of Allah and will say: Was it ye who misled these my slaves or did they (themselves) wander from the way?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdccclxxiii{%
They will say: Be Thou Glorified! it was not for us to choose any protecting friends beside thee; but Thou didst give them and their fathers ease till they forgot the warning and became lost folk.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdccclxxiv{%
Thus they will give you the lie regarding what ye say, then ye can neither avert (the doom) nor obtain help. And whoso among you doeth wrong, We shall make him taste great torment.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdccclxxv{%
We never sent before thee any messengers but lo! they verily ate food and walked in the markets. And We have appointed some of you a test for others: Will ye be steadfast? And thy Lord is ever Seer.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdccclxxvi{%
And those who look not for a meeting with Us say: Why are angels not sent down unto us and (Why) do we not see our Lord! Assuredly they think too highly of themselves and are scornful with great pride.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdccclxxvii{%
On the day when they behold the angels, on that day there will be no good tidings for the guilty; and they will cry: A forbidding ban!\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdccclxxviii{%
And We shall turn unto the work they did and make it scattered motes.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdccclxxix{%
Those who have earned the Garden on that day will be better in their home and happier in their place of noonday rest;\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdccclxxx{%
A day when the heaven with the clouds will be rent asunder and the angels will be sent down, a grand descent.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdccclxxxi{%
The Sovereignty on that day will be the True (Sovereignty) belonging to the Beneficent One, and it will be a hard day for disbelievers.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdccclxxxii{%
On the day when the wrong-doer gnaweth his hands, he will say: Ah, would that I had chosen a way together with the messenger (of Allah)!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdccclxxxiii{%
Alas for me! Ah, would that I had never taken such an one for friend!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdccclxxxiv{%
He verily led me astray from the Reminder after it had reached me. Satan was ever man's deserter in the hour of need.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdccclxxxv{%
And the messenger saith: O my Lord! Lo! mine own folk make this Qur'an of no account.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdccclxxxvi{%
Even so have We appointed unto every prophet an opponent from among the guilty; but Allah sufficeth for a Guide and Helper.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdccclxxxvii{%
And those who disbelieve say: Why is the Qur'an not revealed unto him all at once? (It is revealed) thus that We may strengthen thy heart therewith; and We have arranged it in right order.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdccclxxxviii{%
And they bring thee no similitude but We bring thee the Truth (as against it), and better (than their similitude) as argument.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdccclxxxix{%
Those who will be gathered on their faces unto hell: such are worse in plight and further from the right road.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcccxc{%
We verily gave Moses the Scripture and placed with him his brother Aaron as henchman.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcccxci{%
Then We said: Go together unto the folk who have denied Our revelations. Then We destroyed them, a complete destruction.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcccxcii{%
And Noah's folk, when they denied the messengers, We drowned them and made of them a portent for mankind. We have prepared a painful doom for evil-doers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcccxciii{%
And (the tribes of) A'ad and Thamud, and the dwellers in Ar-Rass, and many generations in between.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcccxciv{%
Each (of them) We warned by examples, and each (of them) We brought to utter ruin.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcccxcv{%
And indeed they have passed by the township whereon was rained the fatal rain. Can it be that they have not seen it? Nay, but they hope for no resurrection.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcccxcvi{%
And when they see thee (O Muhammad) they treat thee only as a jest (saying): Is this he whom Allah sendeth as a messenger?\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcccxcvii{%
He would have led us far away from our gods if we had not been staunch to them. They will know, when they behold the doom, who is more astray as to the road.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcccxcviii{%
Hast thou seen him who chooseth for his god his own lust? Wouldst thou then be guardian over him?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcccxcix{%
Or deemest thou that most of them hear or understand? They are but as the cattle - nay, but they are farther astray?\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcm{%
Hast thou not seen how thy Lord hath spread the shade - And if He willed He could have made it still - then We have made the sun its pilot;\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcmi{%
Then We withdraw it unto Us, a gradual withdrawal?\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcmii{%
And He it is Who maketh night a covering for you, and sleep repose, and maketh day a resurrection.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcmiii{%
And He it is Who sendeth the winds, glad tidings heralding His mercy, and We send down purifying water from the sky,\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcmiv{%
That We may give life thereby to a dead land, and We give many beasts and men that We have created to drink thereof.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcmv{%
And verily We have repeated it among them that they may remember, but most of mankind begrudge aught save ingratitude.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcmvi{%
If We willed, We could raise up a warner in every village.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcmvii{%
So obey not the disbelievers, but strive against them herewith with a great endeavour.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcmviii{%
And He it is Who hath given independence to the two seas (though they meet); one palatable, sweet, and the other saltish, bitter; and hath set a bar and a forbidding ban between them.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcmix{%
And He it is Who hath created man from water, and hath appointed for him kindred by blood and kindred by marriage; for thy Lord is ever Powerful.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcmx{%
Yet they worship instead of Allah that which can neither benefit them nor hurt them. The disbeliever was ever a partisan against his Lord.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcmxi{%
And We have sent thee (O Muhammad) only as a bearer of good tidings and a warner.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcmxii{%
Say: I ask of you no reward for this, save that whoso will may choose a way unto his Lord.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcmxiii{%
And trust thou in the Living One Who dieth not, and hymn His praise. He sufficeth as the Knower of His bondmen's sins,\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcmxiv{%
Who created the heavens and the earth and all that is between them in six Days, then He mounted the Throne. The Beneficent! Ask anyone informed concerning Him!\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcmxv{%
And when it is said unto them: Prostrate to the Beneficent! they say: And what is the Beneficent? Are we to prostrate to whatever thou (Muhammad) biddest us? And it increaseth aversion in them.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcmxvi{%
Blessed be He Who hath placed in the heaven mansions of the stars, and hath placed therein a great lamp and a moon giving light!\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcmxvii{%
And He it is Who hath appointed night and day in succession, for him who desireth to remember, or desireth thankfulness.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcmxviii{%
The (faithful) slaves of the Beneficent are they who walk upon the earth modestly, and when the foolish ones address them answer: Peace;\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcmxix{%
And who spend the night before their Lord, prostrate and standing,\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcmxx{%
And who say: Our Lord! Avert from us the doom of hell; lo! the doom thereof is anguish;\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcmxxi{%
Lo! it is wretched as abode and station;\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcmxxii{%
And those who, when they spend, are neither prodigal nor grudging; and there is ever a firm station between the two;\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcmxxiii{%
And those who cry not unto any other god along with Allah, nor take the life which Allah hath forbidden save in (course of) justice, nor commit adultery - and whoso doeth this shall pay the penalty;\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcmxxiv{%
The doom will be doubled for him on the Day of Resurrection, and he will abide therein disdained for ever;\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcmxxv{%
Save him who repenteth and believeth and doth righteous work; as for such, Allah will change their evil deeds to good deeds. Allah is ever Forgiving, Merciful.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcmxxvi{%
And whosoever repenteth and doeth good, he verily repenteth toward Allah with true repentance -\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcmxxvii{%
And those who will not witness vanity, but when they pass near senseless play, pass by with dignity.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcmxxviii{%
And those who, when they are reminded of the revelations of their Lord, fall not deaf and blind thereat.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcmxxix{%
And who say: Our Lord! Vouchsafe us comfort of our wives and of our offspring, and make us patterns for (all) those who ward off (evil).\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcmxxx{%
They will be awarded the high place forasmuch as they were steadfast, and they will meet therein with welcome and the ward of peace,\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcmxxxi{%
Abiding there for ever. Happy is it as abode and station!\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcmxxxii{%
Say (O Muhammad, unto the disbelievers): My Lord would not concern Himself with you but for your prayer. But now ye have denied (the Truth), therefor there will be judgment.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcmxxxiii{%
\basmalahen Ta. Sin. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcmxxxiv{%
These are revelations of the Scripture that maketh plain.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcmxxxv{%
It may be that thou tormentest thyself (O Muhammad) because they believe not.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcmxxxvi{%
If We will, We can send down on them from the sky a portent so that their necks would remain bowed before it.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcmxxxvii{%
Never cometh there unto them a fresh reminder from the Beneficent One, but they turn away from it.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcmxxxviii{%
Now they have denied (the Truth); but there will come unto them tidings of that whereat they used to scoff.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcmxxxix{%
Have they not seen the earth, how much of every fruitful kind We make to grow therein?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcmxl{%
Lo! herein is indeed a portent; yet most of them are not believers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcmxli{%
And lo! thy Lord! He is indeed the Mighty, the Merciful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcmxlii{%
And when thy Lord called Moses, saying: Go unto the wrongdoing folk,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcmxliii{%
The folk of Pharaoh. Will they not ward off (evil)?\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcmxliv{%
He said: My Lord! Lo! I fear that they will deny me,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcmxlv{%
And I shall be embarrassed, and my tongue will not speak plainly, therefor send for Aaron (to help me).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcmxlvi{%
And they have a crime against me, so I fear that they will kill me.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcmxlvii{%
He said: Nay, verily. So go ye twain with Our tokens. Lo! We shall be with you, Hearing.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcmxlviii{%
And come together unto Pharaoh and say: Lo! we bear a message of the Lord of the Worlds,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmcmxlix{%
(Saying): Let the Children of Israel go with us.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmcml{%
(Pharaoh) said (unto Moses): Did we not rear thee among us as a child? And thou didst dwell many years of thy life among us,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmcmli{%
And thou didst that thy deed which thou didst, and thou wast one of the ingrates.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmcmlii{%
He said: I did it then, when I was of those who are astray.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmcmliii{%
Then I fled from you when I feared you, and my Lord vouchsafed me a command and appointed me (of the number) of those sent (by Him).\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmcmliv{%
And this is the past favour wherewith thou reproachest me: that thou hast enslaved the Children of Israel.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmcmlv{%
Pharaoh said: And what is the Lord of the Worlds?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmcmlvi{%
(Moses) said: Lord of the heavens and the earth and all that is between them, if ye had but sure belief.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmcmlvii{%
(Pharaoh) said unto those around him: Hear ye not?\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmcmlviii{%
He said: Your Lord and the Lord of your fathers.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmcmlix{%
(Pharaoh) said: Lo! your messenger who hath been sent unto you is indeed a madman!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmcmlx{%
He said: Lord of the East and the West and all that is between them, if ye did but understand.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmcmlxi{%
(Pharaoh) said: If thou choosest a god other than me, I assuredly shall place thee among the prisoners.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmcmlxii{%
He said: Even though I show thee something plain?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmcmlxiii{%
(Pharaoh) said: Produce it then, if thou art of the truthful!\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmcmlxiv{%
Then he flung down his staff and it became a serpent manifest,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmcmlxv{%
And he drew forth his hand and lo! it was white to the beholders.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmcmlxvi{%
(Pharaoh) said unto the chiefs about him: Lo! this is verily a knowing wizard,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmcmlxvii{%
Who would drive you out of your land by his magic. Now what counsel ye?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmcmlxviii{%
They said: Put him off, (him) and his brother, and send into the cities summoners\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmcmlxix{%
Who shall bring unto thee every knowing wizard.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmcmlxx{%
So the wizards were gathered together at a set time on a day appointed.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmcmlxxi{%
And it was said unto the people: Are ye (also) gathering?\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmcmlxxii{%
(They said): Aye, so that we may follow the wizards if they are the winners.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmcmlxxiii{%
And when the wizards came they said unto Pharaoh: Will there surely be a reward for us if we are the winners?\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmcmlxxiv{%
He said: Aye, and ye will then surely be of those brought near (to me).\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmcmlxxv{%
Moses said unto them: Throw what ye are going to throw!\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmcmlxxvi{%
Then they threw down their cords and their staves and said: By Pharaoh's might, lo! we verily are the winners.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcmlxxvii{%
Then Moses threw his staff and lo! it swallowed that which they did falsely show.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcmlxxviii{%
And the wizards were flung prostrate,\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcmlxxix{%
Crying: We believe in the Lord of the Worlds,\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcmlxxx{%
The Lord of Moses and Aaron.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcmlxxxi{%
(Pharaoh) said: Ye put your faith in him before I give you leave. Lo! he doubtless is your chief who taught you magic! But verily ye shall come to know. Verily I will cut off your hands and your feet alternately, and verily I will crucify you every one.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcmlxxxii{%
They said: It is no hurt, for lo! unto our Lord we shall return.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcmlxxxiii{%
Lo! we ardently hope that our Lord will forgive us our sins because we are the first of the believers.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcmlxxxiv{%
And We inspired Moses, saying: Take away My slaves by night, for ye will be pursued.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcmlxxxv{%
Then Pharaoh sent into the cities summoners,\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcmlxxxvi{%
(Who said): Lo! these indeed are but a little troop,\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcmlxxxvii{%
And lo! they are offenders against us.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcmlxxxviii{%
And lo! we are a ready host.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcmlxxxix{%
Thus did We take them away from gardens and watersprings,\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcmxc{%
And treasures and a fair estate.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcmxci{%
Thus (were those things taken from them) and We caused the Children of Israel to inherit them.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcmxcii{%
And they overtook them at sunrise.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcmxciii{%
And when the two hosts saw each other, those with Moses said: Lo! we are indeed caught.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcmxciv{%
He said: Nay, verily! for lo! my Lord is with me. He will guide me.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcmxcv{%
Then We inspired Moses, saying: Smite the sea with thy staff. And it parted, and each part was as a mountain vast.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcmxcvi{%
Then brought We near the others to that place.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcmxcvii{%
And We saved Moses and those with him, every one;\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcmxcviii{%
And We drowned the others.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcmxcix{%
Lo! herein is indeed a portent, yet most of them are not believers.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmm{%
And lo, thy Lord! He is indeed the Mighty, the Merciful.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmi{%
Recite unto them the story of Abraham:\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmii{%
When he said unto his father and his folk: What worship ye?\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmiii{%
They said: We worship idols, and are ever devoted unto them.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmiv{%
He said: Do they hear you when ye cry?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmv{%
Or do they benefit or harm you?\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmvi{%
They said: Nay, but we found our fathers acting on this wise.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmvii{%
He said: See now that which ye worship,\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmviii{%
Ye and your forefathers!\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmix{%
Lo! they are (all) an enemy unto me, save the Lord of the Worlds,\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmx{%
Who created me, and He doth guide me,\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmxi{%
And Who feedeth me and watereth me.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmxii{%
And when I sicken, then He healeth me,\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmxiii{%
And Who causeth me to die, then giveth me life (again),\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmxiv{%
And Who, I ardently hope, will forgive me my sin on the Day of Judgment.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmxv{%
My Lord! Vouchsafe me wisdom and unite me to the righteous.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmxvi{%
And give unto me a good report in later generations.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmxvii{%
And place me among the inheritors of the Garden of Delight,\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmxviii{%
And forgive my father. Lo! he is of those who err.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmxix{%
And abase me not on the day when they are raised,\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmxx{%
The day when wealth and sons avail not (any man)\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmxxi{%
Save him who bringeth unto Allah a whole heart.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmxxii{%
And the Garden will be brought nigh for those who ward off (evil).\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmxxiii{%
And hell will appear plainly to the erring.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmxxiv{%
And it will be said unto them: Where is (all) that ye used to worship\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmxxv{%
Instead of Allah? Can they help you or help themselves?\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmxxvi{%
Then will they be hurled therein, they and the seducers\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmxxvii{%
And the hosts of Iblis, together.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmxxviii{%
And they will say, when they are quarrelling therein:\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmxxix{%
By Allah, of a truth we were in error manifest\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmmxxx{%
When we made you equal with the Lord of the Worlds.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmmxxxi{%
It was but the guilty who misled us.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmmxxxii{%
Now we have no intercessors\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmmxxxiii{%
Nor any loving friend.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmmxxxiv{%
Oh, that we had another turn (on earth), that we might be of the believers!\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmmxxxv{%
Lo! herein is indeed a portent, yet most of them are not believers!\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmmxxxvi{%
And lo, thy Lord! He is indeed the Mighty, the Merciful.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmmxxxvii{%
Noah's folk denied the messengers (of Allah),\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmmxxxviii{%
When their brother Noah said unto them: Will ye not ward off (evil)?\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmmxxxix{%
Lo! I am a faithful messenger unto you,\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmmxl{%
So keep your duty to Allah, and obey me.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmmxli{%
And I ask of you no wage therefor; my wage is the concern only of the Lord of the Worlds.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmmxlii{%
So keep your duty to Allah, and obey me.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmmxliii{%
They said: Shall we put faith in thee, when the lowest (of the people) follow thee?\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmmxliv{%
He said: And what knowledge have I of what they may have been doing (in the past)?\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmmxlv{%
Lo! their reckoning is my Lord's concern, if ye but knew;\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmmxlvi{%
And I am not (here) to repulse believers.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmmxlvii{%
I am only a plain warner.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmmxlviii{%
They said: If thou cease not, O Noah, thou wilt surely be among those stoned (to death).\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmmxlix{%
He said: My Lord! Lo! my own folk deny me.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmml{%
Therefor judge Thou between us, a (conclusive) judgment, and save me and those believers who are with me.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmmli{%
And We saved him and those with him in the laden ship.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmmlii{%
Then afterward We drowned the others.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmmliii{%
Lo! herein is indeed a portent, yet most of them are not believers.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmmliv{%
And lo, thy Lord, He is indeed the Mighty, the Merciful.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmmlv{%
(The tribe of) A'ad denied the messengers (of Allah).\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmmlvi{%
When their brother Hud said unto them: Will ye not ward off (evil)?\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmmlvii{%
Lo! I am a faithful messenger unto you,\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmmlviii{%
So keep your duty to Allah and obey me.\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmmlix{%
And I ask of you no wage therefor; my wage is the concern only of the Lord of the Worlds.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmmlx{%
Build ye on every high place a monument for vain delight?\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmmlxi{%
And seek ye out strongholds, that haply ye may last for ever?\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmmlxii{%
And if ye seize by force, seize ye as tyrants?\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmmlxiii{%
Rather keep your duty to Allah, and obey me.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmmlxiv{%
Keep your duty toward Him Who hath aided you with (the good things) that ye know,\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmmlxv{%
Hath aided you with cattle and sons.\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmmlxvi{%
And gardens and watersprings.\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmmlxvii{%
Lo! I fear for you the retribution of an awful day.\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmmlxviii{%
They said: It is all one to us whether thou preachest or art not of those who preach;\qt@no{136}}%
\qt@newcmd\qurantrans@en@mmmlxix{%
This is but a fable of the men of old,\qt@no{137}}%
\qt@newcmd\qurantrans@en@mmmlxx{%
And we shall not be doomed.\qt@no{138}}%
\qt@newcmd\qurantrans@en@mmmlxxi{%
And they denied him; therefor We destroyed them. Lo! herein is indeed a portent, yet most of them are not believers.\qt@no{139}}%
\qt@newcmd\qurantrans@en@mmmlxxii{%
And lo! thy Lord, He is indeed the Mighty, the Merciful.\qt@no{140}}%
\qt@newcmd\qurantrans@en@mmmlxxiii{%
(The tribe of) Thamud denied the messengers (of Allah)\qt@no{141}}%
\qt@newcmd\qurantrans@en@mmmlxxiv{%
When their brother Salih said unto them: Will ye not ward off (evil)?\qt@no{142}}%
\qt@newcmd\qurantrans@en@mmmlxxv{%
Lo! I am a faithful messenger unto you,\qt@no{143}}%
\qt@newcmd\qurantrans@en@mmmlxxvi{%
So keep your duty to Allah and obey me.\qt@no{144}}%
\qt@newcmd\qurantrans@en@mmmlxxvii{%
And I ask of you no wage therefor; my wage is the concern only of the Lord of the Worlds.\qt@no{145}}%
\qt@newcmd\qurantrans@en@mmmlxxviii{%
Will ye be left secure in that which is here before us,\qt@no{146}}%
\qt@newcmd\qurantrans@en@mmmlxxix{%
In gardens and watersprings.\qt@no{147}}%
\qt@newcmd\qurantrans@en@mmmlxxx{%
And tilled fields and heavy-sheathed palm-trees,\qt@no{148}}%
\qt@newcmd\qurantrans@en@mmmlxxxi{%
Though ye hew out dwellings in the mountain, being skilful?\qt@no{149}}%
\qt@newcmd\qurantrans@en@mmmlxxxii{%
Therefor keep your duty to Allah and obey me,\qt@no{150}}%
\qt@newcmd\qurantrans@en@mmmlxxxiii{%
And obey not the command of the prodigal,\qt@no{151}}%
\qt@newcmd\qurantrans@en@mmmlxxxiv{%
Who spread corruption in the earth, and reform not.\qt@no{152}}%
\qt@newcmd\qurantrans@en@mmmlxxxv{%
They said: Thou art but one of the bewitched;\qt@no{153}}%
\qt@newcmd\qurantrans@en@mmmlxxxvi{%
Thou art but a mortal like us. So bring some token if thou art of the truthful.\qt@no{154}}%
\qt@newcmd\qurantrans@en@mmmlxxxvii{%
He said: (Behold) this she-camel. She hath the right to drink (at the well), and ye have the right to drink, (each) on an appointed day.\qt@no{155}}%
\qt@newcmd\qurantrans@en@mmmlxxxviii{%
And touch her not with ill lest there come on you the retribution of an awful day.\qt@no{156}}%
\qt@newcmd\qurantrans@en@mmmlxxxix{%
But they hamstrung her, and then were penitent.\qt@no{157}}%
\qt@newcmd\qurantrans@en@mmmxc{%
So the retribution came on them. Lo! herein is indeed a portent, yet most of them are not believers.\qt@no{158}}%
\qt@newcmd\qurantrans@en@mmmxci{%
And lo! thy Lord! He is indeed the Mighty, the Merciful.\qt@no{159}}%
\qt@newcmd\qurantrans@en@mmmxcii{%
The folk of Lot denied the messengers (of Allah),\qt@no{160}}%
\qt@newcmd\qurantrans@en@mmmxciii{%
When their brother Lot said unto them: Will ye not ward off (evil)?\qt@no{161}}%
\qt@newcmd\qurantrans@en@mmmxciv{%
Lo! I am a faithful messenger unto you,\qt@no{162}}%
\qt@newcmd\qurantrans@en@mmmxcv{%
So keep your duty to Allah and obey me.\qt@no{163}}%
\qt@newcmd\qurantrans@en@mmmxcvi{%
And I ask of you no wage therefor; my wage is the concern only of the Lord of the Worlds.\qt@no{164}}%
\qt@newcmd\qurantrans@en@mmmxcvii{%
What! Of all creatures do ye come unto the males,\qt@no{165}}%
\qt@newcmd\qurantrans@en@mmmxcviii{%
And leave the wives your Lord created for you? Nay, but ye are froward folk.\qt@no{166}}%
\qt@newcmd\qurantrans@en@mmmxcix{%
They said: If thou cease not, O Lot, thou wilt soon be of the outcast.\qt@no{167}}%
\qt@newcmd\qurantrans@en@mmmc{%
He said: I am in truth of those who hate your conduct.\qt@no{168}}%
\qt@newcmd\qurantrans@en@mmmci{%
My Lord! Save me and my household from what they do.\qt@no{169}}%
\qt@newcmd\qurantrans@en@mmmcii{%
So We saved him and his household, every one,\qt@no{170}}%
\qt@newcmd\qurantrans@en@mmmciii{%
Save an old woman among those who stayed behind.\qt@no{171}}%
\qt@newcmd\qurantrans@en@mmmciv{%
Then afterward We destroyed the others.\qt@no{172}}%
\qt@newcmd\qurantrans@en@mmmcv{%
And We rained on them a rain. And dreadful is the rain of those who have been warned.\qt@no{173}}%
\qt@newcmd\qurantrans@en@mmmcvi{%
Lo! herein is indeed a portent, yet most of them are not believers.\qt@no{174}}%
\qt@newcmd\qurantrans@en@mmmcvii{%
And lo! thy Lord, He is indeed the Mighty, the Merciful.\qt@no{175}}%
\qt@newcmd\qurantrans@en@mmmcviii{%
The dwellers in the wood (of Midian) denied the messengers (of Allah),\qt@no{176}}%
\qt@newcmd\qurantrans@en@mmmcix{%
When Shu'eyb said unto them: Will ye not ward off (evil)?\qt@no{177}}%
\qt@newcmd\qurantrans@en@mmmcx{%
Lo! I am a faithful messenger unto you,\qt@no{178}}%
\qt@newcmd\qurantrans@en@mmmcxi{%
So keep your duty to Allah and obey me.\qt@no{179}}%
\qt@newcmd\qurantrans@en@mmmcxii{%
And I ask of you no wage for it; my wage is the concern only of the Lord of the Worlds.\qt@no{180}}%
\qt@newcmd\qurantrans@en@mmmcxiii{%
Give full measure, and be not of those who give less (than the due).\qt@no{181}}%
\qt@newcmd\qurantrans@en@mmmcxiv{%
And weigh with the true balance.\qt@no{182}}%
\qt@newcmd\qurantrans@en@mmmcxv{%
Wrong not mankind in their goods, and do not evil, making mischief, in the earth.\qt@no{183}}%
\qt@newcmd\qurantrans@en@mmmcxvi{%
And keep your duty unto Him Who created you and the generations of the men of old.\qt@no{184}}%
\qt@newcmd\qurantrans@en@mmmcxvii{%
They said: Thou art but one of the bewitched;\qt@no{185}}%
\qt@newcmd\qurantrans@en@mmmcxviii{%
Thou art but a mortal like us, and lo! we deem thee of the liars.\qt@no{186}}%
\qt@newcmd\qurantrans@en@mmmcxix{%
Then make fragments of the heaven fall upon us, if thou art of the truthful.\qt@no{187}}%
\qt@newcmd\qurantrans@en@mmmcxx{%
He said: My Lord is Best Aware of what ye do.\qt@no{188}}%
\qt@newcmd\qurantrans@en@mmmcxxi{%
But they denied him, so there came on them the retribution of the day of gloom. Lo! it was the retribution of an awful day.\qt@no{189}}%
\qt@newcmd\qurantrans@en@mmmcxxii{%
Lo! herein is indeed a portent; yet most of them are not believers.\qt@no{190}}%
\qt@newcmd\qurantrans@en@mmmcxxiii{%
And lo! thy Lord! He is indeed the Mighty, the Merciful.\qt@no{191}}%
\qt@newcmd\qurantrans@en@mmmcxxiv{%
And lo! it is a revelation of the Lord of the Worlds,\qt@no{192}}%
\qt@newcmd\qurantrans@en@mmmcxxv{%
Which the True Spirit hath brought down\qt@no{193}}%
\qt@newcmd\qurantrans@en@mmmcxxvi{%
Upon thy heart, that thou mayst be (one) of the warners,\qt@no{194}}%
\qt@newcmd\qurantrans@en@mmmcxxvii{%
In plain Arabic speech.\qt@no{195}}%
\qt@newcmd\qurantrans@en@mmmcxxviii{%
And lo! it is in the Scriptures of the men of old.\qt@no{196}}%
\qt@newcmd\qurantrans@en@mmmcxxix{%
Is it not a token for them that the doctors of the Children of Israel know it?\qt@no{197}}%
\qt@newcmd\qurantrans@en@mmmcxxx{%
And if We had revealed it unto one of any other nation than the Arabs,\qt@no{198}}%
\qt@newcmd\qurantrans@en@mmmcxxxi{%
And he had read it unto them, they would not have believed in it.\qt@no{199}}%
\qt@newcmd\qurantrans@en@mmmcxxxii{%
Thus do We make it traverse the hearts of the guilty.\qt@no{200}}%
\qt@newcmd\qurantrans@en@mmmcxxxiii{%
They will not believe in it till they behold the painful doom,\qt@no{201}}%
\qt@newcmd\qurantrans@en@mmmcxxxiv{%
So that it will come upon them suddenly, when they perceive not.\qt@no{202}}%
\qt@newcmd\qurantrans@en@mmmcxxxv{%
Then they will say: Are we to be reprieved?\qt@no{203}}%
\qt@newcmd\qurantrans@en@mmmcxxxvi{%
Would they (now) hasten on Our doom?\qt@no{204}}%
\qt@newcmd\qurantrans@en@mmmcxxxvii{%
Hast thou then seen, if We content them for (long) years,\qt@no{205}}%
\qt@newcmd\qurantrans@en@mmmcxxxviii{%
And then cometh that which they were promised,\qt@no{206}}%
\qt@newcmd\qurantrans@en@mmmcxxxix{%
(How) that wherewith they were contented naught availeth them?\qt@no{207}}%
\qt@newcmd\qurantrans@en@mmmcxl{%
And We destroyed no township but it had its warners\qt@no{208}}%
\qt@newcmd\qurantrans@en@mmmcxli{%
For reminder, for We never were oppressors.\qt@no{209}}%
\qt@newcmd\qurantrans@en@mmmcxlii{%
The devils did not bring it down.\qt@no{210}}%
\qt@newcmd\qurantrans@en@mmmcxliii{%
It is not meet for them, nor is it in their power,\qt@no{211}}%
\qt@newcmd\qurantrans@en@mmmcxliv{%
Lo! verily they are banished from the hearing.\qt@no{212}}%
\qt@newcmd\qurantrans@en@mmmcxlv{%
Therefor invoke not with Allah another god, lest thou be one of the doomed.\qt@no{213}}%
\qt@newcmd\qurantrans@en@mmmcxlvi{%
And warn thy tribe of near kindred,\qt@no{214}}%
\qt@newcmd\qurantrans@en@mmmcxlvii{%
And lower thy wing (in kindness) unto those believers who follow thee.\qt@no{215}}%
\qt@newcmd\qurantrans@en@mmmcxlviii{%
And if they (thy kinsfolk) disobey thee, say: Lo! I am innocent of what they do.\qt@no{216}}%
\qt@newcmd\qurantrans@en@mmmcxlix{%
And put thy trust in the Mighty, the Merciful.\qt@no{217}}%
\qt@newcmd\qurantrans@en@mmmcl{%
Who seeth thee when thou standest up (to pray)\qt@no{218}}%
\qt@newcmd\qurantrans@en@mmmcli{%
And (seeth) thine abasement among those who fall prostrate (in worship).\qt@no{219}}%
\qt@newcmd\qurantrans@en@mmmclii{%
Lo! He, only He, is the Hearer, the Knower.\qt@no{220}}%
\qt@newcmd\qurantrans@en@mmmcliii{%
Shall I inform you upon whom the devils descend?\qt@no{221}}%
\qt@newcmd\qurantrans@en@mmmcliv{%
They descend on every sinful, false one.\qt@no{222}}%
\qt@newcmd\qurantrans@en@mmmclv{%
They listen eagerly, but most of them are liars.\qt@no{223}}%
\qt@newcmd\qurantrans@en@mmmclvi{%
As for poets, the erring follow them.\qt@no{224}}%
\qt@newcmd\qurantrans@en@mmmclvii{%
Hast thou not seen how they stray in every valley,\qt@no{225}}%
\qt@newcmd\qurantrans@en@mmmclviii{%
And how they say that which they do not?\qt@no{226}}%
\qt@newcmd\qurantrans@en@mmmclix{%
Save those who believe and do good works, and remember Allah much, and vindicate themselves after they have been wronged. Those who do wrong will come to know by what a (great) reverse they will be overturned!\qt@no{227}}%
\qt@newcmd\qurantrans@en@mmmclx{%
\basmalahen Ta. Sin. These are revelations of the Qur'an and a Scripture that maketh plain;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmclxi{%
A guidance and good tidings for believers\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmclxii{%
Who establish worship and pay the poor-due and are sure of the Hereafter.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmclxiii{%
Lo! as for those who believe not in the Hereafter, We have made their works fairseeming unto them so that they are all astray.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmclxiv{%
Those are they for whom is the worst of punishment, and in the Hereafter they will be the greatest losers.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmclxv{%
Lo! as for thee (Muhammad), thou verily receivest the Qur'an from the presence of One Wise, Aware.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmclxvi{%
(Remember) when Moses said unto his household: Lo! I spy afar off a fire; I will bring you tidings thence, or bring to you a borrowed flame that ye may warm yourselves.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmclxvii{%
But when he reached it, he was called, saying: Blessed is Whosoever is in the fire and Whosoever is round about it! And Glorified be Allah, the Lord of the Worlds!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmclxviii{%
O Moses! Lo! it is I, Allah, the Mighty, the Wise.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmclxix{%
And throw down thy staff! But when he saw it writhing as it were a demon, he turned to flee headlong; (but it was said unto him): O Moses! Fear not! the emissaries fear not in My presence,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmclxx{%
Save him who hath done wrong and afterward hath changed evil for good. And lo! I am Forgiving, Merciful.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmclxxi{%
And put thy hand into the bosom of thy robe, it will come forth white but unhurt. (This will be one) among nine tokens unto Pharaoh and his people Lo! they were ever evil-living folk.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmclxxii{%
But when Our tokens came unto them, plain to see, they said: This is mere magic,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmclxxiii{%
And they denied them, though their souls acknowledged them, for spite and arrogance. Then see the nature of the consequence for the wrong-doers!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmclxxiv{%
And We verily gave knowledge unto David and Solomon, and they said: Praise be to Allah, Who hath preferred us above many of His believing slaves!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmclxxv{%
And Solomon was David's heir. And he said: O mankind! Lo! we have been taught the language of birds, and have been given (abundance) of all things. This surely is evident favour.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmclxxvi{%
And there were gathered together unto Solomon his armies of the jinn and humankind, and of the birds, and they were set in battle order;\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmclxxvii{%
Till, when they reached the Valley of the Ants, an ant exclaimed: O ants! Enter your dwellings lest Solomon and his armies crush you, unperceiving.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmclxxviii{%
And (Solomon) smiled, laughing at her speech, and said: My Lord, arouse me to be thankful for Thy favour wherewith Thou hast favoured me and my parents, and to do good that shall be pleasing unto Thee, and include me in (the number of) Thy righteous slaves.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmclxxix{%
And he sought among the birds and said: How is it that I see not the hoopoe, or is he among the absent?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmclxxx{%
I verily will punish him with hard punishment or I verily will slay him, or he verily shall bring me a plain excuse.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmclxxxi{%
But he was not long in coming, and he said: I have found out (a thing) that thou apprehendest not, and I come unto thee from Sheba with sure tidings.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmclxxxii{%
Lo! I found a woman ruling over them, and she hath been given (abundance) of all things, and hers is a mighty throne.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmclxxxiii{%
I found her and her people worshipping the sun instead of Allah; and Satan maketh their works fairseeming unto them, and debarreth them from the way (of Truth), so that they go not aright;\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmclxxxiv{%
So that they worship not Allah, Who bringeth forth the hidden in the heavens and the earth, and knoweth what ye hide and what ye proclaim,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmclxxxv{%
Allah; there is no Allah save Him, the Lord of the Tremendous Throne.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmclxxxvi{%
(Solomon) said: We shall see whether thou speakest truth or whether thou art of the liars.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmclxxxvii{%
Go with this my letter and throw it down unto them; then turn away and see what (answer) they return,\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmclxxxviii{%
(The Queen of Sheba) said (when she received the letter): O chieftains! Lo! there hath been thrown unto me a noble letter.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmclxxxix{%
Lo! it is from Solomon, and lo! it is: In the name of Allah, the Beneficent, the Merciful;\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcxc{%
Exalt not yourselves against me, but come unto me as those who surrender.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcxci{%
She said: O chieftains! Pronounce for me in my case. I decide no case till ye are present with me.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcxcii{%
They said: We are lords of might and lords of great prowess, but it is for thee to command; so consider what thou wilt command.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcxciii{%
She said: Lo! kings, when they enter a township, ruin it and make the honour of its people shame. Thus will they do.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcxciv{%
But lo! I am going to send a present unto them, and to see with what (answer) the messengers return.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcxcv{%
So when (the envoy) came unto Solomon, (the King) said: What! Would ye help me with wealth? But that which Allah hath given me is better than that which He hath given you. Nay it is ye (and not I) who exult in your gift.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcxcvi{%
Return unto them. We verily shall come unto them with hosts that they cannot resist, and we shall drive them out from thence with shame, and they will be abased.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmcxcvii{%
He said: O chiefs! Which of you will bring me her throne before they come unto me, surrendering?\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmcxcviii{%
A stalwart of the jinn said: I will bring it thee before thou canst rise from thy place. Lo! I verily am strong and trusty for such work.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmcxcix{%
One with whom was knowledge of the Scripture said: I will bring it thee before thy gaze returneth unto thee. And when he saw it set in his presence, (Solomon) said: This is of the bounty of my Lord, that He may try me whether I give thanks or am ungrateful. Whosoever giveth thanks he only giveth thanks for (the good of) his own soul; and whosoever is ungrateful (is ungrateful only to his own soul's hurt). For lo! my Lord is Absolute in independence, Bountiful.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmcc{%
He said: Disguise her throne for her that we may see whether she will go aright or be of those not rightly guided.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmcci{%
So, when she came, it was said (unto her): Is thy throne like this? She said: (It is) as though it were the very one. And (Solomon said): We were given the knowledge before her and we had surrendered (to Allah).\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccii{%
And (all) that she was wont to worship instead of Allah hindered her, for she came of disbelieving folk.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmcciii{%
It was said unto her: Enter the hall. And when she saw it she deemed it a pool and bared her legs. (Solomon) said: Lo! it is a hall, made smooth, of glass. She said: My Lord! Lo! I have wronged myself, and I surrender with Solomon unto Allah, the Lord of the Worlds.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmcciv{%
And We verily sent unto Thamud their brother Salih, saying: Worship Allah. And lo! they (then became two parties quarrelling.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccv{%
He said: O my people! Why will ye hasten on the evil rather than the good? Why will ye not ask pardon of Allah, that ye may receive mercy.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccvi{%
They said: We augur evil of thee and those with thee. He said: Your evil augury is with Allah. Nay, but ye are folk that are being tested.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccvii{%
And there were in the city nine persons who made mischief in the land and reformed not.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccviii{%
They said: Swear one to another by Allah that we verily will attack him and his household by night, and afterward we will surely say unto his friend: We witnessed not the destruction of his household. And lo! we are truthtellers.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmccix{%
So they plotted a plot: and We plotted a plot, while they perceived not.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmccx{%
Then see the nature of the consequence of their plotting, for lo! We destroyed them and their people, every one.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmccxi{%
See, yonder are their dwellings empty and in ruins because they did wrong. Lo! herein is indeed a portent for a people who have knowledge.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmccxii{%
And we saved those who believed and used to ward off (evil).\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmccxiii{%
And Lot! when he said unto his folk: Will ye commit abomination knowingly?\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmccxiv{%
Must ye needs lust after men instead of women? Nay, but ye are folk who act senselessly.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmccxv{%
But the answer of his folk was naught save that they said: Expel the household of Lot from your township, for they (forsooth) are folk who would keep clean!\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmccxvi{%
Then We saved him and his household save his wife; We destined her to be of those who stayed behind.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmccxvii{%
And We rained a rain upon them. Dreadful is the rain of those who have been warned.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmccxviii{%
Say (O Muhammad): Praise be to Allah, and peace be on His slaves whom He hath chosen! Is Allah best, or (all) that ye ascribe as partners (unto Him)?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmccxix{%
Is not He (best) Who created the heavens and the earth, and sendeth down for you water from the sky wherewith We cause to spring forth joyous orchards, whose trees it never hath been yours to cause to grow. Is there any Allah beside Allah? Nay, but they are folk who ascribe equals (unto Him)!\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmccxx{%
Is not He (best) Who made the earth a fixed abode, and placed rivers in the folds thereof, and placed firm hills therein, and hath set a barrier between the two seas? Is there any Allah beside Allah? Nay, but most of them know not!\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmccxxi{%
Is not He (best) Who answereth the wronged one when he crieth unto Him and removeth the evil, and hath made you viceroys of the earth? Is there any Allah beside Allah? Little do they reflect!\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmccxxii{%
Is not He (best) Who guideth you in the darkness of the land and the sea, He Who sendeth the winds as heralds of His mercy? Is there any Allah beside Allah? High Exalted be Allah from all that they ascribe as partner (unto Him)!\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmccxxiii{%
Is not He (best) Who produceth creation, then reproduceth it, and Who provideth for you from the heaven and the earth? Is there any Allah beside Allah? Say: Bring your proof, if ye are truthful!\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmccxxiv{%
Say (O Muhammad): None in the heavens and the earth knoweth the Unseen save Allah; and they know not when they will be raised (again).\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmccxxv{%
Nay, but doth their knowledge reach to the Hereafter? Nay, for they are in doubt concerning it. Nay, for they cannot see it.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmccxxvi{%
Yet those who disbelieve say: When we have become dust like our fathers, shall we verily be brought forth (again)?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmccxxvii{%
We were promised this, forsooth, we and our fathers. (All) this is naught but fables of the men of old.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmccxxviii{%
Say (unto them, O Muhammad): Travel in the land and see the nature of the sequel for the guilty!\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmccxxix{%
And grieve thou not for them, nor be in distress because of what they plot (against thee).\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmccxxx{%
And they say: When (will) this promise (be fulfilled), if ye are truthful?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmccxxxi{%
Say: It may be that a part of that which ye would hasten on is close behind you.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmccxxxii{%
Lo! thy Lord is full of bounty for mankind, but most of them do not give thanks.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmccxxxiii{%
Lo! thy Lord knoweth surely all that their bosoms hide, and all that they proclaim.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmccxxxiv{%
And there is nothing hidden in the heaven or the earth but it is in a clear Record.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmccxxxv{%
Lo! this Qur'an narrateth unto the Children of Israel most of that concerning which they differ.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmccxxxvi{%
And lo! it is a guidance and a mercy for believers.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmccxxxvii{%
Lo! thy Lord will judge between them of His wisdom, and He is the Mighty, the Wise.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmccxxxviii{%
Therefor (O Muhammad) put thy trust in Allah, for thou (standest) on the plain Truth.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmccxxxix{%
Lo! thou canst not make the dead to hear, nor canst thou make the deaf to hear the call when they have turned to flee;\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmccxl{%
Nor canst thou lead the blind out of their error. Thou canst make none to hear, save those who believe Our revelations and who have surrendered.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmccxli{%
And when the word is fulfilled concerning them, We shall bring forth a beast of the earth to speak unto them because mankind had not faith in Our revelations.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmccxlii{%
And (remind them of) the Day when We shall gather out of every nation a host of those who denied Our revelations, and they will be set in array;\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmccxliii{%
Till, when they come (before their Lord), He will say: Did ye deny My revelations when ye could not compass them in knowledge, or what was it that ye did?\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmccxliv{%
And the Word will be fulfilled concerning them because they have done wrong, and they will not speak.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmccxlv{%
Have they not seen how We have appointed the night that they may rest therein, and the day sight-giving? Lo! therein verily are portents for a people who believe.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmccxlvi{%
And (remind them of) the Day when the Trumpet will be blown, and all who are in the heavens and the earth will start in fear, save him whom Allah willeth. And all come unto Him, humbled.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmccxlvii{%
And thou seest the hills thou deemest solid flying with the flight of clouds: the doing of Allah Who perfecteth all things. Lo! He is Informed of what ye do.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmccxlviii{%
Whoso bringeth a good deed will have better than its worth; and such are safe from fear that Day.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmccxlix{%
And whoso bringeth an ill-deed, such will be flung down on their faces in the Fire. Are ye rewarded aught save what ye did?\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmccl{%
(Say): I (Muhammad) am commanded only to serve the Lord of this land which He hath hallowed, and unto Whom all things belong. And I am commanded to be of those who surrender (unto Him),\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmccli{%
And to recite the Qur'an. And whoso goeth right, goeth right only for (the good of) his own soul; and as for him who goeth astray - (Unto him) say: Lo! I am only a warner.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmcclii{%
And say: Praise be to Allah Who will show you His portents so that ye shall know them. And thy Lord is not unaware of what ye (mortals) do.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmccliii{%
\basmalahen Ta. Sin. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmccliv{%
These are revelations of the Scripture that maketh plain.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcclv{%
We narrate unto thee (somewhat) of the story of Moses and Pharaoh with truth, for folk who believe.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcclvi{%
Lo! Pharaoh exalted himself in the earth and made its people castes. A tribe among them he oppressed, killing their sons and sparing their women. Lo! he was of those who work corruption.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcclvii{%
And We desired to show favour unto those who were oppressed in the earth, and to make them examples and to make them the inheritors,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcclviii{%
And to establish them in the earth, and to show Pharaoh and Haman and their hosts that which they feared from them.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcclix{%
And We inspired the mother of Moses, saying: Suckle him and, when thou fearest for him, then cast him into the river and fear not nor grieve. Lo! We shall bring him back unto thee and shall make him (one) of Our messengers.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcclx{%
And the family of Pharaoh took him up, that he might become for them an enemy and a sorrow, Lo! Pharaoh and Haman and their hosts were ever sinning.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcclxi{%
And the wife of Pharaoh said: (He will be) a consolation for me and for thee. Kill him not. Peradventure he may be of use to us, or we may choose him for a son. And they perceived not.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcclxii{%
And the heart of the mother of Moses became void, and she would have betrayed him if We had not fortified her heart, that she might be of the believers.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcclxiii{%
And she said unto his sister: Trace him. So she observed him from afar, and they perceived not.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcclxiv{%
And We had before forbidden foster-mothers for him, so she said: Shall I show you a household who will rear him for you and take care of him?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcclxv{%
So We restored him to his mother that she might be comforted and not grieve, and that she might know that the promise of Allah is true. But most of them know not.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcclxvi{%
And when he reached his full strength and was ripe, We gave him wisdom and knowledge. Thus do We reward the good.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcclxvii{%
And he entered the city at a time of carelessness of its folk, and he found therein two men fighting, one of his own caste, and the other of his enemies; and he who was of his caste asked him for help against him who was of his enemies. So Moses struck him with his fist and killed him. He said: This is of the devil's doing. Lo! he is an enemy, a mere misleader.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcclxviii{%
He said: My Lord! Lo! I have wronged my soul, so forgive me. Then He forgave him. Lo! He is the Forgiving, the Merciful.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcclxix{%
He said: My Lord! Forasmuch as Thou hast favoured me, I will nevermore be a supporter of the guilty.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcclxx{%
And morning found him in the city, fearing, vigilant, when behold! he who had appealed to him the day before cried out to him for help. Moses said unto him: Lo! thou art indeed a mere hothead.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcclxxi{%
And when he would have fallen upon the man who was an enemy unto them both, he said: O Moses! Wouldst thou kill me as thou didst kill a person yesterday. Thou wouldst be nothing but a tyrant in the land, thou wouldst not be of the reformers.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcclxxii{%
And a man came from the uttermost part of the city, running. He said: O Moses! Lo! the chiefs take counsel against thee to slay thee; therefor escape. Lo! I am of those who give thee good advice.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcclxxiii{%
So he escaped from thence, fearing, vigilant. He said: My Lord! Deliver me from the wrongdoing folk.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcclxxiv{%
And when he turned his face toward Midian, he said: Peradventure my Lord will guide me in the right road.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcclxxv{%
And when he came unto the water of Midian he found there a whole tribe of men, watering. And he found apart from them two women keeping back (their flocks). He said: What aileth you? The two said: We cannot give (our flocks) to drink till the shepherds return from the water; and our father is a very old man.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcclxxvi{%
So he watered (their flock) for them. Then he turned aside into the shade, and said: My Lord! I am needy of whatever good Thou sendest down for me.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcclxxvii{%
Then there came unto him one of the two women, walking shyly. She said: Lo! my father biddeth thee, that he may reward thee with a payment for that thou didst water (the flock) for us. Then, when he came unto him and told him the (whole) story, he said: Fear not! Thou hast escaped from the wrongdoing folk.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcclxxviii{%
One of the two women said: O my father! Hire him! For the best (man) that thou canst hire in the strong, the trustworthy.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcclxxix{%
He said: Lo! I fain would marry thee to one of these two daughters of mine on condition that thou hirest thyself to me for (the term of) eight pilgrimages. Then if thou completest ten it will be of thine own accord, for I would not make it hard for thee. Allah willing, thou wilt find me of the righteous.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcclxxx{%
He said: That (is settled) between thee and me. Whichever of the two terms I fulfil, there will be no injustice to me, and Allah is Surety over what we say.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcclxxxi{%
Then, when Moses had fulfilled the term, and was travelling with his housefolk, he saw in the distance a fire and said unto his housefolk: Bide ye (here). Lo! I see in the distance a fire; peradventure I shall bring you tidings thence, or a brand from the fire that ye may warm yourselves.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcclxxxii{%
And when he reached it, he was called from the right side of the valley in the blessed field, from the tree: O Moses! Lo! I, even I, am Allah, the Lord of the Worlds;\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcclxxxiii{%
Throw down thy staff. And when he saw it writhing as it had been a demon, he turned to flee headlong, (and it was said unto him): O Moses! Draw nigh and fear not. Lo! thou art of those who are secure.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcclxxxiv{%
Thrust thy hand into the bosom of thy robe it will come forth white without hurt. And guard thy heart from fear. Then these shall be two proofs from your Lord unto Pharaoh and his chiefs. Lo! they are evil-living folk.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcclxxxv{%
He said: My Lord! Lo! I killed a man among them and I fear that they will kill me.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcclxxxvi{%
My brother Aaron is more eloquent than me in speech. Therefor send him with me as a helper to confirm me. Lo! I fear that they will give the lie to me.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcclxxxvii{%
He said: We will strengthen thine arm with thy brother, and We will give unto you both power so that they cannot reach you for Our portents. Ye twain, and those who follow you, will be the winners.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcclxxxviii{%
But when Moses came unto them with Our clear tokens, they said: This is naught but invented magic. We never heard of this among our fathers of old.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcclxxxix{%
And Moses said: My Lord is Best Aware of him who bringeth guidance from His presence, and whose will be the sequel of the Home (of bliss). Lo! wrong-doers will not be successful.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmccxc{%
And Pharaoh said: O chiefs! I know not that ye have a god other than me, so kindle for me (a fire), O Haman, to bake the mud; and set up for me a lofty tower in order that I may survey the god of Moses; and lo! I deem him of the liars.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmccxci{%
And he and his hosts were haughty in the land without right, and deemed that they would never be brought back to Us.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmccxcii{%
Therefor We seized him and his hosts, and abandoned them unto the sea. Behold the nature of the consequence for evil-doers!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmccxciii{%
And We made them patterns that invite unto the Fire, and on the Day of Resurrection they will not be helped.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmccxciv{%
And We made a curse to follow them in this world, and on the Day of Resurrection they will be among the hateful.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccxcv{%
And We verily gave the Scripture unto Moses after We had destroyed the generations of old: clear testimonies for mankind, and a guidance and a mercy, that haply they might reflect.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmccxcvi{%
And thou (Muhammad) wast not on the western side (of the Mount) when We expounded unto Moses the commandment, and thou wast not among those present;\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmccxcvii{%
But We brought forth generations, and their lives dragged on for them. And thou wast not a dweller in Midian, reciting unto them Our revelations, but We kept sending (messengers to men).\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccxcviii{%
And thou was not beside the Mount when We did call; but (the knowledge of it is) a mercy from thy Lord that thou mayst warn a folk unto whom no warner came before thee, that haply they may give heed.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccxcix{%
Otherwise, if disaster should afflict them because of that which their own hands have sent before (them), they might say: Our Lord! Why sentest Thou no messenger unto us, that we might have followed Thy revelations and been of the believers?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccc{%
But when there came unto them the Truth from Our presence, they said: Why is he not given the like of what was given unto Moses? Did they not disbelieve in that which was given unto Moses of old? They say: Two magics that support each other; and they say: Lo! in both we are disbelievers.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccci{%
Say (unto them, O Muhammad): Then bring a scripture from the presence of Allah that giveth clearer guidance than these two (that) I may follow it, if ye are truthful.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcccii{%
And if they answer thee not, then know that what they follow is their lusts. And who goeth farther astray than he who followeth his lust without guidance from Allah. Lo! Allah guideth not wrongdoing folk.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmccciii{%
And now verily We have caused the Word to reach them, that haply they may give heed.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmccciv{%
Those unto whom We gave the Scripture before it, they believe in it,\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcccv{%
And when it is recited unto them, they say: We believe in it. Lo! it is the Truth from our Lord. Lo! even before it we were of those who surrender (unto Him).\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcccvi{%
These will be given their reward twice over, because they are steadfast and repel evil with good, and spend of that wherewith We have provided them,\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcccvii{%
And when they hear vanity they withdraw from it and say: Unto us our works and unto you your works. Peace be unto you! We desire not the ignorant.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcccviii{%
Lo! thou (O Muhammad) guidest not whom thou lovest, but Allah guideth whom He will. And He is Best Aware of those who walk aright.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcccix{%
And they say: If we were to follow the Guidance with thee we should be torn out of our land. Have We not established for them a sure sanctuary, whereunto the produce of all things is brought (in trade), a provision from Our presence? But most of them know not.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcccx{%
And how many a community have We destroyed that was thankless for its means of livelihood! And yonder are their dwellings, which have not been inhabited after them save a little. And We, even We, were the inheritors.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcccxi{%
And never did thy Lord destroy the townships, till He had raised up in their mother(-town) a messenger reciting unto them Our revelations. And never did We destroy the townships unless the folk thereof were evil-doers.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcccxii{%
And whatsoever ye have been given is a comfort of the life of the world and an ornament thereof; and that which Allah hath is better and more lasting. Have ye then no sense?\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcccxiii{%
Is he whom We have promised a fair promise which he will find (true) like him whom We suffer to enjoy awhile the comfort of the life of the world, then on the Day of Resurrection he will be of those arraigned?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmcccxiv{%
On the day when He will call unto them and say: Where are My partners whom ye imagined?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmcccxv{%
Those concerning whom the Word will have come true will say: Our Lord! These are they whom we led astray. We led them astray even as we ourselves were astray. We declare our innocence before Thee: us they never worshipped.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmcccxvi{%
And it will be said: Cry unto your (so-called) partners (of Allah). And they will cry unto them, and they will give no answer unto them, and they will see the Doom. Ah, if they had but been guided!\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmcccxvii{%
And on the Day when He will call unto them and say: What answer gave ye to the messengers?\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmcccxviii{%
On that day (all) tidings will be dimmed for them, nor will they ask one of another,\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmcccxix{%
But as for him who shall repent and believe and do right, he haply may be one of the successful.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmcccxx{%
Thy Lord bringeth to pass what He willeth and chooseth. They have never any choice. Glorified be Allah and Exalted above all that they associate (with Him)!\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmcccxxi{%
And thy Lord knoweth what their breasts conceal, and what they publish.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmcccxxii{%
And He is Allah; there is no Allah save Him. His is all praise in the former and the latter (state), and His is the command, and unto Him ye will be brought back.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmcccxxiii{%
Say: Have ye thought, if Allah made night everlasting for you till the Day of Resurrection, who is a god beside Allah who could bring you light? Will ye not then hear?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmcccxxiv{%
Say: Have ye thought, if Allah made day everlasting for you till the Day of Resurrection, who is a god beside Allah who could bring you night wherein ye rest? Will ye not then see?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmcccxxv{%
Of His mercy hath He appointed for you night and day, that therein ye may rest, and that ye may seek His bounty, and that haply ye may be thankful.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmcccxxvi{%
And on the Day when He shall call unto them and say: Where are My partners whom ye pretended?\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmcccxxvii{%
And We shall take out from every nation a witness and We shall say: Bring your proof. Then they will know that Allah hath the Truth, and all that they invented will have failed them.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmcccxxviii{%
Now Korah was of Moses' folk, but he oppressed them; and We gave him so much treasure that the stores thereof would verily have been a burden for a troop of mighty men. When his own folk said unto him: Exult not; lo! Allah loveth not the exultant;\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmcccxxix{%
But seek the abode of the Hereafter in that which Allah hath given thee and neglect not thy portion of the world, and be thou kind even as Allah hath been kind to thee, and seek not corruption in the earth; lo! Allah loveth not corrupters,\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmcccxxx{%
He said: I have been given it only on account of knowledge I possess. Knew he not that Allah had destroyed already of the generations before him men who were mightier than him in strength and greater in respect of following? The guilty are not questioned of their sins.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmcccxxxi{%
Then went he forth before his people in his pomp. Those who were desirous of the life of the world said: Ah, would that we had the like of what hath been given unto Korah! Lo! he is lord of rare good fortune.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmcccxxxii{%
But those who had been given knowledge said: Woe unto you! The reward of Allah for him who believeth and doeth right is better, and only the steadfast will obtain it.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmcccxxxiii{%
So We caused the earth to swallow him and his dwelling-place. Then he had no host to help him against Allah, nor was he of those who can save themselves.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmcccxxxiv{%
And morning found those who had coveted his place but yesterday crying: Ah, welladay! Allah enlargeth the provision for whom He will of His slaves and straiteneth it (for whom He will). If Allah had not been gracious unto us He would have caused it to swallow us (also). Ah, welladay! the disbelievers never prosper.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmcccxxxv{%
As for that Abode of the Hereafter We assign it unto those who seek not oppression in the earth, nor yet corruption. The sequel is for those who ward off (evil).\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmcccxxxvi{%
Whoso bringeth a good deed, he will have better than the same; while as for him who bringeth an ill-deed, those who do ill-deeds will be requited only what they did.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmcccxxxvii{%
Lo! He Who hath given thee the Qur'an for a law will surely bring thee home again. Say: My Lord is Best Aware of him who bringeth guidance and him who is in error manifest.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmcccxxxviii{%
Thou hadst no hope that the Scripture would be inspired in thee; but it is a mercy from thy Lord, so never be a helper to the disbelievers.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmcccxxxix{%
And let them not divert thee from the revelations of Allah after they have been sent down unto thee; but call (mankind) unto thy Lord, and be not of those who ascribe partners (unto Him).\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmcccxl{%
And cry not unto any other god along with Allah. There is no Allah save Him. Everything will perish save His countenance. His is the command, and unto Him ye will be brought back.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmcccxli{%
\basmalahen Alif. Lam. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcccxlii{%
Do men imagine that they will be left (at ease) because they say, We believe, and will not be tested with affliction?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcccxliii{%
Lo! We tested those who were before you. Thus Allah knoweth those who are sincere, and knoweth those who feign.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcccxliv{%
Or do those who do ill-deeds imagine that they can outstrip Us? Evil (for them) is that which they decide.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcccxlv{%
Whoso looketh forward to the meeting with Allah (let him know that) Allah's reckoning is surely nigh, and He is the Hearer, the Knower.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcccxlvi{%
And whosoever striveth, striveth only for himself, for lo! Allah is altogether Independent of (His) creatures.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcccxlvii{%
And as for those who believe and do good works, We shall remit from them their evil deeds and shall repay them the best that they did.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcccxlviii{%
We have enjoined on man kindness to parents; but if they strive to make thee join with Me that of which thou hast no knowledge, then obey them not. Unto Me is your return and I shall tell you what ye used to do.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcccxlix{%
And as for those who believe and do good works, We verily shall make them enter in among the righteous.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcccl{%
Of mankind is he who saith: We believe in Allah, but, if he be made to suffer for the sake of Allah, he mistaketh the persecution of mankind for Allah's punishment; and then, if victory cometh from thy Lord, will say: Lo! we were with you (all the while). Is not Allah Best Aware of what is in the bosoms of (His) creatures?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcccli{%
Verily Allah knoweth those who believe, and verily He knoweth the hypocrites.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmccclii{%
Those who disbelieve say unto those who believe: Follow our way (of religion) and we verily will bear your sins (for you). They cannot bear aught of their sins. Lo! they verily are liars.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcccliii{%
But they verily will bear their own loads and other loads beside their own, and they verily will be questioned on the Day of Resurrection concerning that which they invented.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcccliv{%
And verily we sent Noah (as Our messenger) unto his folk, and he continued with them for a thousand years save fifty years; and the flood engulfed them, for they were wrong-doers.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmccclv{%
And We rescued him and those with him in the ship, and made of it a portent for the peoples.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmccclvi{%
And Abraham! (Remember) when he said unto his folk: Serve Allah, and keep your duty unto Him; that is better for you if ye did but know.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmccclvii{%
Ye serve instead of Allah only idols, and ye only invent a lie. Lo! those whom ye serve instead of Allah own no provision for you. So seek your provision from Allah, and serve Him, and give thanks unto Him, (for) unto Him ye will be brought back.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmccclviii{%
But if ye deny, then nations have denied before you. The messenger is only to convey (the message) plainly.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmccclix{%
See they not how Allah produceth creation, then reproduceth it? Lo! for Allah that is easy.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmccclx{%
Say (O Muhammad): Travel in the land and see how He originated creation, then Allah bringeth forth the later growth. Lo! Allah is Able to do all things.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmccclxi{%
He punisheth whom He will and showeth mercy unto whom He will, and unto Him ye will be turned.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmccclxii{%
Ye cannot escape (from Him) in the earth or in the sky, and beside Allah there is for you no friend or helper.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmccclxiii{%
Those who disbelieve in the revelations of Allah and in (their) Meeting with Him, such have no hope of My mercy. For such there is a painful doom.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmccclxiv{%
But the answer of his folk was only that they said: ``Kill him" or ``Burn him." Then Allah saved him from the Fire. Lo! herein verily are portents for folk who believe.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmccclxv{%
He said: Ye have chosen only idols instead of Allah. The love between you is only in the life of the world. Then on the Day of Resurrection ye will deny each other and curse each other, and your abode will be the Fire, and ye will have no helpers.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmccclxvi{%
And Lot believed him, and said: Lo! I am a fugitive unto my Lord. Lo! He, only He, is the Mighty, the Wise.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmccclxvii{%
And We bestowed on him Isaac and Jacob, and We established the prophethood and the Scripture among his seed, and We gave him his reward in the world, and lo! in the Hereafter he verily is among the righteous.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmccclxviii{%
And Lot! (Remember) when he said unto his folk: Lo! ye commit lewdness such as no creature did before you.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmccclxix{%
For come ye not in unto males, and cut ye not the road (for travellers), and commit ye not abomination in your meetings? But the answer of his folk was only that they said: Bring Allah's doom upon us if thou art a truthteller!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmccclxx{%
He said: My Lord! Give me victory over folk who work corruption.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmccclxxi{%
And when Our messengers brought Abraham the good news, they said: Lo! we are about to destroy the people of that township, for its people are wrong-doers.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmccclxxii{%
He said: Lo! Lot is there. They said: We are best aware of who is there. We are to deliver him and his household, all save his wife, who is of those who stay behind.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmccclxxiii{%
And when Our messengers came unto Lot, he was troubled upon their account, for he could not protect them; but they said: Fear not, nor grieve! Lo! we are to deliver thee and thy household, (all) save thy wife, who is of those who stay behind.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmccclxxiv{%
Lo! We are about to bring down upon the folk of this township a fury from the sky because they are evil-livers.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmccclxxv{%
And verily of that We have left a clear sign for people who have sense.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmccclxxvi{%
And unto Midian We sent Shu'eyb, their brother. He said: O my people! Serve Allah, and look forward to the Last Day, and do not evil, making mischief, in the earth.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmccclxxvii{%
But they denied him, and the dreadful earthquake took them, and morning found them prostrate in their dwelling place.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmccclxxviii{%
And (the tribes of) A'ad and Thamud! (Their fate) is manifest unto you from their (ruined and deserted) dwellings. Satan made their deeds seem fair unto them and so debarred them from the Way, though they were keen observers.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmccclxxix{%
And Korah, Pharaoh and Haman! Moses came unto them with clear proofs (of Allah's Sovereignty), but they were boastful in the land. And they were not winners (in the race).\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmccclxxx{%
So We took each one in his sin; of them was he on whom We sent a hurricane, and of them was he who was overtaken by the (Awful) Cry, and of them was he whom We caused the earth to swallow, and of them was he whom We drowned. It was not for Allah to wrong them, but they wronged themselves.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmccclxxxi{%
The likeness of those who choose other patrons than Allah is as the likeness of the spider when she taketh unto herself a house, and lo! the frailest of all houses is the spider's house, if they but knew.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmccclxxxii{%
Lo! Allah knoweth what thing they invoke instead of Him. He is the Mighty, the Wise.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccclxxxiii{%
As for these similitudes, We coin them for mankind, but none will grasp their meaning save the wise.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmccclxxxiv{%
Allah created the heavens and the earth with truth. Lo! therein is indeed a portent for believers.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmccclxxxv{%
Recite that which hath been inspired in thee of the Scripture, and establish worship. Lo! worship preserveth from lewdness and iniquity, but verily remembrance of Allah is more important. And Allah knoweth what ye do.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccclxxxvi{%
And argue not with the People of the Scripture unless it be in (a way) that is better, save with such of them as do wrong; and say: We believe in that which hath been revealed unto us and revealed unto you; our Allah and your Allah is One, and unto Him we surrender.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccclxxxvii{%
In like manner We have revealed unto thee the Scripture, and those unto whom We gave the Scripture aforetime will believe therein; and of these (also) there are some who believe therein. And none deny Our revelations save the disbelievers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccclxxxviii{%
And thou (O Muhammad) wast not a reader of any scripture before it, nor didst thou write it with thy right hand, for then might those have doubted, who follow falsehood.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccclxxxix{%
But it is clear revelations in the hearts of those who have been given knowledge, and none deny Our revelations save wrong-doers.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcccxc{%
And they say: Why are not portents sent down upon him from his Lord? Say: Portents are with Allah only, and I am but a plain warner.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmcccxci{%
Is it not enough for them that We have sent down unto thee the Scripture which is read unto them? Lo! herein verily is mercy, and a reminder for folk who believe.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmcccxcii{%
Say (unto them, O Muhammad): Allah sufficeth for witness between me and you. He knoweth whatsoever is in the heavens and the earth. And those who believe in vanity and disbelieve in Allah, they it is who are the losers.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcccxciii{%
They bid thee hasten on the doom (of Allah). And if a term had not been appointed, the doom would assuredly have come unto them (ere now). And verily it will come upon them suddenly when they perceive not.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcccxciv{%
They bid thee hasten on the doom, when lo! hell verily will encompass the disbelievers\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcccxcv{%
On the day when the doom will overwhelm them from above them and from underneath their feet, and He will say: Taste what ye used to do!\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcccxcvi{%
O my bondmen who believe! Lo! My earth is spacious. Therefor serve Me only.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcccxcvii{%
Every soul will taste of death. Then unto Us ye will be returned.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcccxcviii{%
Those who believe and do good works, them verily We shall house in lofty dwellings of the Garden underneath which rivers flow. There they will dwell secure. How sweet the guerdon of the toilers,\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcccxcix{%
Who persevere, and put their trust in their Lord!\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcd{%
And how many an animal there is that beareth not its own provision! Allah provideth for it and for you. He is the Hearer, the Knower.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcdi{%
And if thou wert to ask them: Who created the heavens and the earth, and constrained the sun and the moon (to their appointed work)? they would say: Allah. How then are they turned away?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmcdii{%
Allah maketh the provision wide for whom He will of His bondmen, and straiteneth it for whom (He will). Lo! Allah is Aware of all things.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmcdiii{%
And if thou wert to ask them: Who causeth water to come down from the sky, and therewith reviveth the earth after its death? they verily would say: Allah. Say: Praise be to Allah! But most of them have no sense.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmcdiv{%
This life of the world is but a pastime and a game. Lo! the home of the Hereafter - that is Life, if they but knew.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmcdv{%
And when they mount upon the ships they pray to Allah, making their faith pure for Him only, but when He bringeth them safe to land, behold! they ascribe partners (unto Him),\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmcdvi{%
That they may disbelieve in that which We have given them, and that they may take their ease. But they will come to know.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmcdvii{%
Have they not seen that We have appointed a sanctuary immune (from violence), while mankind are ravaged all around them? Do they then believe in falsehood and disbelieve in the bounty of Allah?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmcdviii{%
Who doeth greater wrong than he who inventeth a lie concerning Allah, or denieth the truth when it cometh unto him? Is not there a home in hell for disbelievers?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmcdix{%
As for those who strive in Us, We surely guide them to Our paths, and lo! Allah is with the good.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmcdx{%
\basmalahen Alif. Lam. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcdxi{%
The Romans have been defeated\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcdxii{%
In the nearer land, and they, after their defeat will be victorious\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcdxiii{%
Within ten years - Allah's is the command in the former case and in the latter - and in that day believers will rejoice\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcdxiv{%
In Allah's help to victory. He helpeth to victory whom He will. He is the Mighty, the Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcdxv{%
It is a promise of Allah. Allah faileth not His promise, but most of mankind know not.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcdxvi{%
They know only some appearance of the life of the world, and are heedless of the Hereafter.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcdxvii{%
Have they not pondered upon themselves? Allah created not the heavens and the earth, and that which is between them, save with truth and for a destined end. But truly many of mankind are disbelievers in the meeting with their Lord.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcdxviii{%
Have they not travelled in the land and seen the nature of the consequence for those who were before them? They were stronger than these in power, and they dug the earth and built upon it more than these have built. Messengers of their own came unto them with clear proofs (of Allah's Sovereignty). Surely Allah wronged them not, but they did wrong themselves.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcdxix{%
Then evil was the consequence to those who dealt in evil, because they denied the revelations of Allah and made a mock of them.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcdxx{%
Allah produceth creation, then He reproduceth it, then unto Him ye will be returned.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcdxxi{%
And in the day when the Hour riseth the unrighteous will despair.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcdxxii{%
There will be none to intercede for them of those whom they made equal with Allah. And they will reject their partners (whom they ascribed unto Him).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcdxxiii{%
In the day when the Hour cometh, in that day they will be sundered.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcdxxiv{%
As for those who believed and did good works, they will be made happy in a Garden.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcdxxv{%
But as for those who disbelieved and denied Our revelations, and denied the meeting of the Hereafter, such will be brought to doom.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcdxxvi{%
So glory be to Allah when ye enter the night and when ye enter the morning -\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcdxxvii{%
Unto Him be praise in the heavens and the earth! - and at the sun's decline and in the noonday.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcdxxviii{%
He bringeth forth the living from the dead, and He bringeth forth the dead from the living, and He reviveth the earth after her death. And even so will ye be brought forth.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcdxxix{%
And of His signs is this: He created you of dust, and behold you human beings, ranging widely!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcdxxx{%
And of His signs is this: He created for you helpmeets from yourselves that ye might find rest in them, and He ordained between you love and mercy. Lo! herein indeed are portents for folk who reflect.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcdxxxi{%
And of His signs is the creation of the heavens and the earth, and the difference of your languages and colours. Lo! herein indeed are portents for men of knowledge.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcdxxxii{%
And of His signs is your slumber by night and by day, and your seeking of His bounty. Lo! herein indeed are portents for folk who heed.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcdxxxiii{%
And of His signs is this: He showeth you the lightning for a fear and for a hope, and sendeth down water from the sky, and thereby quickeneth the earth after her death. Lo! herein indeed are portents for folk who understand.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcdxxxiv{%
And of His signs is this: The heavens and the earth stand fast by His command, and afterward, when He calleth you, lo! from the earth ye will emerge.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcdxxxv{%
Unto Him belongeth whosoever is in the heavens and the earth. All are obedient unto Him.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcdxxxvi{%
He it is Who produceth creation, then reproduceth it, and it is easier for Him. His is the Sublime Similitude in the heavens and the earth. He is the Mighty, the Wise.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcdxxxvii{%
He coineth for you a similitude of yourselves. Have ye, from among those whom your right hands possess, partners in the wealth We have bestowed upon you, equal with you in respect thereof, so that ye fear them as ye fear each other (that ye ascribe unto Us partners out of that which We created)? Thus We display the revelations for people who have sense.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcdxxxviii{%
Nay, but those who do wrong follow their own lusts without knowledge. Who is able to guide him whom Allah hath sent astray? For such there are no helpers.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcdxxxix{%
So set thy purpose (O Muhammad) for religion as a man by nature upright - the nature (framed) of Allah, in which He hath created man. There is no altering (the laws of) Allah's creation. That is the right religion, but most men know not -\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcdxl{%
Turning unto Him (only); and be careful of your duty unto Him and establish worship, and be not of those who ascribe partners (unto Him);\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcdxli{%
Of those who split up their religion and became schismatics, each sect exulting in its tenets.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcdxlii{%
And when harm toucheth men they cry unto their Lord, turning to Him in repentance; then, when they have tasted of His mercy, behold! some of them attribute partners to their Lord\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcdxliii{%
So as to disbelieve in that which We have given them. (Unto such it is said): Enjoy yourselves awhile, but ye will come to know.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcdxliv{%
Or have We revealed unto them any warrant which speaketh of that which they associate with Him?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcdxlv{%
And when We cause mankind to taste of mercy they rejoice therein; but if an evil thing befall them as the consequence of their own deeds, lo! they are in despair!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcdxlvi{%
See they not that Allah enlargeth the provision for whom He will, and straiteneth (it for whom He will). Lo! herein indeed are portents for folk who believe.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmcdxlvii{%
So give to the kinsman his due, and to the needy, and to the wayfarer. That is best for those who seek Allah's Countenance. And such are they who are successful.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmcdxlviii{%
That which ye give in usury in order that it may increase on (other) people's property hath no increase with Allah; but that which ye give in charity, seeking Allah's Countenance, hath increase manifold.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmcdxlix{%
Allah is He Who created you and then sustained you, then causeth you to die, then giveth life to you again. Is there any of your (so-called) partners (of Allah) that doeth aught of that? Praised and Exalted be He above what they associate (with Him)!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmcdl{%
Corruption doth appear on land and sea because of (the evil) which men's hands have done, that He may make them taste a part of that which they have done, in order that they may return.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmcdli{%
Say (O Muhammad, to the disbelievers): Travel in the land, and see the nature of the consequence for those who were before you! Most of them were idolaters.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmcdlii{%
So set thy purpose resolutely for the right religion, before the inevitable day cometh from Allah. On that day mankind will be sundered-\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmcdliii{%
Whoso disbelieveth must (then) bear the consequences of his disbelief, while those who do right make provision for themselves -\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmcdliv{%
That He may reward out of His bounty those who believe and do good works. Lo! He loveth not the disbelievers (in His guidance).\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmcdlv{%
And of His signs is this: He sendeth herald winds to make you taste His mercy, and that the ships may sail at His command, and that ye may seek his favour, and that haply ye may be thankful.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmcdlvi{%
Verily We sent before thee (Muhammad) messengers to their own folk. Then we took vengeance upon those who were guilty (in regard to them). To help believers is ever incumbent upon Us.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmcdlvii{%
Allah is He Who sendeth the winds so that they raise clouds, and spreadeth them along the sky as pleaseth Him, and causeth them to break and thou seest the rain downpouring from within them. And when He maketh it to fall on whom He will of His bondmen, lo! they rejoice;\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmcdlviii{%
Though before that, even before it was sent down upon them, they were in despair.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcdlix{%
Look, therefore, at the prints of Allah's mercy (in creation): how He quickeneth the earth after her death. Lo! He verily is the Quickener of the Dead, and He is Able to do all things.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmcdlx{%
And if We sent a wind and they beheld it yellow, they verily would still continue in their disbelief.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmcdlxi{%
For verily thou (Muhammad) canst not make the dead to hear, nor canst thou make the deaf to hear the call when they have turned to flee.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcdlxii{%
Nor canst thou guide the blind out of their error. Thou canst make none to hear save those who believe in Our revelations so that they surrender (unto Him).\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcdlxiii{%
Allah is He Who shaped you out of weakness, then appointed after weakness strength, then, after strength, appointed weakness and grey hair. He createth what He will. He is the Knower, the Mighty.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcdlxiv{%
And on the day when the Hour riseth the guilty will vow that they did tarry but an hour - thus were they ever deceived.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcdlxv{%
But those to whom knowledge and faith are given will say: The truth is, ye have tarried, by Allah's decree, until the Day of Resurrection. This is the Day of Resurrection, but ye used not to know.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcdlxvi{%
In that day their excuses will not profit those who did injustice, nor will they be allowed to make amends.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcdlxvii{%
Verily We have coined for mankind in this Qur'an all kinds of similitudes; and indeed if thou camest unto them with a miracle, those who disbelieve would verily exclaim: Ye are but tricksters!\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcdlxviii{%
Thus doth Allah seal the hearts of those who know not.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcdlxix{%
So have patience (O Muhammad)! Allah's promise is the very truth, and let not those who have no certainty make thee impatient.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcdlxx{%
\basmalahen Alif. Lam. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcdlxxi{%
These are revelations of the wise Scripture,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcdlxxii{%
A guidance and a mercy for the good,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcdlxxiii{%
Those who establish worship and pay the poor-due and have sure faith in the Hereafter.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcdlxxiv{%
Such have guidance from their Lord. Such are the successful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcdlxxv{%
And of mankind is he who payeth for mere pastime of discourse, that he may mislead from Allah's way without knowledge, and maketh it the butt of mockery. For such there is a shameful doom.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcdlxxvi{%
And when Our revelations are recited unto him he turneth away in pride as if he heard them not, as if there were a deafness in his ears. So give him tidings of a painful doom.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcdlxxvii{%
Lo! those who believe and do good works, for them are the gardens of delight,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcdlxxviii{%
Wherein they will abide. It is a promise of Allah in truth. He is the Mighty, the Wise.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcdlxxix{%
He hath created the heavens without supports that ye can see, and hath cast into the earth firm hills, so that it quake not with you; and He hath dispersed therein all kinds of beasts. And We send down water from the sky and We cause (plants) of every goodly kind to grow therein.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcdlxxx{%
This is the Creation of Allah. Now show me that which those (ye worship) beside Him have created. Nay, but the wrong-doers are in error manifest!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxi{%
And verily We gave Luqman wisdom, saying: Give thanks unto Allah; and whosoever giveth thanks, he giveth thanks for (the good of) his soul. And whosoever refuseth - Lo! Allah is Absolute, Owner of Praise.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxii{%
And (remember) when Luqman said unto his son, when he was exhorting him: O my dear son! Ascribe no partners unto Allah. Lo! to ascribe partners (unto Him) is a tremendous wrong -\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxiii{%
And We have enjoined upon man concerning his partners - His mother beareth him in weakness upon weakness, and his weaning is in two years - Give thanks unto Me and unto thy parents. Unto Me is the journeying.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxiv{%
But if they strive with thee to make thee ascribe unto Me as partner that of which thou hast no knowledge, then obey them not. Consort with them in the world kindly, and follow the path of him who repenteth unto Me. Then unto Me will be your return, and I shall tell you what ye used to do -\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxv{%
O my dear son! Lo! though it be but the weight of a grain of mustard-seed, and though it be in a rock, or in the heavens, or in the earth, Allah will bring it forth. Lo! Allah is Subtile, Aware.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxvi{%
O my dear son! Establish worship and enjoin kindness and forbid iniquity, and persevere whatever may befall thee. Lo! that is of the steadfast heart of things.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxvii{%
Turn not thy cheek in scorn toward folk, nor walk with pertness in the land. Lo! Allah loveth not each braggart boaster.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxviii{%
Be modest in thy bearing and subdue thy voice. Lo! the harshest of all voices is the voice of the ass.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxix{%
See ye not how Allah hath made serviceable unto you whatsoever is in the skies and whatsoever is in the earth and hath loaded you with His favours both without and within? Yet of mankind is he who disputeth concerning Allah, without knowledge or guidance or a scripture giving light.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcdxc{%
And if it be said unto them: Follow that which Allah hath revealed, they say: Nay, but we follow that wherein we found our fathers. What! Even though the devil were inviting them unto the doom of flame?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcdxci{%
Whosoever surrendereth his purpose to Allah while doing good, he verily hath grasped the firm hand-hold. Unto Allah belongeth the sequel of all things.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcdxcii{%
And whosoever disbelieveth, let not his disbelief afflict thee (O Muhammad). Unto Us is their return, and We shall tell them what they did. Lo! Allah is Aware of what is in the breasts (of men).\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcdxciii{%
We give them comfort for a little, and then We drive them to a heavy doom.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcdxciv{%
If thou shouldst ask them: Who created the heavens and the earth? they would answer: Allah. Say: Praise be to Allah! But most of them know not.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcdxcv{%
Unto Allah belongeth whatsoever is in the heavens and the earth. Lo! Allah, He is the Absolute, the Owner of Praise.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcdxcvi{%
And if all the trees in the earth were pens, and the sea, with seven more seas to help it, (were ink), the words of Allah could not be exhausted. Lo! Allah is Mighty, Wise.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcdxcvii{%
Your creation and your raising (from the dead) are only as (the creation and the raising of) a single soul. Lo! Allah is Hearer, Knower.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcdxcviii{%
Hast thou not seen how Allah causeth the night to pass into the day and causeth the day to pass into the night, and hath subdued the sun and the moon (to do their work), each running unto an appointed term; and that Allah is Informed of what ye do?\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcdxcix{%
That (is so) because Allah, He is the True, and that which they invoke beside Him is the False, and because Allah, He is the Sublime, the Great.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmd{%
Hast thou not seen how the ships glide on the sea by Allah's grace, that He may show you of His wonders? Lo! therein indeed are portents for every steadfast, grateful (heart).\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdi{%
And if a wave enshroudeth them like awnings, they cry unto Allah, making their faith pure for Him only. But when He bringeth them safe to land, some of them compromise. None denieth Our signs save every traitor ingrate.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdii{%
O mankind! Keep your duty to your Lord and fear a Day when the parent will not be able to avail the child in aught, nor the child to avail the parent. Lo! Allah's promise is the very truth. Let not the life of the world beguile you, nor let the deceiver beguile you, in regard to Allah.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdiii{%
Lo! Allah! With Him is knowledge of the Hour. He sendeth down the rain, and knoweth that which is in the wombs. No soul knoweth what it will earn to-morrow, and no soul knoweth in what land it will die. Lo! Allah is Knower, Aware.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdiv{%
\basmalahen Alif. Lam. Mim\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdv{%
The revelation of the Scripture whereof there is no doubt is from the Lord of the Worlds.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdvi{%
Or say they: He hath invented it? Nay, but it is the Truth from thy Lord, that thou mayst warn a folk to whom no warner came before thee, that haply they may walk aright.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdvii{%
Allah it is Who created the heavens and the earth, and that which is between them, in six Days. Then He mounted the Throne. Ye have not, beside Him, a protecting friend or mediator. Will ye not then remember?\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdviii{%
He directeth the ordinance from the heaven unto the earth; then it ascendeth unto Him in a Day, whereof the measure is a thousand years of that ye reckon.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdix{%
Such is the Knower of the Invisible and the Visible, the Mighty, the Merciful,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdx{%
Who made all things good which He created, and He began the creation of man from clay;\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdxi{%
Then He made his seed from a draught of despised fluid;\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdxii{%
Then He fashioned him and breathed into him of His Spirit; and appointed for you hearing and sight and hearts. Small thanks give ye!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdxiii{%
And they say: When we are lost in the earth, how can we then be re-created? Nay but they are disbelievers in the meeting with their Lord.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdxiv{%
Say: The angel of death, who hath charge concerning you, will gather you, and afterward unto your Lord ye will be returned.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdxv{%
Couldst thou but see when the guilty hang their heads before their Lord, (and say): Our Lord! We have now seen and heard, so send us back; we will do right, now we are sure.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdxvi{%
And if We had so willed, We could have given every soul its guidance, but the word from Me concerning evildoers took effect: that I will fill hell with the jinn and mankind together.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdxvii{%
So taste (the evil of your deeds). Forasmuch as ye forgot the meeting of this your day, lo! We forget you. Taste the doom of immortality because of what ye used to do.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdxviii{%
Only those believe in Our revelations who, when they are reminded of them, fall down prostrate and hymn the praise of their Lord, and they are not scornful,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdxix{%
Who forsake their beds to cry unto their Lord in fear and hope, and spend of that We have bestowed on them.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdxx{%
No soul knoweth what is kept hid for them of joy, as a reward for what they used to do.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdxxi{%
Is he who is a believer like unto him who is an evil-liver? They are not alike.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdxxii{%
But as for those who believe and do good works, for them are the Gardens of Retreat - a welcome (in reward) for what they used to do.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdxxiii{%
And as for those who do evil, their retreat is the Fire. Whenever they desire to issue forth from thence, they are brought back thither. Unto them it is said: Taste the torment of the Fire which ye used to deny.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdxxiv{%
And verily We make them taste the lower punishment before the greater, that haply they may return.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdxxv{%
And who doth greater wrong than he who is reminded of the revelations of his Lord, then turneth from them. Lo! We shall requite the guilty.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdxxvi{%
We verily gave Moses the Scripture; so be not ye in doubt of his receiving it; and We appointed it a guidance for the Children of Israel.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdxxvii{%
And when they became steadfast and believed firmly in Our revelations, We appointed from among them leaders who guided by Our command.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdxxviii{%
Lo! thy Lord will judge between them on the Day of Resurrection concerning that wherein they used to differ.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdxxix{%
Is it not a guidance for them (to observe) how many generations We destroyed before them, amid whose dwelling places they do walk? Lo! therein verily are portents! Will they not then heed?\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdxxx{%
Have they not seen how We lead the water to the barren land and therewith bring forth crops whereof their cattle eat, and they themselves? Will they not then see?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdxxxi{%
And they say: When cometh this victory (of yours) if ye are truthful?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdxxxii{%
Say (unto them): On the day of the victory the faith of those who disbelieve (and who then will believe) will not avail them, neither will they be reprieved.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdxxxiii{%
So withdraw from them (O Muhammad), and await (the event). Lo! they (also) are awaiting (it).\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdxxxiv{%
\basmalahen O Prophet! Keep thy duty to Allah and obey not the disbelievers and the hypocrites. Lo! Allah is Knower, Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdxxxv{%
And follow that which is inspired in thee from thy Lord. Lo! Allah is Aware of what ye do.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdxxxvi{%
And put thy trust in Allah, for Allah is sufficient as Trustee.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdxxxvii{%
Allah hath not assigned unto any man two hearts within his body, nor hath He made your wives whom ye declare (to be your mothers) your mothers, nor hath He made those whom ye claim (to be your sons) your sons. This is but a saying of your mouths. But Allah saith the truth and He showeth the way.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdxxxviii{%
Proclaim their real parentage. That will be more equitable in the sight of Allah. And if ye know not their fathers, then (they are) your brethren in the faith, and your clients. And there is no sin for you in the mistakes that ye make unintentionally, but what your hearts purpose (that will be a sin for you). Allah is ever Forgiving, Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdxxxix{%
The Prophet is closer to the believers than their selves, and his wives are (as) their mothers. And the owners of kinship are closer one to another in the ordinance of Allah than (other) believers and the fugitives (who fled from Mecca), except that ye should do kindness to your friends. This is written in the Book (of nature).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdxl{%
And when We exacted a covenant from the prophets, and from thee (O Muhammad) and from Noah and Abraham and Moses and Jesus son of Mary. We took from them a solemn covenant;\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdxli{%
That He may ask the loyal of their loyalty. And He hath prepared a painful doom for the unfaithful.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdxlii{%
O ye who believe! Remember Allah's favour unto you when there came against you hosts, and We sent against them a great wind and hosts ye could not see. And Allah is ever Seer of what ye do.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdxliii{%
When they came upon you from above you and from below you, and when eyes grew wild and hearts reached to the throats, and ye were imagining vain thoughts concerning Allah.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdxliv{%
There were the believers sorely tried, and shaken with a mighty shock.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdxlv{%
And when the hypocrites, and those in whose hearts is a disease, were saying: Allah and His messenger promised us naught but delusion.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdxlvi{%
And when a party of them said: O folk of Yathrib! There is no stand (possible) for you, therefor turn back. And certain of them (even) sought permission of the Prophet, saying: Our homes lie open (to the enemy). And they lay not open. They but wished to flee.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdxlvii{%
If the enemy had entered from all sides and they had been exhorted to treachery, they would have committed it, and would have hesitated thereupon but little.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdxlviii{%
And verily they had already sworn unto Allah that they would not turn their backs (to the foe). An oath to Allah must be answered for.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdxlix{%
Say: Flight will not avail you if ye flee from death or killing, and then ye dwell in comfort but a little while.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdl{%
Say: Who is he who can preserve you from Allah if He intendeth harm for you, or intendeth mercy for you. They will not find that they have any friend or helper other than Allah.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdli{%
Allah already knoweth those of you who hinder, and those who say unto their brethren: ``Come ye hither unto us!" and they come not to the stress of battle save a little,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdlii{%
Being sparing of their help to you (believers). But when the fear cometh, then thou (Muhammad) seest them regarding thee with rolling eyes like one who fainteth unto death. Then, when the fear departeth, they scald you with sharp tongues in their greed for wealth (from the spoil). Such have not believed. Therefor Allah maketh their deeds fruitless. And that is easy for Allah.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdliii{%
They hold that the clans have not retired (for good); and if the clans should advance (again), they would fain be in the desert with the wandering Arabs, asking for the news of you; and if they were among you, they would not give battle, save a little.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdliv{%
Verily in the messenger of Allah ye have a good example for him who looketh unto Allah and the Last Day, and remembereth Allah much.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdlv{%
And when the true believers saw the clans, they said: This is that which Allah and His messenger promised us. Allah and His messenger are true. It did but confirm them in their faith and resignation.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdlvi{%
Of the believers are men who are true to that which they covenanted with Allah. Some of them have paid their vow by death (in battle), and some of them still are waiting; and they have not altered in the least;\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdlvii{%
That Allah may reward the true men for their truth, and punish the hypocrites if He will, or relent toward them (if He will). Lo! Allah is Forgiving, Merciful.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdlviii{%
And Allah repulsed the disbelievers in their wrath; they gained no good. Allah averted their attack from the believers. Allah is ever Strong, Mighty.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdlix{%
And He brought those of the People of the Scripture who supported them down from their strongholds, and cast panic into their hearts. Some ye slew, and ye made captive some.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdlx{%
And He caused you to inherit their land and their houses and their wealth, and land ye have not trodden. Allah is ever Able to do all things.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdlxi{%
O Prophet! Say unto thy wives: If ye desire the world's life and its adornment, come! I will content you and will release you with a fair release.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdlxii{%
But if ye desire Allah and His messenger and the abode of the Hereafter, then lo! Allah hath prepared for the good among you an immense reward.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdlxiii{%
O ye wives of the Prophet! Whosoever of you committeth manifest lewdness, the punishment for her will be doubled, and that is easy for Allah.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdlxiv{%
And whosoever of you is submissive unto Allah and His messenger and doeth right, We shall give her her reward twice over, and We have prepared for her a rich provision.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdlxv{%
O ye wives of the Prophet! Ye are not like any other women. If ye keep your duty (to Allah), then be not soft of speech, lest he in whose heart is a disease aspire (to you), but utter customary speech.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdlxvi{%
And stay in your houses. Bedizen not yourselves with the bedizenment of the Time of Ignorance. Be regular in prayer, and pay the poor-due, and obey Allah and His messenger. Allah's wish is but to remove uncleanness far from you, O Folk of the Household, and cleanse you with a thorough cleansing.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdlxvii{%
And bear in mind that which is recited in your houses of the revelations of Allah and wisdom. Lo! Allah is Subtile, Aware.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdlxviii{%
Lo! men who surrender unto Allah, and women who surrender, and men who believe and women who believe, and men who obey and women who obey, and men who speak the truth and women who speak the truth, and men who persevere (in righteousness) and women who persevere, and men who are humble and women who are humble, and men who give alms and women who give alms, and men who fast and women who fast, and men who guard their modesty and women who guard (their modesty), and men who remember Allah much and women who remember - Allah hath prepared for them forgiveness and a vast reward.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdlxix{%
And it becometh not a believing man or a believing woman, when Allah and His messenger have decided an affair (for them), that they should (after that) claim any say in their affair; and whoso is rebellious to Allah and His messenger, he verily goeth astray in error manifest.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdlxx{%
And when thou saidst unto him on whom Allah hath conferred favour and thou hast conferred favour: Keep thy wife to thyself, and fear Allah. And thou didst hide in thy mind that which Allah was to bring to light, and thou didst fear mankind whereas Allah hath a better right that thou shouldst fear Him. So when Zeyd had performed that necessary formality (of divorce) from her, We gave her unto thee in marriage, so that (henceforth) there may be no sin for believers in respect of wives of their adopted sons, when the latter have performed the necessary formality (of release) from them. The commandment of Allah must be fulfilled.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdlxxi{%
There is no reproach for the Prophet in that which Allah maketh his due. That was Allah's way with those who passed away of old - and the commandment of Allah is certain destiny -\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdlxxii{%
Who delivered the messages of Allah and feared Him, and feared none save Allah. Allah keepeth good account.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdlxxiii{%
Muhammad is not the father of any man among you, but he is the messenger of Allah and the Seal of the Prophets; and Allah is ever Aware of all things.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdlxxiv{%
O ye who believe! Remember Allah with much remembrance.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdlxxv{%
And glorify Him early and late.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdlxxvi{%
He it is Who blesseth you, and His angels (bless you), that He may bring you forth from darkness unto light; and He is ever Merciful to the believers.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdlxxvii{%
Their salutation on the day when they shall meet Him will be: Peace. And He hath prepared for them a goodly recompense.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdlxxviii{%
O Prophet! Lo! We have sent thee as a witness and a bringer of good tidings and a warner.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdlxxix{%
And as a summoner unto Allah by His permission, and as a lamp that giveth light.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdlxxx{%
And announce unto the believers the good tidings that they will have great bounty from Allah.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdlxxxi{%
And incline not to the disbelievers and the hypocrites. Disregard their noxious talk, and put thy trust in Allah. Allah is sufficient as Trustee.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdlxxxii{%
O ye who believe! If ye wed believing women and divorce them before ye have touched them, then there is no period that ye should reckon. But content them and release them handsomely.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdlxxxiii{%
O Prophet! Lo! We have made lawful unto thee thy wives unto whom thou hast paid their dowries, and those whom thy right hand possesseth of those whom Allah hath given thee as spoils of war, and the daughters of thine uncle on the father's side and the daughters of thine aunts on the father's side, and the daughters of thine uncle on the mother's side and the daughters of thine aunts on the mother's side who emigrated with thee, and a believing woman if she give herself unto the Prophet and the Prophet desire to ask her in marriage - a privilege for thee only, not for the (rest of) believers - We are Aware of that which We enjoined upon them concerning their wives and those whom their right hands possess - that thou mayst be free from blame, for Allah is ever Forgiving, Merciful.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdlxxxiv{%
Thou canst defer whom thou wilt of them and receive unto thee whom thou wilt, and whomsoever thou desirest of those whom thou hast set aside (temporarily), it is no sin for thee (to receive her again); that is better; that they may be comforted and not grieve, and may all be pleased with what thou givest them. Allah knoweth what is in your hearts (O men), and Allah is ever Forgiving, Clement.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdlxxxv{%
It is not allowed thee to take (other) women henceforth, nor that thou shouldst change them for other wives even though their beauty pleased thee, save those whom thy right hand possesseth. And Allah is ever Watcher over all things.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdlxxxvi{%
O Ye who believe! Enter not the dwellings of the Prophet for a meal without waiting for the proper time, unless permission be granted you. But if ye are invited, enter, and, when your meal is ended, then disperse. Linger not for conversation. Lo! that would cause annoyance to the Prophet, and he would be shy of (asking) you (to go); but Allah is not shy of the truth. And when ye ask of them (the wives of the Prophet) anything, ask it of them from behind a curtain. That is purer for your hearts and for their hearts. And it is not for you to cause annoyance to the messenger of Allah, nor that ye should ever marry his wives after him. Lo! that in Allah's sight would be an enormity.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdlxxxvii{%
Whether ye divulge a thing or keep it hidden, lo! Allah is ever Knower of all things.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdlxxxviii{%
It is no sin for them (thy wives) to converse freely) with their fathers, or their sons, or their brothers, or their brothers' sons, or the sons of their sisters or of their own women, or their slaves. O women! Keep your duty to Allah. Lo! Allah is ever Witness over all things.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdlxxxix{%
Lo! Allah and His angels shower blessings on the Prophet. O ye who believe! Ask blessings on him and salute him with a worthy salutation.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdxc{%
Lo! those who malign Allah and His messenger, Allah hath cursed them in the world and the Hereafter, and hath prepared for them the doom of the disdained.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdxci{%
And those who malign believing men and believing women undeservedly, they bear the guilt of slander and manifest sin.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdxcii{%
O Prophet! Tell thy wives and thy daughters and the women of the believers to draw their cloaks close round them (when they go abroad). That will be better, so that they may be recognised and not annoyed. Allah is ever Forgiving, Merciful.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdxciii{%
If the hypocrites, and those in whose hearts is a disease, and the alarmists in the city do not cease, We verily shall urge thee on against them, then they will be your neighbours in it but a little while.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdxciv{%
Accursed, they will be seized wherever found and slain with a (fierce) slaughter.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdxcv{%
That was the way of Allah in the case of those who passed away of old; thou wilt not find for the way of Allah aught of power to change.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdxcvi{%
Men ask thee of the Hour. Say: The knowledge of it is with Allah only. What can convey (the knowledge) unto thee? It may be that the Hour is nigh.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdxcvii{%
Lo! Allah hath cursed the disbelievers, and hath prepared for them a flaming fire,\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdxcviii{%
Wherein they will abide for ever. They will find (then) no protecting friend nor helper.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdxcix{%
On the day when their faces are turned over in the Fire, they say: Oh, would that we had obeyed Allah and had obeyed His messenger!\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdc{%
And they say: Our Lord! Lo! we obeyed our princes and great men, and they misled us from the Way.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdci{%
Our Lord! Oh, give them double torment and curse them with a mighty curse.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdcii{%
O ye who believe! Be not as those who slandered Moses, but Allah proved his innocence of that which they alleged, and he was well esteemed in Allah's sight.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdciii{%
O ye who believe! Guard your duty to Allah, and speak words straight to the point;\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdciv{%
He will adjust your works for you and will forgive you your sins. Whosoever obeyeth Allah and His messenger, he verily hath gained a signal victory.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdcv{%
Lo! We offered the trust unto the heavens and the earth and the hills, but they shrank from bearing it and were afraid of it. And man assumed it. Lo! he hath proved a tyrant and a fool.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdcvi{%
So Allah punisheth hypocritical men and hypocritical women, and idolatrous men and idolatrous women. But Allah pardoneth believing men and believing women, and Allah is ever Forgiving, Merciful.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdcvii{%
\basmalahen Praise be to Allah, unto Whom belongeth whatsoever is in the heavens and whatsoever is in the earth. His is the praise in the Hereafter, and He is the Wise, the Aware.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdcviii{%
He knoweth that which goeth into the earth and that which cometh forth from it, and that descendeth from the heaven and that which ascendeth into it. He is the Merciful, the Forgiving.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdcix{%
Those who disbelieve say: The Hour will never come unto us. Say: Nay, by my Lord, but it is coming unto you surely. (He is) the Knower of the Unseen. Not an atom's weight, or less than that or greater, escapeth Him in the heavens or in the earth, but it is in a clear Record,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdcx{%
That He may reward those who believe and do good works. For them is pardon and a rich provision.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdcxi{%
But those who strive against Our revelations, challenging (Us), theirs will be a painful doom of wrath.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdcxii{%
Those who have been given knowledge see that what is revealed unto thee from thy Lord is the truth and leadeth unto the path of the Mighty, the Owner of Praise.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdcxiii{%
Those who disbelieve say: Shall we show you a man who will tell you (that) when ye have become dispersed in dust with most complete dispersal still, even then, ye will be created anew?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdcxiv{%
Hath he invented a lie concerning Allah, or is there in him a madness? Nay, but those who disbelieve in the Hereafter are in torment and far error.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdcxv{%
Have they not observed what is before them and what is behind them of the sky and the earth? If We will, We can make the earth swallow them, or cause obliteration from the sky to fall on them. Lo! herein surely is a portent for every slave who turneth (to Allah) repentant.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdcxvi{%
And assuredly We gave David grace from Us, (saying): O ye hills and birds, echo his psalms of praise! And We made the iron supple unto him,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdcxvii{%
Saying: Make thou long coats of mail and measure the links (thereof). And do ye right. Lo! I am Seer of what ye do.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdcxviii{%
And unto Solomon (We gave) the wind, whereof the morning course was a month's journey and the evening course a month's journey, and We caused the fount of copper to gush forth for him, and (We gave him) certain of the jinn who worked before him by permission of his Lord. And such of them as deviated from Our command, them We caused to taste the punishment of flaming Fire.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdcxix{%
They made for him what he willed: synagogues and statues, basins like wells and boilers built into the ground. Give thanks, O House of David! Few of My bondmen are thankful.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdcxx{%
And when We decreed death for him, nothing showed his death to them save a creeping creature of the earth which gnawed away his staff. And when he fell the jinn saw clearly how, if they had known the Unseen, they would not have continued in despised toil.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdcxxi{%
There was indeed a sign for Sheba in their dwelling-place: Two gardens on the right hand and the left (as who should say): Eat of the provision of your Lord and render thanks to Him. A fair land and an indulgent Lord!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdcxxii{%
But they were froward, so We sent on them the flood of 'Iram, and in exchange for their two gardens gave them two gardens bearing bitter fruit, the tamarisk and here and there a lote-tree.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdcxxiii{%
This We awarded them because of their ingratitude. Punish We ever any save the ingrates?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdcxxiv{%
And We set, between them and the towns which We had blessed, towns easy to be seen, and We made the stage between them easy, (saying): Travel in them safely both by night and day.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdcxxv{%
But they said: Our Lord! Make the stage between our journeys longer. And they wronged themselves, therefore We made them bywords (in the land) and scattered them abroad, a total scattering. Lo! herein verily are portents for each steadfast, grateful (heart).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdcxxvi{%
And Satan indeed found his calculation true concerning them, for they follow him, all save a group of true believers.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdcxxvii{%
And he had no warrant whatsoever against them, save that We would know him who believeth in the Hereafter from him who is in doubt thereof; and thy Lord (O Muhammad) taketh note of all things.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdcxxviii{%
Say (O Muhammad): Call upon those whom ye set up beside Allah! They possess not an atom's weight either in the heavens or in the earth, nor have they any share in either, nor hath He an auxiliary among them.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdcxxix{%
No intercession availeth with Him save for him whom He permitteth. Yet, when fear is banished from their hearts, they say: What was it that your Lord said? They say: The Truth. And He is the Sublime, the Great.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdcxxx{%
Say: Who giveth you provision from the sky and the earth? Say: Allah, Lo! we or you assuredly are rightly guided or in error manifest.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdcxxxi{%
Say: Ye will not be asked of what we committed, nor shall we be asked of what ye do.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdcxxxii{%
Say: Our Lord will bring us all together, then He will judge between us with truth. He is the All-knowing Judge.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdcxxxiii{%
Say: Show me those whom ye have joined unto Him as partners. Nay (ye dare not)! For He is Allah, the Mighty, the Wise.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdcxxxiv{%
And We have not sent thee (O Muhammad) save as a bringer of good tidings and a warner unto all mankind; but most of mankind know not.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdcxxxv{%
And they say: When is this promise (to be fulfilled) if ye are truthful?\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcxxxvi{%
Say (O Muhammad): Yours is the promise of a Day which ye cannot postpone nor hasten by an hour.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcxxxvii{%
And those who disbelieve say: We believe not in this Qur'an nor in that which was before it; but oh, if thou couldst see, when the wrong-doers are brought up before their Lord, how they cast the blame one to another; how those who were despised (in the earth) say unto those who were proud: But for you, we should have been believers.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcxxxviii{%
Those who were proud say unto those who were despised: Did we drive you away from the guidance after it had come unto you? Nay, but ye were guilty.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcxxxix{%
Those who were despised say unto those who were proud: Nay but (it was your) scheming night and day, when ye commanded us to disbelieve in Allah and set up rivals unto Him. And they are filled with remorse when they behold the doom; and We place carcans on the necks of those who disbelieved. Are they requited aught save what they used to do?\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcxl{%
And We sent not unto any township a warner, but its pampered ones declared: Lo! we are disbelievers in that wherewith ye have been sent.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcxli{%
And they say: We are more (than you) in wealth and children. We are not the punished!\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcxlii{%
Say (O Muhammad): Lo! my Lord enlargeth the provision for whom He will and narroweth it (for whom He will). But most of mankind know not.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcxliii{%
And it is not your wealth nor your children that will bring you near unto Us, but he who believeth and doeth good (he draweth near). As for such, theirs will be twofold reward for what they did and they will dwell secure in lofty halls.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcxliv{%
And as for those who strive against Our revelations, challenging, they will be brought to the doom.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcxlv{%
Say: Lo! my Lord enlargeth the provision for whom He will of His bondmen, and narroweth (it) for him. And whatsoever ye spend (for good) He replaceth it. And He is the Best of Providers.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcxlvi{%
And on the day when He will gather them all together, He will say unto the angels: Did these worship you?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcxlvii{%
They will say: Be Thou Glorified. Thou (alone) art our Guardian, not them! Nay, but they worshipped the jinn; most of them were believers in them.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdcxlviii{%
That day ye will possess no use nor hurt one for another. And We shall say unto those who did wrong: Taste the doom of the Fire which ye used to deny.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcxlix{%
And if Our revelations are recited unto them in plain terms, they say: This is naught else than a man who would turn you away from what your fathers used to worship; and they say: This is naught else than an invented lie. Those who disbelieve say of the truth when it reacheth them: This is naught else than mere magic.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcl{%
And We have given them no scriptures which they study, nor sent We unto them, before thee, any warner.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdcli{%
Those before them denied, and these have not attained a tithe of that which We bestowed on them (of old); yet they denied My messengers. How intense then was My abhorrence (of them)!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdclii{%
Say (unto them, O Muhammad): I exhort you unto one thing only: that ye awake, for Allah's sake, by twos and singly, and then reflect: There is no madness in your comrade. He is naught else than a warner unto you in face of a terrific doom.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcliii{%
Say: Whatever reward I might have asked of you is yours. My reward is the affair of Allah only. He is Witness over all things.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdcliv{%
Say: Lo! my Lord hurleth the truth. (He is) the Knower of Things Hidden.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdclv{%
Say: The Truth hath come, and falsehood showeth not its face and will not return.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdclvi{%
Say: If I err, I err only to my own loss, and if I am rightly guided it is because of that which my Lord hath revealed unto me. Lo! He is Hearer, Nigh.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdclvii{%
Couldst thou but see when they are terrified with no escape, and are seized from near at hand,\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdclviii{%
And say: We (now) believe therein. But how can they reach (faith) from afar off,\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdclix{%
When they disbelieved in it of yore. They aim at the unseen from afar off.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdclx{%
And a gulf is set between them and that which they desire, as was done for people of their kind of old. Lo! they were in hopeless doubt.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdclxi{%
\basmalahen Praise be to Allah, the Creator of the heavens and the earth, Who appointeth the angels messengers having wings two, three and four. He multiplieth in creation what He will. Lo! Allah is Able to do all things.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdclxii{%
That which Allah openeth unto mankind of mercy none can withhold it; and that which He withholdeth none can release thereafter. He is the Mighty, the Wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdclxiii{%
O mankind! Remember Allah's grace toward you! Is there any creator other than Allah who provideth for you from the sky and the earth? There is no Allah save Him. Whither then are ye turned?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdclxiv{%
And if they deny thee, (O Muhammad), messengers (of Allah) were denied before thee. Unto Allah all things are brought back.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdclxv{%
O mankind! Lo! the promise of Allah is true. So let not the life of the world beguile you, and let not the (avowed) beguiler beguile you with regard to Allah.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdclxvi{%
Lo! the devil is an enemy for you, so treat him as an enemy. He only summoneth his faction to be owners of the flaming Fire.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdclxvii{%
Those who disbelieve, theirs will be an awful doom; and those who believe and do good works, theirs will be forgiveness and a great reward.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdclxviii{%
Is he, the evil of whose deeds is made fairseeming unto him so that he deemeth it good, (other than Satan's dupe)? Allah verily sendeth whom He will astray, and guideth whom He will; so let not thy soul expire in sighings for them. Lo! Allah is Aware of what they do!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdclxix{%
And Allah it is Who sendeth the winds and they raise a cloud; then We lead it unto a dead land and revive therewith the earth after its death. Such is the Resurrection.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdclxx{%
Whoso desireth power (should know that) all power belongeth to Allah. Unto Him good words ascend, and the pious deed doth He exalt; but those who plot iniquities, theirs will be an awful doom; and the plotting of such (folk) will come to naught.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdclxxi{%
Allah created you from dust, then from a little fluid, then He made you pairs (the male and female). No female beareth or bringeth forth save with His knowledge. And no-one groweth old who groweth old, nor is aught lessened of his life, but it is recorded in a Book, Lo! that is easy for Allah.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdclxxii{%
And the two seas are not alike: this, fresh, sweet, good to drink, this (other) bitter, salt. And from them both ye eat fresh meat and derive the ornament that ye wear. And thou seest the ship cleaving them with its prow that ye may seek of His bounty, and that haply ye may give thanks.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdclxxiii{%
He maketh the night to pass into the day and He maketh the day to pass into the night. He hath subdued the sun and moon to service. Each runneth unto an appointed term. Such is Allah, your Lord; His is the Sovereignty; and those unto whom ye pray instead of Him own not so much as the white spot on a date-stone.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdclxxiv{%
If ye pray unto them they hear not your prayer, and if they heard they could not grant it you. On the Day of Resurrection they will disown association with you. None can inform you like Him Who is Aware.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdclxxv{%
O mankind! Ye are the poor in your relation to Allah. And Allah! He is the Absolute, the Owner of Praise.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdclxxvi{%
If He will, He can be rid of you and bring (instead of you) some new creation.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdclxxvii{%
That is not a hard thing for Allah.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdclxxviii{%
And no burdened soul can bear another's burden, and if one heavy laden crieth for (help with) his load, naught of it will be lifted even though he (unto whom he crieth) be of kin. Thou warnest only those who fear their Lord in secret, and have established worship. He who groweth (in goodness), groweth only for himself, (he cannot by his merit redeem others). Unto Allah is the journeying.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdclxxix{%
The blind man is not equal with the seer;\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdclxxx{%
Nor is darkness (tantamount to) light;\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdclxxxi{%
Nor is the shadow equal with the sun's full heat;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdclxxxii{%
Nor are the living equal with the dead. Lo! Allah maketh whom He will to hear. Thou canst not reach those who are in the graves.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdclxxxiii{%
Thou art but a warner.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdclxxxiv{%
Lo! We have sent thee with the Truth, a bearer of glad tidings and a warner; and there is not a nation but a warner hath passed among them.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdclxxxv{%
And if they deny thee, those before them also denied. Their messengers came unto them with clear proofs (of Allah's Sovereignty), and with the Psalms and the Scripture giving light.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdclxxxvi{%
Then seized I those who disbelieved, and how intense was My abhorrence!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdclxxxvii{%
Hast thou not seen that Allah causeth water to fall from the sky, and We produce therewith fruit of divers hues; and among the hills are streaks white and red, of divers hues, and (others) raven-black;\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdclxxxviii{%
And of men and beasts and cattle, in like manner, divers hues? The erudite among His bondmen fear Allah alone. Lo! Allah is Mighty, Forgiving.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdclxxxix{%
Lo! those who read the Scripture of Allah, and establish worship, and spend of that which We have bestowed on them secretly and openly, they look forward to imperishable gain,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcxc{%
That He will pay them their wages and increase them of His grace. Lo! He is Forgiving, Responsive.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcxci{%
As for that which We inspire in thee of the Scripture, it is the Truth confirming that which was (revealed) before it. Lo! Allah is indeed Observer, Seer of His slaves.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcxcii{%
Then We gave the Scripture as inheritance unto those whom We elected of Our bondmen. But of them are some who wrong themselves and of them are some who are lukewarm, and of them are some who outstrip (others) through good deeds, by Allah's leave. That is the great favour!\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcxciii{%
Gardens of Eden! They enter them wearing armlets of gold and pearl and their raiment therein is silk.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcxciv{%
And they say: Praise be to Allah Who hath put grief away from us. Lo! Our Lord is Forgiving, Bountiful,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcxcv{%
Who, of His grace, hath installed us in the mansion of eternity, where toil toucheth us not nor can weariness affect us.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcxcvi{%
But as for those who disbelieve, for them is fire of hell; it taketh not complete effect upon them so that they can die, nor is its torment lightened for them. Thus We punish every ingrate.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcxcvii{%
And they cry for help there, (saying): Our Lord! Release us; we will do right, not (the wrong) that we used to do. Did not We grant you a life long enough for him who reflected to reflect therein? And the warner came unto you. Now taste (the flavour of your deeds), for evil-doers have no helper.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcxcviii{%
Lo! Allah is the Knower of the Unseen of the heavens and the earth. Lo! He is Aware of the secret of (men's) breasts.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcxcix{%
He it is Who hath made you regents in the earth; so he who disbelieveth, his disbelief be on his own head. Their disbelief increaseth for the disbelievers, in their Lord's sight, naught save abhorrence. Their disbelief increaseth for the disbelievers naught save loss.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcc{%
Say: Have ye seen your partner-gods to whom ye pray beside Allah? Show me what they created of the earth! Or have they any portion in the heavens? Or have We given them a scripture so they act on clear proof therefrom? Nay, the evil-doers promise one another only to deceive.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcci{%
Lo! Allah graspeth the heavens and the earth that they deviate not, and if they were to deviate there is not one that could grasp them after Him. Lo! He is ever Clement, Forgiving.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdccii{%
And they swore by Allah, their most binding oath, that if a warner came unto them they would be more tractable than any of the nations; yet, when a warner came unto them it aroused in them naught save repugnance,\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcciii{%
(Shown in their) behaving arrogantly in the land and plotting evil; and the evil plot encloseth but the men who make it. Then, can they expect aught save the treatment of the folk of old? Thou wilt not find for Allah's way of treatment any substitute, nor wilt thou find for Allah's way of treatment aught of power to change.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcciv{%
Have they not travelled in the land and seen the nature of the consequence for those who were before them, and they were mightier than these in power? Allah is not such that aught in the heavens or in the earth escapeth Him. Lo! He is the Wise, the Mighty.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdccv{%
If Allah took mankind to task by that which they deserve, He would not leave a living creature on the surface of the earth; but He reprieveth them unto an appointed term, and when their term cometh - then verily (they will know that) Allah is ever Seer of His slaves.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdccvi{%
\basmalahen Ya Sin.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdccvii{%
By the wise Qur'an,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdccviii{%
Lo! thou art of those sent\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdccix{%
On a straight path,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdccx{%
A revelation of the Mighty, the Merciful,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdccxi{%
That thou mayst warn a folk whose fathers were not warned, so they are heedless.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdccxii{%
Already hath the judgment, (for their infidelity) proved true of most of them, for they believe not.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdccxiii{%
Lo! We have put on their necks carcans reaching unto the chins, so that they are made stiff-necked.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdccxiv{%
And We have set a bar before them and a bar behind them, and (thus) have covered them so that they see not.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdccxv{%
Whether thou warn them or thou warn them not, it is alike for them, for they believe not.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdccxvi{%
Thou warnest only him who followeth the Reminder and feareth the Beneficent in secret. To him bear tidings of forgiveness and a rich reward.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdccxvii{%
Lo! We it is Who bring the dead to life. We record that which they send before (them, and their footprints. And all things We have kept in a clear Register.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdccxviii{%
Coin for them a similitude: The people of the city when those sent (from Allah) came unto them;\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdccxix{%
When We sent unto them twain, and they denied them both, so We reinforced them with a third, and they said: Lo! we have been sent unto you.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdccxx{%
They said: Ye are but mortals like unto us. The Beneficent hath naught revealed. Ye do but lie!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdccxxi{%
They answered: Our Lord knoweth that we are indeed sent unto you,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdccxxii{%
And our duty is but plain conveyance (of the message).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdccxxiii{%
(The people of the city) said: We augur ill of you. If ye desist not, we shall surely stone you, and grievous torture will befall you at our hands.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdccxxiv{%
They said: Your evil augury be with you! Is it because ye are reminded (of the truth)? Nay, but ye are froward folk!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdccxxv{%
And there came from the uttermost part of the city a man running. He cried: O my people! Follow those who have been sent!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdccxxvi{%
Follow those who ask of you no fee, and who are rightly guided.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdccxxvii{%
For what cause should I not serve Him Who hath created me, and unto Whom ye will be brought back?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdccxxviii{%
Shall I take (other) gods in place of Him when, if the Beneficent should wish me any harm, their intercession will avail me naught, nor can they save?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdccxxix{%
Then truly I should be in error manifest.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdccxxx{%
Lo! I have believed in your Lord, so hear me!\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdccxxxi{%
It was said (unto him): Enter paradise. He said: Would that my people knew\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdccxxxii{%
With what (munificence) my Lord hath pardoned me and made me of the honoured ones!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdccxxxiii{%
We sent not down against his people after him a host from heaven, nor do We ever send.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdccxxxiv{%
It was but one Shout, and lo! they were extinct.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdccxxxv{%
Ah, the anguish for the bondmen! Never came there unto them a messenger but they did mock him!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdccxxxvi{%
Have they not seen how many generations We destroyed before them, which indeed returned not unto them;\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdccxxxvii{%
But all, without exception, will be brought before Us.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdccxxxviii{%
A token unto them is the dead earth. We revive it, and We bring forth from it grain so that they eat thereof;\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdccxxxix{%
And We have placed therein gardens of the date-palm and grapes, and We have caused springs of water to gush forth therein,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdccxl{%
That they may eat of the fruit thereof, and their hands made it not. Will they not, then, give thanks?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdccxli{%
Glory be to Him Who created all the sexual pairs, of that which the earth groweth, and of themselves, and of that which they know not!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdccxlii{%
A token unto them is night. We strip it of the day, and lo! they are in darkness.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdccxliii{%
And the sun runneth on unto a resting-place for him. That is the measuring of the Mighty, the Wise.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdccxliv{%
And for the moon We have appointed mansions till she return like an old shrivelled palm-leaf.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdccxlv{%
It is not for the sun to overtake the moon, nor doth the night outstrip the day. They float each in an orbit.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdccxlvi{%
And a token unto them is that We bear their offspring in the laden ship,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdccxlvii{%
And have created for them of the like thereof whereon they ride.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdccxlviii{%
And if We will, We drown them, and there is no help for them, neither can they be saved;\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdccxlix{%
Unless by mercy from Us and as comfort for a while.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdccl{%
When it is said unto them: Beware of that which is before you and that which is behind you, that haply ye may find mercy (they are heedless).\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdccli{%
Never came a token of the tokens of their Lord to them, but they did turn away from it!\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcclii{%
And when it is said unto them: Spend of that wherewith Allah hath provided you, those who disbelieve say unto those who believe: Shall we feed those whom Allah, if He willed, would feed? Ye are in naught else than error manifest.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdccliii{%
And they say: When will this promise be fulfilled, if ye are truthful?\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdccliv{%
They await but one Shout, which will surprise them while they are disputing.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdcclv{%
Then they cannot make bequest, nor can they return to their own folk.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdcclvi{%
And the trumpet is blown and lo! from the graves they hie unto their Lord,\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdcclvii{%
Crying: Woe upon us! Who hath raised us from our place of sleep? This is that which the Beneficent did promise, and the messengers spoke truth.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdcclviii{%
It is but one Shout, and behold them brought together before Us!\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdcclix{%
This day no soul is wronged in aught; nor are ye requited aught save what ye used to do.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdcclx{%
Lo! those who merit paradise this day are happily employed,\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdcclxi{%
They and their wives, in pleasant shade, on thrones reclining;\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdcclxii{%
Theirs the fruit (of their good deeds) and theirs (all) that they ask;\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdcclxiii{%
The word from a Merciful Lord (for them) is: Peace!\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdcclxiv{%
But avaunt ye, O ye guilty, this day!\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdcclxv{%
Did I not charge you, O ye sons of Adam, that ye worship not the devil - Lo! he is your open foe! -\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdcclxvi{%
But that ye worship Me? That was the right path.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdcclxvii{%
Yet he hath led astray of you a great multitude. Had ye then no sense?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdcclxviii{%
This is hell which ye were promised (if ye followed him).\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdcclxix{%
Burn therein this day for that ye disbelieved.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdcclxx{%
This day We seal up their mouths, and their hands speak out to Us and their feet bear witness as to what they used to earn.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdcclxxi{%
And had We willed, We verily could have quenched their eyesight so that they should struggle for the way. Then how could they have seen?\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdcclxxii{%
And had We willed, We verily could have fixed them in their place, making them powerless to go forward or turn back.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdcclxxiii{%
He whom we bring unto old age, We reverse him in creation (making him go back to weakness after strength). Have ye then no sense?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdcclxxiv{%
And We have not taught him (Muhammad) poetry, nor is it meet for him. This is naught else than a Reminder and a Lecture making plain,\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdcclxxv{%
To warn whosoever liveth, and that the word may be fulfilled against the disbelievers.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdcclxxvi{%
Have they not seen how We have created for them of Our handiwork the cattle, so that they are their owners,\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdcclxxvii{%
And have subdued them unto them, so that some of them they have for riding, some for food?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdcclxxviii{%
Benefits and (divers) drinks have they from them. Will they not then give thanks?\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdcclxxix{%
And they have taken (other) gods beside Allah, in order that they may be helped.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmdcclxxx{%
It is not in their power to help them; but they (the worshippers) are unto them a host in arms.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxi{%
So let not their speech grieve thee (O Muhammad). Lo! We know what they conceal and what proclaim.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxii{%
Hath not man seen that We have created him from a drop of seed? Yet lo! he is an open opponent.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxiii{%
And he hath coined for Us a similitude, and hath forgotten the fact of his creation, saying: Who will revive these bones when they have rotted away?\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxiv{%
Say: He will revive them Who produced them at the first, for He is Knower of every creation,\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxv{%
Who hath appointed for you fire from the green tree, and behold! ye kindle from it.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxvi{%
Is not He Who created the heavens and the earth Able to create the like of them? Aye, that He is! for He is the All-Wise Creator,\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxvii{%
But His command, when He intendeth a thing, is only that He saith unto it: Be! and it is.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxviii{%
Therefor Glory be to Him in Whose hand is the dominion over all things! Unto Him ye will be brought back.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxix{%
\basmalahen By those who set the ranks in battle order\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdccxc{%
And those who drive away (the wicked) with reproof\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdccxci{%
And those who read (the Word) for a reminder,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdccxcii{%
Lo! thy Lord is surely One;\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdccxciii{%
Lord of the heavens and of the earth and all that is between them, and Lord of the sun's risings.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdccxciv{%
Lo! We have adorned the lowest heaven with an ornament, the planets;\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdccxcv{%
With security from every froward devil.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdccxcvi{%
They cannot listen to the Highest Chiefs for they are pelted from every side,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdccxcvii{%
Outcast, and theirs is a perpetual torment;\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdccxcviii{%
Save him who snatcheth a fragment, and there pursueth him a piercing flame.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdccxcix{%
Then ask them (O Muhammad): Are they stronger as a creation, or those (others) whom we have created? Lo! We created them of plastic clay.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdccc{%
Nay, but thou dost marvel when they mock\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdccci{%
And heed not when they are reminded,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdcccii{%
And seek to scoff when they behold a portent.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdccciii{%
And they say: Lo! this is mere magic;\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdccciv{%
When we are dead and have become dust and bones, shall we then, forsooth, be raised (again)?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdcccv{%
And our forefathers?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdcccvi{%
Say (O Muhammad): Ye, in truth; and ye will be brought low.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdcccvii{%
There is but one Shout, and lo! they behold,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdcccviii{%
And say: Ah, woe for us! This is the Day of Judgment.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdcccix{%
This is the Day of Separation, which ye used to deny.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdcccx{%
(And it is said unto the angels): Assemble those who did wrong, together with their wives and what they used to worship\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdcccxi{%
Instead of Allah, and lead them to the path to hell;\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdcccxii{%
And stop them, for they must be questioned.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdcccxiii{%
What aileth you that ye help not one another?\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdcccxiv{%
Nay, but this day they make full submission.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdcccxv{%
And some of them draw near unto others, mutually questioning.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdcccxvi{%
They say: Lo! ye used to come unto us, imposing, (swearing that ye spoke the truth).\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdcccxvii{%
They answer: Nay, but ye (yourselves) were not believers.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcccxviii{%
We had no power over you, but ye were wayward folk.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcccxix{%
Now the Word of our Lord hath been fulfilled concerning us. Lo! we are about to taste (the doom).\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcccxx{%
Thus we misled you. Lo! we were (ourselves) astray.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcccxxi{%
Then lo! this day they (both) are sharers in the doom.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcccxxii{%
Lo! thus deal We with the guilty.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcccxxiii{%
For when it was said unto them, There is no Allah save Allah, they were scornful\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcccxxiv{%
And said: Shall we forsake our gods for a mad poet?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcccxxv{%
Nay, but he brought the Truth, and he confirmed those sent (before him).\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcccxxvi{%
Lo! (now) verily ye taste the painful doom -\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcccxxvii{%
Ye are requited naught save what ye did -\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcccxxviii{%
Save single-minded slaves of Allah;\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcccxxix{%
For them there is a known provision,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdcccxxx{%
Fruits. And they will be honoured\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxi{%
In the Gardens of delight,\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxii{%
On couches facing one another;\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxiii{%
A cup from a gushing spring is brought round for them,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxiv{%
White, delicious to the drinkers,\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxv{%
Wherein there is no headache nor are they made mad thereby.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxvi{%
And with them are those of modest gaze, with lovely eyes,\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxvii{%
(Pure) as they were hidden eggs (of the ostrich).\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxviii{%
And some of them draw near unto others, mutually questioning.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxix{%
A speaker of them saith: Lo! I had a comrade\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdcccxl{%
Who used to say: Art thou in truth of those who put faith (in his words)?\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdcccxli{%
Can we, when we are dead and have become mere dust and bones - can we (then) verily be brought to book?\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdcccxlii{%
He saith: Will ye look?\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdcccxliii{%
Then looketh he and seeth him in the depth of hell.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdcccxliv{%
He saith: By Allah, thou verily didst all but cause my ruin,\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdcccxlv{%
And had it not been for the favour of my Lord, I too had been of those haled forth (to doom).\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdcccxlvi{%
Are we then not to die\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdcccxlvii{%
Saving our former death, and are we not to be punished?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdcccxlviii{%
Lo! this is the supreme triumph.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdcccxlix{%
For the like of this, then, let the workers work.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdcccl{%
Is this better as a welcome, or the tree of Zaqqum?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdcccli{%
Lo! We have appointed it a torment for wrong-doers.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdccclii{%
Lo! it is a tree that springeth in the heart of hell.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdcccliii{%
Its crop is as it were the heads of devils\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdcccliv{%
And lo! they verily must eat thereof, and fill (their) bellies therewith.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdccclv{%
And afterward, lo! thereupon they have a drink of boiling water\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdccclvi{%
And afterward, lo! their return is surely unto hell.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdccclvii{%
They indeed found their fathers astray,\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdccclviii{%
But they make haste (to follow) in their footsteps.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdccclix{%
And verily most of the men of old went astray before them,\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdccclx{%
And verily We sent among them warners.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdccclxi{%
Then see the nature of the consequence for those warned,\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdccclxii{%
Save single-minded slaves of Allah.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmdccclxiii{%
And Noah verily prayed unto Us, and gracious was the Hearer of his prayer\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmdccclxiv{%
And We saved him and his household from the great distress,\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmdccclxv{%
And made his seed the survivors,\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmdccclxvi{%
And left for him among the later folk (the salutation):\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmdccclxvii{%
Peace be unto Noah among the peoples!\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmdccclxviii{%
Lo! thus do We reward the good.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmdccclxix{%
Lo! he is one of Our believing slaves.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmdccclxx{%
Then We did drown the others.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmdccclxxi{%
And lo! of his persuasion verily was Abraham\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmdccclxxii{%
When he came unto his Lord with a whole heart;\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmdccclxxiii{%
When he said unto his father and his folk: What is it that ye worship?\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmdccclxxiv{%
Is it a falsehood - gods beside Allah - that ye desire?\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmdccclxxv{%
What then is your opinion of the Lord of the Worlds?\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmdccclxxvi{%
And he glanced a glance at the stars\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmdccclxxvii{%
Then said: Lo! I feel sick!\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmdccclxxviii{%
And they turned their backs and went away from him.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmdccclxxix{%
Then turned he to their gods and said: Will ye not eat?\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmdccclxxx{%
What aileth you that ye speak not?\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxi{%
Then he attacked them, striking with his right hand.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxii{%
And (his people) came toward him, hastening.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxiii{%
He said: Worship ye that which ye yourselves do carve\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxiv{%
When Allah hath created you and what ye make?\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxv{%
They said: Build for him a building and fling him in the red-hotfire.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxvi{%
And they designed a snare for him, but We made them the undermost.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxvii{%
And he said: Lo! I am going unto my Lord Who will guide me.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxviii{%
My Lord! Vouchsafe me of the righteous.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxix{%
So We gave him tidings of a gentle son.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmmdcccxc{%
And when (his son) was old enough to walk with him, (Abraham) said: O my dear son, I have seen in a dream that I must sacrifice thee. So look, what thinkest thou? He said: O my father! Do that which thou art commanded. Allah willing, thou shalt find me of the steadfast.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmmdcccxci{%
Then, when they had both surrendered (to Allah), and he had flung him down upon his face,\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmmdcccxcii{%
We called unto him: O Abraham!\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmmdcccxciii{%
Thou hast already fulfilled the vision. Lo! thus do We reward the good.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmmdcccxciv{%
Lo! that verily was a clear test.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmmdcccxcv{%
Then We ransomed him with a tremendous victim.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmmdcccxcvi{%
And We left for him among the later folk (the salutation):\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmmdcccxcvii{%
Peace be unto Abraham!\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmmdcccxcviii{%
Thus do We reward the good.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmmdcccxcix{%
Lo! he is one of Our believing slaves.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmmcm{%
And we gave him tidings of the birth of Isaac, a prophet of the righteous.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmmcmi{%
And We blessed him and Isaac. And of their seed are some who do good, and some who plainly wrong themselves.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmmcmii{%
And We verily gave grace unto Moses and Aaron,\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmmcmiii{%
And saved them and their people from the great distress,\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmmcmiv{%
And helped them so that they became the victors.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmmcmv{%
And We gave them the clear Scripture\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmmcmvi{%
And showed them the right path.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmmcmvii{%
And We left for them among the later folk (the salutation):\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmmcmviii{%
Peace be unto Moses and Aaron!\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmmcmix{%
Lo! thus do We reward the good.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmmcmx{%
Lo! they are two of Our believing slaves.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmmcmxi{%
And lo! Elias was of those sent (to warn),\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmmcmxii{%
When he said unto his folk: Will ye not ward off (evil)?\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmmcmxiii{%
Will ye cry unto Baal and forsake the Best of creators,\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmmcmxiv{%
Allah, your Lord and Lord of your forefathers?\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmmcmxv{%
But they denied him, so they surely will be haled forth (to the doom)\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmmcmxvi{%
Save single-minded slaves of Allah.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmmcmxvii{%
And we left for him among the later folk (the salutation):\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmmcmxviii{%
Peace be unto Elias!\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmmcmxix{%
Lo! thus do We reward the good.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmmcmxx{%
Lo! he is one of our believing slaves.\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmmcmxxi{%
And lo! Lot verily was of those sent (to warn).\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmmcmxxii{%
When We saved him and his household, every one,\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmmcmxxiii{%
Save an old woman among those who stayed behind;\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmmcmxxiv{%
Then We destroyed the others.\qt@no{136}}%
\qt@newcmd\qurantrans@en@mmmcmxxv{%
And lo! ye verily pass by (the ruin of) them in the morning\qt@no{137}}%
\qt@newcmd\qurantrans@en@mmmcmxxvi{%
And at night-time; have ye then no sense?\qt@no{138}}%
\qt@newcmd\qurantrans@en@mmmcmxxvii{%
And lo! Jonah verily was of those sent (to warn)\qt@no{139}}%
\qt@newcmd\qurantrans@en@mmmcmxxviii{%
When he fled unto the laden ship,\qt@no{140}}%
\qt@newcmd\qurantrans@en@mmmcmxxix{%
And then drew lots and was of those rejected;\qt@no{141}}%
\qt@newcmd\qurantrans@en@mmmcmxxx{%
And the fish swallowed him while he was blameworthy;\qt@no{142}}%
\qt@newcmd\qurantrans@en@mmmcmxxxi{%
And had he not been one of those who glorify (Allah)\qt@no{143}}%
\qt@newcmd\qurantrans@en@mmmcmxxxii{%
He would have tarried in its belly till the day when they are raised;\qt@no{144}}%
\qt@newcmd\qurantrans@en@mmmcmxxxiii{%
Then We cast him on a desert shore while he was sick;\qt@no{145}}%
\qt@newcmd\qurantrans@en@mmmcmxxxiv{%
And We caused a tree of gourd to grow above him;\qt@no{146}}%
\qt@newcmd\qurantrans@en@mmmcmxxxv{%
And We sent him to a hundred thousand (folk) or more\qt@no{147}}%
\qt@newcmd\qurantrans@en@mmmcmxxxvi{%
And they believed, therefor We gave them comfort for a while.\qt@no{148}}%
\qt@newcmd\qurantrans@en@mmmcmxxxvii{%
Now ask them (O Muhammad): Hath thy Lord daughters whereas they have sons?\qt@no{149}}%
\qt@newcmd\qurantrans@en@mmmcmxxxviii{%
Or created We the angels females while they were present?\qt@no{150}}%
\qt@newcmd\qurantrans@en@mmmcmxxxix{%
Lo! it is of their falsehood that they say:\qt@no{151}}%
\qt@newcmd\qurantrans@en@mmmcmxl{%
Allah hath begotten. Allah! verily they tell a lie.\qt@no{152}}%
\qt@newcmd\qurantrans@en@mmmcmxli{%
(And again of their falsehood): He hath preferred daughters to sons.\qt@no{153}}%
\qt@newcmd\qurantrans@en@mmmcmxlii{%
What aileth you? How judge ye?\qt@no{154}}%
\qt@newcmd\qurantrans@en@mmmcmxliii{%
Will ye not then reflect?\qt@no{155}}%
\qt@newcmd\qurantrans@en@mmmcmxliv{%
Or have ye a clear warrant?\qt@no{156}}%
\qt@newcmd\qurantrans@en@mmmcmxlv{%
Then produce your writ, if ye are truthful.\qt@no{157}}%
\qt@newcmd\qurantrans@en@mmmcmxlvi{%
And they imagine kinship between him and the jinn, whereas the jinn know well that they will be brought before (Him).\qt@no{158}}%
\qt@newcmd\qurantrans@en@mmmcmxlvii{%
Glorified be Allah from that which they attribute (unto Him),\qt@no{159}}%
\qt@newcmd\qurantrans@en@mmmcmxlviii{%
Save single-minded slaves of Allah.\qt@no{160}}%
\qt@newcmd\qurantrans@en@mmmcmxlix{%
Lo! verily, ye and that which ye worship,\qt@no{161}}%
\qt@newcmd\qurantrans@en@mmmcml{%
Ye cannot excite (anyone) against Him.\qt@no{162}}%
\qt@newcmd\qurantrans@en@mmmcmli{%
Save him who is to burn in hell.\qt@no{163}}%
\qt@newcmd\qurantrans@en@mmmcmlii{%
There is not one of us but hath his known position.\qt@no{164}}%
\qt@newcmd\qurantrans@en@mmmcmliii{%
Lo! we, even we are they who set the ranks,\qt@no{165}}%
\qt@newcmd\qurantrans@en@mmmcmliv{%
Lo! we, even we are they who hymn His praise\qt@no{166}}%
\qt@newcmd\qurantrans@en@mmmcmlv{%
And indeed they used to say:\qt@no{167}}%
\qt@newcmd\qurantrans@en@mmmcmlvi{%
If we had but a reminder from the men of old\qt@no{168}}%
\qt@newcmd\qurantrans@en@mmmcmlvii{%
We would be single-minded slaves of Allah.\qt@no{169}}%
\qt@newcmd\qurantrans@en@mmmcmlviii{%
Yet (now that it is come) they disbelieve therein; but they will come to know.\qt@no{170}}%
\qt@newcmd\qurantrans@en@mmmcmlix{%
And verily Our word went forth of old unto Our bondmen sent (to warn)\qt@no{171}}%
\qt@newcmd\qurantrans@en@mmmcmlx{%
That they verily would be helped,\qt@no{172}}%
\qt@newcmd\qurantrans@en@mmmcmlxi{%
And that Our host, they verily would be the victors.\qt@no{173}}%
\qt@newcmd\qurantrans@en@mmmcmlxii{%
So withdraw from them (O Muhammad) awhile,\qt@no{174}}%
\qt@newcmd\qurantrans@en@mmmcmlxiii{%
And watch, for they will (soon) see.\qt@no{175}}%
\qt@newcmd\qurantrans@en@mmmcmlxiv{%
Would they hasten on Our doom?\qt@no{176}}%
\qt@newcmd\qurantrans@en@mmmcmlxv{%
But when it cometh home to them, then it will be a hapless morn for those who have been warned.\qt@no{177}}%
\qt@newcmd\qurantrans@en@mmmcmlxvi{%
Withdraw from them awhile\qt@no{178}}%
\qt@newcmd\qurantrans@en@mmmcmlxvii{%
And watch, for they will (soon) see.\qt@no{179}}%
\qt@newcmd\qurantrans@en@mmmcmlxviii{%
Glorified be thy Lord, the Lord of Majesty, from that which they attribute (unto Him)\qt@no{180}}%
\qt@newcmd\qurantrans@en@mmmcmlxix{%
And peace be unto those sent (to warn).\qt@no{181}}%
\qt@newcmd\qurantrans@en@mmmcmlxx{%
And praise be to Allah, Lord of the Worlds!\qt@no{182}}%
\qt@newcmd\qurantrans@en@mmmcmlxxi{%
\basmalahen Sad. By the renowned Qur'an,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcmlxxii{%
Nay, but those who disbelieve are in false pride and schism.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcmlxxiii{%
How many a generation We destroyed before them, and they cried out when it was no longer the time for escape!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcmlxxiv{%
And they marvel that a warner from among themselves hath come unto them, and the disbelievers say: This is a wizard, a charlatan.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcmlxxv{%
Maketh he the gods One Allah? Lo! that is an astounding thing.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcmlxxvi{%
The chiefs among them go about, exhorting: Go and be staunch to your gods! Lo! this is a thing designed.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcmlxxvii{%
We have not heard of this in later religion. This is naught but an invention.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcmlxxviii{%
Hath the reminder been unto him (alone) among us? Nay, but they are in doubt concerning My reminder; nay but they have not yet tasted My doom.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcmlxxix{%
Or are theirs the treasures of the mercy of thy Lord, the Mighty, the Bestower?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcmlxxx{%
Or is the kingdom of the heavens and the earth and all that is between them theirs? Then let them ascend by ropes!\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxi{%
A defeated host are (all) the factions that are there.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxii{%
The folk of Noah before them denied (their messenger) and (so did the tribe of) A'ad, and Pharaoh firmly planted,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxiii{%
And (the tribe of) Thamud, and the folk of Lot, and the dwellers in the wood: these were the factions.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxiv{%
Not one of them but did deny the messengers, therefor My doom was justified,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxv{%
These wait for but one Shout, there will be no second thereto.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxvi{%
They say: Our Lord! Hasten on for us our fate before the Day of Reckoning.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxvii{%
Bear with what they say, and remember Our bondman David, lord of might, Lo! he was ever turning in repentance (toward Allah).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxviii{%
Lo! We subdued the hills to hymn the praises (of their Lord) with him at nightfall and sunrise,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxix{%
And the birds assembled; all were turning unto Him.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcmxc{%
We made his kingdom strong and gave him wisdom and decisive speech.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcmxci{%
And hath the story of the litigants come unto thee? How they climbed the wall into the royal chamber;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcmxcii{%
How they burst in upon David, and he was afraid of them. They said: Be not afraid! (We are) two litigants, one of whom hath wronged the other, therefor judge aright between us; be not unjust; and show us the fair way.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcmxciii{%
Lo! this my brother hath ninety and nine ewes while I had one ewe; and he said: Entrust it to me, and he conquered me in speech.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcmxciv{%
(David) said: He hath wronged thee in demanding thine ewe in addition to his ewes, and lo! many partners oppress one another, save such as believe and do good works, and they are few. And David guessed that We had tried him, and he sought forgiveness of his Lord, and he bowed himself and fell down prostrate and repented.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcmxcv{%
So We forgave him that; and lo! he had access to Our presence and a happy journey's end.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcmxcvi{%
(And it was said unto him): O David! Lo! We have set thee as a viceroy in the earth; therefor judge aright between mankind, and follow not desire that it beguile thee from the way of Allah. Lo! those who wander from the way of Allah have an awful doom, forasmuch as they forgot the Day of Reckoning.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcmxcvii{%
And We created not the heaven and the earth and all that is between them in vain. That is the opinion of those who disbelieve. And woe unto those who disbelieve, from the Fire!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcmxcviii{%
Shall We treat those who believe and do good works as those who spread corruption in the earth; or shall We treat the pious as the wicked?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcmxcix{%
(This is) a Scripture that We have revealed unto thee, full of blessing, that they may ponder its revelations, and that men of understanding may reflect.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmm{%
And We bestowed on David, Solomon. How excellent a slave! Lo! he was ever turning in repentance (toward Allah).\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmi{%
When there were shown to him at eventide lightfooted coursers\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmii{%
And he said: Lo! I have preferred the good things (of the world) to the remembrance of my Lord; till they were taken out of sight behind the curtain.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmiii{%
(Then he said): Bring them back to me, and fell to slashing (with his sword their) legs and necks.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmiv{%
And verily We tried Solomon, and set upon his throne a (mere) body. Then did he repent.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmv{%
He said: My Lord! Forgive me and bestow on me sovereignty such as shall not belong to any after me. Lo! Thou art the Bestower.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmvi{%
So We made the wind subservient unto him, setting fair by his command whithersoever he intended.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmvii{%
And the unruly, every builder and diver (made We subservient),\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmviii{%
And others linked together in chains,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmix{%
(Saying): This is Our gift, so bestow thou, or withhold, without reckoning.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmx{%
And lo! he hath favour with Us, and a happy journey's end.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmxi{%
And make mention (O Muhammad) of Our bondman Job, when he cried unto his Lord (saying): Lo! the devil doth afflict me with distress and torment.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmxii{%
(And it was said unto him): Strike the ground with thy foot. This (spring) is a cool bath and a refreshing drink.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmxiii{%
And We bestowed on him (again) his household and therewith the like thereof, a mercy from Us, and a memorial for men of understanding.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmxiv{%
And (it was said unto him): Take in thine hand a branch and smite therewith, and break not thine oath. Lo! We found him steadfast, how excellent a slave! Lo! he was ever turning in repentance (to his Lord).\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmxv{%
And make mention of Our bondmen, Abraham, Isaac and Jacob, men of parts and vision.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmxvi{%
Lo! We purified them with a pure thought, remembrance of the Home (of the Hereafter).\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmxvii{%
Lo! in Our sight they are verily of the elect, the excellent.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmxviii{%
And make mention of Ishmael and Elisha and Dhu'l-Kifl. All are of the chosen.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmxix{%
This is a reminder. And lo! for those who ward off (evil) is a happy journey's end,\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmxx{%
Gardens of Eden, whereof the gates are opened for them,\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmxxi{%
Wherein, reclining, they call for plenteous fruit and cool drink (that is) therein.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmxxii{%
And with them are those of modest gaze, companions.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmxxiii{%
This it is that ye are promised for the Day of Reckoning.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmxxiv{%
Lo! this in truth is Our provision, which will never waste away.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmxxv{%
This (is for the righteous). And lo! for the transgressors there with be an evil journey's end,\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmxxvi{%
Hell, where they will burn, an evil resting-place.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmxxvii{%
Here is a boiling and an ice-cold draught, so let them taste it,\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmxxviii{%
And other (torment) of the kind in pairs (the two extremes)!\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmxxix{%
Here is an army rushing blindly with you. (Those who are already in the Fire say): No word of welcome for them. Lo! they will roast at the Fire.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmxxx{%
They say: Nay, but you (misleaders), for you there is no word of welcome. Ye prepared this for us (by your misleading). Now hapless is the plight.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmxxxi{%
They say: Our Lord! Whoever did prepare this for us, oh, give him double portion of the Fire!\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmxxxii{%
And they say: What aileth us that we behold not men whom we were wont to count among the wicked?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmxxxiii{%
Did we take them (wrongly) for a laughing-stock, or have our eyes missed them?\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmxxxiv{%
Lo! that is very truth: the wrangling of the dwellers in the Fire.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmxxxv{%
Say (unto them, O Muhammad): I am only a warner, and there is no Allah save Allah, the One, the Absolute,\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmxxxvi{%
Lord of the heavens and the earth and all that is between them, the Mighty, the Pardoning.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmxxxvii{%
Say: It is tremendous tidings\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmxxxviii{%
Whence ye turn away!\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmxxxix{%
I had no knowledge of the Highest Chiefs when they disputed;\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmxl{%
It is revealed unto me only that I may be a plain warner.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmxli{%
When thy Lord said unto the angels: Lo! I am about to create a mortal out of mire,\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmxlii{%
And when I have fashioned him and breathed into him of My Spirit, then fall down before him prostrate,\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmxliii{%
The angels fell down prostrate, every one,\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmxliv{%
Saving Iblis; he was scornful and became one of the disbelievers.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmxlv{%
He said: O Iblis! What hindereth thee from falling prostrate before that which I have created with both My hands? Art thou too proud or art thou of the high exalted?\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmxlvi{%
He said: I am better than him. Thou createdst me of fire, whilst him Thou didst create of clay.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmxlvii{%
He said: Go forth from hence, for lo! thou art outcast,\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmxlviii{%
And lo! My curse is on thee till the Day of Judgment.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmxlix{%
He said: My Lord! Reprieve me till the day when they are raised.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmml{%
He said: Lo! thou art of those reprieved\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmli{%
Until the day of the time appointed.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmlii{%
He said: Then, by Thy might, I surely will beguile them every one,\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmliii{%
Save Thy single-minded slaves among them.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmliv{%
He said: The Truth is, and the Truth I speak,\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmlv{%
That I shall fill hell with thee and with such of them as follow thee, together.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmlvi{%
Say (O Muhammad, unto mankind): I ask of you no fee for this, and I am no simulating.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmlvii{%
Lo! it is naught else than a reminder for all peoples\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmlviii{%
And ye will come in time to know the truth thereof.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmlix{%
\basmalahen The revelation of the Scripture is from Allah, the Mighty, the Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmlx{%
Lo! We have revealed the Scripture unto thee (Muhammad) with truth; so worship Allah, making religion pure for Him (only).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmlxi{%
Surely pure religion is for Allah only. And those who choose protecting friends beside Him (say): We worship them only that they may bring us near unto Allah. Lo! Allah will judge between them concerning that wherein they differ. Lo! Allah guideth not him who is a liar, an ingrate.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmlxii{%
If Allah had willed to choose a son, He could have chosen what He would of that which He hath created. Be He Glorified! He is Allah, the One, the Absolute.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmlxiii{%
He hath created the heavens and the earth with truth. He maketh night to succeed day, and He maketh day to succeed night, and He constraineth the sun and the moon to give service, each running on for an appointed term. Is not He the Mighty, the Forgiver?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmlxiv{%
He created you from one being, then from that (being) He made its mate; and He hath provided for you of cattle eight kinds. He created you in the wombs of your mothers, creation after creation, in a threefold gloom. Such is Allah, your Lord. His is the Sovereignty. There is no Allah save Him. How then are ye turned away?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmlxv{%
If ye are thankless, yet Allah is Independent of you, though He is not pleased with thanklessness for His bondmen; and if ye are thankful He is pleased therewith for you. No laden soul will bear another's load. Then unto your Lord is your return; and He will tell you what ye used to do. Lo! He knoweth what is in the breasts (of men).\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmlxvi{%
And when some hurt toucheth man, he crieth unto his Lord, turning unto Him (repentant). Then, when He granteth him a boon from Him he forgetteth that for which he cried unto Him before, and setteth up rivals to Allah that he may beguile (men) from his way. Say (O Muhammad, unto such an one): Take pleasure in thy disbelief a while. Lo! thou art of the owners of the Fire.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmlxvii{%
Is he who payeth adoration in the watches of the night, prostrate and standing, bewaring of the Hereafter and hoping for the mercy of his Lord, (to be accounted equal with a disbeliever)? Say (unto them, O Muhammad): Are those who know equal with those who know not? But only men of understanding will pay heed.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmlxviii{%
Say: O My bondmen who believe! Observe your duty to your Lord. For those who do good in this world there is good, and Allah's earth is spacious. Verily the steadfast will be paid their wages without stint.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmlxix{%
Say (O Muhammad): Lo! I am commanded to worship Allah, making religion pure for Him (only).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmlxx{%
And I am commanded to be the first of those who are muslims (surrender unto Him).\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmlxxi{%
Say: Lo! if I should disobey my Lord, I fear the doom of a tremendous Day.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmlxxii{%
Say: Allah I worship, making my religion pure for Him (only).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmlxxiii{%
Then worship what ye will beside Him. Say: The losers will be those who lose themselves and their housefolk on the Day of Resurrection. Ah, that will be the manifest loss!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmlxxiv{%
They have an awning of fire above them and beneath them a dais (of fire). With this doth Allah appal His bondmen. O My bondmen, therefor fear Me!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmlxxv{%
And those who put away false gods lest they should worship them and turn to Allah in repentance, for them there are glad tidings. Therefor give good tidings (O Muhammad) to My bondmen\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmlxxvi{%
Who hear advice and follow the best thereof. Such are those whom Allah guideth, and such are men of understanding.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmlxxvii{%
Is he on whom the word of doom is fulfilled (to be helped), and canst thou (O Muhammad) rescue him who is in the Fire?\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmlxxviii{%
But those who keep their duty to their Lord, for them are lofty halls with lofty halls above them, built (for them), beneath which rivers flow. (It is) a promise of Allah. Allah faileth not His promise.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmlxxix{%
Hast thou not seen how Allah hath sent down water from the sky and hath caused it to penetrate the earth as watersprings, and afterward thereby produceth crops of divers hues; and afterward they wither and thou seest them turn yellow; then He maketh them chaff. Lo! herein verily is a reminder for men of understanding.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmlxxx{%
Is he whose bosom Allah hath expanded for Al-Islam, so that he followeth a light from his Lord, (as he who disbelieveth)? Then woe unto those whose hearts are hardened against remembrance of Allah. Such are in plain error.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmlxxxi{%
Allah hath (now) revealed the fairest of statements, a Scripture consistent, (wherein promises of reward are) paired (with threats of punishment), whereat doth creep the flesh of those who fear their Lord, so that their flesh and their hearts soften to Allah's reminder. Such is Allah's guidance, wherewith He guideth whom He will. And him whom Allah sendeth astray, for him there is no guide.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmlxxxii{%
Is he then, who will strike his face against the awful doom upon the Day of Resurrection (as he who doeth right)? And it will be said unto the wrong-doers: Taste what ye used to earn.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmlxxxiii{%
Those before them denied, and so the doom came on them whence they knew not.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmlxxxiv{%
Thus Allah made them taste humiliation in the life of the world, and verily the doom of the Hereafter will be greater if they did but know.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmlxxxv{%
And verily We have coined for mankind in this Qur'an all kinds of similitudes, that haply they may reflect;\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmlxxxvi{%
A Lecture in Arabic, containing no crookedness, that haply they may ward off (evil).\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmlxxxvii{%
Allah coineth a similitude: A man in relation to whom are several part-owners, quarrelling, and a man belonging wholly to one man. Are the two equal in similitude? Praise be to Allah! But most of them know not.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmlxxxviii{%
Lo! thou wilt die, and lo! they will die;\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmlxxxix{%
Then lo! on the Day of Resurrection, before your Lord ye will dispute.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmxc{%
And who doth greater wrong than he who telleth a lie against Allah, and denieth the truth when it reacheth him? Will not the home of disbelievers be in hell?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmxci{%
And whoso bringeth the truth and believeth therein - Such are the dutiful.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmxcii{%
They shall have what they will of their Lord's bounty. That is the reward of the good:\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmxciii{%
That Allah will remit from them the worst of what they did, and will pay them for reward the best they used to do.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmxciv{%
Will not Allah defend His slave? Yet they would frighten thee with those beside Him. He whom Allah sendeth astray, for him there is no guide.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmxcv{%
And he whom Allah guideth, for him there can be no misleader. Is not Allah Mighty, Able to Requite (the wrong)?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmxcvi{%
And verily, if thou shouldst ask them: Who created the heavens and the earth? they will say: Allah. Say: Bethink you then of those ye worship beside Allah, if Allah willed some hurt for me, could they remove from me His hurt; or if He willed some mercy for me, could they restrain His mercy? Say: Allah is my all. In Him do (all) the trusting put their trust.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmxcvii{%
Say: O my people! Act in your manner. Lo! I (too) am acting. Thus ye will come to know\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmxcviii{%
Who it is unto whom cometh a doom that will abase him, and on whom there falleth everlasting doom.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmxcix{%
Lo! We have revealed unto thee (Muhammad) the Scripture for mankind with truth. Then whosoever goeth right it is for his soul, and whosoever strayeth, strayeth only to its hurt. And thou art not a warder over them.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmc{%
Allah receiveth (men's) souls at the time of their death, and that (soul) which dieth not (yet) in its sleep. He keepeth that (soul) for which He hath ordained death and dismisseth the rest till an appointed term. Lo! herein verily are portents for people who take thought.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmci{%
Or choose they intercessors other than Allah? Say: What! Even though they have power over nothing and have no intelligence?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcii{%
Say: Unto Allah belongeth all intercession. His is the Sovereignty of the heavens and the earth. And afterward unto Him ye will be brought back.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmciii{%
And when Allah alone is mentioned, the hearts of those who believe not in the Hereafter are repelled, and when those (whom they worship) beside Him are mentioned, behold! they are glad.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmciv{%
Say: O Allah! Creator of the heavens and the earth! Knower of the Invisible and the Visible! Thou wilt judge between Thy slaves concerning that wherein they used to differ.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcv{%
And though those who do wrong possess all that is in the earth, and therewith as much again, they verily will seek to ransom themselves therewith on the Day of Resurrection from the awful doom; and there will appear unto them, from their Lord, that wherewith they never reckoned.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcvi{%
And the evils that they earned will appear unto them, and that whereat they used to scoff will surround them.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcvii{%
Now when hurt toucheth a man he crieth unto Us, and afterward when We have granted him a boon from Us, he saith: Only by force of knowledge I obtained it. Nay, but it is a test. But most of them know not.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcviii{%
Those before them said it, yet (all) that they had earned availed them not;\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcix{%
But the evils that they earned smote them; and such of these as do wrong, the evils that they earn will smite them; they cannot escape.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcx{%
Know they not that Allah enlargeth providence for whom He will, and straiteneth it (for whom He will). Lo! herein verily are portents for people who believe.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcxi{%
Say: O My slaves who have been prodigal to their own hurt! Despair not of the mercy of Allah, Who forgiveth all sins. Lo! He is the Forgiving, the Merciful.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcxii{%
Turn unto your Lord repentant, and surrender unto Him, before there come unto you the doom, when ye cannot be helped.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcxiii{%
And follow the better (guidance) of that which is revealed unto you from your Lord, before the doom cometh on you suddenly when ye know not,\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcxiv{%
Lest any soul should say: Alas, my grief that I was unmindful of Allah, and I was indeed among the scoffers!\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcxv{%
Or should say: If Allah had but guided me I should have been among the dutiful!\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcxvi{%
Or should say, when it seeth the doom: Oh, that I had but a second chance that I might be among the righteous!\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcxvii{%
(But now the answer will be): Nay, for My revelations came unto thee, but thou didst deny them and wast scornful and wast among the disbelievers.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcxviii{%
And on the Day of Resurrection thou (Muhammad) seest those who lied concerning Allah with their faces blackened. Is not the home of the scorners in hell?\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcxix{%
And Allah delivereth those who ward off (evil) because of their deserts. Evil toucheth them not, nor do they grieve.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcxx{%
Allah is Creator of all things, and He is Guardian over all things.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcxxi{%
His are the keys of the heavens and the earth, and they who disbelieve the revelations of Allah - such are they who are the losers.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcxxii{%
Say (O Muhammad, to the disbelievers): Do ye bid me serve other than Allah? O ye fools!\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcxxiii{%
And verily it hath been revealed unto thee as unto those before thee (saying): If thou ascribe a partner to Allah thy work will fail and thou indeed wilt be among the losers.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcxxiv{%
Nay, but Allah must thou serve, and be among the thankful!\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcxxv{%
And they esteem not Allah as He hath the right to be esteemed, when the whole earth is His handful on the Day of Resurrection, and the heavens are rolled in His right hand. Glorified is He and High Exalted from all that they ascribe as partner (unto Him).\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcxxvi{%
And the trumpet is blown, and all who are in the heavens and all who are in the earth swoon away, save him whom Allah willeth. Then it is blown a second time, and behold them standing waiting!\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcxxvii{%
And the earth shineth with the light of her Lord, and the Book is set up, and the prophets and the witnesses are brought, and it is judged between them with truth, and they are not wronged.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcxxviii{%
And each soul is paid in full for what it did. And He is Best Aware of what they do.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcxxix{%
And those who disbelieve are driven unto hell in troops till, when they reach it and the gates thereof are opened, and the warders thereof say unto them: Came there not unto you messengers of your own, reciting unto you the revelations of your Lord and warning you of the meeting of this your Day? they say: Yea, verily. But the word of doom of disbelievers is fulfilled.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcxxx{%
It is said (unto them): Enter ye the gates of hell to dwell therein. Thus hapless is the journey's end of the scorners.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcxxxi{%
And those who keep their duty to their Lord are driven unto the Garden in troops till, when they reach it, and the gates thereof are opened, and the warders thereof say unto them: Peace be unto you! Ye are good, so enter ye (the Garden of delight), to dwell therein;\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcxxxii{%
They say: Praise be to Allah, Who hath fulfilled His promise unto us and hath made us inherit the land, sojourning in the Garden where we will! So bounteous is the wage of workers.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcxxxiii{%
And thou (O Muhammad) seest the angels thronging round the Throne, hymning the praises of their Lord. And they are judged aright. And it is said: Praise be to Allah, the Lord of the Worlds!\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcxxxiv{%
\basmalahen Ha. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcxxxv{%
The revelation of the Scripture is from Allah, the Mighty, the Knower,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcxxxvi{%
The Forgiver of sin, the Accepter of repentance, the Stern in punishment, the Bountiful. There is no Allah save Him. Unto Him is the journeying.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcxxxvii{%
None argue concerning the revelations of Allah save those who disbelieve, so let not their turn of fortune in the land deceive thee (O Muhammad).\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcxxxviii{%
The folk of Noah and the factions after them denied (their messengers) before these, and every nation purposed to seize their messenger and argued falsely, (thinking) thereby to refute the Truth. Then I seized them, and how (awful) was My punishment.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcxxxix{%
Thus was the word of thy Lord concerning those who disbelieve fulfilled: That they are owners of the Fire.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcxl{%
Those who bear the Throne, and all who are round about it, hymn the praises of their Lord and believe in Him and ask forgiveness for those who believe (saying): Our Lord! Thou comprehendest all things in mercy and knowledge, therefor forgive those who repent and follow Thy way. Ward off from them the punishment of hell.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcxli{%
Our Lord! And make them enter the Gardens of Eden which thou hast promised them, with such of their fathers and their wives and their descendants as do right. Lo! Thou, only Thou, art the Mighty, the Wise.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcxlii{%
And ward off from them ill-deeds; and he from whom Thou wardest off ill-deeds that day, him verily hast Thou taken into mercy. That is the supreme triumph.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcxliii{%
Lo! (on that day) those who disbelieve are informed by proclamation: Verily Allah's abhorrence is more terrible than your abhorrence one of another, when ye were called unto the faith but did refuse.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcxliv{%
They say: Our Lord! Twice hast Thou made us die, and twice hast Thou made us live. Now we confess our sins. Is there any way to go out?\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcxlv{%
(It is said unto them): This is (your plight) because, when Allah only was invoked, ye disbelieved, but when some partner was ascribed to Him ye were believing. But the command belongeth only to Allah, the Sublime, the Majestic.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcxlvi{%
He it is Who showeth you His portents, and sendeth down for you provision from the sky. None payeth heed save him who turneth (unto Him) repentant.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcxlvii{%
Therefor (O believers) pray unto Allah, making religion pure for Him (only), however much the disbelievers be averse -\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcxlviii{%
The Exalter of Ranks, the Lord of the Throne. He causeth the Spirit of His command upon whom He will of His slaves, that He may warn of the Day of Meeting,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcxlix{%
The day when they come forth, nothing of them being hidden from Allah. Whose is the Sovereignty this day? It is Allah's, the One, the Almighty.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcl{%
This day is each soul requited that which it hath earned; no wrong (is done) this day. Lo! Allah is swift at reckoning.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcli{%
Warn them (O Muhammad) of the Day of the approaching (doom), when the hearts will be choking the throats, (when) there will be no friend for the wrong-doers, nor any intercessor who will be heard.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmclii{%
He knoweth the traitor of the eyes, and that which the bosoms hide.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcliii{%
Allah judgeth with truth, while those to whom they cry instead of Him judge not at all. Lo! Allah, He is the Hearer, the Seer.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcliv{%
Have they not travelled in the land to see the nature of the consequence for those who disbelieved before them? They were mightier than these in power and (in the) traces (which they left behind them) in the earth. Yet Allah seized them for their sins, and they had no protector from Allah.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmclv{%
That was because their messengers kept bringing them clear proofs (of Allah's Sovereignty) but they disbelieved; so Allah seized them. Lo! He is Strong, severe in punishment.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmclvi{%
And verily We sent Moses with Our revelations and a clear warrant\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmclvii{%
Unto Pharaoh and Haman and Korah, but they said: A lying sorcerer!\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmclviii{%
And when he brought them the Truth from Our presence, they said: Slay the sons of those who believe with him, and spare their women. But the plot of disbelievers is in naught but error.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmclix{%
And Pharaoh said: Suffer me to kill Moses, and let him cry unto his Lord. Lo! I fear that he will alter your religion or that he will cause confusion in the land.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmclx{%
Moses said: Lo! I seek refuge in my Lord and your Lord from every scorner who believeth not in a Day of Reckoning.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmclxi{%
And a believing man of Pharaoh's family, who hid his faith, said: Would ye kill a man because he saith: My Lord is Allah, and hath brought you clear proofs from your Lord? If he is lying, then his lie is upon him; and if he is truthful, then some of that wherewith he threateneth you will strike you. Lo! Allah guideth not one who is a prodigal, a liar.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmclxii{%
O my people! Yours is the kingdom to-day, ye being uppermost in the land. But who would save us from the wrath of Allah should it reach us? Pharaoh said: I do but show you what I think, and I do but guide you to wise policy.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmclxiii{%
And he who believed said: O my people! Lo! I fear for you a fate like that of the factions (of old);\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmclxiv{%
A plight like that of Noah's folk, and A'ad and Thamud, and those after them, and Allah willeth no injustice for (His) slaves.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmclxv{%
And, O my people! Lo! I fear for you a Day of Summoning,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmclxvi{%
A day when ye will turn to flee, having no preserver from Allah: and he whom Allah sendeth astray, for him there is no guide.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmclxvii{%
And verily Joseph brought you of old clear proofs, yet ye ceased not to be in doubt concerning what he brought you till, when he died, ye said: Allah will not send any messenger after him. Thus Allah deceiveth him who is a prodigal, a doubter.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmclxviii{%
Those who wrangle concerning the revelations of Allah without any warrant that hath come unto them, it is greatly hateful in the sight of Allah and in the sight of those who believe. Thus doth Allah print on every arrogant, disdainful heart.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmclxix{%
And Pharaoh said: O Haman! Build for me a tower that haply I may reach the roads,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmclxx{%
The roads of the heavens, and may look upon the god of Moses, though verily I think him a liar. Thus was the evil that he did made fairseeming unto Pharaoh, and he was debarred from the (right) way. The plot of Pharaoh ended but in ruin.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmclxxi{%
And he who believed said: O my people! Follow me. I will show you the way of right conduct.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmclxxii{%
O my people! Lo! this life of the world is but a passing comfort, and lo! the Hereafter, that is the enduring home.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmclxxiii{%
Whoso doeth an ill-deed, he will be repaid the like thereof, while whoso doeth right, whether male or female, and is a believer, (all) such will enter the Garden, where they will be nourished without stint.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmclxxiv{%
And, O my people! What aileth me that I call you unto deliverance when ye call me unto the Fire?\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmclxxv{%
Ye call me to disbelieve in Allah and ascribe unto Him as partners that whereof I have no knowledge, while I call you unto the Mighty, the Forgiver.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmclxxvi{%
Assuredly that whereunto ye call me hath no claim in the world or in the Hereafter, and our return will be unto Allah, and the prodigals will be owners of the Fire.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmclxxvii{%
And ye will remember what I say unto you. I confide my cause unto Allah. Lo! Allah is Seer of (His) slaves.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmclxxviii{%
So Allah warded off from him the evils which they plotted, while a dreadful doom encompassed Pharaoh's folk,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmclxxix{%
The Fire; they are exposed to it morning and evening; and on the day when the Hour upriseth (it is said): Cause Pharaoh's folk to enter the most awful doom.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmclxxx{%
And when they wrangle in the Fire, the weak say unto those who were proud: Lo! we were a following unto you; will ye therefor rid us of a portion of the Fire?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmclxxxi{%
Those who were proud say: Lo! we are all (together) herein. Lo! Allah hath judged between (His) slaves.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmclxxxii{%
And those in the Fire say unto the guards of hell: Entreat your Lord that He relieve us of a day of the torment.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmclxxxiii{%
They say: Came not your messengers unto you with clear proofs? They say: Yea, verily. They say: Then do ye pray, although the prayer of disbelievers is in vain.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmclxxxiv{%
Lo! We verily do help Our messengers, and those who believe, in the life of the world and on the day when the witnesses arise,\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmclxxxv{%
The day when their excuse availeth not the evil-doers, and theirs is the curse, and theirs the ill abode.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmclxxxvi{%
And We verily gave Moses the guidance, and We caused the Children of Israel to inherit the Scripture,\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmclxxxvii{%
A guide and a reminder for men of understanding.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmclxxxviii{%
Then have patience (O Muhammad). Lo! the promise of Allah is true. And ask forgiveness of thy sin, and hymn the praise of thy Lord at fall of night and in the early hours.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmclxxxix{%
Lo! those who wrangle concerning the revelations of Allah without a warrant having come unto them, there is naught else in their breasts save pride which they will never attain. So take thou refuge in Allah. Lo! He, only He, is the Hearer, the Seer.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcxc{%
Assuredly the creation of the heavens and the earth is greater than the creation of mankind; but most of mankind know not.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcxci{%
And the blind man and the seer are not equal, neither are those who believe and do good works (equal with) the evil-doer. Little do ye reflect!\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcxcii{%
Lo! the Hour is surely coming, there is no doubt thereof; yet most of mankind believe not.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcxciii{%
And your Lord hath said: Pray unto Me and I will hear your prayer. Lo! those who scorn My service, they will enter hell, disgraced.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcxciv{%
Allah it is Who hath appointed for you night that ye may rest therein, and day for seeing. Lo! Allah is a Lord of bounty for mankind, yet most of mankind give not thanks.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcxcv{%
Such is Allah, your Lord, the Creator of all things, There is no Allah save Him. How then are ye perverted?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcxcvi{%
Thus are they perverted who deny the revelations of Allah.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcxcvii{%
Allah it is Who appointed for you the earth for a dwelling-place and the sky for a canopy, and fashioned you and perfected your shapes, and hath provided you with good things. Such is Allah, your Lord. Then blessed be Allah, the Lord of the Worlds!\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcxcviii{%
He is the Living One. There is no Allah save Him. So pray unto Him, making religion pure for Him (only). Praise be to Allah, the Lord of the Worlds!\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcxcix{%
Say (O Muhammad): I am forbidden to worship those unto whom ye cry beside Allah since there have come unto me clear proofs from my Lord, and I am commanded to surrender to the Lord of the Worlds.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcc{%
He it is Who created you from dust, then from a drop (of seed) then from a clot, then bringeth you forth as a child, then (ordaineth) that ye attain full strength and afterward that ye become old men - though some among you die before - and that ye reach an appointed term, that haply ye may understand.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcci{%
He it is Who quickeneth and giveth death. When He ordaineth a thing, He saith unto it only: Be! and it is.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmccii{%
Hast thou not seen those who wrangle concerning the revelations of Allah, how they are turned away? -\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcciii{%
Those who deny the Scripture and that wherewith We send Our messengers. But they will come to know,\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcciv{%
When carcans are about their necks and chains. They are dragged\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmccv{%
Through boiling waters; then they are thrust into the Fire.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmccvi{%
Then it is said unto them: Where are (all) that ye used to make partners (in the Sovereignty)\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmccvii{%
Beside Allah? They say: They have failed us; but we used not to pray to anything before. Thus doth Allah send astray the disbelievers (in His guidance).\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmccviii{%
(And it is said unto them): This is because ye exulted in the earth without right, and because ye were petulant.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmccix{%
Enter ye the gates of hell, to dwell therein. Evil is the habitation of the scornful.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmccx{%
Then have patience (O Muhammad). Lo! the promise of Allah is true. And whether we let thee see a part of that which We promise them, or (whether) We cause thee to die, still unto Us they will be brought back.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmccxi{%
Verily We sent messengers before thee, among them those of whom We have told thee, and some of whom We have not told thee; and it was not given to any messenger that he should bring a portent save by Allah's leave, but when Allah's commandment cometh (the cause) is judged aright, and the followers of vanity will then be lost.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmccxii{%
Allah it is Who hath appointed for you cattle, that ye may ride on some of them, and eat of some -\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmccxiii{%
(Many) benefits ye have from them - and that ye may satisfy by their means a need that is in your breasts, and may be borne upon them as upon the ship.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmccxiv{%
And He showeth you His tokens. Which, then, of the tokens of Allah do ye deny?\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmccxv{%
Have they not travelled in the land to see the nature of the consequence for those before them? They were more numerous than these, and mightier in power and (in the) traces (which they left behind them) in the earth. But all that they used to earn availed them not.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmccxvi{%
And when their messengers brought them clear proofs (of Allah's Sovereignty) they exulted in the knowledge they (themselves) possessed. And that which they were wont to mock befell them.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmccxvii{%
Then, when they saw Our doom, they said: We believe in Allah only and reject (all) that we used to associate (with Him).\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmccxviii{%
But their faith could not avail them when they saw Our doom. This is Allah's law which hath ever taken course for His bondmen. And then the disbelievers will be ruined.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmccxix{%
\basmalahen Ha. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmccxx{%
A revelation from the Beneficent, the Merciful,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmccxxi{%
A Scripture whereof the verses are expounded, a Lecture in Arabic for people who have knowledge,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmccxxii{%
Good tidings and a warning. But most of them turn away so that they hear not.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmccxxiii{%
And they say: Our hearts are protected from that unto which thou (O Muhammad) callest us, and in our ears there is a deafness, and between us and thee there is a veil. Act, then. Lo! we also shall be acting.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmccxxiv{%
Say (unto them O Muhammad): I am only a mortal like you. It is inspired in me that your Allah is One Allah, therefor take the straight path unto Him and seek forgiveness of Him. And woe unto the idolaters,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmccxxv{%
Who give not the poor-due, and who are disbelievers in the Hereafter.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmccxxvi{%
Lo! as for those who believe and do good works, for them is a reward enduring.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmccxxvii{%
Say (O Muhammad, unto the idolaters): Disbelieve ye verily in Him Who created the earth in two Days, and ascribe ye unto Him rivals? He (and none else) is the Lord of the Worlds.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmccxxviii{%
He placed therein firm hills rising above it, and blessed it and measured therein its sustenance in four Days, alike for (all) who ask;\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmccxxix{%
Then turned He to the heaven when it was smoke, and said unto it and unto the earth: Come both of you, willingly or loth. They said: We come, obedient.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmccxxx{%
Then He ordained them seven heavens in two Days and inspired in each heaven its mandate; and We decked the nether heaven with lamps, and rendered it inviolable. That is the measuring of the Mighty, the Knower.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmccxxxi{%
But if they turn away, then say: I warn you of a thunderbolt like the thunderbolt (which fell of old upon the tribes) of A'ad and Thamud;\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmccxxxii{%
When their messengers came unto them from before them and behind them, saying: Worship none but Allah! they said: If our Lord had willed, He surely would have sent down angels (unto us), so lo! we are disbelievers in that wherewith ye have been sent.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmccxxxiii{%
As for A'ad, they were arrogant in the land without right, and they said: Who is mightier than us in power? Could they not see that Allah Who created them, He was mightier than them in power? And they denied Our revelations.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmccxxxiv{%
Therefor We let loose on them a raging wind in evil days, that We might make them taste the torment of disgrace in the life of the world. And verily the doom of the Hereafter will be more shameful, and they will not be helped.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmccxxxv{%
And as for Thamud, We gave them guidance, but they preferred blindness to the guidance, so the bolt of the doom of humiliation overtook them because of what they used to earn.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmccxxxvi{%
And We delivered those who believed and used to keep their duty to Allah.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmccxxxvii{%
And (make mention of) the day when the enemies of Allah are gathered unto the Fire, they are driven on\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmccxxxviii{%
Till, when they reach it, their ears and their eyes and their skins testify against them as to what they used to do.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmccxxxix{%
And they say unto their skins: Why testify ye against us? They say: Allah hath given us speech Who giveth speech to all things, and Who created you at the first, and unto Whom ye are returned.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmccxl{%
Ye did not hide yourselves lest your ears and your eyes and your skins should testify against you, but ye deemed that Allah knew not much of what ye did.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmccxli{%
That, your thought which ye did think about your Lord, hath ruined you; and ye find yourselves (this day) among the lost.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmccxlii{%
And though they are resigned, yet the Fire is still their home; and if they ask for favour, yet they are not of those unto whom favour can be shown.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmccxliii{%
And We assigned them comrades (in the world), who made their present and their past fairseeming unto them. And the Word concerning nations of the jinn and humankind who passed away before them hath effect for them. Lo! they were ever losers.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmccxliv{%
Those who disbelieve say: Heed not this Qur'an, and drown the hearing of it; haply ye may conquer.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccxlv{%
But verily We shall cause those who disbelieve to taste an awful doom, and verily We shall requite them the worst of what they used to do.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmccxlvi{%
That is the reward of Allah's enemies: the Fire. Therein is their immortal home, payment forasmuch as they denied Our revelations.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmccxlvii{%
And those who disbelieve will say: Our Lord! Show us those who beguiled us of the jinn and humankind. We will place them underneath our feet that they may be among the nethermost.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmccxlviii{%
Lo! those who say: Our Lord is Allah, and afterward are upright, the angels descend upon them, saying: Fear not nor grieve, but hear good tidings of the paradise which ye are promised.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccxlix{%
We are your protecting friends in the life of the world and in the Hereafter. There ye will have (all) that your souls desire, and there ye will have (all) for which ye pray.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccl{%
A gift of welcome from One Forgiving, Merciful.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmccli{%
And who is better in speech than him who prayeth unto his Lord and doeth right, and saith: Lo! I am of those who are muslims (surrender unto Him).\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcclii{%
The good deed and the evil deed are not alike. Repel the evil deed with one which is better, then lo! he, between whom and thee there was enmity (will become) as though he was a bosom friend.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmccliii{%
But none is granted it save those who are steadfast, and none is granted it save the owner of great happiness.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmccliv{%
And if a whisper from the devil reach thee (O Muhammad) then seek refuge in Allah. Lo! He is the Hearer, the Knower.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcclv{%
And of His portents are the night and the day and the sun and the moon. Do not prostrate to the sun or the moon; but prostrate to Allah Who created them, if it is in truth Him Whom ye worship.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcclvi{%
But if they are too proud - still those who are with thy Lord glorify Him night and day, and tire not.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcclvii{%
And of His portents (is this): that thou seest the earth lowly, but when We send down water thereon it thrilleth and groweth. Lo! He Who quickeneth it is verily the Quickener of the Dead. Lo! He is Able to do all things.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcclviii{%
Lo! those who distort Our revelations are not hid from Us. Is he who is hurled into the Fire better, or he who cometh secure on the Day of Resurrection? Do what ye will. Lo! He is Seer of what ye do.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcclix{%
Lo! those who disbelieve in the Reminder when it cometh unto them (are guilty), for lo! it is an unassailable Scripture.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcclx{%
Falsehood cannot come at it from before it or from behind it. (It is) a revelation from the Wise, the Owner of Praise.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcclxi{%
Naught is said unto thee (Muhammad) save what was said unto the messengers before thee. Lo! thy Lord is owner of forgiveness, and owner (also) of dire punishment.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcclxii{%
And if We had appointed it a Lecture in a foreign tongue they would assuredly have said: If only its verses were expounded (so that we might understand)? What! A foreign tongue and an Arab? - Say unto them (O Muhammad): For those who believe it is a guidance and a healing; and as for those who disbelieve, there is a deafness in their ears, and it is blindness for them. Such are called to from afar.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcclxiii{%
And We verily gave Moses the Scripture, but there hath been dispute concerning it; and but for a Word that had already gone forth from thy Lord, it would ere now have been judged between them; but lo! they are in hopeless doubt concerning it.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcclxiv{%
Whoso doeth right it is for his soul, and whoso doeth wrong it is against it. And thy Lord is not at all a tyrant to His slaves.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcclxv{%
Unto Him is referred (all) knowledge of the Hour. And no fruits burst forth from their sheaths, and no female carrieth or bringeth forth but with His knowledge. And on the day when He calleth unto them: Where are now My partners? they will say: We confess unto Thee, not one of us is a witness (for them).\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcclxvi{%
And those to whom they used to cry of old have failed them, and they perceive they have no place of refuge.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcclxvii{%
Man tireth not of praying for good, and if ill toucheth him, then he is disheartened, desperate.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcclxviii{%
And verily, if We cause him to taste mercy after some hurt that hath touched him, he will say: This is my own; and I deem not that the Hour will ever rise, and if I am brought back to my Lord, I surely shall be better off with Him - But We verily shall tell those who disbelieve (all) that they did, and We verily shall make them taste hard punishment.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcclxix{%
When We show favour unto man, he withdraweth and turneth aside, but when ill toucheth him then he aboundeth in prayer.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcclxx{%
Bethink you: If it is from Allah and ye reject it - Who is further astray than one who is at open feud (with Allah)?\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcclxxi{%
We shall show them Our portents on the horizons and within themselves until it will be manifest unto them that it is the Truth. Doth not thy Lord suffice, since He is Witness over all things?\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcclxxii{%
How! Are they still in doubt about the meeting with their Lord? Lo! Is not He surrounding all things?\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcclxxiii{%
\basmalahen Ha. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcclxxiv{%
A'in. Sin. Qaf.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcclxxv{%
Thus Allah the Mighty, the Knower inspireth thee (Muhammad) as (He inspired) those before thee.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcclxxvi{%
Unto Him belongeth all that is in the heavens and all that is in the earth, and He is the Sublime, the Tremendous.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcclxxvii{%
Almost might the heavens above be rent asunder while the angels hymn the praise of their Lord and ask forgiveness for those on the earth. Lo! Allah, He is the Forgiver, the Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcclxxviii{%
And as for those who choose protecting friends beside Him, Allah is Warden over them, and thou art in no wise a guardian over them.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcclxxix{%
And thus We have inspired in thee a Lecture in Arabic, that thou mayst warn the mother-town and those around it, and mayst warn of a day of assembling whereof there is no doubt. A host will be in the Garden, and a host of them in the Flame.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcclxxx{%
Had Allah willed, He could have made them one community, but Allah bringeth whom He will into His mercy. And the wrong-doers have no friend nor helper.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxi{%
Or have they chosen protecting friends besides Him? But Allah, He (alone) is the Protecting Friend. He quickeneth the dead, and He is Able to do all things.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxii{%
And in whatsoever ye differ, the verdict therein belongeth to Allah. Such is my Lord, in Whom I put my trust, and unto Whom I turn.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxiii{%
The Creator of the heavens and the earth. He hath made for you pairs of yourselves, and of the cattle also pairs, whereby He multiplieth you. Naught is as His likeness; and He is the Hearer, the Seer.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxiv{%
His are the keys of the heavens and the earth. He enlargeth providence for whom He will and straiteneth (it for whom He will). Lo! He is Knower of all things.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxv{%
He hath ordained for you that religion which He commended unto Noah, and that which We inspire in thee (Muhammad), and that which We commended unto Abraham and Moses and Jesus, saying: Establish the religion, and be not divided therein. Dreadful for the idolaters is that unto which thou callest them. Allah chooseth for Himself whom He will, and guideth unto Himself him who turneth (toward Him).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxvi{%
And they were not divided until after the knowledge came unto them, through rivalry among themselves; and had it not been for a Word that had already gone forth from thy Lord for an appointed term, it surely had been judged between them. And those who were made to inherit the Scripture after them are verily in hopeless doubt concerning it.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxvii{%
Unto this, then, summon (O Muhammad). And be thou upright as thou art commanded, and follow not their lusts, but say: I believe in whatever scripture Allah hath sent down, and I am commanded to be just among you. Allah is our Lord and your Lord. Unto us our works and unto you your works; no argument between us and you. Allah will bring us together, and unto Him is the journeying.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxviii{%
And those who argue concerning Allah after He hath been acknowledged, their argument hath no weight with their Lord, and wrath is upon them and theirs will be an awful doom.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxix{%
Allah it is Who hath revealed the Scripture with truth, and the Balance. How canst thou know? It may be that the Hour is nigh.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmccxc{%
Those who believe not therein seek to hasten it, while those who believe are fearful of it and know that it is the Truth. Are not they who dispute, in doubt concerning the Hour, far astray?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmccxci{%
Allah is gracious unto His slaves. He provideth for whom He will. And He is the Strong, the Mighty.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmccxcii{%
Whoso desireth the harvest of the Hereafter, We give him increase in its harvest. And whoso desireth the harvest of the world, We give him thereof, and he hath no portion in the Hereafter.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmccxciii{%
Or have they partners (of Allah) who have made lawful for them in religion that which Allah allowed not? And but for a decisive word (gone forth already), it would have been judged between them. Lo! for wrong-doers is a painful doom.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmccxciv{%
Thou seest the wrong-doers fearful of that which they have earned, and it will surely befall them, while those who believe and do good works (will be) in flowering meadows of the Gardens, having what they wish from their Lord. This is the great preferment.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmccxcv{%
This it is which Allah announceth unto His bondmen who believe and do good works. Say (O Muhammad, unto mankind): I ask of you no fee therefor, save lovingkindness among kinsfolk. And whoso scoreth a good deed We add unto its good for him. Lo! Allah is Forgiving, Responsive.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmccxcvi{%
Or say they: He hath invented a lie concerning Allah? If Allah willed, He could have sealed thy heart (against them). And Allah will wipe out the lie and will vindicate the truth by His words. Lo! He is Aware of what is hidden in the breasts (of men).\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmccxcvii{%
And He it is Who accepteth repentance from His bondmen, and pardoneth the evil deeds, and knoweth what ye do,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmccxcviii{%
And accepteth those who do good works, and giveth increase unto them of His bounty. And as for disbelievers, theirs will be an awful doom.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccxcix{%
And if Allah were to enlarge the provision for His slaves they would surely rebel in the earth, but He sendeth down by measure as He willeth. Lo! He is Informed, a Seer of His bondmen.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmccc{%
And He it is Who sendeth down the saving rain after they have despaired, and spreadeth out His mercy. He is the Protecting Friend, the Praiseworthy.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmccci{%
And of His portents is the creation of the heaven and the earth, and of whatever beasts He hath dispersed therein. And He is Able to gather them when He will.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcccii{%
Whatever of misfortune striketh you, it is what your right hands have earned. And He forgiveth much.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccciii{%
Ye cannot escape in the earth, for beside Allah ye have no protecting friend nor any helper.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccciv{%
And of His portents are the ships, like banners on the sea;\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcccv{%
If He will He calmeth the wind so that they keep still upon its surface - Lo! herein verily are signs for every steadfast grateful (heart). -\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcccvi{%
Or He causeth them to perish on account of that which they have earned - And He forgiveth much -\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcccvii{%
And that those who argue concerning Our revelations may know they have no refuge.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcccviii{%
Now whatever ye have been given is but a passing comfort for the life of the world, and that which Allah hath is better and more lasting for those who believe and put their trust in their Lord,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcccix{%
And those who shun the worst of sins and indecencies and, when they are wroth, forgive,\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcccx{%
And those who answer the call of their Lord and establish worship, and whose affairs are a matter of counsel, and who spend of what We have bestowed on them,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcccxi{%
And those who, when great wrong is done to them, defend themselves,\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcccxii{%
The guerdon of an ill-deed is an ill the like thereof. But whosoever pardoneth and amendeth, his wage is the affair of Allah. Lo! He loveth not wrong-doers.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcccxiii{%
And whoso defendeth himself after he hath suffered wrong - for such, there is no way (of blame) against them.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcccxiv{%
The way (of blame) is only against those who oppress mankind, and wrongfully rebel in the earth. For such there is a painful doom.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcccxv{%
And verily whoso is patient and forgiveth - lo! that, verily, is (of) the steadfast heart of things.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcccxvi{%
He whom Allah sendeth astray, for him there is no protecting friend after Him. And thou (Muhammad) wilt see the evil-doers when they see the doom, (how) they say: Is there any way of return?\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcccxvii{%
And thou wilt see them exposed to (the Fire), made humble by disgrace, and looking with veiled eyes. And those who believe will say: Lo! the (eternal) losers are they who lose themselves and their housefolk on the Day of Resurrection. Lo! are not the wrong-doers in perpetual torment?\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcccxviii{%
And they will have no protecting friends to help them instead of Allah. He whom Allah sendeth astray, for him there is no road.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcccxix{%
Answer the call of your Lord before there cometh unto you from Allah a Day which there is no averting. Ye have no refuge on that Day, nor have a ye any (power of) refusal.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcccxx{%
But if they are averse, We have not sent thee as a warder over them. Thine is only to convey (the message). And lo! when We cause man to taste of mercy from Us he exulteth therefor. And if some evil striketh them because of that which their own hands have sent before, then lo! man is an ingrate.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcccxxi{%
Unto Allah belongeth the Sovereignty of the heavens and the earth. He createth what He will. He bestoweth female (offspring) upon whom He will, and bestoweth male (offspring) upon whom He will;\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcccxxii{%
Or He mingleth them, males and females, and He maketh barren whom He will. Lo! He is Knower, Powerful.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcccxxiii{%
And it was not (vouchsafed) to any mortal that Allah should speak to him unless (it be) by revelation or from behind a veil, or (that) He sendeth a messenger to reveal what He will by His leave. Lo! He is Exalted, Wise.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcccxxiv{%
And thus have We inspired in thee (Muhammad) a Spirit of Our command. Thou knewest not what the Scripture was, nor what the Faith. But We have made it a light whereby We guide whom We will of Our bondmen. And lo! thou verily dost guide unto a right path,\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcccxxv{%
The path of Allah, unto Whom belongeth whatsoever is in the heavens and whatsoever is in the earth. Do not all things reach Allah at last?\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcccxxvi{%
\basmalahen Ha. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcccxxvii{%
By the Scripture which maketh plain,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcccxxviii{%
Lo! We have appointed it a Lecture, in Arabic that haply ye may understand.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcccxxix{%
And Lo! in the Source of Decrees, which We possess, it is indeed sublime, decisive.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcccxxx{%
Shall We utterly ignore you because ye are a wanton folk?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxi{%
How many a prophet did We send among the men of old!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxii{%
And never came there unto them a prophet but they used to mock him.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxiii{%
Then We destroyed men mightier than these in prowess; and the example of the men of old hath gone (before them).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxiv{%
And if thou (Muhammad) ask them: Who created the heavens and the earth, they will surely answer: The Mighty, the Knower created them;\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxv{%
Who made the earth a resting-place for you, and placed roads for you therein, that haply ye may find your way;\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxvi{%
And Who sendeth down water from the sky in (due) measure, and We revive a dead land therewith. Even so will ye be brought forth;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxvii{%
He Who created all the pairs, and appointed for you ships and cattle whereupon ye ride.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxviii{%
That ye may mount upon their backs, and may remember your Lord's favour when ye mount thereon, and may say: Glorified be He Who hath subdued these unto us, and we were not capable (of subduing them);\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxix{%
And lo! unto our Lord we surely are returning.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcccxl{%
And they allot to Him a portion of His bondmen! Lo! man is verily a mere ingrate.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcccxli{%
Or chooseth He daughters of all that He hath created, and honoureth He you with sons?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcccxlii{%
And if one of them hath tidings of that which he likeneth to the Beneficent One, his countenance becometh black and he is full of inward rage.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcccxliii{%
(Liken they then to Allah) that which is bred up in outward show, and in dispute cannot make itself plain?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcccxliv{%
And they make the angels, who are the slaves of the Beneficent, females. Did they witness their creation? Their testimony will be recorded and they will be questioned.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcccxlv{%
And they say: If the Beneficent One had (so) willed, we should not have worshipped them. They have no knowledge whatsoever of that. They do but guess.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcccxlvi{%
Or have We given them any scripture before (this Qur'an) so that they are holding fast thereto?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcccxlvii{%
Nay, for they say only: Lo! we found our fathers following a religion, and we are guided by their footprints.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcccxlviii{%
And even so We sent not a warner before thee (Muhammad) into any township but its luxurious ones said: Lo! we found our fathers following a religion, and we are following their footprints.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcccxlix{%
(And the warner) said: What! Even though I bring you better guidance than that ye found your fathers following? They answered: Lo! in what ye bring we are disbelievers.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcccl{%
So We requited them. Then see the nature of the consequence for the rejecters!\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcccli{%
And when Abraham said unto his father and his folk: Lo! I am innocent of what ye worship\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccclii{%
Save Him Who did create me, for He will surely guide me.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcccliii{%
And he made it a word enduring among his seed, that haply they might return.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcccliv{%
Nay, but I let these and their fathers enjoy life (only) till there should come unto them the Truth and a messenger making plain.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmccclv{%
And now that the Truth hath come unto them they say: This is mere magic, and lo! we are disbelievers therein.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccclvi{%
And they say: If only this Qur'an had been revealed to some great man of the two towns?\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccclvii{%
Is it they who apportion thy Lord's mercy? We have apportioned among them their livelihood in the life of the world, and raised some of them above others in rank that some of them may take labour from others; and the mercy of thy Lord is better than (the wealth) that they amass.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmccclviii{%
And were it not that mankind would have become one community, We might well have appointed, for those who disbelieve in the Beneficent, roofs of silver for their houses and stairs (of silver) whereby to mount,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmccclix{%
And for their houses doors (of silver) and couches of silver whereon to recline,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmccclx{%
And ornaments of gold. Yet all that would have been but a provision of the life of the world. And the Hereafter with your Lord would have been for those who keep from evil.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmccclxi{%
And he whose sight is dim to the remembrance of the Beneficent, We assign unto him a devil who becometh his comrade;\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmccclxii{%
And lo! they surely turn them from the way of Allah, and yet they deem that they are rightly guided;\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmccclxiii{%
Till, when he cometh unto Us, he saith (unto his comrade): Ah, would that between me and thee there were the distance of the two horizons - an evil comrade!\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmccclxiv{%
And it profiteth you not this day, because ye did wrong, that ye will be sharers in the doom.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmccclxv{%
Canst thou (Muhammad) make the deaf to hear, or canst thou guide the blind or him who is in error manifest?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmccclxvi{%
And if We take thee away, We surely shall take vengeance on them,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmccclxvii{%
Or (if) We show thee that wherewith We threaten them; for lo! We have complete command of them.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmccclxviii{%
So hold thou fast to that which is inspired in thee. Lo! thou art on a right path.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmccclxix{%
And lo! it is in truth a Reminder for thee and for thy folk; and ye will be questioned.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmccclxx{%
And ask those of Our messengers whom We sent before thee: Did We ever appoint gods to be worshipped beside the Beneficent?\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmccclxxi{%
And verily We sent Moses with Our revelations unto Pharaoh and his chiefs, and he said: I am a messenger of the Lord of the Worlds.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmccclxxii{%
But when he brought them Our tokens, behold! they laughed at them.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmccclxxiii{%
And every token that We showed them was greater than its sister (token), and We grasped them with the torment, that haply they might turn again.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmccclxxiv{%
And they said: O wizard! Entreat thy Lord for us by the pact that He hath made with thee. Lo! we verily will walk aright.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmccclxxv{%
But when We eased them of the torment, behold! they broke their word.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmccclxxvi{%
And Pharaoh caused a proclamation to be made among his people saying: O my people! Is not mine the sovereignty of Egypt and these rivers flowing under me? Can ye not then discern?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmccclxxvii{%
I am surely better than this fellow, who is despicable and can hardly make (his meaning) plain!\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmccclxxviii{%
Why, then, have armlets of gold not been set upon him, or angels sent along with him?\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmccclxxix{%
Thus he persuaded his people to make light (of Moses), and they obeyed him. Lo! they were a wanton folk.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmccclxxx{%
So, when they angered Us, We punished them and drowned them every one.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxi{%
And We made them a thing past, and an example for those after (them).\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxii{%
And when the son of Mary is quoted as an example, behold! the folk laugh out,\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxiii{%
And say: Are our gods better, or is he? They raise not the objection save for argument. Nay! but they are a contentious folk.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxiv{%
He is nothing but a slave on whom We bestowed favour, and We made him a pattern for the Children of Israel.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxv{%
And had We willed We could have set among you angels to be viceroys in the earth.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxvi{%
And lo! verily there is knowledge of the Hour. So doubt ye not concerning it, but follow Me. This is the right path.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxvii{%
And let not Satan turn you aside. Lo! he is an open enemy for you.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxviii{%
When Jesus came with clear proofs (of Allah's Sovereignty), he said: I have come unto you with wisdom, and to make plain some of that concerning which ye differ. So keep your duty to Allah, and obey me.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxix{%
Lo! Allah, He is my Lord and your Lord. So worship Him. This is a right path.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcccxc{%
But the factions among them differed. Then woe unto those who do wrong from the doom of a painful day.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcccxci{%
Await they aught save the Hour, that it shall come upon them suddenly, when they know not?\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcccxcii{%
Friends on that day will be foes one to another, save those who kept their duty (to Allah).\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcccxciii{%
O My slaves! For you there is no fear this day, nor is it ye who grieve;\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcccxciv{%
(Ye) who believed Our revelations and were self-surrendered,\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcccxcv{%
Enter the Garden, ye and your wives, to be made glad.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcccxcvi{%
Therein are brought round for them trays of gold and goblets, and therein is all that souls desire and eyes find sweet. And ye are immortal therein.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcccxcvii{%
This is the Garden which ye are made to inherit because of what ye used to do.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcccxcviii{%
Therein for you is fruit in plenty whence to eat.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcccxcix{%
Lo! the guilty are immortal in hell's torment.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcd{%
It is not relaxed for them, and they despair therein.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcdi{%
We wronged them not, but they it was who did the wrong.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmcdii{%
And they cry: O master! Let thy Lord make an end of us. He saith: Lo! here ye must remain.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmcdiii{%
We verily brought the Truth unto you, but ye were, most of you, averse to the Truth.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmcdiv{%
Or do they determine any thing (against the Prophet)? Lo! We (also) are determining.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmcdv{%
Or deem they that We cannot hear their secret thoughts and private confidences? Nay, but Our envoys, present with them, do record.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmcdvi{%
Say (O Muhammad): If the Beneficent One hath a son, then, I shall be first among the worshippers. (But there is no son).\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmcdvii{%
Glorified be the Lord of the heavens and the earth, the Lord of the Throne, from that which they ascribe (unto Him)!\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmcdviii{%
So let them flounder (in their talk) and play until they meet the Day which they are promised.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmcdix{%
And He it is Who in the heaven is Allah, and in the earth Allah. He is the Wise, the Knower.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmcdx{%
And blessed be He unto Whom belongeth the Sovereignty of the heavens and the earth and all that is between them, and with Whom is knowledge of the Hour, and unto Whom ye will be returned.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmcdxi{%
And those unto whom they cry instead of Him possess no power of intercession, saving him who beareth witness unto the Truth knowingly.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmcdxii{%
And if thou ask them who created them, they will surely say: Allah. How then are they turned away?\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmcdxiii{%
And he saith: O my Lord! Lo! these are a folk who believe not.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmcdxiv{%
Then bear with them (O Muhammad) and say: Peace. But they will come to know.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmmcdxv{%
\basmalahen Ha. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcdxvi{%
By the Scripture that maketh plain\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcdxvii{%
Lo! We revealed it on a blessed night - Lo! We are ever warning -\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcdxviii{%
Whereon every wise command is made clear\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcdxix{%
As a command from Our presence - Lo! We are ever sending -\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcdxx{%
A mercy from thy Lord. Lo! He, even He is the Hearer, the Knower,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcdxxi{%
Lord of the heavens and the earth and all that is between them, if ye would be sure.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcdxxii{%
There is no Allah save Him. He quickeneth and giveth death; your Lord and Lord of your forefathers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcdxxiii{%
Nay, but they play in doubt.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcdxxiv{%
But watch thou (O Muhammad) for the day when the sky will produce visible smoke\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcdxxv{%
That will envelop the people. This will be a painful torment.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcdxxvi{%
(Then they will say): Our Lord relieve us of the torment. Lo! we are believers.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcdxxvii{%
How can there be remembrance for them, when a messenger making plain (the Truth) had already come unto them,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcdxxviii{%
And they had turned away from him and said: One taught (by others), a madman?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcdxxix{%
Lo! We withdraw the torment a little. Lo! ye return (to disbelief).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcdxxx{%
On the day when We shall seize them with the greater seizure, (then) in truth We shall punish.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxi{%
And verily We tried before them Pharaoh's folk, when there came unto them a noble messenger,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxii{%
Saying: Give up to me the slaves of Allah. Lo! I am a faithful messenger unto you.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxiii{%
And saying: Be not proud against Allah. Lo! I bring you a clear warrant.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxiv{%
And lo! I have sought refuge in my Lord and your Lord lest ye stone me to death.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxv{%
And if ye put no faith in me, then let me go.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxvi{%
And he cried unto his Lord, (saying): These are guilty folk.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxvii{%
Then (his Lord commanded): Take away My slaves by night. Lo! ye will be followed,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxviii{%
And leave the sea behind at rest, for lo! they are a drowned host.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxix{%
How many were the gardens and the watersprings that they left behind,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcdxl{%
And the cornlands and the goodly sites\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmcdxli{%
And pleasant things wherein they took delight!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcdxlii{%
Even so (it was), and We made it an inheritance for other folk;\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcdxliii{%
And the heaven and the earth wept not for them, nor were they reprieved.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcdxliv{%
And We delivered the Children of Israel from the shameful doom;\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmcdxlv{%
(We delivered them) from Pharaoh. Lo! he was a tyrant of the wanton ones.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmcdxlvi{%
And We chose them, purposely, above (all) creatures.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcdxlvii{%
And We gave them portents wherein was a clear trial.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcdxlviii{%
Lo! these, forsooth, are saying:\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcdxlix{%
There is naught but our first death, and we shall not be raised again.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcdl{%
Bring back our fathers, if ye speak the truth!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcdli{%
Are they better, or the folk of Tubb'a and those before them? We destroyed them, for surely they were guilty.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcdlii{%
And We created not the heavens and the earth, and all that is between them, in play.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcdliii{%
We created them not save with truth; but most of them know not.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcdliv{%
Assuredly the Day of Decision is the term for all of them,\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcdlv{%
A day when friend can in naught avail friend, nor can they be helped,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcdlvi{%
Save him on whom Allah hath mercy. Lo! He is the Mighty, the Merciful.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcdlvii{%
Lo! the tree of Zaqqum,\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcdlviii{%
The food of the sinner!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcdlix{%
Like molten brass, it seetheth in their bellies\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcdlx{%
As the seething of boiling water.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcdlxi{%
(And it will be said): Take him and drag him to the midst of hell,\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcdlxii{%
Then pour upon his head the torment of boiling water.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcdlxiii{%
(Saying): Taste! Lo! thou wast forsooth the mighty, the noble!\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcdlxiv{%
Lo! this is that whereof ye used to doubt.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcdlxv{%
Lo! those who kept their duty will be in a place secured.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcdlxvi{%
Amid gardens and watersprings,\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcdlxvii{%
Attired in silk and silk embroidery, facing one another.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcdlxviii{%
Even so (it will be). And We shall wed them unto fair ones with wide, lovely eyes.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcdlxix{%
They call therein for every fruit in safety.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcdlxx{%
They taste not death therein, save the first death. And He hath saved them from the doom of hell,\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxi{%
A bounty from thy Lord. That is the supreme triumph.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxii{%
And We have made (this Scripture) easy in thy language only that they may heed.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxiii{%
Wait then (O Muhammad). Lo! they (too) are waiting.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxiv{%
\basmalahen Ha. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxv{%
The revelation of the Scripture is from Allah, the Mighty, the Wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxvi{%
Lo! in the heavens and the earth are portents for believers.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxvii{%
And in your creation, and all the beasts that He scattereth in the earth, are portents for a folk whose faith is sure.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxviii{%
And the difference of night and day and the provision that Allah sendeth down from the sky and thereby quickeneth the earth after her death, and the ordering of the winds, are portents for a people who have sense.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxix{%
These are the portents of Allah which We recite unto thee (Muhammad) with truth. Then in what fact, after Allah and His portents, will they believe?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxx{%
Woe unto each sinful liar,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxi{%
Who heareth the revelations of Allah recited unto him, and then continueth in pride as though he heard them not. Give him tidings of a painful doom.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxii{%
And when he knoweth aught of Our revelations he maketh it a jest. For such there is a shameful doom.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxiii{%
Beyond them there is hell, and that which they have earned will naught avail them, nor those whom they have chosen for protecting friends beside Allah. Theirs will be an awful doom.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxiv{%
This is guidance. And those who disbelieve the revelations of their Lord, for them there is a painful doom of wrath.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxv{%
Allah it is Who hath made the sea of service unto you that the ships may run thereon by His command, and that ye may seek of His bounty, and that haply ye may be thankful;\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxvi{%
And hath made of service unto you whatsoever is in the heavens and whatsoever is in the earth; it is all from Him. Lo! herein verily are portents for a people who reflect.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxvii{%
Tell those who believe to forgive those who hope not for the days of Allah; in order that He may requite folk what they used to earn.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxviii{%
Whoso doeth right, it is for his soul, and whoso doeth wrong, it is against it. And afterward unto your Lord ye will be brought back.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxix{%
And verily we gave the Children of Israel the Scripture and the Command and the Prophethood, and provided them with good things and favoured them above (all) peoples;\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcdxc{%
And gave them plain commandments. And they differed not until after the knowledge came unto them, through rivalry among themselves. Lo! thy Lord will judge between them on the Day of Resurrection concerning that wherein they used to differ.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcdxci{%
And now have We set thee (O Muhammad) on a clear road of (Our) commandment; so follow it, and follow not the whims of those who know not.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcdxcii{%
Lo! they can avail thee naught against Allah. And lo! as for the wrong-doers, some of them are friends of others; and Allah is the Friend of those who ward off (evil).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcdxciii{%
This is clear indication for mankind, and a guidance and a mercy for a folk whose faith is sure.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcdxciv{%
Or do those who commit ill-deeds suppose that We shall make them as those who believe and do good works, the same in life and death? Bad is their judgment!\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcdxcv{%
And Allah hath created the heavens and the earth with truth, and that every soul may be repaid what it hath earned. And they will not be wronged.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcdxcvi{%
Hast thou seen him who maketh his desire his god, and Allah sendeth him astray purposely, and sealeth up his hearing and his heart, and setteth on his sight a covering? Then who will lead him after Allah (hath condemned him)? Will ye not then heed?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcdxcvii{%
And they say: There is naught but our life of the world; we die and we live, and naught destroyeth us save time; when they have no knowledge whatsoever of (all) that; they do but guess.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcdxcviii{%
And when Our clear revelations are recited unto them their only argument is that they say: Bring (back) our fathers. then, if ye are truthful.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcdxcix{%
Say (unto them, O Muhammad): Allah giveth life to you, then causeth you to die, then gathereth you unto the Day of Resurrection whereof there is no doubt. But most of mankind know not.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmd{%
And unto Allah belongeth the Sovereignty of the heavens and the earth; and on the day when the Hour riseth, on that day those who follow falsehood will be lost.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdi{%
And thou wilt see each nation crouching, each nation summoned to its record. (And it will be said unto them): This day ye are requited what ye used to do.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdii{%
This Our Book pronounceth against you with truth. Lo! We have caused (all) that ye did to be recorded.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdiii{%
Then, as for those who believed and did good works, their Lord will bring them in unto His mercy. That is the evident triumph.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdiv{%
And as for those who disbelieved (it will be said unto them): Were not Our revelations recited unto you? But ye were scornful and became a guilty folk.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdv{%
And when it was said: Lo! Allah's promise is the truth, and there is no doubt of the Hour's coming, ye said: We know not what the Hour is. We deem it naught but a conjecture, and we are by no means convinced.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdvi{%
And the evils of what they did will appear unto them, and that which they used to deride will befall them.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdvii{%
And it will be said: This day We forget you, even as ye forgot the meeting of this your day; and your habitation is the Fire, and there is none to help you.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdviii{%
This, forasmuch as ye made the revelations of Allah a jest, and the life of the world beguiled you. Therefor this day they come not forth from thence, nor can they make amends.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdix{%
Then praise be to Allah, Lord of the heavens and Lord of the earth, the Lord of the Worlds.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdx{%
And unto Him (alone) belongeth Majesty in the heavens and the earth, and He is the Mighty, the Wise.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdxi{%
\basmalahen Ha. Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdxii{%
The revelation of the Scripture is from Allah the Mighty, the Wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdxiii{%
We created not the heavens and the earth and all that is between them save with truth, and for a term appointed. But those who disbelieve turn away from that whereof they are warned.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdxiv{%
Say (unto them, O Muhammad): Have ye thought on all that ye invoke beside Allah? Show me what they have created of the earth. Or have they any portion in the heavens? Bring me a scripture before this (Scripture), or some vestige of knowledge (in support of what ye say), if ye are truthful.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdxv{%
And who is further astray than those who, instead of Allah, pray unto such as hear not their prayer until the Day of Resurrection, and are unconscious of their prayer,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdxvi{%
And when mankind are gathered (to the Judgment) will become enemies for them, and will become deniers of having been worshipped.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdxvii{%
And when Our clear revelations are recited unto them, those who disbelieve say of the Truth when it reacheth them: This is mere magic.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdxviii{%
Or say they: He hath invented it? Say (O Muhammad): If I have invented it, still ye have no power to support me against Allah. He is Best Aware of what ye say among yourselves concerning it. He sufficeth for a witness between me and you. And He is the Forgiving, the Merciful.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdxix{%
Say: I am no new thing among the messengers (of Allah), nor know I what will be done with me or with you. I do but follow that which is inspired in me, and I am but a plain warner.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdxx{%
Bethink you: If it is from Allah and ye disbelieve therein, and a witness of the Children of Israel hath already testified to the like thereof and hath believed, and ye are too proud (what plight is yours)? Lo! Allah guideth not wrong-doing folk.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdxxi{%
And those who disbelieve say of those who believe: If it had been (any) good, they would not have been before us in attaining it. And since they will not be guided by it, they say: This is an ancient lie;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdxxii{%
When before it there was the Scripture of Moses, an example and a mercy; and this is a confirming Scripture in the Arabic language, that it may warn those who do wrong and bring good tidings for the righteous.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdxxiii{%
Lo! those who say: Our Lord is Allah, and thereafter walk aright, there shall no fear come upon them neither shall they grieve.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdxxiv{%
Such are rightful owners of the Garden, immortal therein, as a reward for what they used to do.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdxxv{%
And We have commended unto man kindness toward parents. His mother beareth him with reluctance, and bringeth him forth with reluctance, and the bearing of him and the weaning of him is thirty months, till, when he attaineth full strength and reacheth forty years, he saith: My Lord! Arouse me that I may give thanks for the favour wherewith Thou hast favoured me and my parents, and that I may do right acceptable unto Thee. And be gracious unto me in the matter of my seed. Lo! I have turned unto Thee repentant, and lo! I am of those who surrender (unto Thee).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdxxvi{%
Those are they from whom We accept the best of what they do, and overlook their evil deeds. (They are) among the owners of the Garden. This is the true promise which they were promised (in the world).\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdxxvii{%
And whoso saith unto his parents: Fie upon you both! Do ye threaten me that I shall be brought forth (again) when generations before me have passed away? And they twain cry unto Allah for help (and say): Woe unto thee! Believe! Lo! the promise of Allah is true. But he saith: This is naught save fables of the men of old:\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdxxviii{%
Such are those on whom the Word concerning nations of the jinn and mankind which have passed away before them hath effect. Lo! they are the losers.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdxxix{%
And for all there will be ranks from what they do, that He may pay them for their deeds; and they will not be wronged.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdxxx{%
And on the day when those who disbelieve are exposed to the Fire (it will be said): Ye squandered your good things in the life of the world and sought comfort therein. Now this day ye are rewarded with the doom of ignominy because ye were disdainful in the land without a right, and because ye used to transgress.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdxxxi{%
And make mention (O Muhammad) of the brother of A'ad when he warned his folk among the wind-curved sandhills - and verily warners came and went before and after him - saying: Serve none but Allah. Lo! I fear for you the doom of a tremendous Day.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdxxxii{%
They said: Hast come to turn us away from our gods? Then bring upon us that wherewith thou threatenest us, if thou art of the truthful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdxxxiii{%
He said: The knowledge is with Allah only. I convey unto you that wherewith I have been sent, but I see you are a folk that know not.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdxxxiv{%
Then, when they beheld it as a dense cloud coming toward their valleys, they said: Here is a cloud bringing us rain. Nay, but it is that which ye did seek to hasten, a wind wherein is painful torment,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdxxxv{%
Destroying all things by commandment of its Lord. And morning found them so that naught could be seen save their dwellings. Thus do We reward the guilty folk.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdxxxvi{%
And verily We had empowered them with that wherewith We have not empowered you, and had assigned them ears and eyes and hearts; but their ears and eyes and hearts availed them naught since they denied the revelations of Allah; and what they used to mock befell them.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdxxxvii{%
And verily We have destroyed townships round about you, and displayed (for them) Our revelation, that haply they might return.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdxxxviii{%
Then why did those whom they had chosen for gods as a way of approach (unto Allah) not help them? Nay, but they did fail them utterly. And (all) that was their lie, and what they used to invent.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdxxxix{%
And when We inclined toward thee (Muhammad) certain of the jinn, who wished to hear the Qur'an and, when they were in its presence, said: Give ear! and, when it was finished, turned back to their people, warning.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdxl{%
They said: O our people! Lo! we have heard a scripture which hath been revealed after Moses, confirming that which was before it, guiding unto the truth and a right road.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdxli{%
O our people! respond to Allah's summoner and believe in Him. He will forgive you some of your sins and guard you from a painful doom.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdxlii{%
And whoso respondeth not to Allah's summoner he can nowise escape in the earth, and he hath no protecting friends instead of Him. Such are in error manifest.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdxliii{%
Have they not seen that Allah, Who created the heavens and the earth and was not wearied by their creation, is Able to give life to the dead? Aye, He verily is Able to do all things.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdxliv{%
And on the day when those who disbelieve are exposed to the Fire (they will be asked): Is not this real? They will say: Yea, by our Lord. He will say: Then taste the doom for that ye disbelieved.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdxlv{%
Then have patience (O Muhammad) even as the stout of heart among the messengers (of old) had patience, and seek not to hasten on (the doom) for them. On the day when they see that which they are promised (it will seem to them) as though they had tarried but an hour of daylight. A clear message. Shall any be destroyed save evil-living folk?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdxlvi{%
\basmalahen Those who disbelieve and turn (men) from the way of Allah, He rendereth their actions vain.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdxlvii{%
And those who believe and do good works and believe in that which is revealed unto Muhammad - and it is the truth from their Lord - He riddeth them of their ill-deeds and improveth their state.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdxlviii{%
That is because those who disbelieve follow falsehood and because those who believe follow the truth from their Lord. Thus Allah coineth their similitudes for mankind.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdxlix{%
Now when ye meet in battle those who disbelieve, then it is smiting of the necks until, when ye have routed them, then making fast of bonds; and afterward either grace or ransom till the war lay down its burdens. That (is the ordinance). And if Allah willed He could have punished them (without you) but (thus it is ordained) that He may try some of you by means of others. And those who are slain in the way of Allah, He rendereth not their actions vain.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdl{%
He will guide them and improve their state,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdli{%
And bring them in unto the Garden which He hath made known to them.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdlii{%
O ye who believe! If ye help Allah, He will help you and will make your foothold firm.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdliii{%
And those who disbelieve, perdition is for them, and He will make their actions vain.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdliv{%
That is because they are averse to that which Allah hath revealed, therefor maketh He their actions fruitless.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdlv{%
Have they not travelled in the land to see the nature of the consequence for those who were before them? Allah wiped them out. And for the disbelievers there will be the like thereof.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdlvi{%
That is because Allah is patron of those who believe, and because the disbelievers have no patron.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdlvii{%
Lo! Allah will cause those who believe and do good works to enter Gardens underneath which rivers flow; while those who disbelieve take their comfort in this life and eat even as the cattle eat, and the Fire is their habitation.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdlviii{%
And how many a township stronger than thy township (O Muhammad) which hath cast thee out, have We destroyed, and they had no helper!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdlix{%
Is he who relieth on a clear proof from his Lord like those for whom the evil that they do is beautified while they follow their own lusts?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdlx{%
A similitude of the Garden which those who keep their duty (to Allah) are promised: Therein are rivers of water unpolluted, and rivers of milk whereof the flavour changeth not, and rivers of wine delicious to the drinkers, and rivers of clear-run honey; therein for them is every kind of fruit, with pardon from their Lord. (Are those who enjoy all this) like those who are immortal in the Fire and are given boiling water to drink so that it teareth their bowels?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdlxi{%
Among them are some who give ear unto thee (Muhammad) till, when they go forth from thy presence they say unto those who have been given knowledge: What was that he said just now? Those are they whose hearts Allah hath sealed, and they follow their own lusts.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdlxii{%
While as for those who walk aright, He addeth to their guidance, and giveth them their protection (against evil).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdlxiii{%
Await they aught save the Hour, that it should come upon them unawares? And the beginnings thereof have already come. But how, when it hath come upon them, can they take their warning?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdlxiv{%
So know (O Muhammad) that there is no Allah save Allah, and ask forgiveness for thy sin and for believing men and believing women. Allah knoweth (both) your place of turmoil and your place of rest.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdlxv{%
And those who believe say: If only a surah were revealed! But when a decisive surah is revealed and war is mentioned therein, thou seest those in whose hearts is a disease looking at thee with the look of men fainting unto death. Therefor woe unto them!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdlxvi{%
Obedience and a civil word. Then, when the matter is determined, if they are loyal to Allah it will be well for them.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdlxvii{%
Would ye then, if ye were given the command, work corruption in the land and sever your ties of kinship?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdlxviii{%
Such are they whom Allah curseth so that He deafeneth them and maketh blind their eyes.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdlxix{%
Will they then not meditate on the Qur'an, or are there locks on the hearts?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdlxx{%
Lo! those who turn back after the guidance hath been manifested unto them, Satan hath seduced them, and He giveth them the rein.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdlxxi{%
That is because they say unto those who hate what Allah hath revealed: We will obey you in some matters; and Allah knoweth their secret talk.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdlxxii{%
Then how (will it be with them) when the angels gather them, smiting their faces and their backs!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdlxxiii{%
That will be because they followed that which angereth Allah, and hated that which pleaseth Him. Therefor He hath made their actions vain.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdlxxiv{%
Or do those in whose hearts is a disease deem that Allah will not bring to light their (secret) hates?\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdlxxv{%
And if We would, We could show them unto thee (Muhammad) so that thou shouldst know them surely by their marks. And thou shalt know them by the burden of their talk. And Allah knoweth your deeds.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdlxxvi{%
And verily We shall try you till We know those of you who strive hard (for the cause of Allah) and the steadfast, and till We test your record.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdlxxvii{%
Lo! those who disbelieve and turn from the way of Allah and oppose the messenger after the guidance hath been manifested unto them, they hurt Allah not a jot, and He will make their actions fruitless.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdlxxviii{%
O ye who believe! Obey Allah and obey the messenger, and render not your actions vain.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdlxxix{%
Lo! those who disbelieve and turn from the way of Allah and then die disbelievers, Allah surely will not pardon them.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdlxxx{%
So do not falter and cry out for peace when ye (will be) the uppermost, and Allah is with you, and He will not grudge (the reward of) your actions.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxi{%
The life of the world is but a sport and a pastime. And if ye believe and ward off (evil). He will give you your wages, and will not ask of you your wordly wealth.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxii{%
If He should ask it of you and importune you, ye would hoard it, and He would bring to light your (secret) hates.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxiii{%
Lo! ye are those who are called to spend in the way of Allah, yet among you there are some who hoard. And as for him who hoardeth, he hoardeth only from his soul. And Allah is the Rich, and ye are the poor. And if ye turn away He will exchange you for some other folk, and they will not be the likes of you.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxiv{%
\basmalahen Lo! We have given thee (O Muhammad) a signal victory,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxv{%
That Allah may forgive thee of thy sin that which is past and that which is to come, and may perfect His favour unto thee, and may guide thee on a right path,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxvi{%
And that Allah may help thee with strong help -\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxvii{%
He it is Who sent down peace of reassurance into the hearts of the believers that they might add faith unto their faith. Allah's are the hosts of the heavens and the earth, and Allah is ever Knower, Wise -\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxviii{%
That He may bring the believing men and the believing women into Gardens underneath which rivers flow, wherein they will abide, and may remit from them their evil deeds - That, in the sight of Allah, is the supreme triumph -\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxix{%
And may punish the hypocritical men and the hypocritical women, and the idolatrous men and the idolatrous women, who think an evil thought concerning Allah. For them is the evil turn of fortune, and Allah is wroth against them and hath cursed them, and hath made ready for them hell, a hapless journey's end.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdxc{%
Allah's are the hosts of the heavens and the earth, and Allah is ever Mighty, Wise.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdxci{%
Lo! We have sent thee (O Muhammad) as a witness and a bearer of good tidings and a warner,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdxcii{%
That ye (mankind) may believe in Allah and His messenger, and may honour Him, and may revere Him, and may glorify Him at early dawn and at the close of day.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdxciii{%
Lo! those who swear allegiance unto thee (Muhammad), swear allegiance only unto Allah. The Hand of Allah is above their hands. So whosoever breaketh his oath, breaketh it only to his soul's hurt; while whosoever keepeth his covenant with Allah, on him will He bestow immense reward.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdxciv{%
Those of the wandering Arabs who were left behind will tell thee: Our possessions and our households occupied us, so ask forgiveness for us! They speak with their tongues that which is not in their hearts. Say: Who can avail you aught against Allah, if He intend you hurt or intend you profit? Nay, but Allah is ever Aware of what ye do.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdxcv{%
Nay, but ye deemed that the messenger and the believers would never return to their own folk, and that was made fairseeming in your hearts, and ye did think an evil thought, and ye were worthless folk.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdxcvi{%
And so for him who believeth not in Allah and His messenger - Lo! We have prepared a flame for disbelievers.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdxcvii{%
And Allah's is the Sovereignty of the heavens and the earth. He forgiveth whom He will, and punisheth whom He will. And Allah is ever Forgiving, Merciful.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdxcviii{%
Those who were left behind will say, when ye set forth to capture booty: Let us go with you. They fain would change the verdict of Allah. Say (unto them, O Muhammad): Ye shall not go with us. Thus hath Allah said beforehand. Then they will say: Ye are envious of us. Nay, but they understand not, save a little.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdxcix{%
Say unto those of the wandering Arabs who were left behind: Ye will be called against a folk of mighty prowess, to fight them until they surrender; and if ye obey, Allah will give you a fair reward; but if ye turn away as ye did turn away before, He will punish you with a painful doom.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdc{%
There is no blame for the blind, nor is there blame for the lame, nor is there blame for the sick (that they go not forth to war). And whoso obeyeth Allah and His messenger, He will make him enter Gardens underneath which rivers flow; and whoso turneth back, him will He punish with a painful doom.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdci{%
Allah was well pleased with the believers when they swore allegiance unto thee beneath the tree, and He knew what was in their hearts, and He sent down peace of reassurance on them, and hath rewarded them with a near victory;\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcii{%
And much booty that they will capture. Allah is ever Mighty, Wise.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdciii{%
Allah promiseth you much booty that ye will capture, and hath given you this in advance, and hath withheld men's hands from you, that it may be a token for the believers, and that He may guide you on a right path.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdciv{%
And other (gain), which ye have not been able to achieve, Allah will compass it, Allah is Able to do all things.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcv{%
And if those who disbelieve join battle with you they will take to flight, and afterward they will find no protecting friend nor helper.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcvi{%
It is the law of Allah which hath taken course aforetime. Thou wilt not find for the law of Allah aught of power to change.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcvii{%
And He it is Who hath withheld men's hands from you, and hath withheld your hands from them, in the valley of Mecca, after He had made you victors over them. Allah is Seer of what ye do.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcviii{%
These it was who disbelieved and debarred you from the Inviolable Place of Worship, and debarred the offering from reaching its goal. And if it had not been for believing men and believing women, whom ye know not - lest ye should tread them under foot and thus incur guilt for them unknowingly; that Allah might bring into His mercy whom He will - If (the believers and the disbelievers) had been clearly separated We verily had punished those of them who disbelieved with painful punishment.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcix{%
When those who disbelieve had set up in their hearts zealotry, the zealotry of the Age of Ignorance, then Allah sent down His peace of reassurance upon His messenger and upon the believers and imposed on them the word of self-restraint, for they were worthy of it and meet for it. And Allah is Aware of all things.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcx{%
Allah hath fulfilled the vision for His messenger in very truth. Ye shall indeed enter the Inviolable Place of Worship, if Allah will, secure, (having your hair) shaven and cut, not fearing. But He knoweth that which ye know not, and hath given you a near victory beforehand.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcxi{%
He it is Who hath sent His messenger with the guidance and the religion of truth, that He may cause it to prevail over all religion. And Allah sufficeth as a Witness.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcxii{%
Muhammad is the messenger of Allah. And those with him are hard against the disbelievers and merciful among themselves. Thou (O Muhammad) seest them bowing and falling prostrate (in worship), seeking bounty from Allah and (His) acceptance. The mark of them is on their foreheads from the traces of prostration. Such is their likeness in the Torah and their likeness in the Gospel - like as sown corn that sendeth forth its shoot and strengtheneth it and riseth firm upon its stalk, delighting the sowers - that He may enrage the disbelievers with (the sight of) them. Allah hath promised, unto such of them as believe and do good works, forgiveness and immense reward.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcxiii{%
\basmalahen O ye who believe! Be not forward in the presence of Allah and His messenger, and keep your duty to Allah. Lo! Allah is Hearer, Knower.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcxiv{%
O ye who believe! Lift not up your voices above the voice of the Prophet, nor shout when speaking to him as ye shout one to another, lest your works be rendered vain while ye perceive not.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcxv{%
Lo! they who subdue their voices in the presence of the messenger of Allah, those are they whose hearts Allah hath proven unto righteousness. Theirs will be forgiveness and immense reward.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcxvi{%
Lo! those who call thee from behind the private apartments, most of them have no sense.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcxvii{%
And if they had had patience till thou camest forth unto them, it had been better for them. And Allah is Forgiving, Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdcxviii{%
O ye who believe! If an evil-liver bring you tidings, verify it, lest ye smite some folk in ignorance and afterward repent of what ye did.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcxix{%
And know that the messenger of Allah is among you. If he were to obey you in much of the government, ye would surely be in trouble; but Allah hath endeared the faith to you and hath beautified it in your hearts, and hath made disbelief and lewdness and rebellion hateful unto you. Such are they who are the rightly guided.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcxx{%
(It is) a bounty and a grace from Allah; and Allah is Knower, Wise.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdcxxi{%
And if two parties of believers fall to fighting, then make peace between them. And if one party of them doeth wrong to the other, fight ye that which doeth wrong till it return unto the ordinance of Allah; then, if it return, make peace between them justly, and act equitably. Lo! Allah loveth the equitable.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdcxxii{%
The believers are naught else than brothers. Therefore make peace between your brethren and observe your duty to Allah that haply ye may obtain mercy.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdcxxiii{%
O ye who believe! Let not a folk deride a folk who may be better than they (are), not let women (deride) women who may be better than they are; neither defame one another, nor insult one another by nicknames. Bad is the name of lewdness after faith. And whoso turneth not in repentance, such are evil-doers.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdcxxiv{%
O ye who believe! Shun much suspicion; for lo! some suspicion is a crime. And spy not, neither backbite one another. Would one of you love to eat the flesh of his dead brother? Ye abhor that (so abhor the other)! And keep your duty (to Allah). Lo! Allah is Relenting, Merciful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdcxxv{%
O mankind! Lo! We have created you male and female, and have made you nations and tribes that ye may know one another. Lo! the noblest of you, in the sight of Allah, is the best in conduct. Lo! Allah is Knower, Aware.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdcxxvi{%
The wandering Arabs say: We believe. Say (unto them, O Muhammad): Ye believe not, but rather say ``We submit," for the faith hath not yet entered into your hearts. Yet, if ye obey Allah and His messenger, He will not withhold from you aught of (the reward of) your deeds. Lo! Allah is Forgiving, Merciful.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxxvii{%
The (true) believers are those only who believe in Allah and His messenger and afterward doubt not, but strive with their wealth and their lives for the cause of Allah. Such are the sincere.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxxviii{%
Say (unto them, O Muhammad): Would ye teach Allah your religion, when Allah knoweth all that is in the heavens and all that is in the earth, and Allah is Aware of all things?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxxix{%
They make it a favour unto thee (Muhammad) that they have surrendered (unto Him). Say: Deem not your Surrender a favour unto me; but Allah doth confer a favour on you, inasmuch as He hath led you to the Faith, if ye are earnest.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxxx{%
Lo! Allah knoweth the Unseen of the heavens and the earth. And Allah is Seer of what ye do.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxi{%
\basmalahen Qaf. By the Glorious Qur'an,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxii{%
Nay, but they marvel that a warner of their own hath come unto them; and the disbelievers say: This is a strange thing:\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxiii{%
When we are dead and have become dust (shall we be brought back again)? That would be a far return!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxiv{%
We know that which the earth taketh of them, and with Us is a recording Book.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxv{%
Nay, but they have denied the truth when it came unto them, therefor they are now in troubled case.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxvi{%
Have they not then observed the sky above them, how We have constructed it and beautified it, and how there are no rifts therein?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxvii{%
And the earth have We spread out, and have flung firm hills therein, and have caused of every lovely kind to grow thereon,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxviii{%
A vision and a reminder for every penitent slave.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxix{%
And We send down from the sky blessed water whereby We give growth unto gardens and the grain of crops,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdcxl{%
And lofty date-palms with ranged clusters,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdcxli{%
Provision (made) for men; and therewith We quicken a dead land. Even so will be the resurrection of the dead.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdcxlii{%
The folk of Noah denied (the truth) before them, and (so did) the dwellers at Ar-Rass and (the tribe of) Thamud,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdcxliii{%
And (the tribe of) A'ad, and Pharaoh, and the brethren of Lot,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdcxliv{%
And the dwellers in the wood, and the folk of Tubb'a: every one denied their messengers, therefor My threat took effect.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxlv{%
Were We then worn out by the first creation? Yet they are in doubt about a new creation.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxlvi{%
We verily created man and We know what his soul whispereth to him, and We are nearer to him than his jugular vein.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxlvii{%
When the two Receivers receive (him), seated on the right hand and on the left,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxlviii{%
He uttereth no word but there is with him an observer ready.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxlix{%
And the agony of death cometh in truth. (And it is said unto him): This is that which thou wast wont to shun.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcl{%
And the trumpet is blown. This is the threatened Day.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcli{%
And every soul cometh, along with it a driver and a witness.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdclii{%
(And unto the evil-doer it is said): Thou wast in heedlessness of this. Now We have removed from thee thy covering, and piercing is thy sight this day.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcliii{%
And (unto the evil-doer) his comrade saith: This is that which I have ready (as testimony).\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcliv{%
(And it is said): Do ye twain hurl to hell each rebel ingrate,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdclv{%
Hinderer of good, transgressor, doubter,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdclvi{%
Who setteth up another god along with Allah. Do ye twain hurl him to the dreadful doom.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdclvii{%
His comrade saith: Our Lord! I did not cause him to rebel, but he was (himself) far gone in error.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdclviii{%
He saith: Contend not in My presence, when I had already proffered unto you the warning.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdclix{%
The sentence that cometh from Me cannot be changed, and I am in no wise a tyrant unto the slaves.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdclx{%
On the day when We say unto hell: Art thou filled? and it saith: Can there be more to come?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdclxi{%
And the Garden is brought nigh for those who kept from evil, no longer distant.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdclxii{%
(And it is said): This is that which ye were promised. (It is) for every penitent and heedful one,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdclxiii{%
Who feareth the Beneficent in secret and cometh with a contrite heart.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdclxiv{%
Enter it in peace. This is the day of immortality.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdclxv{%
There they have all that they desire, and there is more with Us.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdclxvi{%
And how many a generation We destroyed before them, who were mightier than these in prowess so that they overran the lands! Had they any place of refuge (when the judgment came)?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdclxvii{%
Lo! therein verily is a reminder for him who hath a heart, or giveth ear with full intelligence.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdclxviii{%
And verily We created the heavens and the earth, and all that is between them, in six Days, and naught of weariness touched Us.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdclxix{%
Therefor (O Muhammad) bear with what they say, and hymn the praise of thy Lord before the rising and before the setting of the sun;\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdclxx{%
And in the night-time hymn His praise, and after the (prescribed) prostrations.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdclxxi{%
And listen on the day when the crier crieth from a near place,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdclxxii{%
The day when they will hear the (Awful) Cry in truth. That is the day of coming forth (from the graves).\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdclxxiii{%
Lo! We it is Who quicken and give death, and unto Us is the journeying.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdclxxiv{%
On the day when the earth splitteth asunder from them, hastening forth (they come). That is a gathering easy for Us (to make).\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdclxxv{%
We are Best Aware of what they say, and thou (O Muhammad) art in no wise a compeller over them. But warn by the Qur'an him who feareth My threat.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdclxxvi{%
\basmalahen By those that winnow with a winnowing\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdclxxvii{%
And those that bear the burden (of the rain)\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdclxxviii{%
And those that glide with ease (upon the sea)\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdclxxix{%
And those who distribute (blessings) by command,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdclxxx{%
Lo! that wherewith ye are threatened is indeed true,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxi{%
And lo! the judgment will indeed befall.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxii{%
By the heaven full of paths,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxiii{%
Lo! ye, forsooth, are of various opinion (concerning the truth).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxiv{%
He is made to turn away from it who is (himself) averse.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxv{%
Accursed be the conjecturers\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxvi{%
Who are careless in an abyss!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxvii{%
They ask: When is the Day of Judgment?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxviii{%
(It is) the day when they will be tormented at the Fire,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxix{%
(And it will be said unto them): Taste your torment (which ye inflicted). This is what ye sought to hasten.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxc{%
Lo! those who keep from evil will dwell amid gardens and watersprings,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxci{%
Taking that which their Lord giveth them; for lo! aforetime they were doers of good;\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxcii{%
They used to sleep but little of the night,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxciii{%
And ere the dawning of each day would seek forgiveness,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxciv{%
And in their wealth the beggar and the outcast had due share.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcxcv{%
And in the earth are portents for those whose faith is sure.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcxcvi{%
And (also) in yourselves. Can ye then not see?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcxcvii{%
And in the heaven is your providence and that which ye are promised;\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcxcviii{%
And by the Lord of the heavens and the earth, it is the truth, even as (it is true) that ye speak.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcxcix{%
Hath the story of Abraham's honoured guests reached thee (O Muhammad)?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcc{%
When they came in unto him and said: Peace! he answered, Peace! (and thought): Folk unknown (to me).\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcci{%
Then he went apart unto his housefolk so that they brought a fatted calf;\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdccii{%
And he set it before them, saying: Will ye not eat?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcciii{%
Then he conceived a fear of them. They said: Fear not! and gave him tidings of (the birth of) a wise son.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcciv{%
Then his wife came forward, making moan, and smote her face, and cried: A barren old woman!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdccv{%
They said: Even so saith thy Lord. Lo! He is the Wise, the Knower.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdccvi{%
(Abraham) said: And (afterward) what is your errand, O ye sent (from Allah)?\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdccvii{%
They said: Lo! we are sent unto a guilty folk,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdccviii{%
That we may send upon them stones of clay,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdccix{%
Marked by thy Lord for (the destruction of) the wanton.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdccx{%
Then we brought forth such believers as were there.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdccxi{%
But We found there but one house of those surrendered (to Allah).\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdccxii{%
And We left behind therein a portent for those who fear a painful doom.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdccxiii{%
And in Moses (too, there is a portent) when We sent him unto Pharaoh with clear warrant,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdccxiv{%
But he withdrew (confiding) in his might, and said: A wizard or a madman.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdccxv{%
So We seized him and his hosts and flung them in the sea, for he was reprobate.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdccxvi{%
And in (the tribe of) A'ad (there is a portent) when we sent the fatal wind against them.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdccxvii{%
It spared naught that it reached, but made it (all) as dust.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdccxviii{%
And in (the tribe of) Thamud (there is a portent) when it was told them: Take your ease awhile.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdccxix{%
But they rebelled against their Lord's decree, and so the thunderbolt overtook them even while they gazed;\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdccxx{%
And they were unable to rise up, nor could they help themselves.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdccxxi{%
And the folk of Noah aforetime. Lo! they were licentious folk.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdccxxii{%
We have built the heaven with might, and We it is Who make the vast extent (thereof).\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdccxxiii{%
And the earth have We laid out, how gracious is the Spreader (thereof)!\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdccxxiv{%
And all things We have created by pairs, that haply ye may reflect.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdccxxv{%
Therefor flee unto Allah; lo! I am a plain warner unto you from him.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdccxxvi{%
And set not any other god along with Allah; lo! I am a plain warner unto you from Him.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdccxxvii{%
Even so there came no messenger unto those before them but they said: A wizard or a madman!\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdccxxviii{%
Have they handed down (the saying) as an heirloom one unto another? Nay, but they are froward folk.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmdccxxix{%
So withdraw from them (O Muhammad), for thou art in no wise blameworthy,\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmdccxxx{%
And warn, for warning profiteth believers.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxi{%
I created the jinn and humankind only that they might worship Me.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxii{%
I seek no livelihood from them, nor do I ask that they should feed Me.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxiii{%
Lo! Allah! He it is that giveth livelihood, the Lord of unbreakable might.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxiv{%
And lo! for those who (now) do wrong there is an evil day like unto the evil day (which came for) their likes (of old); so let them not ask Me to hasten on (that day).\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxv{%
And woe unto those who disbelieve, from (that) their day which they are promised.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxvi{%
\basmalahen By the Mount,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxvii{%
And a Scripture inscribed\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxviii{%
On fine parchment unrolled,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxix{%
And the House frequented,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdccxl{%
And the roof exalted,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccxli{%
And the sea kept filled,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdccxlii{%
Lo! the doom of thy Lord will surely come to pass;\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdccxliii{%
There is none that can ward it off.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccxliv{%
On the day when the heaven will heave with (awful) heaving,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccxlv{%
And the mountains move away with (awful) movement,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccxlvi{%
Then woe that day unto the deniers\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccxlvii{%
Who play in talk of grave matters;\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccxlviii{%
The day when they are thrust with a (disdainful) thrust, into the fire of hell\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccxlix{%
(And it is said unto them): This is the Fire which ye were wont to deny.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccl{%
Is this magic, or do ye not see?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccli{%
Endure the heat thereof, and whether ye are patient of it or impatient of it is all one for you. Ye are only being paid for what ye used to do.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcclii{%
Lo! those who kept their duty dwell in gardens and delight,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdccliii{%
Happy because of what their Lord hath given them, and (because) their Lord hath warded off from them the torment of hell-fire.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccliv{%
(And it is said unto them): Eat and drink in health (as a reward) for what ye used to do,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcclv{%
Reclining on ranged couches. And we wed them unto fair ones with wide, lovely eyes.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcclvi{%
And they who believe and whose seed follow them in faith, We cause their seed to join them (there), and We deprive them of nought of their (life's) work. Every man is a pledge for that which he hath earned.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcclvii{%
And We provide them with fruit and meat such as they desire.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcclviii{%
There they pass from hand to hand a cup wherein is neither vanity nor cause of sin.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcclix{%
And there go round, waiting on them menservants of their own, as they were hidden pearls.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcclx{%
And some of them draw near unto others, questioning,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcclxi{%
Saying: Lo! of old, when we were with our families, we were ever anxious;\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcclxii{%
But Allah hath been gracious unto us and hath preserved us from the torment of the breath of Fire.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcclxiii{%
Lo! we used to pray unto Him of old. Lo! He is the Benign, the Merciful.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcclxiv{%
Therefor warn (men, O Muhammad). By the grace of Allah thou art neither soothsayer nor madman.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcclxv{%
Or say they: (he is) a poet, (one) for whom we may expect the accident of time?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdcclxvi{%
Say (unto them): Except (your fill)! Lo! I am with you among the expectant.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdcclxvii{%
Do their minds command them to do this, or are they an outrageous folk?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdcclxviii{%
Or say they: He hath invented it? Nay, but they will not believe!\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdcclxix{%
Then let them produce speech the like thereof, if they are truthful.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdcclxx{%
Or were they created out of naught? Or are they the creators?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxi{%
Or did they create the heavens and the earth? Nay, but they are sure of nothing!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxii{%
Or do they own the treasures of thy Lord? Or have they been given charge (thereof)?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxiii{%
Or have they any stairway (unto heaven) by means of which they overhear (decrees). Then let their listener produce some warrant manifest!\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxiv{%
Or hath He daughters whereas ye have sons?\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxv{%
Or askest thou (Muhammad) a fee from them so that they are plunged in debt?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxvi{%
Or possess they the Unseen so that they can write (it) down?\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxvii{%
Or seek they to ensnare (the messenger)? But those who disbelieve, they are the ensnared!\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxviii{%
Or have they any god beside Allah? Glorified be Allah from all that they ascribe as partner (unto Him)!\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxix{%
And if they were to see a fragment of the heaven falling, they would say: A heap of clouds.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxx{%
Then let them be (O Muhammad), till they meet their day, in which they will be thunder-stricken,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxi{%
A day in which their guile will naught avail them, nor will they be helped.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxii{%
And verily, for those who do wrong, there is a punishment beyond that. But most of them know not.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxiii{%
So wait patiently (O Muhammad) for thy Lord's decree, for surely thou art in Our sight; and hymn the praise of thy Lord when thou uprisest,\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxiv{%
And in the night-time also hymn His praise, and at the setting of the stars.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxv{%
\basmalahen By the Star when it setteth,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxvi{%
Your comrade erreth not, nor is deceived;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxvii{%
Nor doth he speak of (his own) desire.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxviii{%
It is naught save an inspiration that is inspired,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxix{%
Which one of mighty powers hath taught him,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccxc{%
One vigorous; and he grew clear to view\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdccxci{%
When he was on the uppermost horizon.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdccxcii{%
Then he drew nigh and came down\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccxciii{%
Till he was (distant) two bows' length or even nearer,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccxciv{%
And He revealed unto His slave that which He revealed.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccxcv{%
The heart lied not (in seeing) what it saw.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccxcvi{%
Will ye then dispute with him concerning what he seeth?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccxcvii{%
And verily he saw him yet another time\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccxcviii{%
By the lote-tree of the utmost boundary,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccxcix{%
Nigh unto which is the Garden of Abode.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccc{%
When that which shroudeth did enshroud the lote-tree,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdccci{%
The eye turned not aside nor yet was overbold.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcccii{%
Verily he saw one of the greater revelations of his Lord.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccciii{%
Have ye thought upon Al-Lat and Al-'Uzza\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdccciv{%
And Manat, the third, the other?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcccv{%
Are yours the males and His the females?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcccvi{%
That indeed were an unfair division!\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcccvii{%
They are but names which ye have named, ye and your fathers, for which Allah hath revealed no warrant. They follow but a guess and that which (they) themselves desire. And now the guidance from their Lord hath come unto them.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcccviii{%
Or shall man have what he coveteth?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcccix{%
But unto Allah belongeth the after (life), and the former.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcccx{%
And how many angels are in the heavens whose intercession availeth naught save after Allah giveth leave to whom He chooseth and accepteth.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcccxi{%
Lo! it is those who disbelieve in the Hereafter who name the angels with the names of females.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcccxii{%
And they have no knowledge thereof. They follow but a guess, and lo! a guess can never take the place of the truth.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcccxiii{%
Then withdraw (O Muhammad) from him who fleeth from Our remembrance and desireth but the life of the world.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcccxiv{%
Such is their sum of knowledge. Lo! thy Lord is Best Aware of him who strayeth, and He is Best Aware of him whom goeth right.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdcccxv{%
And unto Allah belongeth whatsoever is in the heavens and whatsoever is in the earth, that He may reward those who do evil with that which they have done, and reward those who do good with goodness.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdcccxvi{%
Those who avoid enormities of sin and abominations, save the unwilled offences - (for them) lo! thy Lord is of vast mercy. He is Best Aware of you (from the time) when He created you from the earth, and when ye were hidden in the bellies of your mothers. Therefor ascribe not purity unto yourselves. He is Best Aware of him who wardeth off (evil).\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdcccxvii{%
Didst thou (O Muhammad) observe him who turned away,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdcccxviii{%
And gave a little, then was grudging?\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdcccxix{%
Hath he knowledge of the Unseen so that he seeth?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdcccxx{%
Or hath he not had news of what is in the books of Moses\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxi{%
And Abraham who paid his debt:\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxii{%
That no laden one shall bear another's load,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxiii{%
And that man hath only that for which he maketh effort,\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxiv{%
And that his effort will be seen.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxv{%
And afterward he will be repaid for it with fullest payment;\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxvi{%
And that thy Lord, He is the goal;\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxvii{%
And that He it is who maketh laugh, and maketh weep,\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxviii{%
And that He it is Who giveth death and giveth life;\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxix{%
And that He createth the two spouses, the male and the female,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxx{%
From a drop (of seed) when it is poured forth;\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxi{%
And that He hath ordained the second bringing forth;\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxii{%
And that He it is Who enricheth and contenteth;\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxiii{%
And that He it is Who is the Lord of Sirius;\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxiv{%
And that He destroyed the former (tribe of) A'ad,\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxv{%
And (the tribe of) Thamud He spared not;\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxvi{%
And the folk of Noah aforetime, Lo! they were more unjust and more rebellious;\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxvii{%
And Al-Mu'tafikah He destroyed\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxviii{%
So that there covered them that which did cover.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxix{%
Concerning which then, of the bounties of thy Lord, canst thou dispute?\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmdcccxl{%
This is a warner of the warners of old.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmdcccxli{%
The threatened Hour is nigh.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlii{%
None beside Allah can disclose it.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmdcccxliii{%
Marvel ye then at this statement,\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmdcccxliv{%
And laugh and not weep,\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlv{%
While ye amuse yourselves?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlvi{%
Rather prostrate yourselves before Allah and serve Him.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlvii{%
\basmalahen The hour drew nigh and the moon was rent in twain.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlviii{%
And if they behold a portent they turn away and say: Prolonged illusion.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlix{%
They denied (the Truth) and followed their own lusts. Yet everything will come to a decision\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcccl{%
And surely there hath come unto them news whereof the purport should deter,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcccli{%
Effective wisdom; but warnings avail not.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccclii{%
So withdraw from them (O Muhammad) on the day when the Summoner summoneth unto a painful thing.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcccliii{%
With downcast eyes, they come forth from the graves as they were locusts spread abroad,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcccliv{%
Hastening toward the summoner; the disbelievers say: This is a hard day.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccclv{%
The folk of Noah denied before them, yea, they denied Our slave and said: A madman; and he was repulsed.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccclvi{%
So he cried unto his Lord, saying: I am vanquished, so give help.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccclvii{%
Then opened We the gates of heaven with pouring water\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccclviii{%
And caused the earth to gush forth springs, so that the waters met for a predestined purpose.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccclix{%
And We carried him upon a thing of planks and nails,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccclx{%
That ran (upon the waters) in Our sight, as a reward for him who was rejected.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccclxi{%
And verily We left it as a token; but is there any that remembereth?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccclxii{%
Then see how (dreadful) was My punishment after My warnings!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdccclxiii{%
And in truth We have made the Qur'an easy to remember; but is there any that remembereth?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdccclxiv{%
(The tribe of) A'ad rejected warnings. Then how (dreadful) was My punishment after My warnings.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccclxv{%
Lo! We let loose on them a raging wind on a day of constant calamity,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdccclxvi{%
Sweeping men away as though they were uprooted trunks of palm-trees.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdccclxvii{%
Then see how (dreadful) was My punishment after My warnings!\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdccclxviii{%
And in truth We have made the Qur'an easy to remember; but is there any that remembereth?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdccclxix{%
(The tribe of) Thamud rejected warnings\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdccclxx{%
For they said; Is it a mortal man, alone among us, that we are to follow? Then indeed we should fall into error and madness.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxi{%
Hath the remembrance been given unto him alone among us? Nay, but he is a rash liar.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxii{%
(Unto their warner it was said): To-morrow they will know who is the rash liar.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxiii{%
Lo! We are sending the she-camel as a test for them; so watch them and have patience;\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxiv{%
And inform them that the water is to be shared between (her and) them. Every drinking will be witnessed.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxv{%
But they call their comrade and he took and hamstrung (her).\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxvi{%
Then see how (dreadful) was My punishment after My warnings!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxvii{%
Lo! We sent upon them one Shout, and they became as the dry twigs (rejected by) the builder of a cattle-fold.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxviii{%
And in truth We have made the Qur'an easy to remember; but is there any that remembereth?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxix{%
The folk of Lot rejected warnings.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxx{%
Lo! We sent a storm of stones upon them (all) save the family of Lot, whom We rescued in the last watch of the night,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxi{%
As grace from Us. Thus We reward him who giveth thanks.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxii{%
And he indeed had warned them of Our blow, but they did doubt the warnings.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxiii{%
They even asked of him his guests for an ill purpose. Then We blinded their eyes (and said): Taste now My punishment after My warnings!\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxiv{%
And in truth the punishment decreed befell them early in the morning.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxv{%
Now taste My punishment after My warnings!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxvi{%
And in truth We have made the Qur'an easy to remember; but is there any that remembereth?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxvii{%
And warnings came in truth unto the house of Pharaoh\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxviii{%
Who denied Our revelations, every one. Therefore We grasped them with the grasp of the Mighty, the Powerful.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxix{%
Are your disbelievers better than those, or have ye some immunity in the scriptures?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcccxc{%
Or say they: We are a host victorious?\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcccxci{%
The hosts will all be routed and will turn and flee.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcii{%
Nay, but the Hour (of doom) is their appointed tryst, and the Hour will be more wretched and more bitter (than their earthly failure).\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcccxciii{%
Lo! the guilty are in error and madness.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcccxciv{%
On the day when they are dragged into the Fire upon their faces (it is said unto them): Feel the touch of hell.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcv{%
Lo! We have created every thing by measure.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcvi{%
And Our commandment is but one (commandment), as the twinkling of an eye.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcvii{%
And verily We have destroyed your fellows; but is there any that remembereth?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcviii{%
And every thing they did is in the scriptures,\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcix{%
And every small and great thing is recorded.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcm{%
Lo! the righteous will dwell among gardens and rivers,\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcmi{%
Firmly established in the favour of a Mighty King.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcmii{%
\basmalahen The Beneficent\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcmiii{%
Hath made known the Qur'an.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcmiv{%
He hath created man.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcmv{%
He hath taught him utterance.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcmvi{%
The sun and the moon are made punctual.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcmvii{%
The stars and the trees prostrate.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcmviii{%
And the sky He hath uplifted; and He hath set the measure,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcmix{%
That ye exceed not the measure,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcmx{%
But observe the measure strictly, nor fall short thereof.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcmxi{%
And the earth hath He appointed for (His) creatures,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcmxii{%
Wherein are fruit and sheathed palm-trees,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcmxiii{%
Husked grain and scented herb.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcmxiv{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcmxv{%
He created man of clay like the potter's,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcmxvi{%
And the jinn did He create of smokeless fire.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcmxvii{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcmxviii{%
Lord of the two Easts, and Lord of the two Wests!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcmxix{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcmxx{%
He hath loosed the two seas. They meet.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcmxxi{%
There is a barrier between them. They encroach not (one upon the other).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcmxxii{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcmxxiii{%
There cometh forth from both of them the pearl and coral-stone.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcmxxiv{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcmxxv{%
His are the ships displayed upon the sea, like banners.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcmxxvi{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcmxxvii{%
Everyone that is thereon will pass away;\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmcmxxviii{%
There remaineth but the Countenance of thy Lord of Might and Glory.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcmxxix{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcmxxx{%
All that are in the heavens and the earth entreat Him. Every day He exerciseth (universal) power.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxi{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxii{%
We shall dispose of you, O ye two dependents (man and jinn).\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxiii{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxiv{%
O company of jinn and men, if ye have power to penetrate (all) regions of the heavens and the earth, then penetrate (them)! Ye will never penetrate them save with (Our) sanction.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxv{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxvi{%
There will be sent, against you both, heat of fire and flash of brass, and ye will not escape.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxvii{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxviii{%
And when the heaven splitteth asunder and becometh rosy like red hide -\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxix{%
Which is it, of the favours of your Lord, that ye deny? -\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcmxl{%
On that day neither man nor jinni will be questioned of his sin.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcmxli{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcmxlii{%
The guilty will be known by their marks, and will be taken by the forelocks and the feet.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcmxliii{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcmxliv{%
This is hell which the guilty deny.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcmxlv{%
They go circling round between it and fierce, boiling water.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcmxlvi{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcmxlvii{%
But for him who feareth the standing before his Lord there are two gardens.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcmxlviii{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcmxlix{%
Of spreading branches.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcml{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcmli{%
Wherein are two fountains flowing.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcmlii{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcmliii{%
Wherein is every kind of fruit in pairs.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcmliv{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcmlv{%
Reclining upon couches lined with silk brocade, the fruit of both the gardens near to hand.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcmlvi{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcmlvii{%
Therein are those of modest gaze, whom neither man nor jinni will have touched before them.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcmlviii{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcmlix{%
(In beauty) like the jacynth and the coral-stone.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcmlx{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcmlxi{%
Is the reward of goodness aught save goodness?\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcmlxii{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcmlxiii{%
And beside them are two other gardens,\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcmlxiv{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcmlxv{%
Dark green with foliage.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcmlxvi{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcmlxvii{%
Wherein are two abundant springs.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcmlxviii{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcmlxix{%
Wherein is fruit, the date-palm and pomegranate.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcmlxx{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxi{%
Wherein (are found) the good and beautiful -\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxii{%
Which is it, of the favours of your Lord, that ye deny? -\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxiii{%
Fair ones, close-guarded in pavilions -\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxiv{%
Which is it, of the favours of your Lord, that ye deny? -\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxv{%
Whom neither man nor jinni will have touched before them -\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxvi{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxvii{%
Reclining on green cushions and fair carpets.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxviii{%
Which is it, of the favours of your Lord, that ye deny?\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxix{%
Blessed be the name of thy Lord, Mighty and glorious!\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxx{%
\basmalahen When the event befalleth -\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxi{%
There is no denying that it will befall -\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxii{%
Abasing (some), exalting (others);\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxiii{%
When the earth is shaken with a shock\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxiv{%
And the hills are ground to powder\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxv{%
So that they become a scattered dust,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxvi{%
And ye will be three kinds:\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxvii{%
(First) those on the right hand; what of those on the right hand?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxviii{%
And (then) those on the left hand; what of those on the left hand?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxix{%
And the foremost in the race, the foremost in the race:\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcmxc{%
Those are they who will be brought nigh\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcmxci{%
In gardens of delight;\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcmxcii{%
A multitude of those of old\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcmxciii{%
And a few of those of later time.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcmxciv{%
On lined couches,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcmxcv{%
Reclining therein face to face.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcmxcvi{%
There wait on them immortal youths\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcmxcvii{%
With bowls and ewers and a cup from a pure spring\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcmxcviii{%
Wherefrom they get no aching of the head nor any madness,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcmxcix{%
And fruit that they prefer\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmm{%
And flesh of fowls that they desire.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmi{%
And (there are) fair ones with wide, lovely eyes,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmii{%
Like unto hidden pearls,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmiii{%
Reward for what they used to do.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmiv{%
There hear they no vain speaking nor recrimination\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmv{%
(Naught) but the saying: Peace, (and again) Peace.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmvi{%
And those on the right hand; what of those on the right hand?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmvii{%
Among thornless lote-trees\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmviii{%
And clustered plantains,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmix{%
And spreading shade,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmx{%
And water gushing,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmxi{%
And fruit in plenty\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmxii{%
Neither out of reach nor yet forbidden,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmxiii{%
And raised couches;\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmxiv{%
Lo! We have created them a (new) creation\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmxv{%
And made them virgins,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmxvi{%
Lovers, friends,\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmxvii{%
For those on the right hand;\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmxviii{%
A multitude of those of old\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmxix{%
And a multitude of those of later time.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmxx{%
And those on the left hand: What of those on the left hand?\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmxxi{%
In scorching wind and scalding water\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmxxii{%
And shadow of black smoke,\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmxxiii{%
Neither cool nor refreshing.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmxxiv{%
Lo! heretofore they were effete with luxury\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmxxv{%
And used to persist in the awful sin.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmxxvi{%
And they used to say: When we are dead and have become dust and bones, shall we then, forsooth, be raised again,\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmxxvii{%
And also our forefathers?\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmxxviii{%
Say (unto them, O Muhammad): Lo! those of old and those of later time\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmxxix{%
Will all be brought together to the tryst of an appointed day.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmxxx{%
Then lo! ye, the erring, the deniers,\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmxxxi{%
Ye verily will eat of a tree called Zaqqum\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmxxxii{%
And will fill your bellies therewith;\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmmxxxiii{%
And thereon ye will drink of boiling water,\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmmxxxiv{%
Drinking even as the camel drinketh.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmmxxxv{%
This will be their welcome on the Day of Judgment.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmmxxxvi{%
We created you. Will ye then admit the truth?\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmmxxxvii{%
Have ye seen that which ye emit?\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmmxxxviii{%
Do ye create it or are We the Creator?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmmxxxix{%
We mete out death among you, and We are not to be outrun,\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmmxl{%
That We may transfigure you and make you what ye know not.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmmxli{%
And verily ye know the first creation. Why, then, do ye not reflect?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmmxlii{%
Have ye seen that which ye cultivate?\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmmxliii{%
Is it ye who foster it, or are We the Fosterer?\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmmxliv{%
If We willed, We verily could make it chaff, then would ye cease not to exclaim:\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmmxlv{%
Lo! we are laden with debt!\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmmxlvi{%
Nay, but we are deprived!\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmmxlvii{%
Have ye observed the water which ye drink?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmmxlviii{%
Is it ye who shed it from the raincloud, or are We the Shedder?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmmxlix{%
If We willed We verily could make it bitter. Why then, give ye not thanks?\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmml{%
Have ye observed the fire which ye strike out;\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmmli{%
Was it ye who made the tree thereof to grow, or were We the grower?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmmlii{%
We, even We, appointed it a memorial and a comfort for the dwellers in the wilderness.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmmliii{%
Therefor (O Muhammad), praise the name of thy Lord, the Tremendous.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmmliv{%
Nay, I swear by the places of the stars -\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmmlv{%
And lo! that verily is a tremendous oath, if ye but knew -\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmmlvi{%
That (this) is indeed a noble Qur'an\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmmlvii{%
In a Book kept hidden\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmmlviii{%
Which none toucheth save the purified,\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmmlix{%
A revelation from the Lord of the Worlds.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmmlx{%
Is it this Statement that ye scorn,\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmmlxi{%
And make denial thereof your livelihood?\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmmlxii{%
Why, then, when (the soul) cometh up to the throat (of the dying)\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmmlxiii{%
And ye are at that moment looking\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmmlxiv{%
- And We are nearer unto him than ye are, but ye see not -\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmmlxv{%
Why then, if ye are not in bondage (unto Us),\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmmlxvi{%
Do ye not force it back, if ye are truthful?\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmmlxvii{%
Thus if he is of those brought nigh,\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmmlxviii{%
Then breath of life, and plenty, and a Garden of delight.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmmmlxix{%
And if he is of those on the right hand,\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmmmlxx{%
Then (the greeting) ``Peace be unto thee" from those on the right hand.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmmmlxxi{%
But if he is of the rejecters, the erring,\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmmmlxxii{%
Then the welcome will be boiling water\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmmmlxxiii{%
And roasting at hell-fire.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmmmlxxiv{%
Lo! this is certain truth.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmmmlxxv{%
Therefor (O Muhammad) praise the name of thy Lord, the Tremendous.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmmmlxxvi{%
\basmalahen All that is in the heavens and the earth glorifieth Allah; and He is the Mighty, the Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmlxxvii{%
His is the Sovereignty of the heavens and the earth; He quickeneth and He giveth death; and He is Able to do all things.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmlxxviii{%
He is the First and the Last, and the Outward and the Inward; and He is Knower of all things.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmlxxix{%
He it is Who created the heavens and the earth in six Days; then He mounted the Throne. He knoweth all that entereth the earth and all that emergeth therefrom and all that cometh down from the sky and all that ascendeth therein; and He is with you wheresoever ye may be. And Allah is Seer of what ye do.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmlxxx{%
His is the Sovereignty of the heavens and the earth, and unto Allah (all) things are brought back.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxi{%
He causeth the night to pass into the day, and He causeth the day to pass into the night, and He is knower of all that is in the breasts.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxii{%
Believe in Allah and His messenger, and spend of that whereof He hath made you trustees; and such of you as believe and spend (aright), theirs will be a great reward.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxiii{%
What aileth you that ye believe not in Allah, when the messenger calleth you to believe in your Lord, and He hath already made a covenant with you, if ye are believers?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxiv{%
He it is Who sendeth down clear revelations unto His slave, that He may bring you forth from darkness unto light; and lo! for you, Allah is Full of Pity, Merciful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxv{%
And what aileth you that ye spend not in the way of Allah when unto Allah belongeth the inheritance of the heavens and the earth? Those who spent and fought before the victory are not upon a level (with the rest of you). Such are greater in rank than those who spent and fought afterwards. Unto each hath Allah promised good. And Allah is Informed of what ye do.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxvi{%
Who is he that will lend unto Allah a goodly loan, that He may double it for him and his may be a rich reward?\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxvii{%
On the day when thou (Muhammad) wilt see the believers, men and women, their light shining forth before them and on their right hands, (and wilt hear it said unto them): Glad news for you this day: Gardens underneath which rivers flow, wherein ye are immortal. That is the supreme triumph.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxviii{%
On the day when the hypocritical men and the hypocritical women will say unto those who believe: Look on us that we may borrow from your light! it will be said: Go back and seek for light! Then there will separate them a wall wherein is a gate, the inner side whereof containeth mercy, while the outer side thereof is toward the doom.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxix{%
They will cry unto them (saying): Were we not with you? They will say: Yea, verily; but ye tempted one another, and hesitated, and doubted, and vain desires beguiled you till the ordinance of Allah came to pass; and the deceiver deceived you concerning Allah;\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmxc{%
So this day no ransom can be taken from you nor from those who disbelieved. Your home is the Fire; that is your patron, and a hapless journey's end.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmxci{%
Is not the time ripe for the hearts of those who believe to submit to Allah's reminder and to the truth which is revealed, that they become not as those who received the scripture of old but the term was prolonged for them and so their hearts were hardened, and many of them are evil-livers.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmxcii{%
Know that Allah quickeneth the earth after its death. We have made clear Our revelations for you, that haply ye may understand.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmxciii{%
Lo! those who give alms, both men and women, and lend unto Allah a goodly loan, it will be doubled for them, and theirs will be a rich reward.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmxciv{%
And those who believe in Allah and His messengers, they are the loyal, and the martyrs are with their Lord; they have their reward and their light; while as for those who disbelieve and deny Our revelations, they are owners of hell-fire.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmxcv{%
Know that the life of the world is only play, and idle talk, and pageantry, and boasting among you, and rivalry in respect of wealth and children; as the likeness of vegetation after rain, whereof the growth is pleasing to the husbandman, but afterward it drieth up and thou seest it turning yellow, then it becometh straw. And in the Hereafter there is grievous punishment, and (also) forgiveness from Allah and His good pleasure, whereas the life of the world is but matter of illusion.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmxcvi{%
Race one with another for forgiveness from your Lord and a Garden whereof the breadth is as the breadth of the heavens and the earth, which is in store for those who believe in Allah and His messengers. Such is the bounty of Allah, which He bestoweth upon whom He will, and Allah is of Infinite Bounty.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmxcvii{%
Naught of disaster befalleth in the earth or in yourselves but it is in a Book before we bring it into being - Lo! that is easy for Allah -\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmxcviii{%
That ye grieve not for the sake of that which hath escaped you, nor yet exult because of that which hath been given. Allah loveth not all prideful boasters,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmxcix{%
Who hoard and who enjoin upon the people avarice. And whosoever turneth away, still Allah is the Absolute, the Owner of Praise.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmc{%
We verily sent Our messengers with clear proofs, and revealed with them the Scripture and the Balance, that mankind may observe right measure; and He revealed iron, wherein is mighty power and (many) uses for mankind, and that Allah may know him who helpeth Him and His messengers, though unseen. Lo! Allah is Strong, Almighty.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmci{%
And We verily sent Noah and Abraham and placed the prophethood and the scripture among their seed, and among them there is he who goeth right, but many of them are evil-livers.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcii{%
Then We caused Our messengers to follow in their footsteps; and We caused Jesus, son of Mary, to follow, and gave him the Gospel, and placed compassion and mercy in the hearts of those who followed him. But monasticism they invented - We ordained it not for them - only seeking Allah's pleasure, and they observed it not with right observance. So We give those of them who believe their reward, but many of them are evil-livers.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmciii{%
O ye who believe! Be mindful of your duty to Allah and put faith in His messenger. He will give you twofold of His mercy and will appoint for you a light wherein ye shall walk, and will forgive you. Allah is Forgiving, Merciful;\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmciv{%
That the People of the Scripture may know that they control naught of the bounty of Allah, but that the bounty is in Allah's hand to give to whom He will. And Allah is of Infinite Bounty.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcv{%
\basmalahen Allah hath heard the saying of her that disputeth with thee (Muhammad) concerning her husband, and complaineth unto Allah. And Allah heareth your colloquy. Lo! Allah is Hearer, Knower.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcvi{%
Such of you as put away your wives (by saying they are as their mothers) - They are not their mothers; none are their mothers except those who gave them birth - they indeed utter an ill word and a lie. And lo! Allah is Forgiving, Merciful.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcvii{%
Those who put away their wives (by saying they are as their mothers) and afterward would go back on that which they have said, (the penalty) in that case (is) the freeing of a slave before they touch one another. Unto this ye are exhorted; and Allah is Informed of what ye do.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcviii{%
And he who findeth not (the wherewithal), let him fast for two successive months before they touch one another; and for him who is unable to do so (the penance is) the feeding of sixty needy ones. This, that ye may put trust in Allah and His messenger. Such are the limits (imposed by Allah); and for disbelievers is a painful doom.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcix{%
Lo! those who oppose Allah and His messenger will be abased even as those before them were abased; and We have sent down clear tokens, and for disbelievers is a shameful doom\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcx{%
On the day when Allah will raise them all together and inform them of what they did. Allah hath kept account of it while they forgot it. And Allah is Witness over all things.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxi{%
Hast thou not seen that Allah knoweth all that is in the heavens and all that is in the earth? There is no secret conference of three but He is their fourth, nor of five but He is their sixth, nor of less than that or more but He is with them wheresoever they may be; and afterward, on the Day of Resurrection, He will inform them of what they did. Lo! Allah is Knower of all things.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxii{%
Hast thou not observed those who were forbidden conspiracy and afterward returned to that which they had been forbidden, and (now) conspire together for crime and wrongdoing and disobedience toward the messenger? And when they come unto thee they greet thee with a greeting wherewith Allah greeteth thee not, and say within themselves: Why should Allah punish us for what we say? Hell will suffice them; they will feel the heat thereof - a hapless journey's end!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxiii{%
O ye who believe! When ye conspire together, conspire not together for crime and wrongdoing and disobedience toward the messenger, but conspire together for righteousness and piety, and keep your duty toward Allah, unto whom ye will be gathered.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxiv{%
Lo! Conspiracy is only of the devil, that he may vex those who believe; but he can harm them not at all unless by Allah's leave. In Allah let believers put their trust.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxv{%
O ye who believe! when it is said unto you, Make room! in assemblies, then make room; Allah will make way for you (hereafter). And when it is said, Come up higher! go up higher; Allah will exalt those who believe among you, and those who have knowledge, to high ranks. Allah is Informed of what ye do.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcxvi{%
O ye who believe! When ye hold conference with the messenger, offer an alms before your conference. That is better and purer for you. But if ye cannot find (the wherewithal) then lo! Allah is Forgiving, Merciful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcxvii{%
Fear ye to offer alms before your conference? Then, when ye do it not and Allah hath forgiven you, establish worship and pay the poor-due and obey Allah and His messenger. And Allah is Aware of what ye do.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcxviii{%
Hast thou not seen those who take for friends a folk with whom Allah is wroth? They are neither of you nor of them, and they swear a false oath knowingly.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcxix{%
Allah hath prepared for them a dreadful doom. Evil indeed is that which they are wont to do.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcxx{%
They make a shelter of their oaths and turn (men) from the way of Allah; so theirs will be a shameful doom.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcxxi{%
Their wealth and their children will avail them naught against Allah. Such are rightful owners of the Fire; they will abide therein.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcxxii{%
On the day when Allah will raise them all together, then will they swear unto Him as they (now) swear unto you, and they will fancy that they have some standing. Lo! is it not they who are the liars?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcxxiii{%
The devil hath engrossed them and so hath caused them to forget remembrance of Allah. They are the devil's party. Lo! is it not the devil's party who will be the losers?\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcxxiv{%
Lo! those who oppose Allah and His messenger, they will be among the lowest.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcxxv{%
Allah hath decreed: Lo! I verily shall conquer, I and My messengers. Lo! Allah is Strong, Almighty.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcxxvi{%
Thou wilt not find folk who believe in Allah and the Last Day loving those who oppose Allah and His messenger, even though they be their fathers or their sons or their brethren or their clan. As for such, He hath written faith upon their hearts and hath strengthened them with a Spirit from Him, and He will bring them into Gardens underneath which rivers flow, wherein they will abide. Allah is well pleased with them, and they are well pleased with Him. They are Allah's party. Lo! is it not Allah's party who are the successful?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcxxvii{%
\basmalahen All that is in the heavens and all that is in the earth glorifieth Allah, and He is the Mighty, the Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcxxviii{%
He it is Who hath caused those of the People of the Scripture who disbelieved to go forth from their homes unto the first exile. Ye deemed not that they would go forth, while they deemed that their strongholds would protect them from Allah. But Allah reached them from a place whereof they recked not, and cast terror in their hearts so that they ruined their houses with their own hands and the hands of the believers. So learn a lesson, O ye who have eyes!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcxxix{%
And if Allah had not decreed migration for them, He verily would have punished them in the world, and theirs in the Hereafter is the punishment of the Fire.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcxxx{%
That is because they were opposed to Allah and His messenger; and whoso is opposed to Allah, (for him) verily Allah is stern in reprisal.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxi{%
Whatsoever palm-trees ye cut down or left standing on their roots, it was by Allah's leave, in order that He might confound the evil-livers.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxii{%
And that which Allah gave as spoil unto His messenger from them, ye urged not any horse or riding-camel for the sake thereof, but Allah giveth His messenger lordship over whom He will. Allah is Able to do all things.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxiii{%
That which Allah giveth as spoil unto His messenger from the people of the townships, it is for Allah and His messenger and for the near of kin and the orphans and the needy and the wayfarer, that it become not a commodity between the rich among you. And whatsoever the messenger giveth you, take it. And whatsoever he forbiddeth, abstain (from it). And keep your duty to Allah. Lo! Allah is stern in reprisal.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxiv{%
And (it is) for the poor fugitives who have been driven out from their homes and their belongings, who seek bounty from Allah and help Allah and His messenger. They are the loyal.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxv{%
Those who entered the city and the faith before them love those who flee unto them for refuge, and find in their breasts no need for that which hath been given them, but prefer (the fugitives) above themselves though poverty become their lot. And whoso is saved from his own avarice - such are they who are successful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxvi{%
And those who came (into the faith) after them say: Our Lord! Forgive us and our brethren who were before us in the faith, and place not in our hearts any rancour toward those who believe. Our Lord! Thou art Full of Pity, Merciful.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxvii{%
Hast thou not observed those who are hypocrites, (how) they tell their brethren who disbelieve among the People of the Scripture: If ye are driven out, we surely will go out with you, and we will never obey anyone against you, and if ye are attacked we verily will help you. And Allah beareth witness that they verily are liars.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxviii{%
(For) indeed if they are driven out they go not out with them, and indeed if they are attacked they help them not, and indeed if they had helped them they would have turned and fled, and then they would not have been victorious.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxix{%
Ye are more awful as a fear in their bosoms than Allah. That is because they are a folk who understand not.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcxl{%
They will not fight against you in a body save in fortified villages or from behind walls. Their adversity among themselves is very great. Ye think of them as a whole whereas their hearts are divers. That is because they are a folk who have no sense.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcxli{%
On the likeness of those (who suffered) a short time before them, they taste the ill-effects of their own conduct, and theirs is painful punishment.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcxlii{%
(And the hypocrites are) on the likeness of the devil when he telleth man to disbelieve, then, when he disbelieveth saith: Lo! I am quit of thee. Lo! I fear Allah, the Lord of the Worlds.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcxliii{%
And the consequence for both will be that they are in the Fire, therein abiding. Such is the reward of evil-doers.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcxliv{%
O ye who believe! Observe your duty to Allah. And let every soul look to that which it sendeth on before for the morrow. And observe your duty to Allah. Lo! Allah is Informed of what ye do.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcxlv{%
And be not ye as those who forgot Allah, therefor He caused them to forget their souls. Such are the evil-doers.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcxlvi{%
Not equal are the owners of the Fire and the owners of the Garden. The owners of the Garden, they are the victorious.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcxlvii{%
If We had caused this Qur'an to descend upon a mountain, thou (O Muhammad) verily hadst seen it humbled, rent asunder by the fear of Allah. Such similitudes coin We for mankind that haply they may reflect.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcxlviii{%
He is Allah, than Whom there is no other Allah, the Knower of the Invisible and the Visible. He is the Beneficent, Merciful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcxlix{%
He is Allah, than Whom there is no other Allah, the Sovereign Lord, the Holy One, Peace, the Keeper of Faith, the Guardian, the Majestic, the Compeller, the Superb. Glorified be Allah from all that they ascribe as partner (unto Him).\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcl{%
He is Allah, the Creator, the Shaper out of naught, the Fashioner. His are the most beautiful names. All that is in the heavens and the earth glorifieth Him, and He is the Mighty, the Wise.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcli{%
\basmalahen O ye who believe! Choose not My enemy and your enemy for allies. Do ye give them friendship when they disbelieve in that truth which hath come unto you, driving out the messenger and you because ye believe in Allah, your Lord? If ye have come forth to strive in My way and seeking My good pleasure, (show them not friendship). Do ye show friendship unto them in secret, when I am Best Aware of what ye hide and what ye proclaim? And whosoever doeth it among you, he verily hath strayed from the right way.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclii{%
If they have the upper hand of you, they will be your foes, and will stretch out their hands and their tongues toward you with evil (intent), and they long for you to disbelieve.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcliii{%
Your ties of kindred and your children will avail you naught upon the Day of Resurrection. He will part you. Allah is Seer of what ye do.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcliv{%
There is a goodly pattern for you in Abraham and those with him, when they told their folk: Lo! we are guiltless of you and all that ye worship beside Allah. We have done with you. And there hath arisen between us and you hostility and hate for ever until ye believe in Allah only - save that which Abraham promised his father (when he said): I will ask forgiveness for thee, though I own nothing for thee from Allah - Our Lord! In Thee we put our trust, and unto Thee we turn repentant, and unto Thee is the journeying.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclv{%
Our Lord! Make us not a prey for those who disbelieve, and forgive us, our Lord! Lo! Thou, only Thou, are the Mighty, the Wise.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclvi{%
Verily ye have in them a goodly pattern for everyone who looketh to Allah and the Last Day. And whosoever may turn away, lo! still Allah, He is the Absolute, the Owner of Praise.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclvii{%
It may be that Allah will ordain love between you and those of them with whom ye are at enmity. Allah is Mighty, and Allah is Forgiving, Merciful.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclviii{%
Allah forbiddeth you not those who warred not against you on account of religion and drove you not out from your homes, that ye should show them kindness and deal justly with them. Lo! Allah loveth the just dealers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclix{%
Allah forbiddeth you only those who warred against you on account of religion and have driven you out from your homes and helped to drive you out, that ye make friends of them. Whosoever maketh friends of them - (All) such are wrong-doers.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclx{%
O ye who believe! When believing women come unto you as fugitives, examine them. Allah is Best Aware of their faith. Then, if ye know them for true believers, send them not back unto the disbelievers. They are not lawful for them (the disbelievers), nor are they (the disbelievers) lawful for them. And give them (the disbelievers) that which they have spent (upon them). And it is no sin for you to marry such women when ye have given them their dues. And hold not to the ties of disbelieving women; and ask for (the return of) that which ye have spent; and let them (the disbelievers) ask for that which they have spent. That is the judgment of Allah. He judgeth between you. Allah is Knower, Wise.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxi{%
And if any of your wives have gone from you unto the disbelievers and afterward ye have your turn (of triumph), then give unto those whose wives have gone the like of that which they have spent, and keep your duty to Allah in Whom ye are believers.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxii{%
O Prophet! If believing women come unto thee, taking oath of allegiance unto thee that they will ascribe no thing as partner unto Allah, and will neither steal nor commit adultery nor kill their children, nor produce any lie that they have devised between their hands and feet, nor disobey thee in what is right, then accept their allegiance and ask Allah to forgive them. Lo! Allah is Forgiving, Merciful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmclxiii{%
O ye who believe! Be not friendly with a folk with whom Allah is wroth, (a folk) who have despaired of the Hereafter as the disbelievers despair of those who are in the graves.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmclxiv{%
\basmalahen All that is in the heavens and all that is in the earth glorifieth Allah, and He is the Mighty, the Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclxv{%
O ye who believe! Why say ye that which ye do not?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmclxvi{%
It is most hateful in the sight of Allah that ye say that which ye do not.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmclxvii{%
Lo! Allah loveth them who battle for His cause in ranks, as if they were a solid structure.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclxviii{%
And (remember) when Moses said unto his people: O my people! Why persecute ye me, when ye well know that I am Allah's messenger unto you? So when they went astray Allah sent their hearts astray. And Allah guideth not the evil-living folk.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclxix{%
And when Jesus son of Mary said: O Children of Israel! Lo! I am the messenger of Allah unto you, confirming that which was (revealed) before me in the Torah, and bringing good tidings of a messenger who cometh after me, whose name is the Praised One. Yet when he hath come unto them with clear proofs, they say: This is mere magic.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclxx{%
And who doeth greater wrong than he who inventeth a lie against Allah when he is summoned unto Al-Islam? And Allah guideth not wrongdoing folk.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclxxi{%
Fain would they put out the light of Allah with their mouths, but Allah will perfect His light however much the disbelievers are averse.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclxxii{%
He it is Who hath sent His messenger with the guidance and the religion of truth, that He may make it conqueror of all religion however much idolaters may be averse.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclxxiii{%
O ye who believe! Shall I show you a commerce that will save you from a painful doom?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxxiv{%
Ye should believe in Allah and His messenger, and should strive for the cause of Allah with your wealth and your lives. That is better for you, if ye did but know.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxxv{%
He will forgive you your sins and bring you into Gardens underneath which rivers flow, and pleasant dwellings in Gardens of Eden. That is the supreme triumph.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmclxxvi{%
And (He will give you) another (blessing) which ye love: help from Allah and present victory. Give good tidings (O Muhammad) to believers.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmclxxvii{%
O ye who believe! Be Allah's helpers, even as Jesus son of Mary said unto the disciples: Who are my helpers for Allah? They said: We are Allah's helpers. And a party of the Children of Israel believed, while a party disbelieved. Then We strengthened those who believed against their foe, and they became the uppermost.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmclxxviii{%
\basmalahen All that is in the heavens and all that is in the earth glorifieth Allah, the Sovereign Lord, the Holy One, the Mighty, the Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclxxix{%
He it is Who hath sent among the unlettered ones a messenger of their own, to recite unto them His revelations and to make them grow, and to teach them the Scripture and wisdom, though heretofore they were indeed in error manifest,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmclxxx{%
Along with others of them who have not yet joined them. He is the Mighty, the Wise.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxi{%
That is the bounty of Allah; which He giveth unto whom He will. Allah is of Infinite Bounty.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxii{%
The likeness of those who are entrusted with the Law of Moses, yet apply it not, is as the likeness of the ass carrying books. Wretched is the likeness of folk who deny the revelations of Allah. And Allah guideth not wrongdoing folk.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxiii{%
Say (O Muhammad): O ye who are Jews! If ye claim that ye are favoured of Allah apart from (all) mankind, then long for death if ye are truthful.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxiv{%
But they will never long for it because of all that their own hands have sent before, and Allah is Aware of evil-doers.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxv{%
Say (unto them, O Muhammad): Lo! the death from which ye shrink will surely meet you, and afterward ye will be returned unto the Knower of the Invisible and the Visible, and He will tell you what ye used to do.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxvi{%
O ye who believe! When the call is heard for the prayer of the day of congregation, haste unto remembrance of Allah and leave your trading. That is better for you if ye did but know.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxvii{%
And when the prayer is ended, then disperse in the land and seek of Allah's bounty, and remember Allah much, that ye may be successful.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxviii{%
But when they spy some merchandise or pastime they break away to it and leave thee standing. Say: That which Allah hath is better than pastime and than merchandise, and Allah is the Best of providers.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxix{%
\basmalahen When the hypocrites come unto thee (O Muhammad), they say: We bear witness that thou art indeed Allah's messenger. And Allah knoweth that thou art indeed His messenger, and Allah beareth witness that the hypocrites indeed are speaking falsely.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcxc{%
They make their faith a pretext so that they may turn (men) from the way of Allah. Verily evil is that which they are wont to do,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcxci{%
That is because they believed, then disbelieved, therefore their hearts are sealed so that they understand not.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcxcii{%
And when thou seest them their figures please thee; and if they speak thou givest ear unto their speech. (They are) as though they were blocks of wood in striped cloaks. They deem every shout to be against them. They are the enemy, so beware of them. Allah confound them! How they are perverted!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcxciii{%
And when it is said unto them: Come! The messenger of Allah will ask forgiveness for you! they avert their faces and thou seest them turning away, disdainful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcxciv{%
Whether thou ask forgiveness for them or ask not forgiveness for them is all one for them; Allah will not forgive them. Lo! Allah guideth not the evil-living folk.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxcv{%
They it is who say: Spend not on behalf of those (who dwell) with Allah's messenger that they may disperse (and go away from you); when Allah's are the treasures of the heavens and the earth; but the hypocrites comprehend not.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxcvi{%
They say: Surely, if we return to Al-Madinah the mightier will soon drive out the weaker; when might belongeth to Allah and to His messenger and to the believers; but the hypocrites know not.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxcvii{%
O ye who believe! Let not your wealth nor your children distract you from remembrance of Allah. Those who do so, they are the losers.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxcviii{%
And spend of that wherewith We have provided you before death cometh unto one of you and he saith: My Lord! If only thou wouldst reprieve me for a little while, then I would give alms and be among the righteous.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxcix{%
But Allah reprieveth no soul when its term cometh, and Allah is Informed of what ye do.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcc{%
\basmalahen All that is in the heavens and all that is in the earth glorifieth Allah; unto Him belongeth Sovereignty and unto Him belongeth praise, and He is Able to do all things.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcci{%
He it is Who created you, but one of you is a disbeliever and one of you is a believer, and Allah is Seer of what ye do.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccii{%
He created the heavens and the earth with truth, and He shaped you and made good your shapes, and unto Him is the journeying.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcciii{%
He knoweth all that is in the heavens and the earth, and He knoweth what ye conceal and what ye publish. And Allah is Aware of what is in the breasts (of men).\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcciv{%
Hath not the story reached you of those who disbelieved of old and so did taste the ill-effects of their conduct, and theirs will be a painful doom.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccv{%
That was because their messengers (from Allah) kept coming unto them with clear proofs (of Allah's Sovereignty), but they said: Shall mere mortals guide us? So they disbelieved and turned away, and Allah was independent (of them). Allah is Absolute, Owner of Praise.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccvi{%
Those who disbelieve assert that they will not be raised again. Say (unto them, O Muhammad): Yea, verily, by my Lord! ye will be raised again and then ye will be informed of what ye did; and that is easy for Allah.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccvii{%
So believe in Allah and His messenger and the light which We have revealed. And Allah is Informed of what ye do.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccviii{%
The day when He shall gather you unto the Day of Assembling, that will be a day of mutual disillusion. And whoso believeth in Allah and doeth right, He will remit from him his evil deeds and will bring him unto Gardens underneath which rivers flow, therein to abide for ever. That is the supreme triumph.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccix{%
But those who disbelieve and deny Our revelations, such are owners of the Fire; they will abide therein - a hapless journey's end!\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccx{%
No calamity befalleth save by Allah's leave. And whosoever believeth in Allah, He guideth his heart. And Allah is Knower of all things.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxi{%
Obey Allah and obey His messenger; but if ye turn away, then the duty of Our messenger is only to convey (the message) plainly.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxii{%
Allah! There is no Allah save Him. In Allah, therefore, let believers put their trust.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmccxiii{%
O ye who believe! Lo! among your wives and your children there are enemies for you, therefor beware of them. And if ye efface and overlook and forgive, then lo! Allah is Forgiving, Merciful.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmccxiv{%
Your wealth and your children are only a temptation, whereas Allah! with Him is an immense reward.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmccxv{%
So keep your duty to Allah as best ye can, and listen, and obey, and spend; that is better for your souls. And whoso is saved from his own greed, such are the successful.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmccxvi{%
If ye lend unto Allah a goodly loan, He will double it for you and will forgive you, for Allah is Responsive, Clement,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmccxvii{%
Knower of the Invisible and the Visible, the Mighty, the Wise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmccxviii{%
\basmalahen O Prophet! When ye (men) put away women, put them away for their (legal) period and reckon the period, and keep your duty to Allah, your Lord. Expel them not from their houses nor let them go forth unless they commit open immorality. Such are the limits (imposed by) Allah; and whoso transgresseth Allah's limits, he verily wrongeth his soul. Thou knowest not: it may be that Allah will afterward bring some new thing to pass.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxix{%
Then, when they have reached their term, take them back in kindness or part from them in kindness, and call to witness two just men among you, and keep your testimony upright for Allah. Whoso believeth in Allah and the Last Day is exhorted to act thus. And whosoever keepeth his duty to Allah, Allah will appoint a way out for him,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxx{%
And will provide for him from (a quarter) whence he hath no expectation. And whosoever putteth his trust in Allah, He will suffice him. Lo! Allah bringeth His command to pass. Allah hath set a measure for all things.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxxi{%
And for such of your women as despair of menstruation, if ye doubt, their period (of waiting) shall be three months, along with those who have it not. And for those with child, their period shall be till they bring forth their burden. And whosoever keepeth his duty to Allah, He maketh his course easy for him.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxxii{%
That is the commandment of Allah which He revealeth unto you. And whoso keepeth his duty to Allah, He will remit from him his evil deeds and magnify reward for him.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxxiii{%
Lodge them where ye dwell, according to your wealth, and harass them not so as to straiten life for them. And if they are with child, then spend for them till they bring forth their burden. Then, if they give suck for you, give them their due payment and consult together in kindness; but if ye make difficulties for one another, then let some other woman give suck for him (the father of the child).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxxiv{%
Let him who hath abundance spend of his abundance, and he whose provision is measured, let him spend of that which Allah hath given him. Allah asketh naught of any soul save that which He hath given it. Allah will vouchsafe, after hardship, ease.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxxv{%
And how many a community revolted against the ordinance of its Lord and His messengers, and We called it to a stern account and punished it with dire punishment,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccxxvi{%
So that it tasted the ill-effects of its conduct, and the consequence of its conduct was loss.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccxxvii{%
Allah hath prepared for them stern punishment; so keep your duty to Allah, O men of understanding! O ye who believe! Now Allah hath sent down unto you a reminder,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccxxviii{%
A messenger reciting unto you the revelations of Allah made plain, that He may bring forth those who believe and do good works from darkness unto light. And whosoever believeth in Allah and doeth right, He will bring him into Gardens underneath which rivers flow, therein to abide for ever. Allah hath made good provision for him.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxxix{%
Allah it is who hath created seven heavens, and of the earth the like thereof. The commandment cometh down among them slowly, that ye may know that Allah is Able to do all things, and that Allah surroundeth all things in knowledge.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxxx{%
\basmalahen O Prophet! Why bannest thou that which Allah hath made lawful for thee, seeking to please thy wives? And Allah is Forgiving, Merciful.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxi{%
Allah hath made lawful for you (Muslims) absolution from your oaths (of such a kind), and Allah is your Protector. He is the Knower, the Wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxii{%
When the Prophet confided a fact unto one of his wives and when she afterward divulged it and Allah apprised him thereof, he made known (to her) part thereof and passed over part. And when he told it her she said: Who hath told thee? He said: The Knower, the Aware hath told me.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxiii{%
If ye twain turn unto Allah repentant, (ye have cause to do so) for your hearts desired (the ban); and if ye aid one another against him (Muhammad) then lo! Allah, even He, is his Protecting Friend, and Gabriel and the righteous among the believers; and furthermore the angels are his helpers.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxiv{%
It may happen that his Lord, if he divorce you, will give him in your stead wives better than you, submissive (to Allah), believing, pious, penitent, devout, inclined to fasting, widows and maids.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxv{%
O ye who believe! Ward off from yourselves and your families a Fire whereof the fuel is men and stones, over which are set angels strong, severe, who resist not Allah in that which He commandeth them, but do that which they are commanded.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxvi{%
(Then it will be said): O ye who disbelieve! Make no excuses for yourselves this day. Ye are only being paid for what ye used to do.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxvii{%
O ye who believe! Turn unto Allah in sincere repentance! It may be that your Lord will remit from you your evil deeds and bring you into Gardens underneath which rivers flow, on the day when Allah will not abase the Prophet and those who believe with him. Their light will run before them and on their right hands; they will say: Our Lord! Perfect our light for us, and forgive us! Lo! Thou art Able to do all things.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxviii{%
O Prophet! Strive against the disbelievers and the hypocrites, and be stern with them. Hell will be their home, a hapless journey's end.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxix{%
Allah citeth an example for those who disbelieve: the wife of Noah and the wife of Lot, who were under two of Our righteous slaves yet betrayed them so that they (the husbands) availed them naught against Allah and it was said (unto them): Enter the Fire along with those who enter.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccxl{%
And Allah citeth an example for those who believe: the wife of Pharaoh when she said: My Lord! Build for me a home with thee in the Garden, and deliver me from Pharaoh and his work, and deliver me from evil-doing folk;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxli{%
And Mary, daughter of 'Imran, whose body was chaste, therefor We breathed therein something of Our Spirit. And she put faith in the words of her Lord and His scriptures, and was of the obedient.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxlii{%
\basmalahen Blessed is He in Whose hand is the Sovereignty, and, He is Able to do all things.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxliii{%
Who hath created life and death that He may try you which of you is best in conduct; and He is the Mighty, the Forgiving,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxliv{%
Who hath created seven heavens in harmony. Thou (Muhammad) canst see no fault in the Beneficent One's creation; then look again: Canst thou see any rifts?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxlv{%
Then look again and yet again, thy sight will return unto thee weakened and made dim.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxlvi{%
And verily We have beautified the world's heaven with lamps, and We have made them missiles for the devils, and for them We have prepared the doom of flame.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxlvii{%
And for those who disbelieve in their Lord there is the doom of hell, a hapless journey's end!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxlviii{%
When they are flung therein they hear its roaring as it boileth up,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxlix{%
As it would burst with rage. Whenever a (fresh) host is flung therein the wardens thereof ask them: Came there unto you no warner?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccl{%
They say: Yea, verily, a warner came unto us; but we denied and said: Allah hath naught revealed; ye are in naught but a great error.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccli{%
And they say: Had we been wont to listen or have sense, we had not been among the dwellers in the flames.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcclii{%
So they acknowledge their sins; but far removed (from mercy) are the dwellers in the flames.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccliii{%
Lo! those who fear their Lord in secret, theirs will be forgiveness and a great reward.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccliv{%
And keep your opinion secret or proclaim it, lo! He is Knower of all that is in the breasts (of men).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcclv{%
Should He not know what He created? And He is the Subtile, the Aware.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcclvi{%
He it is Who hath made the earth subservient unto you, so Walk in the paths thereof and eat of His providence. And unto Him will be the resurrection (of the dead).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcclvii{%
Have ye taken security from Him Who is in the heaven that He will not cause the earth to swallow you when lo! it is convulsed?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcclviii{%
Or have ye taken security from Him Who is in the heaven that He will not let loose on you a hurricane? But ye shall know the manner of My warning.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcclix{%
And verily those before them denied, then (see) the manner of My wrath (with them)!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcclx{%
Have they not seen the birds above them spreading out their wings and closing them? Naught upholdeth them save the Beneficent. Lo! He is Seer of all things.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcclxi{%
Or who is he that will be an army unto you to help you instead of the Beneficent? The disbelievers are in naught but illusion.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcclxii{%
Or who is he that will provide for you if He should withhold His providence? Nay, but they are set in pride and frowardness.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcclxiii{%
Is he who goeth groping on his face more rightly guided, or he who walketh upright on a straight road?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcclxiv{%
Say (unto them, O Muhammad): He it is who gave you being, and hath assigned unto you ears and eyes and hearts. Small thanks give ye!\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcclxv{%
Say: He it is Who multiplieth you in the earth, and unto Whom ye will be gathered.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcclxvi{%
And they say: When (will) this promise (be fulfilled), if ye are truthful?\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcclxvii{%
Say: The knowledge is with Allah only, and I am but a plain warner;\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcclxviii{%
But when they see it nigh, the faces of those who disbelieve will be awry, and it will be said (unto them): This is that for which ye used to call.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcclxix{%
Say (O Muhammad): Have ye thought: Whether Allah causeth me (Muhammad) and those with me to perish or hath mercy on us, still, who will protect the disbelievers from a painful doom?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcclxx{%
Say: He is the Beneficent. In Him we believe and in Him we put our trust. And ye will soon know who it is that is in error manifest.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxi{%
Say: Have ye thought: If (all) your water were to disappear into the earth, who then could bring you gushing water?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxii{%
\basmalahen Nun. By the pen and that which they write (therewith),\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxiii{%
Thou art not, for thy Lord's favour unto thee, a madman.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxiv{%
And lo! thine verily will be a reward unfailing.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxv{%
And lo! thou art of a tremendous nature.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxvi{%
And thou wilt see and they will see\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxvii{%
Which of you is the demented.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxviii{%
Lo! thy Lord is Best Aware of him who strayeth from His way, and He is Best Aware of those who walk aright.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxix{%
Therefor obey not thou the rejecters\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxx{%
Who would have had thee compromise, that they may compromise.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxi{%
Neither obey thou each feeble oath-monger,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxii{%
Detracter, spreader abroad of slanders,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxiii{%
Hinderer of the good, transgressor, malefactor\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxiv{%
Greedy therewithal, intrusive.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxv{%
It is because he is possessed of wealth and children\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxvi{%
That, when Our revelations are recited unto him, he saith: Mere fables of the men of old.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxvii{%
We shall brand him on the nose.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxviii{%
Lo! We have tried them as We tried the owners of the garden when they vowed that they would pluck its fruit next morning,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxix{%
And made no exception (for the Will of Allah);\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmccxc{%
Then a visitation from thy Lord came upon it while they slept\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmccxci{%
And in the morning it was as if plucked.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmccxcii{%
And they cried out one unto another in the morning,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmccxciii{%
Saying: Run unto your field if ye would pluck (the fruit).\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmccxciv{%
So they went off, saying one unto another in low tones:\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmccxcv{%
No needy man shall enter it to-day against you.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmccxcvi{%
They went betimes, strong in (this) purpose.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmccxcvii{%
But when they saw it, they said: Lo! we are in error!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmccxcviii{%
Nay, but we are desolate!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmccxcix{%
The best among them said: Said I not unto you: Why glorify ye not (Allah)?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmccc{%
They said: Glorified be our Lord! Lo! we have been wrong-doers.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmccci{%
Then some of them drew near unto others, self-reproaching.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcccii{%
They said: Alas for us! In truth we were outrageous.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmccciii{%
It may be that our Lord will give us better than this in place thereof. Lo! we beseech our Lord.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmccciv{%
Such was the punishment. And verily the punishment of the Hereafter is greater if they did but know.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmcccv{%
Lo! for those who keep from evil are gardens of bliss with their Lord.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmcccvi{%
Shall We then treat those who have surrendered as We treat the guilty?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmcccvii{%
What aileth you? How foolishly ye judge!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmcccviii{%
Or have ye a scripture wherein ye learn\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmcccix{%
That ye shall indeed have all that ye choose?\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmcccx{%
Or have ye a covenant on oath from Us that reacheth to the Day of Judgment, that yours shall be all that ye ordain?\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmcccxi{%
Ask them (O Muhammad) which of them will vouch for that!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmcccxii{%
Or have they other gods? Then let them bring their other gods if they are truthful\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmcccxiii{%
On the day when it befalleth in earnest, and they are ordered to prostrate themselves but are not able,\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmcccxiv{%
With eyes downcast, abasement stupefying them. And they had been summoned to prostrate themselves while they were yet unhurt.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmcccxv{%
Leave Me (to deal) with those who give the lie to this pronouncement. We shall lead them on by steps from whence they know not.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmcccxvi{%
Yet I bear with them, for lo! My scheme is firm.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmcccxvii{%
Or dost thou (Muhammad) ask a fee from them so that they are heavily taxed?\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmcccxviii{%
Or is the Unseen theirs that they can write (thereof)?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmcccxix{%
But wait thou for thy Lord's decree, and be not like him of the fish, who cried out in despair.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmcccxx{%
Had it not been that favour from his Lord had reached him he surely had been cast into the wilderness while he was reprobate.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxi{%
But his Lord chose him and placed him among the righteous.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxii{%
And lo! those who disbelieve would fain disconcert thee with their eyes when they hear the Reminder, and they say: Lo! he is indeed mad;\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxiii{%
When it is naught else than a Reminder to creation.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxiv{%
\basmalahen The Reality!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxv{%
What is the Reality?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxvi{%
Ah, what will convey unto thee what the reality is!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxvii{%
(The tribes of) Thamud and A'ad disbelieved in the judgment to come.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxviii{%
As for Thamud, they were destroyed by the lightning.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxix{%
And as for A'ad, they were destroyed by a fierce roaring wind,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxx{%
Which He imposed on them for seven long nights and eight long days so that thou mightest have seen men lying overthrown, as they were hollow trunks of palm-trees.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxi{%
Canst thou (O Muhammad) see any remnant of them?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxii{%
And Pharaoh and those before him, and the communities that were destroyed, brought error,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxiii{%
And they disobeyed the messenger of their Lord, therefor did He grip them with a tightening grip.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxiv{%
Lo! when the waters rose, We carried you upon the ship\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxv{%
That We might make it a memorial for you, and that remembering ears (that heard the story) might remember.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxvi{%
And when the trumpet shall sound one blast\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxvii{%
And the earth with the mountains shall be lifted up and crushed with one crash,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxviii{%
Then, on that day will the Event befall.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxix{%
And the heaven will split asunder, for that day it will be frail.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcccxl{%
And the angels will be on the sides thereof, and eight will uphold the Throne of thy Lord that day, above them.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcccxli{%
On that day ye will be exposed; not a secret of you will be hidden.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlii{%
Then, as for him who is given his record in his right hand, he will say: Take, read my book!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcccxliii{%
Surely I knew that I should have to meet my reckoning.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcccxliv{%
Then he will be in blissful state\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlv{%
In a high garden\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlvi{%
Whereof the clusters are in easy reach.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlvii{%
(And it will be said unto those therein): Eat and drink at ease for that which ye sent on before you in past days.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlviii{%
But as for him who is given his record in his left hand, he will say: Oh, would that I had not been given my book\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlix{%
And knew not what my reckoning!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcccl{%
Oh, would that it had been death!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcccli{%
My wealth hath not availed me,\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmccclii{%
My power hath gone from me.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcccliii{%
(It will be said): Take him and fetter him\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcccliv{%
And then expose him to hell-fire\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmccclv{%
And then insert him in a chain whereof the length is seventy cubits.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmccclvi{%
Lo! He used not to believe in Allah the Tremendous,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmccclvii{%
And urged not on the feeding of the wretched.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmccclviii{%
Therefor hath he no lover here this day,\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmccclix{%
Nor any food save filth\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmccclx{%
Which none but sinners eat.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmccclxi{%
But nay! I swear by all that ye see\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmccclxii{%
And all that ye see not\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmccclxiii{%
That it is indeed the speech of an illustrious messenger.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmccclxiv{%
It is not poet's speech - little is it that ye believe!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmccclxv{%
Nor diviner's speech - little is it that ye remember!\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmccclxvi{%
It is a revelation from the Lord of the Worlds.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmccclxvii{%
And if he had invented false sayings concerning Us,\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmccclxviii{%
We assuredly had taken him by the right hand\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmccclxix{%
And then severed his life-artery,\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmccclxx{%
And not one of you could have held Us off from him.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxi{%
And lo! it is a warrant unto those who ward off (evil).\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxii{%
And lo! We know that some among you will deny (it).\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxiii{%
And lo! it is indeed an anguish for the disbelievers.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxiv{%
And lo! it is absolute truth.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxv{%
So glorify the name of thy Tremendous Lord.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxvi{%
\basmalahen A questioner questioned concerning the doom about to fall\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxvii{%
Upon the disbelievers, which none can repel,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxviii{%
From Allah, Lord of the Ascending Stairways\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxix{%
(Whereby) the angels and the Spirit ascend unto Him in a Day whereof the span is fifty thousand years.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxx{%
But be patient (O Muhammad) with a patience fair to see.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxi{%
Lo! they behold it afar off\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxii{%
While we behold it nigh:\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxiii{%
The day when the sky will become as molten copper,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxiv{%
And the hills become as flakes of wool,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxv{%
And no familiar friend will ask a question of his friend\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxvi{%
Though they will be given sight of them. The guilty man will long to be able to ransom himself from the punishment of that day at the price of his children\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxvii{%
And his spouse and his brother\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxviii{%
And his kin that harboured him\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxix{%
And all that are in the earth, if then it might deliver him.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcccxc{%
But nay! for lo! it is the fire of hell\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcccxci{%
Eager to roast;\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcii{%
It calleth him who turned and fled (from truth),\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcccxciii{%
And hoarded (wealth) and withheld it.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcccxciv{%
Lo! man was created anxious,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcv{%
Fretful when evil befalleth him\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcvi{%
And, when good befalleth him, grudging;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcvii{%
Save worshippers.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcviii{%
Who are constant at their worship\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcix{%
And in whose wealth there is a right acknowledged\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcd{%
For the beggar and the destitute;\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdi{%
And those who believe in the Day of Judgment,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdii{%
And those who are fearful of their Lord's doom -\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdiii{%
Lo! the doom of their Lord is that before which none can feel secure -\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdiv{%
And those who preserve their chastity\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcdv{%
Save with their wives and those whom their right hands possess, for thus they are not blameworthy;\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcdvi{%
But whoso seeketh more than that, those are they who are transgressors;\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmcdvii{%
And those who keep their pledges and their covenant,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmcdviii{%
And those who stand by their testimony\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmcdix{%
And those who are attentive at their worship.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmcdx{%
These will dwell in Gardens, honoured.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmcdxi{%
What aileth those who disbelieve, that they keep staring toward thee (O Muhammad), open-eyed,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmcdxii{%
On the right and on the left, in groups?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmcdxiii{%
Doth every man among them hope to enter the Garden of Delight?\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmcdxiv{%
Nay, verily. Lo! We created them from what they know.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmcdxv{%
But nay! I swear by the Lord of the rising-places and the setting-places of the planets that We verily are Able\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmcdxvi{%
To replace them by (others) better than them. And we are not to be outrun.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmcdxvii{%
So let them chat and play until they meet their Day which they are promised,\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmcdxviii{%
The day when they come forth from the graves in haste, as racing to a goal,\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmcdxix{%
With eyes aghast, abasement stupefying them: Such is the Day which they are promised.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmcdxx{%
\basmalahen Lo! We sent Noah unto his people (saying): Warn thy people ere the painful doom come unto them.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxi{%
He said: O my people! Lo! I am a plain warner unto you\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxii{%
(Bidding you): Serve Allah and keep your duty unto Him and obey me,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxiii{%
That He may forgive you somewhat of your sins and respite you to an appointed term. Lo! the term of Allah, when it cometh, cannot be delayed, if ye but knew.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxiv{%
He said: My Lord! Lo! I have called unto my people night and day\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxv{%
But all my calling doth but add to their repugnance;\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxvi{%
And lo! whenever I call unto them that Thou mayst pardon them they thrust their fingers in their ears and cover themselves with their garments and persist (in their refusal) and magnify themselves in pride.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxvii{%
And lo! I have called unto them aloud,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxviii{%
And lo! I have made public proclamation unto them, and I have appealed to them in private.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxix{%
And I have said: Seek pardon of your Lord. Lo! He was ever Forgiving.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxx{%
He will let loose the sky for you in plenteous rain,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxi{%
And will help you with wealth and sons, and will assign unto you Gardens and will assign unto you rivers.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxii{%
What aileth you that ye hope not toward Allah for dignity\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxiii{%
When He created you by (divers) stages?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxiv{%
See ye not how Allah hath created seven heavens in harmony,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxv{%
And hath made the moon a light therein, and made the sun a lamp?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxvi{%
And Allah hath caused you to grow as a growth from the earth,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxvii{%
And afterward He maketh you return thereto, and He will bring you forth again, a (new) forthbringing.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxviii{%
And Allah hath made the earth a wide expanse for you\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxix{%
That ye may thread the valley-ways thereof.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdxl{%
Noah said: My Lord! Lo! they have disobeyed me and followed one whose wealth and children increase him in naught save ruin;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcdxli{%
And they have plotted a mighty plot,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlii{%
And they have said: Forsake not your gods. Forsake not Wadd, nor Suwa', nor Yaghuth and Ya'uq and Nasr.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcdxliii{%
And they have led many astray, and Thou increasest the wrong-doers in naught save error.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcdxliv{%
Because of their sins they were drowned, then made to enter a Fire. And they found they had no helpers in place of Allah.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlv{%
And Noah said: My Lord! Leave not one of the disbelievers in the land.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlvi{%
If Thou shouldst leave them, they will mislead Thy slaves and will beget none save lewd ingrates.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlvii{%
My Lord! Forgive me and my parents and him who entereth my house believing, and believing men and believing women, and increase not the wrong-doers in aught save ruin.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlviii{%
\basmalahen Say (O Muhammad): It is revealed unto me that a company of the Jinn gave ear, and they said: Lo! we have heard a marvellous Qur'an,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlix{%
Which guideth unto righteousness, so we believe in it and we ascribe no partner unto our Lord.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdl{%
And (we believe) that He - exalted be the glory of our Lord! - hath taken neither wife nor son,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdli{%
And that the foolish one among us used to speak concerning Allah an atrocious lie.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdlii{%
And lo! we had supposed that humankind and jinn would not speak a lie concerning Allah -\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdliii{%
And indeed (O Muhammad) individuals of humankind used to invoke the protection of individuals of the jinn, so that they increased them in revolt against Allah);\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdliv{%
And indeed they supposed, even as ye suppose, that Allah would not raise anyone (from the dead) -\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdlv{%
And (the Jinn who had listened to the Qur'an said): We had sought the heaven but had found it filled with strong warders and meteors.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdlvi{%
And we used to sit on places (high) therein to listen. But he who listeneth now findeth a flame in wait for him;\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdlvii{%
And we know not whether harm is boded unto all who are in the earth, or whether their Lord intendeth guidance for them.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdlviii{%
And among us there are righteous folk and among us there are far from that. We are sects having different rules.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdlix{%
And we know that we cannot escape from Allah in the earth, nor can we escape by flight.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdlx{%
And when we heard the guidance, we believed therein, and whoso believeth in his Lord, he feareth neither loss nor oppression.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxi{%
And there are among us some who have surrendered (to Allah) and there are among us some who are unjust. And whoso hath surrendered to Allah, such have taken the right path purposefully.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxii{%
And as for those who are unjust, they are firewood for hell.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxiii{%
If they (the idolaters) tread the right path, We shall give them to drink of water in abundance\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxiv{%
That We may test them thereby, and whoso turneth away from the remembrance of his Lord; He will thrust him into ever-growing torment.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxv{%
And the places of worship are only for Allah, so pray not unto anyone along with Allah.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxvi{%
And when the slave of Allah stood up in prayer to Him, they crowded on him, almost stifling.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxvii{%
Say (unto them, O Muhammad): I pray unto Allah only, and ascribe unto Him no partner.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxviii{%
Say: Lo! I control not hurt nor benefit for you.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxix{%
Say: Lo! none can protect me from Allah, nor can I find any refuge beside Him\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxx{%
(Mine is) but conveyance (of the Truth) from Allah, and His messages; and whoso disobeyeth Allah and His messenger, lo! his is fire of hell, wherein such dwell for ever.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxi{%
Till (the day) when they shall behold that which they are promised (they may doubt); but then they will know (for certain) who is weaker in allies and less in multitude.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxii{%
Say (O Muhammad, unto the disbelievers): I know not whether that which ye are promised is nigh, or if my Lord hath set a distant term for it.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxiii{%
(He is) the Knower of the Unseen, and He revealeth unto none His secret,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxiv{%
Save unto every messenger whom He hath chosen, and then He maketh a guard to go before him and a guard behind him\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxv{%
That He may know that they have indeed conveyed the messages of their Lord. He surroundeth all their doings, and He keepeth count of all things.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxvi{%
\basmalahen O thou wrapped up in thy raiment!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxvii{%
Keep vigil the night long, save a little -\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxviii{%
A half thereof, or abate a little thereof\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxix{%
Or add (a little) thereto - and chant the Qur'an in measure,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxx{%
For we shall charge thee with a word of weight.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxi{%
Lo! the vigil of the night is (a time) when impression is more keen and speech more certain.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxii{%
Lo! thou hast by day a chain of business.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiii{%
So remember the name of thy Lord and devote thyself with a complete devotion -\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiv{%
Lord of the East and the West; there is no Allah save Him; so choose thou Him alone for thy defender -\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxv{%
And bear with patience what they utter, and part from them with a fair leave-taking.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvi{%
Leave Me to deal with the deniers, lords of ease and comfort (in this life); and do thou respite them awhile.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvii{%
Lo! with Us are heavy fetters and a raging fire,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxviii{%
And food which choketh (the partaker), and a painful doom\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxix{%
On the day when the earth and the hills rock, and the hills become a heap of running sand.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdxc{%
Lo! We have sent unto you a messenger as witness against you, even as We sent unto Pharaoh a messenger.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdxci{%
But Pharaoh rebelled against the messenger, whereupon We seized him with no gentle grip.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcii{%
Then how, if ye disbelieve, will ye protect yourselves upon the day which will turn children grey,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdxciii{%
The very heaven being then rent asunder. His promise is to be fulfilled.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdxciv{%
Lo! This is a Reminder. Let him who will, then, choose a way unto his Lord.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcv{%
Lo! thy Lord knoweth how thou keepest vigil sometimes nearly two-thirds of the night, or (sometimes) half or a third thereof, as do a party of those with thee. Allah measureth the night and the day. He knoweth that ye count it not, and turneth unto you in mercy. Recite, then, of the Qur'an that which is easy for you. He knoweth that there are sick folk among you, while others travel in the land in search of Allah's bounty, and others (still) are fighting for the cause of Allah. So recite of it that which is easy (for you), and establish worship and pay the poor-due, and (so) lend unto Allah a goodly loan. Whatsoever good ye send before you for your souls, ye will find it with Allah, better and greater in the recompense. And seek forgiveness of Allah. Lo! Allah is Forgiving, Merciful.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcvi{%
\basmalahen O thou enveloped in thy cloak,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcvii{%
Arise and warn!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcviii{%
Thy Lord magnify,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcix{%
Thy raiment purify,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmd{%
Pollution shun!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdi{%
And show not favour, seeking wordly gain!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdii{%
For the sake of thy Lord, be patient!\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdiii{%
For when the trumpet shall sound,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdiv{%
Surely that day will be a day of anguish,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdv{%
Not of ease, for disbelievers.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdvi{%
Leave Me (to deal) with him whom I created lonely,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdvii{%
And then bestowed upon him ample means,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdviii{%
And sons abiding in his presence\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdix{%
And made (life) smooth for him.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdx{%
Yet he desireth that I should give more.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdxi{%
Nay! For lo! he hath been stubborn to Our revelations.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdxii{%
On him I shall impose a fearful doom.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdxiii{%
For lo! he did consider; then he planned -\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdxiv{%
(Self-)destroyed is he, how he planned!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdxv{%
Again (self-)destroyed is he, how he planned! -\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdxvi{%
Then looked he,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdxvii{%
Then frowned he and showed displeasure.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdxviii{%
Then turned he away in pride\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdxix{%
And said: This is naught else than magic from of old;\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdxx{%
This is naught else than speech of mortal man.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdxxi{%
Him shall I fling unto the burning.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdxxii{%
- Ah, what will convey unto thee what that burning is! -\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdxxiii{%
It leaveth naught; it spareth naught\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdxxiv{%
It shrivelleth the man.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdxxv{%
Above it are nineteen.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdxxvi{%
We have appointed only angels to be wardens of the Fire, and their number have We made to be a stumbling-block for those who disbelieve; that those to whom the Scripture hath been given may have certainty, and that believers may increase in faith; and that those to whom the Scripture hath been given and believers may not doubt; and that those in whose hearts there is disease, and disbelievers, may say: What meaneth Allah by this similitude? Thus Allah sendeth astray whom He will, and whom He will He guideth. None knoweth the hosts of thy Lord save Him. This is naught else than a Reminder unto mortals.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdxxvii{%
Nay, by the Moon\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdxxviii{%
And the night when it withdraweth\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdxxix{%
And the dawn when it shineth forth,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdxxx{%
Lo! this is one of the greatest (portents)\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxi{%
As a warning unto men,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxii{%
Unto him of you who will advance or hang back.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxiii{%
Every soul is a pledge for its own deeds;\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxiv{%
Save those who will stand on the right hand.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxv{%
In gardens they will ask one another\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxvi{%
Concerning the guilty:\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxvii{%
What hath brought you to this burning?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxviii{%
They will answer: We were not of those who prayed\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxix{%
Nor did we feed the wretched.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdxl{%
We used to wade (in vain dispute) with (all) waders,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdxli{%
And we used to deny the Day of Judgment,\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdxlii{%
Till the Inevitable came unto us.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmdxliii{%
The mediation of no mediators will avail them then.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmdxliv{%
Why now turn they away from the Admonishment,\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmdxlv{%
As they were frightened asses\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmdxlvi{%
Fleeing from a lion?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmdxlvii{%
Nay, but everyone of them desireth that he should be given open pages (from Allah).\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmdxlviii{%
Nay, verily. They fear not the Hereafter.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmmdxlix{%
Nay, verily. Lo! this is an Admonishment.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmmdl{%
So whosoever will may heed.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmmdli{%
And they will not heed unless Allah willeth (it). He is the fount of fear. He is the fount of Mercy.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmmdlii{%
\basmalahen Nay, I swear by the Day of Resurrection;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdliii{%
Nay, I swear by the accusing soul (that this Scripture is true).\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdliv{%
Thinketh man that We shall not assemble his bones?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdlv{%
Yea, verily. We are Able to restore his very fingers!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdlvi{%
But man would fain deny what is before him.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdlvii{%
He asketh: When will be this Day of Resurrection?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdlviii{%
But when sight is confounded\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdlix{%
And the moon is eclipsed\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdlx{%
And sun and moon are united,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdlxi{%
On that day man will cry: Whither to flee!\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdlxii{%
Alas! No refuge!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdlxiii{%
Unto thy Lord is the recourse that day.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdlxiv{%
On that day man is told the tale of that which he hath sent before and left behind.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdlxv{%
Oh, but man is a telling witness against himself,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdlxvi{%
Although he tender his excuses.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdlxvii{%
Stir not thy tongue herewith to hasten it.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdlxviii{%
Lo! upon Us (resteth) the putting together thereof and the reading thereof.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdlxix{%
And when We read it, follow thou the reading;\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdlxx{%
Then lo! upon Us (resteth) the explanation thereof.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxi{%
Nay, but ye do love the fleeting Now\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxii{%
And neglect the Hereafter.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxiii{%
That day will faces be resplendent,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxiv{%
Looking toward their Lord;\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxv{%
And that day will other faces be despondent,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxvi{%
Thou wilt know that some great disaster is about to fall on them.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxvii{%
Nay, but when the life cometh up to the throat\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxviii{%
And men say: Where is the wizard (who can save him now)?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxix{%
And he knoweth that it is the parting;\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxx{%
And agony is heaped on agony;\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxi{%
Unto thy Lord that day will be the driving.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxii{%
For he neither trusted, nor prayed.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxiii{%
But he denied and flouted.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxiv{%
Then went he to his folk with glee.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxv{%
Nearer unto thee and nearer,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxvi{%
Again nearer unto thee and nearer (is the doom).\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxvii{%
Thinketh man that he is to be left aimless?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxviii{%
Was he not a drop of fluid which gushed forth?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxix{%
Then he became a clot; then (Allah) shaped and fashioned\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdxc{%
And made of him a pair, the male and female.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdxci{%
Is not He (Who doeth so) Able to bring the dead to life?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdxcii{%
\basmalahen Hath there come upon man (ever) any period of time in which he was a thing unremembered?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdxciii{%
Lo! We create man from a drop of thickened fluid to test him; so We make him hearing, knowing.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdxciv{%
Lo! We have shown him the way, whether he be grateful or disbelieving.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdxcv{%
Lo! We have prepared for disbelievers manacles and carcans and a raging fire.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdxcvi{%
Lo! the righteous shall drink of a cup whereof the mixture is of Kafur,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdxcvii{%
A spring wherefrom the slaves of Allah drink, making it gush forth abundantly,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdxcviii{%
(Because) they perform the vow and fear a day whereof the evil is wide-spreading,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdxcix{%
And feed with food the needy wretch, the orphan and the prisoner, for love of Him,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdc{%
(Saying): We feed you, for the sake of Allah only. We wish for no reward nor thanks from you;\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdci{%
Lo! we fear from our Lord a day of frowning and of fate.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcii{%
Therefor Allah hath warded off from them the evil of that day, and hath made them find brightness and joy;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdciii{%
And hath awarded them for all that they endured, a Garden and silk attire;\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdciv{%
Reclining therein upon couches, they will find there neither (heat of) a sun nor bitter cold.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcv{%
The shade thereof is close upon them and the clustered fruits thereof bow down.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcvi{%
Goblets of silver are brought round for them, and beakers (as) of glass\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcvii{%
(Bright as) glass but (made) of silver, which they (themselves) have measured to the measure (of their deeds).\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcviii{%
There are they watered with a cup whereof the mixture is of Zanjabil,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcix{%
(The water of) a spring therein, named Salsabil.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcx{%
There wait on them immortal youths, whom, when thou seest, thou wouldst take for scattered pearls.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxi{%
When thou seest, thou wilt see there bliss and high estate.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxii{%
Their raiment will be fine green silk and gold embroidery. Bracelets of silver will they wear. Their Lord will slake their thirst with a pure drink.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxiii{%
(And it will be said unto them): Lo! this is a reward for you. Your endeavour (upon earth) hath found acceptance.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxiv{%
Lo! We, even We, have revealed unto thee the Qur'an, a revelation;\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxv{%
So submit patiently to thy Lord's command, and obey not of them any guilty one or disbeliever.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxvi{%
Remember the name of thy Lord at morn and evening.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxvii{%
And worship Him (a portion) of the night. And glorify Him through the livelong night.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxviii{%
Lo! these love fleeting life, and put behind them (the remembrance of) a grievous day.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcxix{%
We, even We, created them, and strengthened their frame. And when We will, We can replace them, bringing others like them in their stead.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcxx{%
Lo! this is an Admonishment, that whosoever will may choose a way unto his Lord.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxi{%
Yet ye will not, unless Allah willeth. Lo! Allah is Knower, Wise.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxii{%
He maketh whom He will to enter His mercy, and for evil-doers hath prepared a painful doom.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxiii{%
\basmalahen By the emissary winds, (sent) one after another\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxiv{%
By the raging hurricanes,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxv{%
By those which cause earth's vegetation to revive;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxvi{%
By those who winnow with a winnowing,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxvii{%
By those who bring down the Reminder,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxviii{%
To excuse or to warn,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxix{%
Surely that which ye are promised will befall.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxx{%
So when the stars are put out,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxi{%
And when the sky is riven asunder,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxii{%
And when the mountains are blown away,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxiii{%
And when the messengers are brought unto their time appointed -\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxiv{%
For what day is the time appointed?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxv{%
For the Day of Decision.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxvi{%
And what will convey unto thee what the Day of Decision is! -\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxvii{%
Woe unto the repudiators on that day!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxviii{%
Destroyed We not the former folk,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxix{%
Then caused the latter folk to follow after?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcxl{%
Thus deal We ever with the guilty.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcxli{%
Woe unto the repudiators on that day!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlii{%
Did We not create you from a base fluid\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxliii{%
Which We laid up in a safe abode\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxliv{%
For a known term?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlv{%
Thus We arranged. How excellent is Our arranging!\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlvi{%
Woe unto the repudiators on that day!\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlvii{%
Have We not made the earth a receptacle\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlviii{%
Both for the living and the dead,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlix{%
And placed therein high mountains and given you to drink sweet water therein?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcl{%
Woe unto the repudiators on that day!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcli{%
(It will be said unto them:) Depart unto that (doom) which ye used to deny;\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdclii{%
Depart unto the shadow falling threefold,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcliii{%
(Which yet is) no relief nor shelter from the flame.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcliv{%
Lo! it throweth up sparks like the castles,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdclv{%
(Or) as it might be camels of bright yellow hue.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdclvi{%
Woe unto the repudiators on that day!\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdclvii{%
This is a day wherein they speak not,\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdclviii{%
Nor are they suffered to put forth excuses.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdclix{%
Woe unto the repudiators on that day!\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdclx{%
This is the Day of Decision, We have brought you and the men of old together.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdclxi{%
If now ye have any wit, outwit Me.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdclxii{%
Woe unto the repudiators on that day!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdclxiii{%
Lo! those who kept their duty are amid shade and fountains,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdclxiv{%
And fruits such as they desire.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdclxv{%
(Unto them it is said:) Eat, drink and welcome, O ye blessed, in return for what ye did.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdclxvi{%
Thus do We reward the good.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdclxvii{%
Woe unto the repudiators on that day!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdclxviii{%
Eat and take your ease (on earth) a little. Lo! ye are guilty.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdclxix{%
Woe unto the repudiators on that day!\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmdclxx{%
When it is said unto them: Bow down, they bow not down!\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxi{%
Woe unto the repudiators on that day!\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxii{%
In what statement, after this, will they believe?\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxiii{%
\basmalahen Whereof do they question one another?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxiv{%
(It is) of the awful tidings,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxv{%
Concerning which they are in disagreement.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxvi{%
Nay, but they will come to know!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxvii{%
Nay, again, but they will come to know!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxviii{%
Have We not made the earth an expanse,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxix{%
And the high hills bulwarks?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxx{%
And We have created you in pairs,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxi{%
And have appointed your sleep for repose,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxii{%
And have appointed the night as a cloak,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxiii{%
And have appointed the day for livelihood.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxiv{%
And We have built above you seven strong (heavens),\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxv{%
And have appointed a dazzling lamp,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxvi{%
And have sent down from the rainy clouds abundant water,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxvii{%
Thereby to produce grain and plant,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxviii{%
And gardens of thick foliage.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxix{%
Lo! the Day of Decision is a fixed time,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcxc{%
A day when the trumpet is blown and ye come in multitudes,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcxci{%
And the heaven is opened and becometh as gates,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcii{%
And the hills are set in motion and become as a mirage.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxciii{%
Lo! hell lurketh in ambush,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxciv{%
A home for the rebellious.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcv{%
They will abide therein for ages.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcvi{%
Therein taste they neither coolness nor (any) drink\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcvii{%
Save boiling water and a paralysing cold:\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcviii{%
Reward proportioned (to their evil deeds).\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcix{%
For lo! they looked not for a reckoning;\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcc{%
They called Our revelations false with strong denial.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcci{%
Everything have We recorded in a Book.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccii{%
So taste (of that which ye have earned). No increase do We give you save of torment.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcciii{%
Lo! for the duteous is achievement -\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcciv{%
Gardens enclosed and vineyards,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccv{%
And voluptuous women of equal age;\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccvi{%
And a full cup.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccvii{%
There hear they never vain discourse, nor lying -\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccviii{%
Requital from thy Lord - a gift in payment -\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccix{%
Lord of the heavens and the earth, and (all) that is between them, the Beneficent; with Whom none can converse.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccx{%
On the day when the angels and the Spirit stand arrayed, they speak not, saving him whom the Beneficent alloweth and who speaketh right.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccxi{%
That is the True Day. So whoso will should seek recourse unto his Lord.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdccxii{%
Lo! We warn you of a doom at hand, a day whereon a man will look on that which his own hands have sent before, and the disbeliever will cry: ``Would that I were dust!"\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccxiii{%
\basmalahen By those who drag forth to destruction,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdccxiv{%
By the meteors rushing,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccxv{%
By the lone stars floating,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccxvi{%
By the angels hastening,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdccxvii{%
And those who govern the event,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdccxviii{%
On the day when the first trump resoundeth.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdccxix{%
And the second followeth it,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdccxx{%
On that day hearts beat painfully\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxi{%
While eyes are downcast\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxii{%
(Now) they are saying: Shall we really be restored to our first state\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxiii{%
Even after we are crumbled bones?\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxiv{%
They say: Then that would be a vain proceeding.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxv{%
Surely it will need but one shout,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxvi{%
And lo! they will be awakened.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxvii{%
Hath there come unto thee the history of Moses?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxviii{%
How his Lord called him in the holy vale of Tuwa,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxix{%
(Saying:) Go thou unto Pharaoh - Lo! he hath rebelled -\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxx{%
And say (unto him): Hast thou (will) to grow (in grace)?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxi{%
Then I will guide thee to thy Lord and thou shalt fear (Him).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxii{%
And he showed him the tremendous token.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxiii{%
But he denied and disobeyed,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxiv{%
Then turned he away in haste,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxv{%
Then gathered he and summoned\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxvi{%
And proclaimed: ``I (Pharaoh) am your Lord the Highest."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxvii{%
So Allah seized him (and made him) an example for the after (life) and for the former.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxviii{%
Lo! herein is indeed a lesson for him who feareth.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxix{%
Are ye the harder to create, or is the heaven that He built?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdccxl{%
He raised the height thereof and ordered it;\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdccxli{%
And He made dark the night thereof, and He brought forth the morn thereof.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlii{%
And after that He spread the earth,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdccxliii{%
And produced therefrom the water thereof and the pasture thereof,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccxliv{%
And He made fast the hills,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlv{%
A provision for you and for your cattle.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlvi{%
But when the great disaster cometh,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlvii{%
The day when man will call to mind his (whole) endeavour,\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlviii{%
And hell will stand forth visible to him who seeth,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlix{%
Then, as for him who rebelled\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccl{%
And chose the life of the world,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccli{%
Lo! hell will be his home.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdcclii{%
But as for him who feared to stand before his Lord and restrained his soul from lust,\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccliii{%
Lo! the Garden will be his home.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdccliv{%
They ask thee of the Hour: when will it come to port?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdcclv{%
Why (ask they)? What hast thou to tell thereof?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdcclvi{%
Unto thy Lord belongeth (knowledge of) the term thereof.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdcclvii{%
Thou art but a warner unto him who feareth it.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdcclviii{%
On the day when they behold it, it will be as if they had but tarried for an evening or the morn thereof.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdcclix{%
\basmalahen He frowned and turned away\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcclx{%
Because the blind man came unto him.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxi{%
What could inform thee but that he might grow (in grace)\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxii{%
Or take heed and so the reminder might avail him?\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxiii{%
As for him who thinketh himself independent,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxiv{%
Unto him thou payest regard.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxv{%
Yet it is not thy concern if he grow not (in grace).\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxvi{%
But as for him who cometh unto thee with earnest purpose\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxvii{%
And hath fear,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxviii{%
From him thou art distracted.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxix{%
Nay, but verily it is an Admonishment,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxx{%
So let whosoever will pay heed to it,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxi{%
On honoured leaves\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxii{%
Exalted, purified,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxiii{%
(Set down) by scribes\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxiv{%
Noble and righteous.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxv{%
Man is (self-)destroyed: how ungrateful!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxvi{%
From what thing doth He create him?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxvii{%
From a drop of seed. He createth him and proportioneth him,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxviii{%
Then maketh the way easy for him,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxix{%
Then causeth him to die, and burieth him;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxx{%
Then, when He will, He bringeth him again to life.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxi{%
Nay, but (man) hath not done what He commanded him.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxii{%
Let man consider his food:\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiii{%
How We pour water in showers\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiv{%
Then split the earth in clefts\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxv{%
And cause the grain to grow therein\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvi{%
And grapes and green fodder\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvii{%
And olive-trees and palm-trees\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxviii{%
And garden-closes of thick foliage\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxix{%
And fruits and grasses:\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccxc{%
Provision for you and your cattle.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccxci{%
But when the Shout cometh\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcii{%
On the day when a man fleeth from his brother\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccxciii{%
And his mother and his father\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccxciv{%
And his wife and his children,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcv{%
Every man that day will have concern enough to make him heedless (of others).\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcvi{%
On that day faces will be bright as dawn,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcvii{%
Laughing, rejoicing at good news;\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcviii{%
And other faces, on that day, with dust upon them,\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcix{%
Veiled in darkness,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdccc{%
Those are the disbelievers, the wicked.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdccci{%
\basmalahen When the sun is overthrown,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccii{%
And when the stars fall,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccciii{%
And when the hills are moved,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccciv{%
And when the camels big with young are abandoned,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccv{%
And when the wild beasts are herded together,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccvi{%
And when the seas rise,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccvii{%
And when souls are reunited,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccviii{%
And when the girl-child that was buried alive is asked\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccix{%
For what sin she was slain,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccx{%
And when the pages are laid open,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxi{%
And when the sky is torn away,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxii{%
And when hell is lighted,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxiii{%
And when the Garden is brought nigh,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxiv{%
(Then) every soul will know what it hath made ready.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxv{%
Oh, but I call to witness the planets,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxvi{%
The stars which rise and set,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxvii{%
And the close of night,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxviii{%
And the breath of morning\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxix{%
That this is in truth the word of an honoured messenger,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxx{%
Mighty, established in the presence of the Lord of the Throne,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxi{%
(One) to be obeyed, and trustworthy;\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxii{%
And your comrade is not mad.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxiii{%
Surely he beheld Him on the clear horizon.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxiv{%
And he is not avid of the Unseen.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxv{%
Nor is this the utterance of a devil worthy to be stoned.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxvi{%
Whither then go ye?\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxvii{%
This is naught else than a reminder unto creation,\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxviii{%
Unto whomsoever of you willeth to walk straight.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxix{%
And ye will not, unless (it be) that Allah willeth, the Lord of Creation.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxx{%
\basmalahen When the heaven is cleft asunder,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxi{%
When the planets are dispersed,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxii{%
When the seas are poured forth,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiii{%
And the sepulchres are overturned,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiv{%
A soul will know what it hath sent before (it) and what left behind.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxv{%
O man! What hath made thee careless concerning thy Lord, the Bountiful,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvi{%
Who created thee, then fashioned, then proportioned thee?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvii{%
Into whatsoever form He will, He casteth thee.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxviii{%
Nay, but ye deny the Judgment.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxix{%
Lo! there are above you guardians,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxl{%
Generous and recording,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxli{%
Who know (all) that ye do.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlii{%
Lo! the righteous verily will be in delight.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxliii{%
And lo! the wicked verily will be in hell;\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxliv{%
They will burn therein on the Day of Judgment,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlv{%
And will not be absent thence.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlvi{%
Ah, what will convey unto thee what the Day of Judgment is!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlvii{%
Again, what will convey unto thee what the Day of Judgment is!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlviii{%
A day on which no soul hath power at all for any (other) soul. The (absolute) command on that day is Allah's.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlix{%
\basmalahen Woe unto the defrauders:\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccl{%
Those who when they take the measure from mankind demand it full,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcccli{%
But if they measure unto them or weight for them, they cause them loss.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccclii{%
Do such (men) not consider that they will be raised again\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccliii{%
Unto an Awful Day,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccliv{%
The day when (all) mankind stand before the Lord of the Worlds?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdccclv{%
Nay, but the record of the vile is in Sijjin -\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdccclvi{%
Ah! what will convey unto thee what Sijjin is! -\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdccclvii{%
A written record.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdccclviii{%
Woe unto the repudiators on that day!\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdccclix{%
Those who deny the Day of Judgment\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdccclx{%
Which none denieth save each criminal transgressor,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxi{%
Who, when thou readest unto him Our revelations, saith: (Mere) fables of the men of old.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxii{%
Nay, but that which they have earned is rust upon their hearts.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxiii{%
Nay, but surely on that day they will be covered from (the mercy of) their Lord.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxiv{%
Then lo! they verily will burn in hell,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxv{%
And it will be said (unto them): This is that which ye used to deny.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxvi{%
Nay, but the record of the righteous is in 'Illiyin -\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxvii{%
Ah, what will convey unto thee what 'Illiyin is! -\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxviii{%
A written record,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxix{%
Attested by those who are brought near (unto their Lord).\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxx{%
Lo! the righteous verily are in delight,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxi{%
On couches, gazing,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxii{%
Thou wilt know in their faces the radiance of delight.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxiii{%
They are given to drink of a pure wine, sealed,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxiv{%
Whose seal is musk - for this let (all) those strive who strive for bliss -\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxv{%
And mixed with water of Tasnim,\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxvi{%
A spring whence those brought near (to Allah) drink.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxvii{%
Lo! the guilty used to laugh at those who believed,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxviii{%
And wink one to another when they passed them;\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxix{%
And when they returned to their own folk, they returned jesting;\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxx{%
And when they saw them they said: Lo! these have gone astray.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxi{%
Yet they were not sent as guardians over them.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxii{%
This day it is those who believe who have the laugh of disbelievers,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiii{%
On high couches, gazing.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiv{%
Are not the disbelievers paid for what they used to do?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxv{%
\basmalahen When the heaven is split asunder\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvi{%
And attentive to her Lord in fear,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvii{%
And when the earth is spread out\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxviii{%
And hath cast out all that was in her, and is empty\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxix{%
And attentive to her Lord in fear!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxc{%
Thou, verily, O man, art working toward thy Lord a work which thou wilt meet (in His presence).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxci{%
Then whoso is given his account in his right hand\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcii{%
He truly will receive an easy reckoning\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxciii{%
And will return unto his folk in joy.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxciv{%
But whoso is given his account behind his back,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcv{%
He surely will invoke destruction\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcvi{%
And be thrown to scorching fire.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcvii{%
He verily lived joyous with his folk,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcviii{%
He verily deemed that he would never return (unto Allah).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcix{%
Nay, but lo! his Lord is ever looking on him!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcm{%
Oh, I swear by the afterglow of sunset,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmi{%
And by the night and all that it enshroudeth,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmii{%
And by the moon when she is at the full,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmiii{%
That ye shall journey on from plane to plane.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmiv{%
What aileth them, then, that they believe not\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmv{%
And, when the Qur'an is recited unto them, worship not (Allah)?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmvi{%
Nay, but those who disbelieve will deny;\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmvii{%
And Allah knoweth best what they are hiding.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcmviii{%
So give them tidings of a painful doom,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcmix{%
Save those who believe and do good works, for theirs is a reward unfailing.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcmx{%
\basmalahen By the heaven, holding mansions of the stars,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxi{%
And by the Promised Day.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxii{%
And by the witness and that whereunto he beareth testimony,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxiii{%
(Self-)destroyed were the owners of the ditch\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxiv{%
Of the fuel-fed fire,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxv{%
When they sat by it,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmxvi{%
And were themselves the witnesses of what they did to the believers.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmxvii{%
They had naught against them save that they believed in Allah, the Mighty, the Owner of Praise,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmxviii{%
Him unto Whom belongeth the Sovereignty of the heavens and the earth; and Allah is of all things the Witness.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmxix{%
Lo! they who persecute believing men and believing women and repent not, theirs verily will be the doom of hell, and theirs the doom of burning.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmxx{%
Lo! those who believe and do good works, theirs will be Gardens underneath which rivers flow. That is the Great Success.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxi{%
Lo! the punishment of thy Lord is stern.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxii{%
Lo! He it is Who produceth, then reproduceth,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxiii{%
And He is the Forgiving, the Loving,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxiv{%
Lord of the Throne of Glory,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxv{%
Doer of what He will.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxvi{%
Hath there come unto thee the story of the hosts\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxvii{%
Of Pharaoh and (the tribe of) Thamud?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxviii{%
Nay, but those who disbelieve live in denial\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxix{%
And Allah, all unseen, surroundeth them.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxx{%
Nay, but it is a glorious Qur'an.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxi{%
On a guarded tablet.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxii{%
\basmalahen By the heaven and the Morning Star\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxiii{%
- Ah, what will tell thee what the Morning Star is!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxiv{%
- The piercing Star!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxv{%
No human soul but hath a guardian over it.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxvi{%
So let man consider from what he is created.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxvii{%
He is created from a gushing fluid\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxviii{%
That issued from between the loins and ribs.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxix{%
Lo! He verily is Able to return him (unto life)\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmxl{%
On the day when hidden thoughts shall be searched out.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmxli{%
Then will he have no might nor any helper.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlii{%
By the heaven which giveth the returning rain,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmxliii{%
And the earth which splitteth (with the growth of trees and plants)\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmxliv{%
Lo! this (Qur'an) is a conclusive word,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlv{%
It is no pleasantry.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlvi{%
Lo! they plot a plot (against thee, O Muhammad)\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlvii{%
And I plot a plot (against them).\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlviii{%
So give a respite to the disbelievers. Deal thou gently with them for a while.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlix{%
\basmalahen Praise the name of thy Lord the Most High,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcml{%
Who createth, then disposeth;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmli{%
Who measureth, then guideth;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmlii{%
Who bringeth forth the pasturage,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmliii{%
Then turneth it to russet stubble.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmliv{%
We shall make thee read (O Muhammad) so that thou shalt not forget\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmlv{%
Save that which Allah willeth. Lo! He knoweth the disclosed and that which still is hidden;\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmlvi{%
And We shall ease thy way unto the state of ease.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmlvii{%
Therefor remind (men), for of use is the reminder.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmlviii{%
He will heed who feareth,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmlix{%
But the most hapless will flout it,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmlx{%
He who will be flung to the great Fire\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxi{%
Wherein he will neither die nor live.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxii{%
He is successful who groweth,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxiii{%
And remembereth the name of his Lord, so prayeth,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxiv{%
But ye prefer the life of the world\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxv{%
Although the Hereafter is better and more lasting.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxvi{%
Lo! This is in the former scrolls.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxvii{%
The Books of Abraham and Moses.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxviii{%
\basmalahen Hath there come unto thee tidings of the Overwhelming?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxix{%
On that day (many) faces will be downcast,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxx{%
Toiling, weary,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxi{%
Scorched by burning fire,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxii{%
Drinking from a boiling spring,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxiii{%
No food for them save bitter thorn-fruit\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxiv{%
Which doth not nourish nor release from hunger.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxv{%
In that day other faces will be calm,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxvi{%
Glad for their effort past,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxvii{%
In a high Garden\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxviii{%
Where they hear no idle speech,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxix{%
Wherein is a gushing spring,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxx{%
Wherein are couches raised\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxi{%
And goblets set at hand\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxii{%
And cushions ranged\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiii{%
And silken carpets spread.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiv{%
Will they not regard the camels, how they are created?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxv{%
And the heaven, how it is raised?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvi{%
And the hills, how they are set up?\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvii{%
And the earth, how it is spread?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxviii{%
Remind them, for thou art but a remembrancer,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxix{%
Thou art not at all a warder over them.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmxc{%
But whoso is averse and disbelieveth,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcmxci{%
Allah will punish him with direst punishment.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcii{%
Lo! unto Us is their return\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcmxciii{%
And Ours their reckoning.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcmxciv{%
\basmalahen By the Dawn\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcv{%
And ten nights,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcvi{%
And the Even and the Odd,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcvii{%
And the night when it departeth,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcviii{%
There surely is an oath for thinking man.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcix{%
Dost thou not consider how thy Lord dealt with (the tribe of) A'ad,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmm{%
With many-columned Iram,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmi{%
The like of which was not created in the lands;\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmii{%
And with (the tribe of) Thamud, who clove the rocks in the valley;\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmiii{%
And with Pharaoh, firm of might,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmiv{%
Who (all) were rebellious (to Allah) in these lands,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmv{%
And multiplied iniquity therein?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmvi{%
Therefore thy Lord poured on them the disaster of His punishment.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmvii{%
Lo! thy Lord is ever watchful.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmviii{%
As for man, whenever his Lord trieth him by honouring him, and is gracious unto him, he saith: My Lord honoureth me.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmix{%
But whenever He trieth him by straitening his means of life, he saith: My Lord despiseth me.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmx{%
Nay, but ye (for your part) honour not the orphan\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmxi{%
And urge not on the feeding of the poor.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmxii{%
And ye devour heritages with devouring greed.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmxiii{%
And love wealth with abounding love.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmxiv{%
Nay, but when the earth is ground to atoms, grinding, grinding,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmmxv{%
And thy Lord shall come with angels, rank on rank,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmmxvi{%
And hell is brought near that day; on that day man will remember, but how will the remembrance (then avail him)?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmmxvii{%
He will say: Ah, would that I had sent before me (some provision) for my life!\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmmxviii{%
None punisheth as He will punish on that day!\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmmxix{%
None bindeth as He then will bind.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmmxx{%
But ah! thou soul at peace!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmmxxi{%
Return unto thy Lord, content in His good pleasure!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmmxxii{%
Enter thou among My bondmen!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmmxxiii{%
Enter thou My Garden!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmmxxiv{%
\basmalahen Nay, I swear by this city -\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxxv{%
And thou art an indweller of this city -\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxxvi{%
And the begetter and that which he begat,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxxvii{%
We verily have created man in an atmosphere:\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxxviii{%
Thinketh he that none hath power over him?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxxix{%
And he saith: I have destroyed vast wealth:\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmxxx{%
Thinketh he that none beholdeth him?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxi{%
Did We not assign unto him two eyes\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxii{%
And a tongue and two lips,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxiii{%
And guide him to the parting of the mountain ways?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxiv{%
But he hath not attempted the Ascent -\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxv{%
Ah, what will convey unto thee what the Ascent is! -\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxvi{%
(It is) to free a slave,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxvii{%
And to feed in the day of hunger.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxviii{%
An orphan near of kin,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxix{%
Or some poor wretch in misery,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmxl{%
And to be of those who believe and exhort one another to perseverance and exhort one another to pity.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmxli{%
Their place will be on the right hand.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmxlii{%
But those who disbelieve Our revelations, their place will be on the left hand.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmxliii{%
Fire will be an awning over them.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmxliv{%
\basmalahen By the sun and his brightness,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxlv{%
And the moon when she followeth him,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxlvi{%
And the day when it revealeth him,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxlvii{%
And the night when it enshroudeth him,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxlviii{%
And the heaven and Him Who built it,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxlix{%
And the earth and Him Who spread it,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmml{%
And a soul and Him Who perfected it\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmli{%
And inspired it (with conscience of) what is wrong for it and (what is) right for it.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlii{%
He is indeed successful who causeth it to grow,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmliii{%
And he is indeed a failure who stunteth it.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmliv{%
(The tribe of) Thamud denied (the truth) in their rebellious pride,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmlv{%
When the basest of them broke forth\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmlvi{%
And the messenger of Allah said: It is the she-camel of Allah, so let her drink!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmlvii{%
But they denied him, and they hamstrung her, so Allah doomed them for their sin and rased (their dwellings).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmlviii{%
He dreadeth not the sequel (of events).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmlix{%
\basmalahen By the night enshrouding\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmlx{%
And the day resplendent\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmlxi{%
And Him Who hath created male and female,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmlxii{%
Lo! your effort is dispersed (toward divers ends).\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmlxiii{%
As for him who giveth and is dutiful (toward Allah)\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmlxiv{%
And believeth in goodness;\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmlxv{%
Surely We will ease his way unto the state of ease.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmlxvi{%
But as for him who hoardeth and deemeth himself independent,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlxvii{%
And disbelieveth in goodness;\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmlxviii{%
Surely We will ease his way unto adversity.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmlxix{%
His riches will not save him when he perisheth.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmlxx{%
Lo! Ours it is (to give) the guidance\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxi{%
And lo! unto Us belong the latter portion and the former.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxii{%
Therefor have I warned you of the flaming Fire\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxiii{%
Which only the most wretched must endure,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxiv{%
He who denieth and turneth away.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxv{%
Far removed from it will be the righteous\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxvi{%
Who giveth his wealth that he may grow (in goodness).\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxvii{%
And none hath with him any favour for reward,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxviii{%
Except as seeking (to fulfil) the purpose of his Lord Most High.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxix{%
He verily will be content.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxx{%
\basmalahen By the morning hours\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxi{%
And by the night when it is stillest,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxii{%
Thy Lord hath not forsaken thee nor doth He hate thee,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxiii{%
And verily the latter portion will be better for thee than the former,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxiv{%
And verily thy Lord will give unto thee so that thou wilt be content.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxv{%
Did He not find thee an orphan and protect (thee)?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxvi{%
Did He not find thee wandering and direct (thee)?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxvii{%
Did He not find thee destitute and enrich (thee)?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxviii{%
Therefor the orphan oppress not,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxix{%
Therefor the beggar drive not away,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmxc{%
Therefor of the bounty of thy Lord be thy discourse.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmxci{%
\basmalahen Have We not caused thy bosom to dilate,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxcii{%
And eased thee of the burden\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxciii{%
Which weighed down thy back;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxciv{%
And exalted thy fame?\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxcv{%
But lo! with hardship goeth ease,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxcvi{%
Lo! with hardship goeth ease;\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmxcvii{%
So when thou art relieved, still toil\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmxcviii{%
And strive to please thy Lord.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmxcix{%
\basmalahen By the fig and the olive,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmc{%
By Mount Sinai,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmci{%
And by this land made safe;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcii{%
Surely We created man of the best stature\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmciii{%
Then we reduced him to the lowest of the low,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmciv{%
Save those who believe and do good works, and theirs is a reward unfailing.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcv{%
So who henceforth will give the lie to thee about the judgment?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcvi{%
Is not Allah the most conclusive of all judges?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcvii{%
\basmalahen Read: In the name of thy Lord Who createth,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcviii{%
Createth man from a clot.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcix{%
Read: And thy Lord is the Most Bounteous,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcx{%
Who teacheth by the pen,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxi{%
Teacheth man that which he knew not.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxii{%
Nay, but verily man is rebellious\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxiii{%
That he thinketh himself independent!\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxiv{%
Lo! unto thy Lord is the return.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxv{%
Hast thou seen him who dissuadeth\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmcxvi{%
A slave when he prayeth?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmcxvii{%
Hast thou seen if he relieth on the guidance (of Allah)\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmcxviii{%
Or enjoineth piety?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmcxix{%
Hast thou seen if he denieth (Allah's guidance) and is froward?\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmcxx{%
Is he then unaware that Allah seeth?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxi{%
Nay, but if he cease not We will seize him by the forelock -\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxii{%
The lying, sinful forelock -\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxiii{%
Then let him call upon his henchmen!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxiv{%
We will call the guards of hell.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxv{%
Nay, Obey not thou him. But prostrate thyself, and draw near (unto Allah).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxvi{%
\basmalahen Lo! We revealed it on the Night of Predestination.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxvii{%
Ah, what will convey unto thee what the Night of Power is!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxviii{%
The Night of Power is better than a thousand months.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxix{%
The angels and the Spirit descend therein, by the permission of their Lord, with all decrees.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxx{%
(The night is) Peace until the rising of the dawn.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxi{%
\basmalahen Those who disbelieve among the People of the Scripture and the idolaters could not have left off (erring) till the clear proof came unto them,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxii{%
A messenger from Allah, reading purified pages\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxiii{%
Containing correct scriptures.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxiv{%
Nor were the People of the Scripture divided until after the clear proof came unto them.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxv{%
And they are ordered naught else than to serve Allah, keeping religion pure for Him, as men by nature upright, and to establish worship and to pay the poor-due. That is true religion.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxvi{%
Lo! those who disbelieve, among the People of the Scripture and the idolaters, will abide in fire of hell. They are the worst of created beings.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxvii{%
(And) lo! those who believe and do good works are the best of created beings.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxviii{%
Their reward is with their Lord: Gardens of Eden underneath which rivers flow, wherein they dwell for ever. Allah hath pleasure in them and they have pleasure in Him. This is (in store) for him who feareth his Lord.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxix{%
\basmalahen When Earth is shaken with her (final) earthquake\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxl{%
And Earth yieldeth up her burdens,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxli{%
And man saith: What aileth her?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlii{%
That day she will relate her chronicles,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxliii{%
Because thy Lord inspireth her.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxliv{%
That day mankind will issue forth in scattered groups to be shown their deeds.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlv{%
And whoso doeth good an atom's weight will see it then,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlvi{%
And whoso doeth ill an atom's weight will see it then.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlvii{%
\basmalahen By the snorting courses,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlviii{%
Striking sparks of fire\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlix{%
And scouring to the raid at dawn,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcl{%
Then, therewith, with their trail of dust,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcli{%
Cleaving, as one, the centre (of the foe),\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclii{%
Lo! man is an ingrate unto his Lord\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcliii{%
And lo! he is a witness unto that;\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcliv{%
And lo! in the love of wealth he is violent.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclv{%
Knoweth he not that, when the contents of the graves are poured forth\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclvi{%
And the secrets of the breasts are made known,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmclvii{%
On that day will their Lord be perfectly informed concerning them.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmclviii{%
\basmalahen The Calamity!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclix{%
What is the Calamity?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclx{%
Ah, what will convey unto thee what the Calamity is!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxi{%
A day wherein mankind will be as thickly-scattered moths\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxii{%
And the mountains will become as carded wool.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxiii{%
Then, as for him whose scales are heavy (with good works),\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxiv{%
He will live a pleasant life.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxv{%
But as for him whose scales are light,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxvi{%
A bereft and Hungry One will be his mother,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclxvii{%
Ah, what will convey unto thee what she is! -\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmclxviii{%
Raging Fire.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmclxix{%
\basmalahen Rivalry in worldly increase distracteth you\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxx{%
Until ye come to the graves.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxi{%
Nay, but ye will come to know!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxii{%
Nay, but ye will come to know!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxiii{%
Nay, would that ye knew (now) with a sure knowledge!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxiv{%
For ye will behold hell-fire.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxv{%
Aye, ye will behold it with sure vision.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxvi{%
Then, on that day, ye will be asked concerning pleasure.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxvii{%
\basmalahen By the declining day,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxviii{%
Lo! man is a state of loss,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxix{%
Save those who believe and do good works, and exhort one another to truth and exhort one another to endurance.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxx{%
\basmalahen Woe unto every slandering traducer,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxi{%
Who hath gathered wealth (of this world) and arranged it.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxii{%
He thinketh that his wealth will render him immortal.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxiii{%
Nay, but verily he will be flung to the Consuming One.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxiv{%
Ah, what will convey unto thee what the Consuming One is!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxv{%
(It is) the fire of Allah, kindled,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxvi{%
Which leapeth up over the hearts (of men).\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxvii{%
Lo! it is closed in on them\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxviii{%
In outstretched columns.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxix{%
\basmalahen Hast thou not seen how thy Lord dealt with the owners of the Elephant?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxc{%
Did He not bring their stratagem to naught,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxci{%
And send against them swarms of flying creatures,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcii{%
Which pelted them with stones of baked clay,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxciii{%
And made them like green crops devoured (by cattle)?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxciv{%
\basmalahen For the taming of Qureysh.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcv{%
For their taming (We cause) the caravans to set forth in winter and summer.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcvi{%
So let them worship the Lord of this House,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcvii{%
Who hath fed them against hunger and hath made them safe from fear.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcviii{%
\basmalahen Hast thou observed him who belieth religion?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcix{%
That is he who repelleth the orphan,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcc{%
And urgeth not the feeding of the needy.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcci{%
Ah, woe unto worshippers\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccii{%
Who are heedless of their prayer;\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcciii{%
Who would be seen (at worship)\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcciv{%
Yet refuse small kindnesses!\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmccv{%
\basmalahen Lo! We have given thee Abundance;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccvi{%
So pray unto thy Lord, and sacrifice.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccvii{%
Lo! it is thy insulter (and not thou) who is without posterity.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccviii{%
\basmalahen Say: O disbelievers!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccix{%
I worship not that which ye worship;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccx{%
Nor worship ye that which I worship.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxi{%
And I shall not worship that which ye worship.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxii{%
Nor will ye worship that which I worship.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxiii{%
Unto you your religion, and unto me my religion.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmccxiv{%
\basmalahen When Allah's succour and the triumph cometh\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxv{%
And thou seest mankind entering the religion of Allah in troops,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxvi{%
Then hymn the praises of thy Lord, and seek forgiveness of Him. Lo! He is ever ready to show mercy.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxvii{%
\basmalahen The power of Abu Lahab will perish, and he will perish.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxviii{%
His wealth and gains will not exempt him.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxix{%
He will be plunged in flaming Fire,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxx{%
And his wife, the wood-carrier,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxi{%
Will have upon her neck a halter of palm-fibre.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxii{%
\basmalahen Say: He is Allah, the One!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxiii{%
Allah, the eternally Besought of all!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxiv{%
He begetteth not nor was begotten.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxv{%
And there is none comparable unto Him.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxvi{%
\basmalahen Say: I seek refuge in the Lord of the Daybreak\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxvii{%
From the evil of that which He created;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxviii{%
From the evil of the darkness when it is intense,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxix{%
And from the evil of malignant witchcraft,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxx{%
And from the evil of the envier when he envieth.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxi{%
\basmalahen Say: I seek refuge in the Lord of mankind,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxii{%
The King of mankind,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxiii{%
The god of mankind,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxiv{%
From the evil of the sneaking whisperer,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxv{%
Who whispereth in the hearts of mankind,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxvi{%
Of the jinn and of mankind.\qt@no{6}}%
%% End of file `qurantext-enix.translation.def'
