\qt@newcmd\qurantrans@en@i{%
In the name of God, the Gracious, the Merciful.\qt@no{1}}%
\qt@newcmd\qurantrans@en@ii{%
Praise be to God, Lord of the Worlds.\qt@no{2}}%
\qt@newcmd\qurantrans@en@iii{%
The Most Gracious, the Most Merciful.\qt@no{3}}%
\qt@newcmd\qurantrans@en@iv{%
Master of the Day of Judgment.\qt@no{4}}%
\qt@newcmd\qurantrans@en@v{%
It is You we worship, and upon You we call for help.\qt@no{5}}%
\qt@newcmd\qurantrans@en@vi{%
Guide us to the straight path.\qt@no{6}}%
\qt@newcmd\qurantrans@en@vii{%
The path of those You have blessed, not of those against whom there is anger, nor of those who are misguided.\qt@no{7}}%
\qt@newcmd\qurantrans@en@viii{%
\basmalahen Alif, Lam, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@ix{%
This is the Book in which there is no doubt, a guide for the righteous.\qt@no{2}}%
\qt@newcmd\qurantrans@en@x{%
Those who believe in the unseen, and perform the prayers, and give from what We have provided for them.\qt@no{3}}%
\qt@newcmd\qurantrans@en@xi{%
And those who believe in what was revealed to you, and in what was revealed before you, and are certain of the Hereafter.\qt@no{4}}%
\qt@newcmd\qurantrans@en@xii{%
These are upon guidance from their Lord. These are the successful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@xiii{%
As for those who disbelieve—it is the same for them, whether you have warned them, or have not warned them—they do not believe.\qt@no{6}}%
\qt@newcmd\qurantrans@en@xiv{%
God has set a seal on their hearts and on their hearing, and over their vision is a veil. They will have a severe torment.\qt@no{7}}%
\qt@newcmd\qurantrans@en@xv{%
Among the people are those who say, “We believe in God and in the Last Day,” but they are not believers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@xvi{%
They seek to deceive God and those who believe, but they deceive none but themselves, though they are not aware.\qt@no{9}}%
\qt@newcmd\qurantrans@en@xvii{%
In their hearts is sickness, and God has increased their sickness. They will have a painful punishment because of their denial.\qt@no{10}}%
\qt@newcmd\qurantrans@en@xviii{%
And when it is said to them, “Do not make trouble on earth,” they say, “We are only reformers.”\qt@no{11}}%
\qt@newcmd\qurantrans@en@xix{%
In fact, they are the troublemakers, but they are not aware.\qt@no{12}}%
\qt@newcmd\qurantrans@en@xx{%
And when it is said to them, “Believe as the people have believed,” they say, “Shall we believe as the fools have believed?” In fact, it is they who are the fools, but they do not know.\qt@no{13}}%
\qt@newcmd\qurantrans@en@xxi{%
And when they come across those who believe, they say, “We believe”; but when they are alone with their devils, they say, “We are with you; we were only ridiculing.”\qt@no{14}}%
\qt@newcmd\qurantrans@en@xxii{%
It is God who ridicules them, and leaves them bewildered in their transgression.\qt@no{15}}%
\qt@newcmd\qurantrans@en@xxiii{%
Those are they who have bartered error for guidance; but their trade does not profit them, and they are not guided.\qt@no{16}}%
\qt@newcmd\qurantrans@en@xxiv{%
Their likeness is that of a person who kindled a fire; when it illuminated all around him, God took away their light, and left them in darkness, unable to see.\qt@no{17}}%
\qt@newcmd\qurantrans@en@xxv{%
Deaf, dumb, blind. They will not return.\qt@no{18}}%
\qt@newcmd\qurantrans@en@xxvi{%
Or like a cloudburst from the sky, in which is darkness, and thunder, and lightning. They press their fingers into their ears from the thunderbolts, in fear of death. But God surrounds the disbelievers.\qt@no{19}}%
\qt@newcmd\qurantrans@en@xxvii{%
The lightning almost snatches their sight away. Whenever it illuminates for them, they walk in it; but when it grows dark over them, they stand still. Had God willed, He could have taken away their hearing and their sight. God is capable of everything.\qt@no{20}}%
\qt@newcmd\qurantrans@en@xxviii{%
O people! Worship your Lord who created you and those before you, that you may attain piety.\qt@no{21}}%
\qt@newcmd\qurantrans@en@xxix{%
He who made the earth a habitat for you, and the sky a structure, and sends water down from the sky, and brings out fruits thereby, as a sustenance for you. Therefore, do not assign rivals to God while you know.\qt@no{22}}%
\qt@newcmd\qurantrans@en@xxx{%
And if you are in doubt about what We have revealed to Our servant, then produce a chapter like these, and call your witnesses apart from God, if you are truthful.\qt@no{23}}%
\qt@newcmd\qurantrans@en@xxxi{%
But if you do not—and you will not—then beware the Fire whose fuel is people and stones, prepared for the disbelievers.\qt@no{24}}%
\qt@newcmd\qurantrans@en@xxxii{%
And give good news to those who believe and do righteous deeds; that they will have gardens beneath which rivers flow. Whenever they are provided with fruit therefrom as sustenance, they will say, “This is what we were provided with before,” and they will be given the like of it. And they will have pure spouses therein, and they will abide therein forever.\qt@no{25}}%
\qt@newcmd\qurantrans@en@xxxiii{%
God does not shy away from making an example of a gnat, or something above it. As for those who believe, they know that it is the Truth from their Lord. But as for those who disbelieve, they say, “What did God intend by this example?” He leads astray many thereby, and He guides many thereby; but He misleads thereby only the evildoers.\qt@no{26}}%
\qt@newcmd\qurantrans@en@xxxiv{%
Those who violate God’s covenant after its confirmation, and sever what God has commanded to be joined, and commit evil on earth. These are the losers.\qt@no{27}}%
\qt@newcmd\qurantrans@en@xxxv{%
How can you deny God, when you were dead and He gave you life, then He will put you to death, then He will bring you to life, then to Him you will be returned?\qt@no{28}}%
\qt@newcmd\qurantrans@en@xxxvi{%
It is He who created for you everything on earth, then turned to the heaven, and made them seven heavens. And He is aware of all things.\qt@no{29}}%
\qt@newcmd\qurantrans@en@xxxvii{%
When your Lord said to the angels, “I am placing a successor on earth.” They said, “Will You place in it someone who will cause corruption in it and shed blood, while we declare Your praises and sanctify You?” He said, “I know what you do not know.”\qt@no{30}}%
\qt@newcmd\qurantrans@en@xxxviii{%
And He taught Adam the names, all of them; then he presented them to the angels, and said, “Tell Me the names of these, if you are sincere.”\qt@no{31}}%
\qt@newcmd\qurantrans@en@xxxix{%
They said, “Glory be to You! We have no knowledge except what You have taught us. It is you who are the Knowledgeable, the Wise.”\qt@no{32}}%
\qt@newcmd\qurantrans@en@xl{%
He said, “O Adam, tell them their names.” And when he told them their names, He said, “Did I not tell you that I know the secrets of the heavens and the earth, and that I know what you reveal and what you conceal?”\qt@no{33}}%
\qt@newcmd\qurantrans@en@xli{%
And We said to the angels, “Bow down to Adam.” They bowed down, except for Satan. He refused, was arrogant, and was one of the disbelievers.\qt@no{34}}%
\qt@newcmd\qurantrans@en@xlii{%
We said, “O Adam, inhabit the Garden, you and your spouse, and eat from it freely as you please, but do not approach this tree, lest you become wrongdoers.”\qt@no{35}}%
\qt@newcmd\qurantrans@en@xliii{%
But Satan caused them to slip from it, and caused them to depart the state they were in. We said, “Go down, some of you enemies of one another. And you will have residence on earth, and enjoyment for a while.”\qt@no{36}}%
\qt@newcmd\qurantrans@en@xliv{%
Then Adam received words from his Lord, so He relented towards him. He is the Relenting, the Merciful.\qt@no{37}}%
\qt@newcmd\qurantrans@en@xlv{%
We said, “Go down from it, all of you. Yet whenever guidance comes to you from Me, then whoever follows My guidance—they have nothing to fear, nor shall they grieve.\qt@no{38}}%
\qt@newcmd\qurantrans@en@xlvi{%
But as for those who disbelieve and reject Our signs—these are the inmates of the Fire—wherein they will remain forever.”\qt@no{39}}%
\qt@newcmd\qurantrans@en@xlvii{%
O Children of Israel! Remember My blessings which I bestowed upon you, and fulfill your pledge to Me, and I will fulfill My pledge to you, and fear Me.\qt@no{40}}%
\qt@newcmd\qurantrans@en@xlviii{%
And believe in what I revealed, confirming what is with you; and do not be the first to deny it; and do not exchange My revelations for a small price; and be conscious of Me.\qt@no{41}}%
\qt@newcmd\qurantrans@en@xlix{%
And do not mix truth with falsehood, and do not conceal the truth while you know.\qt@no{42}}%
\qt@newcmd\qurantrans@en@l{%
And attend to your prayers, and practice regular charity, and kneel with those who kneel.\qt@no{43}}%
\qt@newcmd\qurantrans@en@li{%
Do you command people to virtuous conduct, and forget yourselves, even though you read the Scripture? Do you not understand?\qt@no{44}}%
\qt@newcmd\qurantrans@en@lii{%
And seek help through patience and prayer. But it is difficult, except for the devout.\qt@no{45}}%
\qt@newcmd\qurantrans@en@liii{%
Those who know that they will meet their Lord, and that to Him they will return.\qt@no{46}}%
\qt@newcmd\qurantrans@en@liv{%
O Children of Israel! Remember My favor which I bestowed upon you, and I that favored you over all nations.\qt@no{47}}%
\qt@newcmd\qurantrans@en@lv{%
And beware of a Day when no soul will avail another in the least, nor will any intercession be accepted on its behalf, nor will any ransom be taken from it, nor will they be helped.\qt@no{48}}%
\qt@newcmd\qurantrans@en@lvi{%
And recall that We delivered you from the people of Pharaoh. They inflicted on you terrible persecution, killing your sons and sparing your women. Therein was a tremendous trial from your Lord.\qt@no{49}}%
\qt@newcmd\qurantrans@en@lvii{%
And recall that We parted the sea for you, so We saved you, and We drowned the people of Pharaoh as you looked on.\qt@no{50}}%
\qt@newcmd\qurantrans@en@lviii{%
And recall that We appointed for Moses forty nights. Then you took to worshiping the calf after him, and you turned wicked.\qt@no{51}}%
\qt@newcmd\qurantrans@en@lix{%
Then We pardoned you after that, so that you might be grateful.\qt@no{52}}%
\qt@newcmd\qurantrans@en@lx{%
And recall that We gave Moses the Scripture and the Criterion, so that you may be guided.\qt@no{53}}%
\qt@newcmd\qurantrans@en@lxi{%
And recall that Moses said to his people, “O my people, you have done wrong to yourselves by worshiping the calf. So repent to your Maker, and kill your egos. That would be better for you with your Maker.” So He turned to you in repentance. He is the Accepter of Repentance, the Merciful.\qt@no{54}}%
\qt@newcmd\qurantrans@en@lxii{%
And recall that you said, “O Moses, we will not believe in you unless we see God plainly.” Thereupon the thunderbolt struck you, as you looked on.\qt@no{55}}%
\qt@newcmd\qurantrans@en@lxiii{%
Then We revived you after your death, so that you may be appreciative.\qt@no{56}}%
\qt@newcmd\qurantrans@en@lxiv{%
And We shaded you with clouds, and We sent down to you manna and quails: “Eat of the good things We have provided for you.” They did not wrong Us, but they used to wrong their own souls.\qt@no{57}}%
\qt@newcmd\qurantrans@en@lxv{%
And recall that We said, “Enter this town, and eat plentifully from it whatever you wish; but enter the gate humbly, and say, 'Pardon.' We will forgive your sins, and give increase to the virtuous.”\qt@no{58}}%
\qt@newcmd\qurantrans@en@lxvi{%
But the wrongdoers among them substituted words other than those given to them, so We sent down on the wrongdoers a plague from heaven, because of their wicked behavior.\qt@no{59}}%
\qt@newcmd\qurantrans@en@lxvii{%
And recall when Moses prayed for water for his people. We said, “Strike the rock with your staff.” Thereupon twelve springs gushed out from it, and each tribe recognized its drinking-place. “Eat and drink from God’s provision, and do not corrupt the earth with disobedience.”\qt@no{60}}%
\qt@newcmd\qurantrans@en@lxviii{%
And recall when you said, “O Moses, we cannot endure one kind of food, so call to your Lord to produce for us of what the earth grows: of its herbs, and its cucumbers, and its garlic, and its lentils, and its onions.” He said, “Would you substitute worse for better? Go down to Egypt, where you will have what you asked for.” They were struck with humiliation and poverty, and incurred wrath from God. That was because they rejected God’s revelations and wrongfully killed the prophets. That was because they disobeyed and transgressed.\qt@no{61}}%
\qt@newcmd\qurantrans@en@lxix{%
Those who believe, and those who are Jewish, and the Christians, and the Sabeans—any who believe in God and the Last Day, and act righteously—will have their reward with their Lord; they have nothing to fear, nor will they grieve.\qt@no{62}}%
\qt@newcmd\qurantrans@en@lxx{%
And recall when We received a pledge from you, and raised the Mount above you: “Take what We have given you earnestly, and remember what is in it, that you may attain righteousness.”\qt@no{63}}%
\qt@newcmd\qurantrans@en@lxxi{%
But after that you turned away. Were it not for God’s grace and mercy towards you, you would have been among the losers.\qt@no{64}}%
\qt@newcmd\qurantrans@en@lxxii{%
And you surely knew those of you who violated the Sabbath. We said to them, “Be despicable apes!”\qt@no{65}}%
\qt@newcmd\qurantrans@en@lxxiii{%
Thus We made it a deterrent for their generation, and for subsequent generations, and a lesson for the righteous.\qt@no{66}}%
\qt@newcmd\qurantrans@en@lxxiv{%
And recall when Moses said to his people, “God commands you to sacrifice a heifer.” They said, “Do you make a mockery of us?” He said, “God forbid that I should be so ignorant.”\qt@no{67}}%
\qt@newcmd\qurantrans@en@lxxv{%
They said, “Call upon your Lord to show us which one.” He said, “He says she is a heifer, neither too old, nor too young, but in between. So do what you are commanded.”\qt@no{68}}%
\qt@newcmd\qurantrans@en@lxxvi{%
They said, “Call upon your Lord to show us what her color is.” He said, “He says she is a yellow heifer, bright in color, pleasing to the beholders.”\qt@no{69}}%
\qt@newcmd\qurantrans@en@lxxvii{%
They said, “Call upon your Lord to show us which one; the heifers look alike to us; and God willing, we will be guided.”\qt@no{70}}%
\qt@newcmd\qurantrans@en@lxxviii{%
He said, “He says she is a heifer, neither yoked to plow the earth, nor to irrigate the field; sound without blemish.” They said, “Now you have brought the truth.” So they slew her; though they almost did not.\qt@no{71}}%
\qt@newcmd\qurantrans@en@lxxix{%
And recall when you killed a person, and disputed in the matter; but God was to expose what you were hiding.\qt@no{72}}%
\qt@newcmd\qurantrans@en@lxxx{%
We said, “Strike him with part of it.” Thus God brings the dead to life; and He shows you His signs, that you may understand.\qt@no{73}}%
\qt@newcmd\qurantrans@en@lxxxi{%
Then after that your hearts hardened. They were as rocks, or even harder. For there are some rocks from which rivers gush out, and others that splinter and water comes out from them, and others that sink in awe of God. God is not unaware of what you do.\qt@no{74}}%
\qt@newcmd\qurantrans@en@lxxxii{%
Do you hope that they will believe in you, when some of them used to hear the Word of God, and then deliberately distort it, even after understanding it?\qt@no{75}}%
\qt@newcmd\qurantrans@en@lxxxiii{%
And when they come across those who believe, they say, “We believe,” but when they come together privately, they say, “Will you inform them of what God has disclosed to you, so that they might dispute with you concerning it before your Lord?” Do you not understand?\qt@no{76}}%
\qt@newcmd\qurantrans@en@lxxxiv{%
Do they not know that God knows what they conceal and what they reveal?\qt@no{77}}%
\qt@newcmd\qurantrans@en@lxxxv{%
And among them are uneducated who know the Scripture only through hearsay, and they only speculate.\qt@no{78}}%
\qt@newcmd\qurantrans@en@lxxxvi{%
So woe to those who write the Scripture with their own hands, and then say, “This is from God,” that they may exchange it for a little price. Woe to them for what their hands have written, and woe to them for what they earn.\qt@no{79}}%
\qt@newcmd\qurantrans@en@lxxxvii{%
And they say, “The Fire will not touch us except for a number of days.” Say, “Have you received a promise from God—God never breaks His promise—or are you saying about God what you do not know?”\qt@no{80}}%
\qt@newcmd\qurantrans@en@lxxxviii{%
Indeed, whoever commits misdeeds, and becomes besieged by his iniquities—these are the inmates of the Fire, wherein they will dwell forever.\qt@no{81}}%
\qt@newcmd\qurantrans@en@lxxxix{%
As for those who believe and do righteous deeds—these are the inhabitants of Paradise, wherein they will dwell forever.\qt@no{82}}%
\qt@newcmd\qurantrans@en@xc{%
We made a covenant with the Children of Israel: “Worship none but God; and be good to parents, and relatives, and orphans, and the needy; and speak nicely to people; and pray regularly, and give alms.” Then you turned away, except for a few of you, recanting.\qt@no{83}}%
\qt@newcmd\qurantrans@en@xci{%
And We made a covenant with you: “You shall not shed the blood of your own, nor shall you evict your own from your homes.” You agreed, and were all witnesses.\qt@no{84}}%
\qt@newcmd\qurantrans@en@xcii{%
But here you are, killing your own, and expelling a group of your own from their homes—conspiring against them in wrongdoing and hostility. And if they come to you as captives, you ransom them, although it was forbidden to you. Is it that you believe in part of the Scripture, and disbelieve in part? What is the reward for those among you who do that but humiliation in this life? And on the Day of Resurrection, they will be assigned to the most severe torment. God is not unaware of what you do.\qt@no{85}}%
\qt@newcmd\qurantrans@en@xciii{%
Those are they who bought the present life for the Hereafter, so the punishment will not be lightened for them, nor will they be helped.\qt@no{86}}%
\qt@newcmd\qurantrans@en@xciv{%
We gave Moses the Scripture, and sent a succession of messengers after him. And We gave Jesus son of Mary the clear proofs, and We supported him with the Holy Spirit. Is it that whenever a messenger comes to you with anything your souls do not desire, you grew arrogant, calling some impostors, and killing others?\qt@no{87}}%
\qt@newcmd\qurantrans@en@xcv{%
And they said, “Our hearts are sealed.” Rather, God has cursed them for their ingratitude. They have little faith.\qt@no{88}}%
\qt@newcmd\qurantrans@en@xcvi{%
And when a scripture came to them from God, confirming what they have—although previously they were seeking victory against those who disbelieved—but when there came to them what they recognized, they disbelieved in it. So God’s curse is upon the disbelievers.\qt@no{89}}%
\qt@newcmd\qurantrans@en@xcvii{%
Miserable is what they sold their souls for—rejecting what God has revealed, out of resentment that God would send down His grace upon whomever He chooses from among His servants. Thus they incurred wrath upon wrath. And there is a demeaning punishment for the disbelievers.\qt@no{90}}%
\qt@newcmd\qurantrans@en@xcviii{%
And when it is said to them, “Believe in what God has revealed,” they say, “We believe in what was revealed to us,” and they reject anything beyond that, although it is the truth which confirms what they have. Say, “Why did you kill God’s prophets before, if you were believers?”\qt@no{91}}%
\qt@newcmd\qurantrans@en@xcix{%
Moses came to you with clear proofs, yet you adopted the calf in his absence, and you were in the wrong.\qt@no{92}}%
\qt@newcmd\qurantrans@en@c{%
And We made a covenant with you, and raised the Mount above you: “Take what We have given you firmly, and listen.” They said, “We hear and disobey.” And their hearts became filled with the love of the calf because of their disbelief. Say, “Wretched is what your faith commands you to do, if you are believers.”\qt@no{93}}%
\qt@newcmd\qurantrans@en@ci{%
Say, “If the Final Home with God is yours alone, to the exclusion of all other people, then wish for death if you are sincere.”\qt@no{94}}%
\qt@newcmd\qurantrans@en@cii{%
But they will never wish for it, because of what their hands have forwarded. God is aware of the evildoers.\qt@no{95}}%
\qt@newcmd\qurantrans@en@ciii{%
You will find them, of all mankind, the most eager for life, even more than the polytheists. Every one of them wishes he could live a thousand years; but to be granted a long life will not nudge him from the punishment. God is Seeing of what they do.\qt@no{96}}%
\qt@newcmd\qurantrans@en@civ{%
Say, “Whoever is hostile to Gabriel—it is he who revealed it to your heart by God’s leave, confirming what preceded it, and guidance and good news for the believers.”\qt@no{97}}%
\qt@newcmd\qurantrans@en@cv{%
Whoever is hostile to God, and His angels, and His messengers, and Gabriel, and Michael—God is hostile to the faithless.\qt@no{98}}%
\qt@newcmd\qurantrans@en@cvi{%
We have revealed to you clear signs, and none rejects them except the sinners.\qt@no{99}}%
\qt@newcmd\qurantrans@en@cvii{%
Is it not that whenever they make a covenant, some of them toss it aside? In fact, most of them do not believe.\qt@no{100}}%
\qt@newcmd\qurantrans@en@cviii{%
And when there came to them a messenger from God, confirming what they had, a faction of those who were given the Book threw the Book of God behind their backs, as if they do not know.\qt@no{101}}%
\qt@newcmd\qurantrans@en@cix{%
And they followed what the devils taught during the reign of Salomon. It was not Solomon who disbelieved, but it was the devils who disbelieved. They taught the people witchcraft and what was revealed in Babylon to the two angels Harut and Marut. They did not teach anybody until they had said, “We are a test, so do not lose faith.” But they learned from them the means to cause separation between man and his wife. But they cannot harm anyone except with God's permission. And they learned what would harm them and not benefit them. Yet they knew that whoever deals in it will have no share in the Hereafter. Miserable is what they sold their souls for, if they only knew.\qt@no{102}}%
\qt@newcmd\qurantrans@en@cx{%
Had they believed and been righteous, the reward from God would have been better, if they only knew.\qt@no{103}}%
\qt@newcmd\qurantrans@en@cxi{%
O you who believe! Do not say ambiguous words, but say words of respect, and listen. The disbelievers will have a painful torment.\qt@no{104}}%
\qt@newcmd\qurantrans@en@cxii{%
It is never the wish of the disbelievers from among the People of the Book, nor of the polytheists, that any good should be sent down to you from your Lord. But God chooses for His mercy whomever He wills. God is Possessor of Sublime Grace.\qt@no{105}}%
\qt@newcmd\qurantrans@en@cxiii{%
We never nullify a verse, nor cause it to be forgotten, unless We bring one better than it, or similar to it. Do you not know that God is capable of all things?\qt@no{106}}%
\qt@newcmd\qurantrans@en@cxiv{%
Do you not know that to God belongs the sovereignty of the heavens and the earth, and that apart from God you have no guardian or helper?\qt@no{107}}%
\qt@newcmd\qurantrans@en@cxv{%
Or do you want to question your Messenger as Moses was questioned before? Whoever exchanges faith for disbelief has strayed from the right path.\qt@no{108}}%
\qt@newcmd\qurantrans@en@cxvi{%
Many of the People of the Book wish to turn you back into unbelievers after you have believed, out of envy on their part, after the Truth has become clear to them. But pardon and overlook, until God brings His command. God has power over all things.\qt@no{109}}%
\qt@newcmd\qurantrans@en@cxvii{%
And perform the prayer, and give alms. Whatever good you forward for yourselves, you will find it with God. God is Seeing of everything you do.\qt@no{110}}%
\qt@newcmd\qurantrans@en@cxviii{%
And they say, “None will enter Heaven unless he is a Jew or a Christian.” These are their wishes. Say, “Produce your proof, if you are truthful.”\qt@no{111}}%
\qt@newcmd\qurantrans@en@cxix{%
In fact, whoever submits himself to God, and is a doer of good, will have his reward with his Lord—they have nothing to fear, nor shall they grieve.\qt@no{112}}%
\qt@newcmd\qurantrans@en@cxx{%
The Jews say, “The Christians are not based on anything;” and the Christians say, “The Jews are not based on anything.” Yet they both read the Scripture. Similarly, the ignorant said the same thing. God will judge between them on the Day of Resurrection regarding their differences.\qt@no{113}}%
\qt@newcmd\qurantrans@en@cxxi{%
Who is more unjust than him who forbids the remembrance of God’s name in places of worship, and contributes to their ruin? These ought not to enter them except in fear. For them is disgrace in this world, and for them is a terrible punishment in the Hereafter.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cxxii{%
To God belong the East and the West. Whichever way you turn, there is God’s presence. God is Omnipresent and Omniscient.\qt@no{115}}%
\qt@newcmd\qurantrans@en@cxxiii{%
And they say, “God has begotten a son.” Be He glorified. Rather, His is everything in the heavens and the earth; all are obedient to Him.\qt@no{116}}%
\qt@newcmd\qurantrans@en@cxxiv{%
Originator of the heavens and the earth. Whenever He decrees a thing, He says to it, “Be,” and it becomes.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cxxv{%
Those who do not know say, “If only God would speak to us, or a sign would come to us.” Thus said those who were before them. Their hearts are alike. We have made the signs clear for people who are certain.\qt@no{118}}%
\qt@newcmd\qurantrans@en@cxxvi{%
We have sent you with the truth—bringing good news, and giving warnings. You will not be questioned about the inmates of Hell.\qt@no{119}}%
\qt@newcmd\qurantrans@en@cxxvii{%
The Jews and the Christians will not approve of you, unless you follow their creed. Say, “God’s guidance is the guidance.” Should you follow their desires, after the knowledge that has come to you, you will have in God neither guardian nor helper.\qt@no{120}}%
\qt@newcmd\qurantrans@en@cxxviii{%
Those to whom We have given the Scripture follow it, as it ought to be followed—these believe in it. But as for those who reject it—these are the losers.\qt@no{121}}%
\qt@newcmd\qurantrans@en@cxxix{%
O Children of Israel! Remember My blessing which I bestowed upon you, and that I have favored you over all people.\qt@no{122}}%
\qt@newcmd\qurantrans@en@cxxx{%
And beware of a Day when no soul will avail another soul in any way, and no ransom will be accepted from it, and no intercession will benefit it, and they will not be helped.\qt@no{123}}%
\qt@newcmd\qurantrans@en@cxxxi{%
And when his Lord tested Abraham with certain words, and he fulfilled them. He said, “I am making you a leader of humanity.” He said, “And my descendants?” He said, “My pledge does not include the wrongdoers.”\qt@no{124}}%
\qt@newcmd\qurantrans@en@cxxxii{%
And We made the House a focal point for the people, and a sanctuary. Use the shrine of Abraham as a place of prayer. And We commissioned Abraham and Ishmael, “Sanctify My House for those who circle around it, and those who seclude themselves in it, and those who kneel and prostrate.”\qt@no{125}}%
\qt@newcmd\qurantrans@en@cxxxiii{%
When Abraham said, “O My Lord, make this a peaceful land, and provide its people with fruits—whoever of them believes in God and the Last Day.” He said, “And whoever disbelieves, I will give him a little enjoyment, then I will consign him to the punishment of the Fire; how miserable the destiny!”\qt@no{126}}%
\qt@newcmd\qurantrans@en@cxxxiv{%
As Abraham raises the foundations of the House, together with Ishmael, “Our Lord, accept it from us, You are the Hearer, the Knower.\qt@no{127}}%
\qt@newcmd\qurantrans@en@cxxxv{%
Our Lord, and make us submissive to You, and from our descendants a community submissive to You. And show us our rites, and accept our repentance. You are the Acceptor of Repentance, the Merciful.\qt@no{128}}%
\qt@newcmd\qurantrans@en@cxxxvi{%
Our Lord, and raise up among them a messenger, of themselves, who will recite to them Your revelations, and teach them the Book and wisdom, and purify them. You are the Almighty, the Wise.”\qt@no{129}}%
\qt@newcmd\qurantrans@en@cxxxvii{%
Who would forsake the religion of Abraham, except he who fools himself? We chose him in this world, and in the Hereafter he will be among the righteous.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cxxxviii{%
When his Lord said to him, “Submit!” He said, “I have submitted to the Lord of the Worlds.”\qt@no{131}}%
\qt@newcmd\qurantrans@en@cxxxix{%
And Abraham exhorted his sons, and Jacob, “O my sons, God has chosen this religion for you, so do not die unless you have submitted.”\qt@no{132}}%
\qt@newcmd\qurantrans@en@cxl{%
Or were you witnesses when death approached Jacob, and he said to his sons, “What will you worship after Me?” They said, “We will worship your God, and the God of your fathers, Abraham, Ishmael, and Isaac; One God; and to Him we submit.”\qt@no{133}}%
\qt@newcmd\qurantrans@en@cxli{%
That was a community that has passed; for them is what they have earned, and for you is what you have earned; and you will not be questioned about what they used to do.\qt@no{134}}%
\qt@newcmd\qurantrans@en@cxlii{%
And they say, “Be Jews or Christians, and you will be guided.” Say, “Rather, the religion of Abraham, the Monotheist; he was not an idolater.”\qt@no{135}}%
\qt@newcmd\qurantrans@en@cxliii{%
Say, “We believe in God; and in what was revealed to us; and in what was revealed to Abraham, and Ishmael, and Isaac, and Jacob, and the Patriarchs; and in what was given to Moses and Jesus; and in what was given to the prophets—from their Lord. We make no distinction between any of them, and to Him we surrender.”\qt@no{136}}%
\qt@newcmd\qurantrans@en@cxliv{%
If they believe in the same as you have believed in, then they have been guided. But if they turn away, then they are in schism. God will protect you against them; for He is the Hearer, the Knower.\qt@no{137}}%
\qt@newcmd\qurantrans@en@cxlv{%
God’s coloring. And who gives better coloring than God? “And we are devoted to Him.”\qt@no{138}}%
\qt@newcmd\qurantrans@en@cxlvi{%
Say, “Do you argue with us about God, when He is our Lord and your Lord, and We have our works, and you have your works, and we are sincere to Him?”\qt@no{139}}%
\qt@newcmd\qurantrans@en@cxlvii{%
Or do you say that Abraham, Ishmael, Isaac, Jacob, and the Patriarchs were Jews or Christians? Say, “Do you know better, or God?” And who does greater wrong than he who conceals a testimony he has from God? God is not unaware of what you do.\qt@no{140}}%
\qt@newcmd\qurantrans@en@cxlviii{%
That was a community that has passed. To them is what they have earned, and to you is what you have earned. And you will not be questioned about what they used to do.\qt@no{141}}%
\qt@newcmd\qurantrans@en@cxlix{%
The ignorant among the people will say, “What has turned them away from the direction of prayer they once followed?” Say, “To God belong the East and the West. He guides whom He wills to a straight path.”\qt@no{142}}%
\qt@newcmd\qurantrans@en@cl{%
Thus We made you a moderate community, that you may be witnesses to humanity, and that the Messenger may be a witness to you. We only established the direction of prayer, which you once followed, that We may distinguish those who follow the Messenger from those who turn on their heels. It is indeed difficult, except for those whom God has guided. But God would never let your faith go to waste. God is Kind towards the people, Merciful.\qt@no{143}}%
\qt@newcmd\qurantrans@en@cli{%
We have seen your face turned towards the heaven. So We will turn you towards a direction that will satisfy you. So turn your face towards the Sacred Mosque. And wherever you may be, turn your faces towards it. Those who were given the Book know that it is the Truth from their Lord; and God is not unaware of what they do.\qt@no{144}}%
\qt@newcmd\qurantrans@en@clii{%
Even if you were to bring to those who were given the Book every proof, they would not follow your direction, nor are you to follow their direction, nor do they follow the direction of one another. And if you were to follow their desires, after the knowledge that has come to you, you would be in that case one of the wrongdoers.\qt@no{145}}%
\qt@newcmd\qurantrans@en@cliii{%
Those to whom We have given the Book recognize it as they recognize their own children. But some of them conceal the truth while they know.\qt@no{146}}%
\qt@newcmd\qurantrans@en@cliv{%
The truth is from your Lord, so do not be a skeptic.\qt@no{147}}%
\qt@newcmd\qurantrans@en@clv{%
To every community is a direction towards which it turns. Therefore, race towards goodness. Wherever you may be, God will bring you all together. God is capable of everything.\qt@no{148}}%
\qt@newcmd\qurantrans@en@clvi{%
And wherever you come from, turn your face towards the Sacred Mosque. This is the truth from your Lord, and God is not heedless of what you do.\qt@no{149}}%
\qt@newcmd\qurantrans@en@clvii{%
And wherever you come from, turn your face towards the Sacred Mosque. And wherever you may be, turn your faces towards it. So that the people may not have any argument against you—except those who do wrong among them. So do not fear them, but fear Me, that I may complete My blessings upon you, and that you may be guided.\qt@no{150}}%
\qt@newcmd\qurantrans@en@clviii{%
Just as We sent to you a messenger from among you, who recites Our revelations to you, and purifies you, and teaches you the Book and wisdom, and teaches you what you did not know.\qt@no{151}}%
\qt@newcmd\qurantrans@en@clix{%
So remember Me, and I will remember you. And thank Me, and do not be ungrateful.\qt@no{152}}%
\qt@newcmd\qurantrans@en@clx{%
O you who believe! Seek help through patience and prayers. God is with the steadfast.\qt@no{153}}%
\qt@newcmd\qurantrans@en@clxi{%
And do not say of those who are killed in the cause of God, “Dead.” Rather, they are alive, but you do not perceive.\qt@no{154}}%
\qt@newcmd\qurantrans@en@clxii{%
We will certainly test you with some fear and hunger, and some loss of possessions and lives and crops. But give good news to the steadfast.\qt@no{155}}%
\qt@newcmd\qurantrans@en@clxiii{%
Those who, when a calamity afflicts them, say, “To God we belong, and to Him we will return.”\qt@no{156}}%
\qt@newcmd\qurantrans@en@clxiv{%
Upon these are blessings and mercy from their Lord. These are the guided ones.\qt@no{157}}%
\qt@newcmd\qurantrans@en@clxv{%
Safa and Marwa are among the rites of God. Whoever makes the Pilgrimage to the House, or performs the Umrah, commits no error by circulating between them. Whoever volunteers good—God is Appreciative and Cognizant.\qt@no{158}}%
\qt@newcmd\qurantrans@en@clxvi{%
Those who suppress the proofs and the guidance We have revealed, after We have clarified them to humanity in the Scripture—those—God curses them, and the cursers curse them.\qt@no{159}}%
\qt@newcmd\qurantrans@en@clxvii{%
Except those who repent, and reform, and proclaim. Those—I will accept their repentance. I am the Acceptor of Repentance, the Merciful.\qt@no{160}}%
\qt@newcmd\qurantrans@en@clxviii{%
But as for those who reject faith, and die rejecting—those—upon them is the curse of God, and of the angels, and of all humanity.\qt@no{161}}%
\qt@newcmd\qurantrans@en@clxix{%
They will remain under it forever, and the torment will not be lightened for them, and they will not be reprieved.\qt@no{162}}%
\qt@newcmd\qurantrans@en@clxx{%
Your God is one God. There is no god but He, the Benevolent, the Compassionate.\qt@no{163}}%
\qt@newcmd\qurantrans@en@clxxi{%
In the creation of the heavens and the earth; in the alternation of night and day; in the ships that sail the oceans for the benefit of mankind; in the water that God sends down from the sky, and revives the earth with it after it had died, and scatters in it all kinds of creatures; in the changing of the winds, and the clouds disposed between the sky and the earth; are signs for people who understand.\qt@no{164}}%
\qt@newcmd\qurantrans@en@clxxii{%
Yet among the people are those who take other than God as equals to Him. They love them as the love of God. But those who believe have greater love for God. If only the wrongdoers would realize, when they see the torment; that all power is God’s, and that God is severe in punishment.\qt@no{165}}%
\qt@newcmd\qurantrans@en@clxxiii{%
Those who were followed will then disown those who followed them, and they will see the retribution, and ties between them will be severed.\qt@no{166}}%
\qt@newcmd\qurantrans@en@clxxiv{%
Those who followed will say, “If only we can have another chance, we will disown them, as they disowned us.” Thus God will show them their deeds, as regrets to them, and they will not come out of the Fire.\qt@no{167}}%
\qt@newcmd\qurantrans@en@clxxv{%
O people! Eat of what is lawful and good on earth, and do not follow the footsteps of Satan. He is to you an open enemy.\qt@no{168}}%
\qt@newcmd\qurantrans@en@clxxvi{%
He commands you to do evil and vice, and to say about God what you do not know.\qt@no{169}}%
\qt@newcmd\qurantrans@en@clxxvii{%
And when it is said to them, “Follow what God has revealed,” they say, “We will follow what we found our ancestors following.” Even if their ancestors understood nothing, and were not guided?\qt@no{170}}%
\qt@newcmd\qurantrans@en@clxxviii{%
The parable of those who disbelieve is that of someone who calls upon someone who hears nothing except screaming and yelling. Deaf, dumb, and blind—they do not understand.\qt@no{171}}%
\qt@newcmd\qurantrans@en@clxxix{%
O you who believe! Eat of the good things We have provided for you, and give thanks to God, if it is Him that you serve.\qt@no{172}}%
\qt@newcmd\qurantrans@en@clxxx{%
He has forbidden you carrion, and blood, and the flesh of swine, and what was dedicated to other than God. But if anyone is compelled, without desiring or exceeding, he commits no sin. God is Forgiving and Merciful.\qt@no{173}}%
\qt@newcmd\qurantrans@en@clxxxi{%
Those who conceal what God revealed in the Book, and exchange it for a small price—those swallow nothing but fire into their bellies. And God will not speak to them on the Day of Resurrection, nor will He purify them, and they will have a painful punishment.\qt@no{174}}%
\qt@newcmd\qurantrans@en@clxxxii{%
It is they who exchange guidance for error, and forgiveness for punishment. But why do they insist on the Fire?\qt@no{175}}%
\qt@newcmd\qurantrans@en@clxxxiii{%
That is because God has revealed the Book in truth; and those who differ about the Book are in deep discord.\qt@no{176}}%
\qt@newcmd\qurantrans@en@clxxxiv{%
Righteousness does not consist of turning your faces towards the East and the West. But righteous is he who believes in God, and the Last Day, and the angels, and the Scripture, and the prophets. Who gives money, though dear, to near relatives, and orphans, and the needy, and the homeless, and the beggars, and for the freeing of slaves; those who perform the prayers, and pay the obligatory charity, and fulfill their promise when they promise, and patiently persevere in the face of persecution, hardship, and in the time of conflict. These are the sincere; these are the pious.\qt@no{177}}%
\qt@newcmd\qurantrans@en@clxxxv{%
O you who believe! Retaliation for the murdered is ordained upon you: the free for the free, the slave for the slave, the female for the female. But if he is forgiven by his kin, then grant any reasonable demand, and pay with good will. This is a concession from your Lord, and a mercy. But whoever commits aggression after that, a painful torment awaits him.\qt@no{178}}%
\qt@newcmd\qurantrans@en@clxxxvi{%
There is life for you in retaliation, O people of understanding, so that you may refrain.\qt@no{179}}%
\qt@newcmd\qurantrans@en@clxxxvii{%
It is decreed for you: when death approaches one of you, and he leaves wealth, to make a testament in favor of the parents and the relatives, fairly and correctly—a duty upon the righteous.\qt@no{180}}%
\qt@newcmd\qurantrans@en@clxxxviii{%
But whoever changes it after he has heard it, the guilt is upon those who change it. God is All-Hearing, All-Knowing.\qt@no{181}}%
\qt@newcmd\qurantrans@en@clxxxix{%
Should someone suspect bias or injustice on the part of a testator, and then reconciles between them, he commits no sin. God is Forgiving and Merciful.\qt@no{182}}%
\qt@newcmd\qurantrans@en@cxc{%
O you who believe! Fasting is prescribed for you, as it was prescribed for those before you, that you may become righteous.\qt@no{183}}%
\qt@newcmd\qurantrans@en@cxci{%
For a specified number of days. But whoever among you is sick, or on a journey, then a number of other days. For those who are able: a ransom of feeding a needy person. But whoever volunteers goodness, it is better for him. But to fast is best for you, if you only knew.\qt@no{184}}%
\qt@newcmd\qurantrans@en@cxcii{%
Ramadan is the month in which the Quran was revealed. Guidance for humanity, and clear portents of guidance, and the Criterion. Whoever of you witnesses the month, shall fast it. But whoever is sick, or on a journey, then a number of other days. God desires ease for you, and does not desire hardship for you, that you may complete the number, and celebrate God for having guided you, so that you may be thankful.\qt@no{185}}%
\qt@newcmd\qurantrans@en@cxciii{%
And when My servants ask you about Me, I Am near; I answer the call of the caller when he calls on Me. So let them answer Me, and have faith in Me, that they may be rightly guided.\qt@no{186}}%
\qt@newcmd\qurantrans@en@cxciv{%
Permitted for you is intercourse with your wives on the night of the fast. They are a garment for you, and you are a garment for them. God knows that you used to betray yourselves, but He turned to you and pardoned you. So approach them now, and seek what God has ordained for you, and eat and drink until the white streak of dawn can be distinguished from the black streak. Then complete the fast until nightfall. But do not approach them while you are in retreat at the mosques. These are the limits of God, so do not come near them. God thus clarifies His revelations to the people, that they may attain piety.\qt@no{187}}%
\qt@newcmd\qurantrans@en@cxcv{%
And do not consume one another’s wealth by unjust means, nor offer it as bribes to the officials in order to consume part of other people’s wealth illicitly, while you know.\qt@no{188}}%
\qt@newcmd\qurantrans@en@cxcvi{%
They ask you about the crescents. Say, “They are timetables for people, and for the Hajj.” It is not virtuous that you approach homes from their backs, but virtue is to be pious. So approach homes from their doors, and observe God, that you may succeed.\qt@no{189}}%
\qt@newcmd\qurantrans@en@cxcvii{%
And fight in the cause of God those who fight you, but do not commit aggression; God does not love the aggressors.\qt@no{190}}%
\qt@newcmd\qurantrans@en@cxcviii{%
And kill them wherever you overtake them, and expel them from where they had expelled you. Oppression is more serious than murder. But do not fight them at the Sacred Mosque, unless they fight you there. If they fight you, then kill them. Such is the retribution of the disbelievers.\qt@no{191}}%
\qt@newcmd\qurantrans@en@cxcix{%
But if they cease, then God is Forgiving and Merciful.\qt@no{192}}%
\qt@newcmd\qurantrans@en@cc{%
And fight them until there is no oppression, and worship becomes devoted to God alone. But if they cease, then let there be no hostility except against the oppressors.\qt@no{193}}%
\qt@newcmd\qurantrans@en@cci{%
The sacred month for the sacred month; and sacrilege calls for retaliation. Whoever commits aggression against you, retaliate against him in the same measure as he has committed against you. And be conscious of God, and know that God is with the righteous.\qt@no{194}}%
\qt@newcmd\qurantrans@en@ccii{%
And spend in the cause of God, and do not throw yourselves with your own hands into ruin, and be charitable. God loves the charitable.\qt@no{195}}%
\qt@newcmd\qurantrans@en@cciii{%
And carry out the Hajj and the Umrah for God. But if you are prevented, then whatever is feasible of offerings. And do not shave your heads until the offering has reached its destination. Whoever of you is sick, or has an injury of the head, then redemption of fasting, or charity, or worship. When you are secure: whoever continues the Umrah until the Hajj, then whatever is feasible of offering. But if he lacks the means, then fasting for three days during the Hajj and seven when you have returned, making ten in all. This is for he whose household is not present at the Sacred Mosque. And remain conscious of God, and know that God is stern in retribution.\qt@no{196}}%
\qt@newcmd\qurantrans@en@cciv{%
The Hajj is during specific months. Whoever decides to perform the Hajj—there shall be no sexual relations, nor misconduct, nor quarrelling during the Hajj. And whatever good you do, God knows it. And take provisions, but the best provision is righteousness. And be mindful of Me, O people of understanding.\qt@no{197}}%
\qt@newcmd\qurantrans@en@ccv{%
You commit no error by seeking bounty from your Lord. When you disperse from Arafat, remember God at the Sacred Landmark. And remember Him as He has guided you. Although, before that, you were of those astray.\qt@no{198}}%
\qt@newcmd\qurantrans@en@ccvi{%
Then disperse from where the people disperse, and ask God for forgiveness. God is Most Forgiving, Most Merciful.\qt@no{199}}%
\qt@newcmd\qurantrans@en@ccvii{%
When you have completed your rites, remember God as you remember your parents, or even more. Among the people is he who says, “Our Lord, give us in this world,” yet he has no share in the Hereafter.\qt@no{200}}%
\qt@newcmd\qurantrans@en@ccviii{%
And among them is he who says, “Our Lord, give us goodness in this world, and goodness in the Hereafter, and protect us from the torment of the Fire.”\qt@no{201}}%
\qt@newcmd\qurantrans@en@ccix{%
These will have a share of what they have earned. God is swift in reckoning.\qt@no{202}}%
\qt@newcmd\qurantrans@en@ccx{%
And remember God during the designated days. But whoever hurries on in two days commits no wrong, and whoever stays on commits no wrong—provided he maintains righteousness. And obey God, and know that to Him you will be gathered.\qt@no{203}}%
\qt@newcmd\qurantrans@en@ccxi{%
Among the people is he whose speech about the worldly life impresses you, and he calls God to witness what is in his heart, while he is the most hostile of adversaries.\qt@no{204}}%
\qt@newcmd\qurantrans@en@ccxii{%
When he gains power, he strives to spread corruption on earth, destroying properties and lives. God does not like corruption.\qt@no{205}}%
\qt@newcmd\qurantrans@en@ccxiii{%
And when he is told, “Beware of God,” his pride leads him to more sin. Hell is enough for him—a dreadful abode.\qt@no{206}}%
\qt@newcmd\qurantrans@en@ccxiv{%
And among the people is he who sells himself seeking God’s approval. God is kind towards the servants.\qt@no{207}}%
\qt@newcmd\qurantrans@en@ccxv{%
O you who believe! Enter into submission, wholeheartedly, and do not follow the footsteps of Satan; he is to you an outright enemy.\qt@no{208}}%
\qt@newcmd\qurantrans@en@ccxvi{%
But if you slip after the proofs have come to you, know that God is Powerful and Wise.\qt@no{209}}%
\qt@newcmd\qurantrans@en@ccxvii{%
Are they waiting for God Himself to come to them in the shadows of the clouds, together with the angels, and thus the matter is settled? All things are returned to God.\qt@no{210}}%
\qt@newcmd\qurantrans@en@ccxviii{%
Ask the Children of Israel how many clear signs We have given them. Whoever alters the blessing of God after it has come to him—God is severe in retribution.\qt@no{211}}%
\qt@newcmd\qurantrans@en@ccxix{%
Beautified is the life of this world for those who disbelieve, and they ridicule those who believe. But the righteous will be above them on the Day of Resurrection. God provides to whomever He wills without measure.\qt@no{212}}%
\qt@newcmd\qurantrans@en@ccxx{%
Humanity used to be one community; then God sent the prophets, bringing good news and giving warnings. And He sent down with them the Scripture, with the truth, to judge between people regarding their differences. But none differed over it except those who were given it—after the proofs had come to them—out of mutual envy between them. Then God guided those who believed to the truth they had disputed, in accordance with His will. God guides whom He wills to a straight path.\qt@no{213}}%
\qt@newcmd\qurantrans@en@ccxxi{%
Or do you expect to enter Paradise before the example of those who came before you had reached you? Adversity and hardship had afflicted them, and they were so shaken up, that the Messenger and those who believed with him said, “When is God’s victory?” Indeed, God’s victory is near.\qt@no{214}}%
\qt@newcmd\qurantrans@en@ccxxii{%
They ask you what they should give. Say, “Whatever charity you give is for the parents, and the relatives, and the orphans, and the poor, and the wayfarer. Whatever good you do, God is aware of it.\qt@no{215}}%
\qt@newcmd\qurantrans@en@ccxxiii{%
Fighting is ordained for you, even though you dislike it. But it may be that you dislike something while it is good for you, and it may be that you like something while it is bad for you. God knows, and you do not know.\qt@no{216}}%
\qt@newcmd\qurantrans@en@ccxxiv{%
They ask you about fighting during the Holy Month. Say, “Fighting during it is deplorable; but to bar others from God’s path, and to disbelieve in Him, and to prevent access to the Holy Mosque, and to expel its people from it, are more deplorable with God. And persecution is more serious than killing. They will not cease to fight you until they turn you back from your religion, if they can. Whoever among you turns back from his religion, and dies a disbeliever—those are they whose works will come to nothing, in this life, and in the Hereafter. Those are the inmates of the Fire, abiding in it forever.\qt@no{217}}%
\qt@newcmd\qurantrans@en@ccxxv{%
Those who believed, and those who migrated and fought for the sake of God—those look forward to God’s mercy. God is Forgiving and Merciful.\qt@no{218}}%
\qt@newcmd\qurantrans@en@ccxxvi{%
They ask you about intoxicants and gambling. Say, “There is gross sin in them, and some benefits for people, but their sinfulness outweighs their benefit.” And they ask you about what they should give: say, “The surplus.” Thus God explains the revelations to you, so that you may think.\qt@no{219}}%
\qt@newcmd\qurantrans@en@ccxxvii{%
About this world and the next. And they ask you about orphans. Say, “Improvement for them is best. And if you intermix with them, then they are your brethren.” God knows the dishonest from the honest. Had God willed, He could have overburdened you. God is Mighty and Wise.\qt@no{220}}%
\qt@newcmd\qurantrans@en@ccxxviii{%
Do not marry idolatresses, unless they have believed. A believing maid is better than an idolatress, even if you like her. And do not marry idolaters, unless they have believed. A believing servant is better than an idolater, even if you like him. These call to the Fire, but God calls to the Garden and to forgiveness, by His leave. He makes clear His communications to the people, that they may be mindful.\qt@no{221}}%
\qt@newcmd\qurantrans@en@ccxxix{%
And they ask you about menstruation: say, “It is harmful, so keep away from women during menstruation. And do not approach them until they have become pure. Once they have become pure, approach them in the way God has directed you.” God loves the repentant, and He loves those who keep clean.”\qt@no{222}}%
\qt@newcmd\qurantrans@en@ccxxx{%
Your women are cultivation for you; so approach your cultivation whenever you like, and send ahead for yourselves. And fear God, and know that you will meet Him. And give good news to the believers.\qt@no{223}}%
\qt@newcmd\qurantrans@en@ccxxxi{%
And do not allow your oaths in God's name to hinder you from virtue, and righteousness, and making peace between people. God is Listener and Knower.\qt@no{224}}%
\qt@newcmd\qurantrans@en@ccxxxii{%
God does not hold you responsible for your unintentional oaths, but He holds you responsible for your intentions. God is Forgiving and Forbearing.\qt@no{225}}%
\qt@newcmd\qurantrans@en@ccxxxiii{%
Those who vow abstinence from their wives must wait for four months. But if they reconcile—God is Forgiving and Merciful.\qt@no{226}}%
\qt@newcmd\qurantrans@en@ccxxxiv{%
And if they resolve to divorce—God is Hearing and Knowing.\qt@no{227}}%
\qt@newcmd\qurantrans@en@ccxxxv{%
Divorced women shall wait by themselves for three periods. And it is not lawful for them to conceal what God has created in their wombs, if they believe in God and the Last Day. Meanwhile, their husbands have the better right to take them back, if they desire reconciliation. And women have rights similar to their obligations, according to what is fair. But men have a degree over them. God is Mighty and Wise.\qt@no{228}}%
\qt@newcmd\qurantrans@en@ccxxxvi{%
Divorce is allowed twice. Then, either honorable retention, or setting free kindly. It is not lawful for you to take back anything you have given them, unless they fear that they cannot maintain God's limits. If you fear that they cannot maintain God’s limits, then there is no blame on them if she sacrifices something for her release. These are God’s limits, so do not transgress them. Those who transgress God’s limits are the unjust.\qt@no{229}}%
\qt@newcmd\qurantrans@en@ccxxxvii{%
If he divorces her, she shall not be lawful for him again until she has married another husband. If the latter divorces her, then there is no blame on them for reuniting, provided they think they can maintain God's limits. These are God’s limits; He makes them clear to people who know.\qt@no{230}}%
\qt@newcmd\qurantrans@en@ccxxxviii{%
When you divorce women, and they have reached their term, either retain them amicably, or release them amicably. But do not retain them to hurt them and commit aggression. Whoever does that has wronged himself. And do not take God’s revelations for a joke. And remember God's favor to you, and that He revealed to you the Scripture and Wisdom to teach you. And fear God, and know that God is aware of everything.\qt@no{231}}%
\qt@newcmd\qurantrans@en@ccxxxix{%
When you divorce women, and they have reached their term, do not prevent them from marrying their husbands, provided they agree on fair terms. Thereby is advised whoever among you believes in God and the Last Day. That is better and more decent for you. God knows, and you do not know.\qt@no{232}}%
\qt@newcmd\qurantrans@en@ccxl{%
Mothers may nurse their infants for two whole years, for those who desire to complete the nursing-period. It is the duty of the father to provide for them and clothe them in a proper manner. No soul shall be burdened beyond its capacity. No mother shall be harmed on account of her child, and no father shall be harmed on account of his child. The same duty rests upon the heir. If the couple desire weaning, by mutual consent and consultation, they commit no error by doing so. You commit no error by hiring nursing-mothers, as long as you pay them fairly. And be wary of God, and know that God is Seeing of what you do.\qt@no{233}}%
\qt@newcmd\qurantrans@en@ccxli{%
As for those among you who die and leave widows behind, their widows shall wait by themselves for four months and ten days. When they have reached their term, there is no blame on you regarding what they might honorably do with themselves. God is fully acquainted with what you do.\qt@no{234}}%
\qt@newcmd\qurantrans@en@ccxlii{%
You commit no error by announcing your engagement to women, or by keeping it to yourselves. God knows that you will be thinking about them. But do not meet them secretly, unless you have something proper to say. And do not confirm the marriage tie until the writing is fulfilled. And know that God knows what is in your souls, so beware of Him. And know that God is Forgiving and Forbearing.\qt@no{235}}%
\qt@newcmd\qurantrans@en@ccxliii{%
You commit no error by divorcing women before having touched them, or before having set the dowry for them. And compensate them—the wealthy according to his means, and the poor according to his means—with a fair compensation, a duty upon the doers of good.\qt@no{236}}%
\qt@newcmd\qurantrans@en@ccxliv{%
If you divorce them before you have touched them, but after you had set the dowry for them, give them half of what you specified—unless they forego the right, or the one in whose hand is the marriage contract foregoes it. But to forego is nearer to piety. And do not forget generosity between one another. God is seeing of everything you do.\qt@no{237}}%
\qt@newcmd\qurantrans@en@ccxlv{%
Guard your prayers, and the middle prayer, and stand before God in devotion.\qt@no{238}}%
\qt@newcmd\qurantrans@en@ccxlvi{%
But if you are in fear, then on foot, or riding. And when you are safe, remember God, as He taught you what you did not know.\qt@no{239}}%
\qt@newcmd\qurantrans@en@ccxlvii{%
Those of you who die and leave wives behind—a will shall provide their wives with support for a year, provided they do not leave. If they leave, you are not to blame for what they do with themselves, provided it is reasonable. God is Mighty and Wise.\qt@no{240}}%
\qt@newcmd\qurantrans@en@ccxlviii{%
And divorced women shall be provided for, equitably—a duty upon the righteous.\qt@no{241}}%
\qt@newcmd\qurantrans@en@ccxlix{%
God thus explains His revelations to you, so that you may understand.\qt@no{242}}%
\qt@newcmd\qurantrans@en@ccl{%
Have you not considered those who fled their homes, by the thousands, fearful of death? God said to them, “Die.” Then He revived them. God is Gracious towards the people, but most people are not appreciative.\qt@no{243}}%
\qt@newcmd\qurantrans@en@ccli{%
Fight in the cause of God, and know that God is Hearing and Knowing.\qt@no{244}}%
\qt@newcmd\qurantrans@en@cclii{%
Who is he who will offer God a generous loan, so He will multiply it for him manifold? God receives and amplifies, and to Him you will be returned.\qt@no{245}}%
\qt@newcmd\qurantrans@en@ccliii{%
Have you not considered the notables of the Children of Israel after Moses? When they said to a prophet of theirs, “Appoint a king for us, and we will fight in the cause of God.” He said, “Is it possible that, if fighting was ordained for you, you would not fight?” They said, “Why would we not fight in the cause of God, when we were driven out of our homes, along with our children?” But when fighting was ordained for them, they turned away, except for a few of them. But God is aware of the wrongdoers.\qt@no{246}}%
\qt@newcmd\qurantrans@en@ccliv{%
Their prophet said to them, “God has appointed Saul to be your king.” They said, “How can he have authority over us, when we are more worthy of authority than he, and he was not given plenty of wealth?” He said, “God has chosen him over you, and has increased him in knowledge and stature.” God bestows His sovereignty upon whomever He wills. God is Embracing and Knowing.\qt@no{247}}%
\qt@newcmd\qurantrans@en@cclv{%
And their prophet said to them, “The proof of his kingship is that the Ark will be restored to you, bringing tranquility from your Lord, and relics left by the family of Moses and the family of Aaron. It will be carried by the angels. In that is a sign for you, if you are believers.”\qt@no{248}}%
\qt@newcmd\qurantrans@en@cclvi{%
When Saul set out with the troops, he said, “God will be testing you with a river. Whoever drinks from it does not belong with me. But whoever does not drink from it, does belong with me, except for whoever scoops up a little with his hand.” But they drank from it, except for a few of them. Then, when he crossed it, he and those who believed with him, they said, “We have no strength to face Goliath and his troops today.” But those who knew that they would meet God said, “How many a small group has defeated a large group by God’s will. God is with the steadfast.”\qt@no{249}}%
\qt@newcmd\qurantrans@en@cclvii{%
And when they confronted Goliath and his troops, they said, “Our Lord, pour down patience on us, and strengthen our foothold, and support us against the faithless people.”\qt@no{250}}%
\qt@newcmd\qurantrans@en@cclviii{%
And they defeated them by God’s leave, and David killed Goliath, and God gave him sovereignty and wisdom, and taught him as He willed. Were it not for God restraining the people, some by means of others, the earth would have gone to ruin. But God is gracious towards mankind.\qt@no{251}}%
\qt@newcmd\qurantrans@en@cclix{%
These are God’s revelations, which We recite to you in truth. You are one of the messengers.\qt@no{252}}%
\qt@newcmd\qurantrans@en@cclx{%
These messengers: We gave some advantage over others. To some of them God spoke directly, and some He raised in rank. We gave Jesus son of Mary the clear miracles, and We strengthened him with the Holy Spirit. Had God willed, those who succeeded them would not have fought one another, after the clear signs had come to them; but they disputed; some of them believed, and some of them disbelieved. Had God willed, they would not have fought one another; but God does whatever He desires.\qt@no{253}}%
\qt@newcmd\qurantrans@en@cclxi{%
O you who believe! Spend from what We have given you, before a Day comes in which there is neither trading, nor friendship, nor intercession. The disbelievers are the wrongdoers.\qt@no{254}}%
\qt@newcmd\qurantrans@en@cclxii{%
God! There is no god except He, the Living, the Everlasting. Neither slumber overtakes Him, nor sleep. To Him belongs everything in the heavens and everything on earth. Who is he that can intercede with Him except with His permission? He knows what is before them, and what is behind them; and they cannot grasp any of His knowledge, except as He wills. His Throne extends over the heavens and the earth, and their preservation does not burden Him. He is the Most High, the Great.\qt@no{255}}%
\qt@newcmd\qurantrans@en@cclxiii{%
There shall be no compulsion in religion; the right way has become distinct from the wrong way. Whoever renounces evil and believes in God has grasped the most trustworthy handle; which does not break. God is Hearing and Knowing.\qt@no{256}}%
\qt@newcmd\qurantrans@en@cclxiv{%
God is the Lord of those who believe; He brings them out of darkness and into light. As for those who disbelieve, their lords are the evil ones; they bring them out of light and into darkness—these are the inmates of the Fire, in which they will abide forever.\qt@no{257}}%
\qt@newcmd\qurantrans@en@cclxv{%
Have you not considered him who argued with Abraham about his Lord, because God had given him sovereignty? Abraham said, “My Lord is He who gives life and causes death.” He said, “I give life and cause death.” Abraham said, “God brings the sun from the East, so bring it from the West,” so the blasphemer was confounded. God does not guide the wrongdoing people.\qt@no{258}}%
\qt@newcmd\qurantrans@en@cclxvi{%
Or like him who passed by a town collapsed on its foundations. He said, “How can God revive this after its demise?” Thereupon God caused him to die for a hundred years, and then resurrected him. He said, “For how long have you tarried?” He said, “I have tarried for a day, or part of a day.” He said, “No. You have tarried for a hundred years. Now look at your food and your drink—it has not spoiled—and look at your donkey. We will make you a wonder for mankind. And look at the bones, how We arrange them, and then clothe them with flesh.” So when it became clear to him, he said, “I know that God has power over all things.”\qt@no{259}}%
\qt@newcmd\qurantrans@en@cclxvii{%
And when Abraham said, “My Lord, show me how You give life to the dead.” He said, “Have you not believed?” He said, “Yes, but to put my heart at ease.” He said, “Take four birds, and incline them to yourself, then place a part on each hill, then call to them; and they will come rushing to you. And know that God is Powerful and Wise.”\qt@no{260}}%
\qt@newcmd\qurantrans@en@cclxviii{%
The parable of those who spend their wealth in God’s way is that of a grain that produces seven spikes; in each spike is a hundred grains. God multiplies for whom He wills. God is Bounteous and Knowing.\qt@no{261}}%
\qt@newcmd\qurantrans@en@cclxix{%
Those who spend their wealth in the way of God, and then do not follow up what they spent with reminders of their generosity or with insults, will have their reward with their Lord—they have nothing to fear, nor shall they grieve.\qt@no{262}}%
\qt@newcmd\qurantrans@en@cclxx{%
Kind words and forgiveness are better than charity followed by insults. God is Rich and Clement.\qt@no{263}}%
\qt@newcmd\qurantrans@en@cclxxi{%
O you who believe! Do not nullify your charitable deeds with reminders and hurtful words, like him who spends his wealth to be seen by the people, and does not believe in God and the Last Day. His likeness is that of a smooth rock covered with soil: a downpour strikes it, and leaves it bare—they gain nothing from their efforts. God does not guide the disbelieving people.\qt@no{264}}%
\qt@newcmd\qurantrans@en@cclxxii{%
And the parable of those who spend their wealth seeking God’s approval, and to strengthen their souls, is that of a garden on a hillside. If heavy rain falls on it, its produce is doubled; and if no heavy rain falls, then dew is enough. God is seeing of everything you do.\qt@no{265}}%
\qt@newcmd\qurantrans@en@cclxxiii{%
Would anyone of you like to have a garden of palms and vines, under which rivers flow—with all kinds of fruit in it for him, and old age has stricken him, and he has weak children—then a tornado with fire batters it, and it burns down? Thus God makes clear the signs for you, so that you may reflect.\qt@no{266}}%
\qt@newcmd\qurantrans@en@cclxxiv{%
O you who believe! Give of the good things you have earned, and from what We have produced for you from the earth. And do not pick the inferior things to give away, when you yourselves would not accept it except with eyes closed. And know that God is Sufficient and Praiseworthy.\qt@no{267}}%
\qt@newcmd\qurantrans@en@cclxxv{%
Satan promises you poverty, and urges you to immorality; but God promises you forgiveness from Himself, and grace. God is Embracing and Knowing.\qt@no{268}}%
\qt@newcmd\qurantrans@en@cclxxvi{%
He gives wisdom to whomever He wills. Whoever is given wisdom has been given much good. But none pays heed except those with insight.\qt@no{269}}%
\qt@newcmd\qurantrans@en@cclxxvii{%
Whatever charity you give, or a pledge you fulfill, God knows it. The wrongdoers have no helpers.\qt@no{270}}%
\qt@newcmd\qurantrans@en@cclxxviii{%
If you give charity openly, that is good. But if you keep it secret, and give it to the needy in private, that is better for you. It will atone for some of your misdeeds. God is cognizant of what you do.\qt@no{271}}%
\qt@newcmd\qurantrans@en@cclxxix{%
Their guidance is not your responsibility, but God guides whom He wills. Any charity you give is for your own good. Any charity you give shall be for the sake of God. Any charity you give will be repaid to you in full, and you will not be wronged.\qt@no{272}}%
\qt@newcmd\qurantrans@en@cclxxx{%
It is for the poor; those who are restrained in the way of God, and unable to travel in the land. The unaware would think them rich, due to their dignity. You will recognize them by their features. They do not ask from people insistently. Whatever charity you give, God is aware of it.\qt@no{273}}%
\qt@newcmd\qurantrans@en@cclxxxi{%
Those who spend their wealth by night and day, privately and publicly, will receive their reward from their Lord. They have nothing to fear, nor shall they grieve.\qt@no{274}}%
\qt@newcmd\qurantrans@en@cclxxxii{%
Those who swallow usury will not rise, except as someone driven mad by Satan's touch. That is because they say, “Commerce is like usury.” But God has permitted commerce, and has forbidden usury. Whoever, on receiving advice from his Lord, refrains, may keep his past earnings, and his case rests with God. But whoever resumes—these are the dwellers of the Fire, wherein they will abide forever.\qt@no{275}}%
\qt@newcmd\qurantrans@en@cclxxxiii{%
God condemns usury, and He blesses charities. God does not love any sinful ingrate.\qt@no{276}}%
\qt@newcmd\qurantrans@en@cclxxxiv{%
Those who believe, and do good deeds, and pray regularly, and give charity—they will have their reward with their Lord; they will have no fear, nor shall they grieve.\qt@no{277}}%
\qt@newcmd\qurantrans@en@cclxxxv{%
O you who believe! Fear God, and forgo what remains of usury, if you are believers.\qt@no{278}}%
\qt@newcmd\qurantrans@en@cclxxxvi{%
If you do not, then take notice of a war by God and His Messenger. But if you repent, you may keep your capital, neither wronging, nor being wronged.\qt@no{279}}%
\qt@newcmd\qurantrans@en@cclxxxvii{%
But if he is in hardship, then deferment until a time of ease. But to remit it as charity is better for you, if you only knew.\qt@no{280}}%
\qt@newcmd\qurantrans@en@cclxxxviii{%
And guard yourselves against a Day when you will be returned to God; then each soul will be rewarded fully for what it has earned, and they will not be wronged.\qt@no{281}}%
\qt@newcmd\qurantrans@en@cclxxxix{%
O you who believe! When you incur debt among yourselves for a certain period of time, write it down. And have a scribe write in your presence, in all fairness. And let no scribe refuse to write, as God has taught him. So let him write, and let the debtor dictate. And let him fear God, his Lord, and diminish nothing from it. But if the debtor is mentally deficient, or weak, or unable to dictate, then let his guardian dictate with honesty. And call to witness two men from among you. If two men are not available, then one man and two women whose testimony is acceptable to all—if one of them fails to remember, the other would remind her. Witnesses must not refuse when called upon. And do not think it too trivial to write down, whether small or large, including the time of repayment. That is more equitable with God, and stronger as evidence, and more likely to prevent doubt—except in the case of a spot transaction between you—then there is no blame on you if you do not write it down. And let there be witnesses whenever you conclude a contract, and let no harm be done to either scribe or witness. If you do that, it is corruption on your part. And fear God. God teaches you. God is aware of everything.\qt@no{282}}%
\qt@newcmd\qurantrans@en@ccxc{%
If you are on a journey, and cannot find a scribe, then a security deposit should be handed over. But if you trust one another, let the trustee fulfill his trust, and let him fear God, his Lord. And do not conceal testimony. Whoever conceals it is sinner at heart. God is aware of what you do.\qt@no{283}}%
\qt@newcmd\qurantrans@en@ccxci{%
To God belongs everything in the heavens and the earth. Whether you reveal what is within your selves, or conceal it, God will call you to account for it. He forgives whom He wills, and He punishes whom He wills. God is Able to do all things.\qt@no{284}}%
\qt@newcmd\qurantrans@en@ccxcii{%
The Messenger has believed in what was revealed to him from his Lord, as did the believers. They all have believed in God, and His angels, and His scriptures, and His messengers: “We make no distinction between any of His messengers.” And they say, “We hear and we obey. Your forgiveness, our Lord. To you is the destiny.”\qt@no{285}}%
\qt@newcmd\qurantrans@en@ccxciii{%
God does not burden any soul beyond its capacity. To its credit is what it earns, and against it is what it commits. “Our Lord, do not condemn us if we forget or make a mistake. Our Lord, do not burden us as You have burdened those before us. Our Lord, do not burden us with more than we have strength to bear; and pardon us, and forgive us, and have mercy on us. You are our Lord and Master, so help us against the disbelieving people.”\qt@no{286}}%
\qt@newcmd\qurantrans@en@ccxciv{%
\basmalahen Alif, Lam, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@ccxcv{%
God, there is no god but He, the Living, the Eternal.\qt@no{2}}%
\qt@newcmd\qurantrans@en@ccxcvi{%
He sent down to you the Book with the Truth, confirming what came before it; and He sent down the Torah and the Gospel.\qt@no{3}}%
\qt@newcmd\qurantrans@en@ccxcvii{%
Aforetime, as guidance for mankind; and He sent down the Criterion. Those who have rejected God’s signs will have a severe punishment. God is Mighty, Able to take revenge.\qt@no{4}}%
\qt@newcmd\qurantrans@en@ccxcviii{%
Nothing is hidden from God, on earth or in the heaven.\qt@no{5}}%
\qt@newcmd\qurantrans@en@ccxcix{%
It is He who forms you in the wombs as He wills. There is no god except He, the Almighty, the Wise.\qt@no{6}}%
\qt@newcmd\qurantrans@en@ccc{%
It is He who revealed to you the Book. Some of its verses are definitive; they are the foundation of the Book, and others are unspecific. As for those in whose hearts is deviation, they follow the unspecific part, seeking descent, and seeking to derive an interpretation. But none knows its interpretation except God and those firmly rooted in knowledge say, “We believe in it; all is from our Lord.” But none recollects except those with understanding.\qt@no{7}}%
\qt@newcmd\qurantrans@en@ccci{%
“Our Lord, do not cause our hearts to swerve after You have guided us, and bestow on us mercy from Your presence; You are the Giver.”\qt@no{8}}%
\qt@newcmd\qurantrans@en@cccii{%
“Our Lord, You will gather the people for a Day in which there is no doubt.” God will never break His promise.\qt@no{9}}%
\qt@newcmd\qurantrans@en@ccciii{%
As for those who disbelieve, neither their wealth nor their children will avail them anything against God. These will be fuel for the Fire.\qt@no{10}}%
\qt@newcmd\qurantrans@en@ccciv{%
Like the behavior of Pharaoh’s people and those before them. They rejected Our signs, so God seized them for their sins. God is Strict in retribution.\qt@no{11}}%
\qt@newcmd\qurantrans@en@cccv{%
Say to those who disbelieve, “You will be defeated, and rounded up into Hell—an awful resting-place.”\qt@no{12}}%
\qt@newcmd\qurantrans@en@cccvi{%
There was a sign for you in the two parties that met. One party fighting in the way of God, and the other was disbelieving. They saw them with their own eyes twice their number. But God supports with His help whomever He wills. In that is a lesson for those with insight.\qt@no{13}}%
\qt@newcmd\qurantrans@en@cccvii{%
Adorned for the people is the love of desires, such as women, and children, and piles upon piles of gold and silver, and branded horses, and livestock, and fields. These are the conveniences of the worldly life, but with God lies the finest resort.\qt@no{14}}%
\qt@newcmd\qurantrans@en@cccviii{%
Say, “Shall I inform you of something better than that? For those who are righteous, with their Lord are Gardens beneath which rivers flow, where they will remain forever, and purified spouses, and acceptance from God.” God is Observant of the servants.\qt@no{15}}%
\qt@newcmd\qurantrans@en@cccix{%
Those who say, “Our Lord, we have believed, so forgive us our sins, and save us from the suffering of the Fire.”\qt@no{16}}%
\qt@newcmd\qurantrans@en@cccx{%
The patient, and the truthful, and the reverent, and the charitable, and the seekers of forgiveness at dawn.\qt@no{17}}%
\qt@newcmd\qurantrans@en@cccxi{%
God bears witness that there is no god but He, as do the angels, and those endowed with knowledge—upholding justice. There is no god but He, the Mighty, the Wise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@cccxii{%
Religion with God is Islam. Those to whom the Scripture was given differed only after knowledge came to them, out of envy among themselves. Whoever rejects the signs of God—God is quick to take account.\qt@no{19}}%
\qt@newcmd\qurantrans@en@cccxiii{%
If they argue with you, say, “I have surrendered myself to God, and those who follow me.” And say to those who were given the Scripture, and to the unlearned, “Have you surrendered?” If they have surrendered, then they are guided; but if they turn away, then your duty is to convey. God is Seeing of the servants.\qt@no{20}}%
\qt@newcmd\qurantrans@en@cccxiv{%
As for those who defy God’s revelations, and kill the prophets unjustly, and kill those who advocate justice among the people—promise them a painful retribution.\qt@no{21}}%
\qt@newcmd\qurantrans@en@cccxv{%
They are those whose deeds will come to nothing, in this world and in the Hereafter; and they will have no saviors.\qt@no{22}}%
\qt@newcmd\qurantrans@en@cccxvi{%
Have you not considered those who were given a share of the Scripture, as they were called to the Scripture of God to arbitrate between them; then some of them turned back, and declined?\qt@no{23}}%
\qt@newcmd\qurantrans@en@cccxvii{%
That is because they said, “The Fire will not touch us except for a limited number of days.” They have been misled in their religion by the lies they fabricated.\qt@no{24}}%
\qt@newcmd\qurantrans@en@cccxviii{%
How about when We gather them for a Day in which there is no doubt, and each soul will be paid in full for what it has earned, and they will not be wronged?\qt@no{25}}%
\qt@newcmd\qurantrans@en@cccxix{%
Say, “O God, Owner of Sovereignty. You grant sovereignty to whom You will, and You strip sovereignty from whom you will. You honor whom you will, and You humiliate whom you will. In Your hand is all goodness. You are Capable of all things.”\qt@no{26}}%
\qt@newcmd\qurantrans@en@cccxx{%
“You merge the night into the day, and You merge the day into the night; and you bring the living out of the dead, and You bring the dead out of the living; and You provide for whom you will without measure.”\qt@no{27}}%
\qt@newcmd\qurantrans@en@cccxxi{%
Believers are not to take disbelievers for friends instead of believers. Whoever does that has nothing to do with God, unless it is to protect your own selves against them. God warns you to beware of Him. To God is the destiny.\qt@no{28}}%
\qt@newcmd\qurantrans@en@cccxxii{%
Say, “Whether you conceal what is in your hearts, or disclose it, God knows it.” He knows everything in the heavens and the earth. God is Powerful over everything.\qt@no{29}}%
\qt@newcmd\qurantrans@en@cccxxiii{%
On the Day when every soul finds all the good it has done presented. And as for the evil it has done, it will wish there were a great distance between them. God cautions you of Himself. God is Kind towards the servants.\qt@no{30}}%
\qt@newcmd\qurantrans@en@cccxxiv{%
Say, “If you love God, then follow me, and God will love you, and will forgive you your sins.” God is Forgiving and Merciful.\qt@no{31}}%
\qt@newcmd\qurantrans@en@cccxxv{%
Say, “Obey God and the Messenger.” But if they turn away—God does not love the faithless.\qt@no{32}}%
\qt@newcmd\qurantrans@en@cccxxvi{%
God chose Adam, and Noah, and the family of Abraham, and the family of Imran, over all mankind.\qt@no{33}}%
\qt@newcmd\qurantrans@en@cccxxvii{%
Offspring one of the other. God is Hearer and Knower.\qt@no{34}}%
\qt@newcmd\qurantrans@en@cccxxviii{%
The wife of Imran said, “My Lord, I have vowed to You what is in my womb, dedicated, so accept from me; You are the Hearer and Knower.”\qt@no{35}}%
\qt@newcmd\qurantrans@en@cccxxix{%
And when she delivered her, she said, “My Lord, I have delivered a female,” and God was well aware of what she has delivered, “and the male is not like the female, and I have named her Mary, and have commended her and her descendants to Your protection, from Satan the outcast.”\qt@no{36}}%
\qt@newcmd\qurantrans@en@cccxxx{%
Her Lord accepted her with a gracious reception, and brought her a beautiful upbringing, and entrusted her to the care of Zechariah. Whenever Zechariah entered upon her in the sanctuary, he found her with provision. He said, “O Mary, where did you get this from?” She said, “It is from God; God provides to whom He wills without reckoning.”\qt@no{37}}%
\qt@newcmd\qurantrans@en@cccxxxi{%
Thereupon Zechariah prayed to his Lord; he said, “My Lord, bestow on me good offspring from Your presence; You are the Hearer of Prayers.”\qt@no{38}}%
\qt@newcmd\qurantrans@en@cccxxxii{%
Then the angels called out to him, as he stood praying in the sanctuary: “God gives you good news of John; confirming a Word from God, and honorable, and moral, and a prophet; one of the upright.”\qt@no{39}}%
\qt@newcmd\qurantrans@en@cccxxxiii{%
He said, “My Lord, how will I have a son, when old age has overtaken me, and my wife is barren?” He said, “Even so, God does whatever He wills.”\qt@no{40}}%
\qt@newcmd\qurantrans@en@cccxxxiv{%
He said, “My Lord, give me a sign.” He said, “Your sign is that you shall not speak to the people for three days, except by gestures. And remember your Lord much, and praise in the evening and the morning.”\qt@no{41}}%
\qt@newcmd\qurantrans@en@cccxxxv{%
The angels said, “O Mary, God has chosen you, and has purified you. He has chosen you over all the women of the world.\qt@no{42}}%
\qt@newcmd\qurantrans@en@cccxxxvi{%
“O Mary, be devoted to your Lord, and bow down, and kneel with those who kneel.”\qt@no{43}}%
\qt@newcmd\qurantrans@en@cccxxxvii{%
These are accounts from the Unseen, which We reveal to you. You were not with them when they cast their lots as to which of them would take charge of Mary; nor were you with them as they quarreled.\qt@no{44}}%
\qt@newcmd\qurantrans@en@cccxxxviii{%
The Angels said, “O Mary, God gives you good news of a Word from Him. His name is the Messiah, Jesus, son of Mary, well-esteemed in this world and the next, and one of the nearest.\qt@no{45}}%
\qt@newcmd\qurantrans@en@cccxxxix{%
He will speak to the people from the crib, and in adulthood, and will be one of the righteous.”\qt@no{46}}%
\qt@newcmd\qurantrans@en@cccxl{%
She said, “My Lord, how can I have a child, when no man has touched me?” He said, “It will be so. God creates whatever He wills. To have anything done, He only says to it, ‘Be,’ and it is.”\qt@no{47}}%
\qt@newcmd\qurantrans@en@cccxli{%
And He will teach him the Scripture and wisdom, and the Torah and the Gospel.\qt@no{48}}%
\qt@newcmd\qurantrans@en@cccxlii{%
A messenger to the Children of Israel: “I have come to you with a sign from your Lord. I make for you out of clay the figure of a bird; then I breathe into it, and it becomes a bird by God’s leave. And I heal the blind and the leprous, and I revive the dead, by God’s leave. And I inform you concerning what you eat, and what you store in your homes. In that is a sign for you, if you are believers.”\qt@no{49}}%
\qt@newcmd\qurantrans@en@cccxliii{%
“And verifying what lies before me of the Torah, and to make lawful for you some of what was forbidden to you. I have come to you with a sign from your Lord; so fear God, and obey me.”\qt@no{50}}%
\qt@newcmd\qurantrans@en@cccxliv{%
“God is my Lord and your Lord, so worship Him. That is a straight path.”\qt@no{51}}%
\qt@newcmd\qurantrans@en@cccxlv{%
When Jesus sensed disbelief on their part, he said, “Who are my allies towards God?” The disciples said, “We are God’s allies; we have believed in God, and bear witness that we submit.”\qt@no{52}}%
\qt@newcmd\qurantrans@en@cccxlvi{%
“Our Lord, we have believed in what You have revealed, and we have followed the Messenger, so count us among the witnesses.”\qt@no{53}}%
\qt@newcmd\qurantrans@en@cccxlvii{%
They planned, and God planned; but God is the Best of planners.\qt@no{54}}%
\qt@newcmd\qurantrans@en@cccxlviii{%
God said, “O Jesus, I am terminating your life, and raising you to Me, and clearing you of those who disbelieve. And I will make those who follow you superior to those who disbelieve, until the Day of Resurrection. Then to Me is your return; then I will judge between you regarding what you were disputing.\qt@no{55}}%
\qt@newcmd\qurantrans@en@cccxlix{%
As for those who disbelieve, I will punish them with a severe punishment, in this world and the next, and they will have no helpers.\qt@no{56}}%
\qt@newcmd\qurantrans@en@cccl{%
And as for those who believe and do good works, He will give them their rewards in full. God does not love the unjust.”\qt@no{57}}%
\qt@newcmd\qurantrans@en@cccli{%
This is what We recite to you of the Verses and the Wise Reminder.\qt@no{58}}%
\qt@newcmd\qurantrans@en@ccclii{%
The likeness of Jesus in God’s sight is that of Adam: He created him from dust, then said to him, “Be,” and he was.\qt@no{59}}%
\qt@newcmd\qurantrans@en@cccliii{%
The truth is from your Lord, so do not be of those who doubt.\qt@no{60}}%
\qt@newcmd\qurantrans@en@cccliv{%
And if anyone disputes with you about him, after the knowledge that has come to you, say, “Come, let us call our children and your children, and our women and your women, and ourselves and yourselves, and let us invoke God’s curse on the liars.”\qt@no{61}}%
\qt@newcmd\qurantrans@en@ccclv{%
This is the narrative of truth: there is no god but God. God is the Mighty, the Wise.\qt@no{62}}%
\qt@newcmd\qurantrans@en@ccclvi{%
But if they turn away—God knows the corrupt.\qt@no{63}}%
\qt@newcmd\qurantrans@en@ccclvii{%
Say, “O People of the Book, come to terms common between us and you: that we worship none but God, and that we associate nothing with Him, and that none of us takes others as lords besides God.” And if they turn away, say, “Bear witness that we have submitted.”\qt@no{64}}%
\qt@newcmd\qurantrans@en@ccclviii{%
O People of the Book! Why do you argue about Abraham, when the Torah and the Gospel were not revealed until after him? Will you not reason?\qt@no{65}}%
\qt@newcmd\qurantrans@en@ccclix{%
Here you are—you argue about things you know, but why do you argue about things you do not know? God knows, and you do not know.\qt@no{66}}%
\qt@newcmd\qurantrans@en@ccclx{%
Abraham was neither a Jew nor a Christian, but he was a Monotheist, a Muslim. And he was not of the Polytheists.\qt@no{67}}%
\qt@newcmd\qurantrans@en@ccclxi{%
The people most deserving of Abraham are those who followed him, and this prophet, and those who believe. God is the Guardian of the believers.\qt@no{68}}%
\qt@newcmd\qurantrans@en@ccclxii{%
A party of the People of the Book would love to lead you astray, but they only lead themselves astray, and they do not realize it.\qt@no{69}}%
\qt@newcmd\qurantrans@en@ccclxiii{%
O People of the Book! Why do you reject the revelations of God, even as you witness?\qt@no{70}}%
\qt@newcmd\qurantrans@en@ccclxiv{%
O People of the Book! Why do you confound the truth with falsehood, and knowingly conceal the truth?\qt@no{71}}%
\qt@newcmd\qurantrans@en@ccclxv{%
Some of the People of the Book say, “Believe in what was revealed to the believers at the beginning of the day, and reject it at its end, so that they may return.”\qt@no{72}}%
\qt@newcmd\qurantrans@en@ccclxvi{%
And trust none except those who follow your religion.” Say, “Guidance is God’s guidance. If someone is given the like of what you were given, or they argue with you before your Lord, say, “All grace is in God’s hand; He gives it to whomever He wills.” God is Bounteous and Knowing.\qt@no{73}}%
\qt@newcmd\qurantrans@en@ccclxvii{%
He specifies His mercy for whomever He wills. God is Possessor of Sublime Grace.\qt@no{74}}%
\qt@newcmd\qurantrans@en@ccclxviii{%
Among the People of the Book is he, who, if you entrust him with a heap of gold, he will give it back to you. And among them is he, who, if you entrust him with a single coin, he will not give it back to you, unless you keep after him. That is because they say, “We are under no obligation towards the gentiles.” They tell lies about God, and they know it.\qt@no{75}}%
\qt@newcmd\qurantrans@en@ccclxix{%
Indeed, whoever fulfills his commitments and maintains piety—God loves the pious.\qt@no{76}}%
\qt@newcmd\qurantrans@en@ccclxx{%
Those who exchange the covenant of God, and their vows, for a small price, will have no share in the Hereafter, and God will not speak to them, nor will He look at them on the Day of Resurrection, nor will He purify them. They will have a painful punishment.\qt@no{77}}%
\qt@newcmd\qurantrans@en@ccclxxi{%
And among them are those who twist the Scripture with their tongues, that you may think it from the Scripture, when it is not from the Scripture. And they say, “It is from God,” when it is not from God. They tell lies and attribute them to God, knowingly.\qt@no{78}}%
\qt@newcmd\qurantrans@en@ccclxxii{%
No person to whom God has given the Scripture, and wisdom, and prophethood would ever say to the people, “Be my worshipers rather than God’s.” Rather, “Be people of the Lord, according to the Scripture you teach, and the teachings you learn.”\qt@no{79}}%
\qt@newcmd\qurantrans@en@ccclxxiii{%
Nor would he command you to take the angels and the prophets as lords. Would he command you to infidelity after you have submitted?\qt@no{80}}%
\qt@newcmd\qurantrans@en@ccclxxiv{%
God received the covenant of the prophets, “Inasmuch as I have given you of scripture and wisdom; should a messenger come to you verifying what you have, you shall believe in him, and support him.” He said, “Do you affirm My covenant and take it upon yourselves?” They said, “We affirm it.” He said, “Then bear witness, and I am with you among the witnesses.”\qt@no{81}}%
\qt@newcmd\qurantrans@en@ccclxxv{%
Whoever turns away after that—these are the deceitful.\qt@no{82}}%
\qt@newcmd\qurantrans@en@ccclxxvi{%
Do they desire other than the religion of God, when to Him has submitted everything in the heavens and the earth, willingly or unwillingly, and to Him they will be returned?\qt@no{83}}%
\qt@newcmd\qurantrans@en@ccclxxvii{%
Say, “We believe in God, and in what was revealed to us; and in what was revealed to Abraham, and Ishmael, and Isaac, and Jacob, and the Patriarchs; and in what was given to Moses, and Jesus, and the prophets from their Lord. We make no distinction between any of them, and to Him we submit.”\qt@no{84}}%
\qt@newcmd\qurantrans@en@ccclxxviii{%
Whoever seeks other than Islam as a religion, it will not be accepted from him, and in the Hereafter he will be among the losers.\qt@no{85}}%
\qt@newcmd\qurantrans@en@ccclxxix{%
How will God guide a people who disbelieved after having believed, and had witnessed that the Messenger is true, and the clear proofs had come to them? God does not guide the unjust people.\qt@no{86}}%
\qt@newcmd\qurantrans@en@ccclxxx{%
Those—their penalty is that upon them falls the curse of God, and of the angels, and of all mankind.\qt@no{87}}%
\qt@newcmd\qurantrans@en@ccclxxxi{%
Remaining in it eternally, without their punishment being eased from them, and without being reprieved.\qt@no{88}}%
\qt@newcmd\qurantrans@en@ccclxxxii{%
Except those who repent afterwards, and reform; for God is Forgiving and Merciful.\qt@no{89}}%
\qt@newcmd\qurantrans@en@ccclxxxiii{%
As for those who disbelieve after having believed, then plunge deeper into disbelief, their repentance will not be accepted; these are the lost.\qt@no{90}}%
\qt@newcmd\qurantrans@en@ccclxxxiv{%
As for those who disbelieve and die disbelievers, even the earth full of gold would not be accepted from any of them, were he to offer it for ransom. These will have a painful torment, and will have no saviors.\qt@no{91}}%
\qt@newcmd\qurantrans@en@ccclxxxv{%
You will not attain virtuous conduct until you give of what you cherish. Whatever you give away, God is aware of it.\qt@no{92}}%
\qt@newcmd\qurantrans@en@ccclxxxvi{%
All food was permissible to the Children of Israel, except what Israel forbade for itself before the Torah was revealed. Say, “Bring the Torah, and read it, if you are truthful.”\qt@no{93}}%
\qt@newcmd\qurantrans@en@ccclxxxvii{%
Whoever forges lies about God after that—these are the unjust.\qt@no{94}}%
\qt@newcmd\qurantrans@en@ccclxxxviii{%
Say, “God has spoken the truth, so follow the religion of Abraham the Monotheist; he was not a Pagan.”\qt@no{95}}%
\qt@newcmd\qurantrans@en@ccclxxxix{%
The first house established for mankind is the one at Bekka; blessed, and guidance for all people.\qt@no{96}}%
\qt@newcmd\qurantrans@en@cccxc{%
In it are evident signs; the Station of Abraham. Whoever enters it attains security. Pilgrimage to the House is a duty to God for all who can make the journey. But as for those who refuse—God is Independent of the worlds.\qt@no{97}}%
\qt@newcmd\qurantrans@en@cccxci{%
Say, “O People of the Scripture, why do you reject the Revelations of God, when God witnesses what you do?”\qt@no{98}}%
\qt@newcmd\qurantrans@en@cccxcii{%
Say, “O People of the Scripture, why do you hinder from God’s path those who believe, seeking to distort it, even though you are witnesses? God is not unaware of what you do.”\qt@no{99}}%
\qt@newcmd\qurantrans@en@cccxciii{%
O you who believe! If you obey a party of those who were given the Scripture, they will turn you, after your belief, into disbelievers.\qt@no{100}}%
\qt@newcmd\qurantrans@en@cccxciv{%
And how could you disbelieve, when God’s revelations are being recited to you, and among you is His Messenger? Whoever cleaves to God has been guided to a straight path.\qt@no{101}}%
\qt@newcmd\qurantrans@en@cccxcv{%
O you who believe! Revere God with due reverence, and do not die except as Muslims.\qt@no{102}}%
\qt@newcmd\qurantrans@en@cccxcvi{%
And hold fast to the rope of God, altogether, and do not become divided. And remember God’s blessings upon you; how you were enemies, and He reconciled your hearts, and by His grace you became brethren. And you were on the brink of a pit of fire, and He saved you from it. God thus clarifies His revelations for you, so that you may be guided.\qt@no{103}}%
\qt@newcmd\qurantrans@en@cccxcvii{%
And let there be among you a community calling to virtue, and advocating righteousness, and deterring from evil. These are the successful.\qt@no{104}}%
\qt@newcmd\qurantrans@en@cccxcviii{%
And do not be like those who separated and disputed after the clear proofs came to them; for them is a great punishment.\qt@no{105}}%
\qt@newcmd\qurantrans@en@cccxcix{%
On the Day when some faces will be whitened, and some faces will be blackened. As for those whose faces are blackened: “Did you disbelieve after your belief?” Then taste the punishment for having disbelieved.\qt@no{106}}%
\qt@newcmd\qurantrans@en@cd{%
But as for those whose faces are whitened: they are in God’s mercy, remaining in it forever.\qt@no{107}}%
\qt@newcmd\qurantrans@en@cdi{%
These are the revelations of God. We recite them to you in truth. God desires no injustice for mankind.\qt@no{108}}%
\qt@newcmd\qurantrans@en@cdii{%
To God belongs everything in the heavens and everything on earth, and to God all events are referred.\qt@no{109}}%
\qt@newcmd\qurantrans@en@cdiii{%
You are the best community that ever emerged for humanity: you advocate what is moral, and forbid what is immoral, and believe in God. Had the People of the Scripture believed, it would have been better for them. Among them are the believers, but most of them are sinners.\qt@no{110}}%
\qt@newcmd\qurantrans@en@cdiv{%
They will do you no harm, beyond insulting you. And if they fight you, they will turn around and flee, then they will not be helped.\qt@no{111}}%
\qt@newcmd\qurantrans@en@cdv{%
They shall be humiliated wherever they are encountered, except through a rope from God, and a rope from the people; and they incurred wrath from God, and were stricken with misery. That is because they rejected God’s revelations, and killed the prophets unjustly. That is because they rebelled and committed aggression.\qt@no{112}}%
\qt@newcmd\qurantrans@en@cdvi{%
They are not alike. Among the People of the Scripture is a community that is upright; they recite God’s revelations throughout the night, and they prostrate themselves.\qt@no{113}}%
\qt@newcmd\qurantrans@en@cdvii{%
They believe in God and the Last Day, and advocate righteousness and forbid evil, and are quick to do good deeds. These are among the righteous.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cdviii{%
Whatever good they do, they will not be denied it. God knows the righteous.\qt@no{115}}%
\qt@newcmd\qurantrans@en@cdix{%
As for those who disbelieve, neither their possessions nor their children will avail them anything against God. These are the inhabitants of the Fire, abiding therein forever.\qt@no{116}}%
\qt@newcmd\qurantrans@en@cdx{%
The parable of what they spend in this worldly life is that of a frosty wind that strikes the harvest of a people who have wronged their souls, and destroys it. God did not wrong them, but they wronged their own selves.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cdxi{%
O you who believe! Do not befriend outsiders who never cease to wish you harm. They love to see you suffer. Hatred has already appeared from their mouths, but what their hearts conceal is worse. We have made the messages clear for you, if you understand.\qt@no{118}}%
\qt@newcmd\qurantrans@en@cdxii{%
There you are, you love them, but they do not love you, and you believe in the entire scripture. And when they meet you, they say, “We believe;” but when they are alone, they bite their fingers in rage at you. Say, “Die in your rage; God knows what is within the hearts.”\qt@no{119}}%
\qt@newcmd\qurantrans@en@cdxiii{%
If something good happens to you, it upsets them; but if something bad befalls you, they rejoice at it. But if you persevere and maintain righteousness, their schemes will not harm you at all. God comprehends what they do.\qt@no{120}}%
\qt@newcmd\qurantrans@en@cdxiv{%
Remember when you left your home in the morning, to assign battle-positions for the believers. God is Hearing and Knowing.\qt@no{121}}%
\qt@newcmd\qurantrans@en@cdxv{%
When two groups among you almost faltered, but God was their Protector. So in God let the believers put their trust.\qt@no{122}}%
\qt@newcmd\qurantrans@en@cdxvi{%
God had given you victory at Badr, when you were weak. So fear God, that you may be thankful.\qt@no{123}}%
\qt@newcmd\qurantrans@en@cdxvii{%
When you said to the believers, “Is it not enough for you that your Lord has reinforced you with three thousand angels, sent down?”\qt@no{124}}%
\qt@newcmd\qurantrans@en@cdxviii{%
It is; but if you persevere and remain cautious, and they attack you suddenly, your Lord will reinforce you with five thousand angels, well trained.\qt@no{125}}%
\qt@newcmd\qurantrans@en@cdxix{%
God made it but a message of hope for you, and to reassure your hearts thereby. Victory comes only from God the Almighty, the Wise.\qt@no{126}}%
\qt@newcmd\qurantrans@en@cdxx{%
He thus cuts off a section of those who disbelieved, or subdues them, so they retreat disappointed.\qt@no{127}}%
\qt@newcmd\qurantrans@en@cdxxi{%
It is no concern of yours whether He redeems them or punishes them. They are wrongdoers.\qt@no{128}}%
\qt@newcmd\qurantrans@en@cdxxii{%
To God belongs everything in the heavens and the earth. He forgives whom He wills, and He punishes whom He wills. God is Most Forgiving, Most Merciful.\qt@no{129}}%
\qt@newcmd\qurantrans@en@cdxxiii{%
O you who believe! Do not feed on usury, compounded over and over, and fear God, so that you may prosper.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cdxxiv{%
And guard yourselves against the Fire that is prepared for the disbelievers.\qt@no{131}}%
\qt@newcmd\qurantrans@en@cdxxv{%
And obey God and the Messenger, that you may obtain mercy.\qt@no{132}}%
\qt@newcmd\qurantrans@en@cdxxvi{%
And race towards forgiveness from your Lord, and a Garden as wide as the heavens and the earth, prepared for the righteous.\qt@no{133}}%
\qt@newcmd\qurantrans@en@cdxxvii{%
Those who give in prosperity and adversity, and those who restrain anger, and those who forgive people. God loves the doers of good.\qt@no{134}}%
\qt@newcmd\qurantrans@en@cdxxviii{%
And those who, when they commit an indecency or wrong themselves, remember God and ask forgiveness for their sins—and who forgives sins except God? And they do not persist in their wrongdoing while they know.\qt@no{135}}%
\qt@newcmd\qurantrans@en@cdxxix{%
Those—their reward is forgiveness from their Lord, and gardens beneath which rivers flow, abiding therein forever. How excellent is the reward of the workers.\qt@no{136}}%
\qt@newcmd\qurantrans@en@cdxxx{%
Many societies have passed away before you. So travel the earth and note the fate of the deniers.\qt@no{137}}%
\qt@newcmd\qurantrans@en@cdxxxi{%
This is a proclamation to humanity, and guidance, and advice for the righteous.\qt@no{138}}%
\qt@newcmd\qurantrans@en@cdxxxii{%
And do not waver, nor feel remorse. You are the superior ones, if you are believers.\qt@no{139}}%
\qt@newcmd\qurantrans@en@cdxxxiii{%
If a wound afflicts you, a similar wound has afflicted the others. Such days We alternate between the people, that God may know those who believe, and take martyrs from among you. God does not love the evildoers.\qt@no{140}}%
\qt@newcmd\qurantrans@en@cdxxxiv{%
So that God may prove those who believe, and eliminate the disbelievers.\qt@no{141}}%
\qt@newcmd\qurantrans@en@cdxxxv{%
Or do you expect to enter Paradise, before God has distinguished those among you who strive, and before He has distinguished the steadfast?\qt@no{142}}%
\qt@newcmd\qurantrans@en@cdxxxvi{%
You used to wish for death before you have faced it. Now you have seen it before your own eyes.\qt@no{143}}%
\qt@newcmd\qurantrans@en@cdxxxvii{%
Muhammad is no more than a messenger. Messengers have passed on before him. If he dies or gets killed, will you turn on your heels? He who turns on his heels will not harm God in any way. And God will reward the appreciative.\qt@no{144}}%
\qt@newcmd\qurantrans@en@cdxxxviii{%
No soul can die except by God’s leave, at a predetermined time. Whoever desires the reward of the world, We will give him some of it; and whoever desires the reward of the Hereafter, We will give him some of it; and We will reward the appreciative.\qt@no{145}}%
\qt@newcmd\qurantrans@en@cdxxxix{%
How many a prophet fought alongside him numerous godly people? They did not waver for what afflicted them in the cause of God, nor did they weaken, nor did they give in. God loves those who endure.\qt@no{146}}%
\qt@newcmd\qurantrans@en@cdxl{%
Their only words were, “Our Lord, forgive us our offences, and our excesses in our conduct, and strengthen our foothold, and help us against the disbelieving people.”\qt@no{147}}%
\qt@newcmd\qurantrans@en@cdxli{%
So God gave them the reward of this world, and the excellent reward of the Hereafter. God loves the doers of good.\qt@no{148}}%
\qt@newcmd\qurantrans@en@cdxlii{%
O you who believe! If you obey those who disbelieve, they will turn you back on your heels, and you end up losers.\qt@no{149}}%
\qt@newcmd\qurantrans@en@cdxliii{%
God is your Master, and He is the Best of Helpers.\qt@no{150}}%
\qt@newcmd\qurantrans@en@cdxliv{%
We will throw terror into the hearts of those who disbelieve, because they attribute to God partners for which He revealed no sanction. Their lodging is the Fire. Miserable is the lodging of the evildoers.\qt@no{151}}%
\qt@newcmd\qurantrans@en@cdxlv{%
God has fulfilled His promise to you, and you defeated them by His leave; until when you faltered, and disputed the command, and disobeyed after He had shown you what you like. Some of you want this world, and some of you want the next. Then He turned you away from them, to test you; but He pardoned you. God is Gracious towards the believers.\qt@no{152}}%
\qt@newcmd\qurantrans@en@cdxlvi{%
Remember when you fled, not caring for anyone, even though the Messenger was calling you from your rear. Then He repaid you with sorrow upon sorrow, so that you would not grieve over what you missed, or for what afflicted you. God is Informed of what you do.\qt@no{153}}%
\qt@newcmd\qurantrans@en@cdxlvii{%
Then after the setback, He sent down security upon you. Slumber overcame some of you, while others cared only for themselves, thinking of God thoughts that were untrue—thoughts of ignorance—saying, “Is anything up to us?” Say, “Everything is up to God.” They conceal within themselves what they do not reveal to you. And they say, “If it was up to us, none of us would have been killed here.” Say, “Even if you Had stayed in your homes, those destined to be killed would have marched into their death beds.” God thus tests what is in your minds, and purifies what is in your hearts. God knows what the hearts contain.\qt@no{154}}%
\qt@newcmd\qurantrans@en@cdxlviii{%
Those of you who turned back on the day when the two armies clashed—it was Satan who caused them to backslide, on account of some of what they have earned. But God has forgiven them. God is Forgiving and Prudent.\qt@no{155}}%
\qt@newcmd\qurantrans@en@cdxlix{%
O you who believe! Do not be like those who disbelieved, and said of their brethren who marched in the land, or went on the offensive, “Had they stayed with us, they would not have died or been killed.” So that God may make it a cause of regret in their hearts. God gives life and causes death. God is Seeing of what you do.\qt@no{156}}%
\qt@newcmd\qurantrans@en@cdl{%
If you are killed in the cause of God, or die—forgiveness and mercy from God are better than what they hoard.\qt@no{157}}%
\qt@newcmd\qurantrans@en@cdli{%
If you die, or are killed—to God you will be gathered up.\qt@no{158}}%
\qt@newcmd\qurantrans@en@cdlii{%
It is by of grace from God that you were gentle with them. Had you been harsh, hardhearted, they would have dispersed from around you. So pardon them, and ask forgiveness for them, and consult them in the conduct of affairs. And when you make a decision, put your trust in God; God loves the trusting.\qt@no{159}}%
\qt@newcmd\qurantrans@en@cdliii{%
If God supports you, there is none who can overcome you. But if He fails you, who is there to help you after Him? So in God let the believers put their trust.\qt@no{160}}%
\qt@newcmd\qurantrans@en@cdliv{%
It is not for a prophet to act dishonestly. Whoever acts dishonestly will bring his dishonesty on the Day of Resurrection. Then every soul will be paid in full for what it has earned, and they will not be wronged.\qt@no{161}}%
\qt@newcmd\qurantrans@en@cdlv{%
Is someone who pursues God's approval the same as someone who incurs God's wrath and his refuge is Hell—the miserable destination?\qt@no{162}}%
\qt@newcmd\qurantrans@en@cdlvi{%
They have different ranks with God, and God is Seeing of what they do.\qt@no{163}}%
\qt@newcmd\qurantrans@en@cdlvii{%
God has blessed the believers, as He raised up among them a messenger from among themselves, who recites to them His revelations, and purifies them, and teaches them the Scripture and wisdom; although before that they were in evident error.\qt@no{164}}%
\qt@newcmd\qurantrans@en@cdlviii{%
And when a calamity befell you, even after you had inflicted twice as much, you said, “How is this?” Say, “It is from your own selves.” God is Able to do all things.\qt@no{165}}%
\qt@newcmd\qurantrans@en@cdlix{%
What befell you on the day the two armies clashed was with God’s permission; that He may know the believers.\qt@no{166}}%
\qt@newcmd\qurantrans@en@cdlx{%
And that He may know the hypocrites. And it was said to them, “Come, fight in the cause of God, or contribute.” They said, “If we knew how to fight, we would have followed you.” On that day they were closer to infidelity than they were to faith. They say with their mouths what is not in their hearts; but God knows what they hide.\qt@no{167}}%
\qt@newcmd\qurantrans@en@cdlxi{%
Those who said of their brethren, as they stayed behind, “Had they obeyed us, they would not have been killed.” Say, “Then avert death from yourselves, if you are truthful.”\qt@no{168}}%
\qt@newcmd\qurantrans@en@cdlxii{%
Do not consider those killed in the cause of God as dead. In fact, they are alive, at their Lord, well provided for.\qt@no{169}}%
\qt@newcmd\qurantrans@en@cdlxiii{%
Delighting in what God has given them out of His grace, and happy for those who have not yet joined them; that they have nothing to fear, nor will they grieve.\qt@no{170}}%
\qt@newcmd\qurantrans@en@cdlxiv{%
They rejoice in grace from God, and bounty, and that God will not waste the reward of the faithful.\qt@no{171}}%
\qt@newcmd\qurantrans@en@cdlxv{%
Those who responded to God and the Messenger, despite the persecution they had suffered. For the virtuous and the pious among them is a great reward.\qt@no{172}}%
\qt@newcmd\qurantrans@en@cdlxvi{%
Those to whom the people have said, “The people have mobilized against you, so fear them.” But this only increased them in faith, and they said, “God is enough for us; He is the Excellent Protector.”\qt@no{173}}%
\qt@newcmd\qurantrans@en@cdlxvii{%
So they came back with grace from God, and bounty, and no harm having touched them. They pursued what pleases God. God possesses immense grace.\qt@no{174}}%
\qt@newcmd\qurantrans@en@cdlxviii{%
That is only Satan frightening his partisans; so do not fear them, but fear Me, if you are believers.\qt@no{175}}%
\qt@newcmd\qurantrans@en@cdlxix{%
And do not be saddened by those who rush into disbelief. They will not harm God in the least. God desires to give them no share in the Hereafter. A terrible torment awaits them.\qt@no{176}}%
\qt@newcmd\qurantrans@en@cdlxx{%
Those who exchange blasphemy for faith will not harm God in the least. A painful torment awaits them.\qt@no{177}}%
\qt@newcmd\qurantrans@en@cdlxxi{%
Those who disbelieve should not assume that We respite them for their own good. In fact, We only respite them so that they may increase in sinfulness. A humiliating torment awaits them.\qt@no{178}}%
\qt@newcmd\qurantrans@en@cdlxxii{%
God will not leave the believers as you are, without distinguishing the wicked from the sincere. Nor will God inform you of the future, but God elects from among His messengers whom He wills. So believe in God and His messengers. If you believe and practice piety, you will have a splendid reward.\qt@no{179}}%
\qt@newcmd\qurantrans@en@cdlxxiii{%
Those who withhold what God has given them of his bounty should not assume that is good for them. In fact, it is bad for them. They will be encircled by their hoardings on the Day of Resurrection. To God belongs the inheritance of the heavens and the earth, and God is well acquainted with what you do.\qt@no{180}}%
\qt@newcmd\qurantrans@en@cdlxxiv{%
God has heard the statement of those who said, “God is poor, and we are rich.” We will write down what they said, and their wrongful killing of the prophets; and We will say, “Taste the torment of the burning.”\qt@no{181}}%
\qt@newcmd\qurantrans@en@cdlxxv{%
“This is on account of what your hands have forwarded, and because God is not unjust towards the creatures.”\qt@no{182}}%
\qt@newcmd\qurantrans@en@cdlxxvi{%
Those who said, “God has made a covenant with us, that we shall not believe in any messenger unless he brings us an offering to be consumed by fire.” Say, “Messengers have come to you before me with proofs, and with what you asked for; so why did you assassinate them, if you are truthful?”\qt@no{183}}%
\qt@newcmd\qurantrans@en@cdlxxvii{%
If they accuse you of lying, messengers before you were accused of lying. They came with the proofs, and the Psalms, and the Illuminating Scripture.\qt@no{184}}%
\qt@newcmd\qurantrans@en@cdlxxviii{%
Every soul will have a taste of death, and you will receive your recompense on the Day of Resurrection. Whoever is swayed from the Fire, and admitted to Paradise, has won. The life of this world is merely enjoyment of delusion.\qt@no{185}}%
\qt@newcmd\qurantrans@en@cdlxxix{%
You will be tested through your possessions and your persons; and you will hear from those who received the Scripture before you, and from the idol worshipers, much abuse. But if you persevere and lead a righteous life—that indeed is a mark of great determination.\qt@no{186}}%
\qt@newcmd\qurantrans@en@cdlxxx{%
God received a pledge from those who were given the Scripture: “You shall proclaim it to the people, and not conceal it.” But they disregarded it behind their backs, and exchanged it for a small price. What a miserable exchange they made.\qt@no{187}}%
\qt@newcmd\qurantrans@en@cdlxxxi{%
Do not think that those who rejoice in what they have done, and love to be praised for what they have not done—do not think they can evade the punishment. They will have a painful punishment.\qt@no{188}}%
\qt@newcmd\qurantrans@en@cdlxxxii{%
To God belongs the sovereignty of the heavens and the earth. God has power over all things.\qt@no{189}}%
\qt@newcmd\qurantrans@en@cdlxxxiii{%
In the creation of the heavens and the earth, and in the alternation of night and day, are signs for people of understanding.\qt@no{190}}%
\qt@newcmd\qurantrans@en@cdlxxxiv{%
Those who remember God while standing, and sitting, and on their sides; and they reflect upon the creation of the heavens and the earth: “Our Lord, You did not create this in vain, glory to You, so protect us from the punishment of the Fire.”\qt@no{191}}%
\qt@newcmd\qurantrans@en@cdlxxxv{%
“Our Lord, whomever You commit to the Fire, You have disgraced. The wrongdoers will have no helpers.”\qt@no{192}}%
\qt@newcmd\qurantrans@en@cdlxxxvi{%
“Our Lord, we have heard a caller calling to the faith: `Believe in your Lord,' and we have believed. Our Lord! Forgive us our sins, and remit our misdeeds, and make us die in the company of the virtuous.”\qt@no{193}}%
\qt@newcmd\qurantrans@en@cdlxxxvii{%
“Our Lord, and give us what You have promised us through Your messengers, and do not disgrace us on the Day of Resurrection. Surely You never break a promise.”\qt@no{194}}%
\qt@newcmd\qurantrans@en@cdlxxxviii{%
And so their Lord answered them: “I will not waste the work of any worker among you, whether male or female. You are one of another. For those who emigrated, and were expelled from their homes, and were persecuted because of Me, and fought and were killed—I will remit for them their sins, and will admit them into gardens beneath which rivers flow—a reward from God. With God is the ultimate reward.”\qt@no{195}}%
\qt@newcmd\qurantrans@en@cdlxxxix{%
Do not be impressed by the disbelievers’ movements in the land.\qt@no{196}}%
\qt@newcmd\qurantrans@en@cdxc{%
A brief enjoyment, then their abode is Hell. What a miserable resort.\qt@no{197}}%
\qt@newcmd\qurantrans@en@cdxci{%
As for those who feared their Lord: for them will be gardens beneath which rivers flow, wherein they will abide forever—hospitality from God. What God possesses is best for the just.\qt@no{198}}%
\qt@newcmd\qurantrans@en@cdxcii{%
Among the People of the Scripture are those who believe in God, and in what was revealed to you, and in what was revealed to them. They are humble before God, and they do not sell God’s revelations for a cheap price. These will have their reward with their Lord. God is swift in reckoning.\qt@no{199}}%
\qt@newcmd\qurantrans@en@cdxciii{%
O you who believe! Be patient, and advocate patience, and be united, and revere God, so that you may thrive.\qt@no{200}}%
\qt@newcmd\qurantrans@en@cdxciv{%
\basmalahen O people! Fear your Lord, who created you from a single soul, and created from it its mate, and propagated from them many men and women. And revere God whom you ask about, and the parents. Surely, God is Watchful over you.\qt@no{1}}%
\qt@newcmd\qurantrans@en@cdxcv{%
And give orphans their properties, and do not substitute the bad for the good. And do not consume their properties by combining them with yours, for that would be a serious sin.\qt@no{2}}%
\qt@newcmd\qurantrans@en@cdxcvi{%
If you fear you cannot act fairly towards the orphans—then marry the women you like—two, or three, or four. But if you fear you will not be fair, then one, or what you already have. That makes it more likely that you avoid bias.\qt@no{3}}%
\qt@newcmd\qurantrans@en@cdxcvii{%
Give women their dowries graciously. But if they willingly forego some of it, then consume it with enjoyment and pleasure.\qt@no{4}}%
\qt@newcmd\qurantrans@en@cdxcviii{%
Do not give the immature your money which God has assigned to you for support. But provide for them from it, and clothe them, and speak to them with kind words.\qt@no{5}}%
\qt@newcmd\qurantrans@en@cdxcix{%
Test the orphans until they reach the age of marriage. If you find them to be mature enough, hand over their properties to them. And do not consume it extravagantly or hastily before they grow up. The rich shall not charge any wage, but the poor may charge fairly. When you hand over their properties to them, have it witnessed for them. God suffices as a Reckoner.\qt@no{6}}%
\qt@newcmd\qurantrans@en@d{%
Men receive a share of what their parents and relatives leave, and women receive a share of what their parents and relatives leave; be it little or much—a legal share.\qt@no{7}}%
\qt@newcmd\qurantrans@en@di{%
If the distribution is attended by the relatives, and the orphans, and the needy, give them something out of it, and speak to them kindly.\qt@no{8}}%
\qt@newcmd\qurantrans@en@dii{%
Those who are concerned about the fate of their weak children, in case they leave them behind, should fear God, and speak appropriate words.\qt@no{9}}%
\qt@newcmd\qurantrans@en@diii{%
Those who consume the wealth of orphans illicitly consume only fire into their bellies; and they will roast in a Blaze.\qt@no{10}}%
\qt@newcmd\qurantrans@en@div{%
God instructs you regarding your children: The male receives the equivalent of the share of two females. If they are daughters, more than two, they get two-thirds of what he leaves. If there is only one, she gets one-half. As for the parents, each gets one-sixth of what he leaves, if he had children. If he had no children, and his parents inherit from him, his mother gets one-third. If he has siblings, his mother gets one-sixth. After fulfilling any bequest and paying off debts. Your parents and your children—you do not know which are closer to you in welfare. This is God's Law. God is Knowing and Judicious.\qt@no{11}}%
\qt@newcmd\qurantrans@en@dv{%
You get one-half of what your wives leave behind, if they had no children. If they had children, you get one-fourth of what they leave. After fulfilling any bequest and paying off debts. They get one-fourth of what you leave behind, if you have no children. If you have children, they get one-eighth of what you leave. After fulfilling any bequest and paying off debts. If a man or woman leaves neither parents nor children, but has a brother or sister, each of them gets one-sixth. If there are more siblings, they share one-third. After fulfilling any bequest and paying off debts, without any prejudice. This is a will from God. God is Knowing and Clement.\qt@no{12}}%
\qt@newcmd\qurantrans@en@dvi{%
These are the bounds set by God. Whoever obeys God and His Messenger, He will admit him into Gardens beneath which rivers flow, to abide therein forever. That is the great attainment.\qt@no{13}}%
\qt@newcmd\qurantrans@en@dvii{%
But whoever disobeys God and His Messenger, and oversteps His bounds, He will admit him into a Fire, wherein he abides forever, and he will have a shameful punishment.\qt@no{14}}%
\qt@newcmd\qurantrans@en@dviii{%
Those of your women who commit lewdness, you must have four witnesses against them, from among you. If they testify, confine them to the homes until death claims them, or God makes a way for them.\qt@no{15}}%
\qt@newcmd\qurantrans@en@dix{%
If two men among you commit it, punish them both. But if they repent and reform, leave them alone. God is Redeemer, Full of Mercy.\qt@no{16}}%
\qt@newcmd\qurantrans@en@dx{%
Repentance is available from God for those who commit evil out of ignorance, and then repent soon after. These—God will relent towards them. God is Knowing and Wise.\qt@no{17}}%
\qt@newcmd\qurantrans@en@dxi{%
But repentance is not available for those who commit evils, until when death approaches one of them, he says, “Now I repent,” nor for those who die as disbelievers. These—We have prepared for them a painful torment.\qt@no{18}}%
\qt@newcmd\qurantrans@en@dxii{%
O you who believe! It is not permitted for you to inherit women against their will. And do not coerce them in order to take away some of what you had given them, unless they commit a proven adultery. And live with them in kindness. If you dislike them, it may be that you dislike something in which God has placed much good.\qt@no{19}}%
\qt@newcmd\qurantrans@en@dxiii{%
If you wish to replace one wife with another, and you have given one of them a fortune, take nothing back from it. Would you take it back fraudulently and sinfully?\qt@no{20}}%
\qt@newcmd\qurantrans@en@dxiv{%
And how can you take it back, when you have been intimate with one another, and they have received from you a solid commitment?\qt@no{21}}%
\qt@newcmd\qurantrans@en@dxv{%
Do not marry women whom your fathers married, except what is already past. That is improper, indecent, and a bad custom.\qt@no{22}}%
\qt@newcmd\qurantrans@en@dxvi{%
Forbidden for you are your mothers, your daughters, your sisters, your paternal aunts, your maternal aunts, your brother's daughters, your sister's daughters, your foster-mothers who nursed you, your sisters through nursing, your wives' mothers, and your stepdaughters in your guardianship—born of wives you have gone into—but if you have not gone into them, there is no blame on you. And the wives of your genetic sons, and marrying two sisters simultaneously. Except what is past. God is Oft-Forgiving, Most Merciful.\qt@no{23}}%
\qt@newcmd\qurantrans@en@dxvii{%
And all married women, except those you rightfully possess. This is God’s decree, binding upon you. Permitted for you are those that lie outside these limits, provided you seek them in legal marriage, with gifts from your property, seeking wedlock, not prostitution. If you wish to enjoy them, then give them their dowry—a legal obligation. You commit no error by agreeing to any change to the dowry. God is All-Knowing, Most Wise.\qt@no{24}}%
\qt@newcmd\qurantrans@en@dxviii{%
If any of you lack the means to marry free believing women, he may marry one of the believing maids under your control. God is well aware of your faith. You are from one another. Marry them with the permission of their guardians, and give them their recompense fairly—to be protected—neither committing adultery, nor taking secret lovers. When they are married, if they commit adultery, their punishment shall be half that of free women. That is for those among you who fear falling into decadence. But to practice self-restraint is better for you. God is Most Forgiving, Most Merciful.\qt@no{25}}%
\qt@newcmd\qurantrans@en@dxix{%
God intends to make things clear to you, and to guide you in the ways of those before you, and to redeem you. God is Most Knowing, Most Wise.\qt@no{26}}%
\qt@newcmd\qurantrans@en@dxx{%
God intends to redeem you, but those who follow their desires want you to turn away utterly.\qt@no{27}}%
\qt@newcmd\qurantrans@en@dxxi{%
God intends to lighten your burden, for the human being was created weak.\qt@no{28}}%
\qt@newcmd\qurantrans@en@dxxii{%
O you who believe! Do not consume each other’s wealth illicitly, but trade by mutual consent. And do not kill yourselves, for God is Merciful towards you.\qt@no{29}}%
\qt@newcmd\qurantrans@en@dxxiii{%
Whoever does that, out of hostility and wrongdoing, We will cast him into a Fire. And that would be easy for God.\qt@no{30}}%
\qt@newcmd\qurantrans@en@dxxiv{%
If you avoid the worst of what you are forbidden, We will remit your sins, and admit you by a Gate of Honor.\qt@no{31}}%
\qt@newcmd\qurantrans@en@dxxv{%
Do not covet what God has given to some of you in preference to others. For men is a share of what they have earned, and for women is a share of what they have earned. And ask God of his bounty. God has knowledge of everything.\qt@no{32}}%
\qt@newcmd\qurantrans@en@dxxvi{%
To everyone We have assigned beneficiaries in what is left by parents and relatives. Those with whom you have made an agreement, give them their share. God is Witness over all things.\qt@no{33}}%
\qt@newcmd\qurantrans@en@dxxvii{%
Men are the protectors and maintainers of women, as God has given some of them an advantage over others, and because they spend out of their wealth. The good women are obedient, guarding what God would have them guard. As for those from whom you fear disloyalty, admonish them, and abandon them in their beds, then strike them. But if they obey you, seek no way against them. God is Sublime, Great.\qt@no{34}}%
\qt@newcmd\qurantrans@en@dxxviii{%
If you fear a breach between the two, appoint an arbiter from his family and an arbiter from her family. If they wish to reconcile, God will bring them together. God is Knowledgeable, Expert.\qt@no{35}}%
\qt@newcmd\qurantrans@en@dxxix{%
Worship God, and ascribe no partners to Him, and be good to the parents, and the relatives, and the orphans, and the poor, and the neighbor next door, and the distant neighbor, and the close associate, and the traveler, and your servants. God does not love the arrogant showoff.\qt@no{36}}%
\qt@newcmd\qurantrans@en@dxxx{%
Those who are stingy, and exhort people to stinginess, and conceal what God has given them from His bounty. We have prepared for the disbelievers a disgraceful punishment.\qt@no{37}}%
\qt@newcmd\qurantrans@en@dxxxi{%
And those who spend their money to be seen by people, and believe neither in God nor in the Last Day. Whoever has Satan as a companion—what an evil companion.\qt@no{38}}%
\qt@newcmd\qurantrans@en@dxxxii{%
What would they have lost, had they believed in God and the Last Day, and gave out of what God has provided for them? God knows them very well.\qt@no{39}}%
\qt@newcmd\qurantrans@en@dxxxiii{%
God does not commit an atom's weight of injustice; and if there is a good deed, He doubles it, and gives from His Presence a sublime compensation.\qt@no{40}}%
\qt@newcmd\qurantrans@en@dxxxiv{%
Then how will it be, when We bring a witness from every community, and We bring you as a witness against these?\qt@no{41}}%
\qt@newcmd\qurantrans@en@dxxxv{%
On that Day, those who disbelieved and disobeyed the Messenger will wish that the earth were leveled over them. They will conceal nothing from God.\qt@no{42}}%
\qt@newcmd\qurantrans@en@dxxxvi{%
O you who believe! Do not approach the prayer while you are drunk, so that you know what you say; nor after sexual orgasm—unless you are travelling—until you have bathed. If you are sick, or traveling, or one of you comes from the toilet, or you have had intercourse with women, and cannot find water, find clean sand and wipe your faces and your hands with it. God is Pardoning and Forgiving.\qt@no{43}}%
\qt@newcmd\qurantrans@en@dxxxvii{%
Have you not considered those who were given a share of the Book? They buy error, and wish you would lose the way.\qt@no{44}}%
\qt@newcmd\qurantrans@en@dxxxviii{%
But God knows your enemies best. God is sufficient as a Protector, and God is sufficient as a Supporter.\qt@no{45}}%
\qt@newcmd\qurantrans@en@dxxxix{%
Among the Jews are some who take words out of context, and say, “We hear and we disobey”, and “Hear without listening”, and “Observe us,” twisting with their tongues and slandering the religion. Had they said, “We hear and we obey”, and “Listen”, and “Give us your attention,” it would have been better for them, and more upright. But God has cursed them for their disbelief; they do not believe except a little.\qt@no{46}}%
\qt@newcmd\qurantrans@en@dxl{%
O you who were given the Book! Believe in what We sent down, confirming what you have, before We obliterate faces and turn them inside out, or curse them as We cursed the Sabbath-breakers. The command of God is always done.\qt@no{47}}%
\qt@newcmd\qurantrans@en@dxli{%
God does not forgive association with Him, but He forgives anything less than that to whomever He wills. Whoever associates anything with God has devised a monstrous sin.\qt@no{48}}%
\qt@newcmd\qurantrans@en@dxlii{%
Have you not considered those who claim purity for themselves? Rather, God purifies whom He wills, and they will not be wronged a whit.\qt@no{49}}%
\qt@newcmd\qurantrans@en@dxliii{%
See how they devise lies against God. That alone is an outright sin.\qt@no{50}}%
\qt@newcmd\qurantrans@en@dxliv{%
Have you not considered those who were given a share of the Book? They believe in superstition and evil powers, and say of those who disbelieve, “These are better guided on the way than the believers.”\qt@no{51}}%
\qt@newcmd\qurantrans@en@dxlv{%
Those are they whom God has cursed. Whomever God curses, you will find no savior for him.\qt@no{52}}%
\qt@newcmd\qurantrans@en@dxlvi{%
Or do they own a share of the kingdom? Then they would not give people a speck.\qt@no{53}}%
\qt@newcmd\qurantrans@en@dxlvii{%
Or do they envy the people for what God has given them of His grace? We have given the family of Abraham the Book and wisdom, and We have given them a great kingdom.\qt@no{54}}%
\qt@newcmd\qurantrans@en@dxlviii{%
Among them are those who believed in it, and among them are those who held back from it. Hell is a sufficient Inferno.\qt@no{55}}%
\qt@newcmd\qurantrans@en@dxlix{%
Those who reject Our revelations—We will scorch them in a Fire. Every time their skins are cooked, We will replace them with other skins, so they will experience the suffering. God is Most Powerful, Most Wise.\qt@no{56}}%
\qt@newcmd\qurantrans@en@dl{%
As for those who believe and do good deeds, We will admit them into Gardens beneath which rivers flow, abiding therein forever. They will have purified spouses therein, and We will admit them into a shady shade.\qt@no{57}}%
\qt@newcmd\qurantrans@en@dli{%
God instructs you to give back things entrusted to you to their owners. And when you judge between people, judge with justice. God’s instructions to you are excellent. God is All-Hearing, All-Seeing.\qt@no{58}}%
\qt@newcmd\qurantrans@en@dlii{%
O you who believe! Obey God and obey the Messenger and those in authority among you. And if you dispute over anything, refer it to God and the Messenger, if you believe in God and the Last Day. That is best, and a most excellent determination.\qt@no{59}}%
\qt@newcmd\qurantrans@en@dliii{%
Have you not observed those who claim that they believe in what was revealed to you, and in what was revealed before you, yet they seek Satanic sources for legislation, in spite of being commanded to reject them? Satan means to mislead them far away.\qt@no{60}}%
\qt@newcmd\qurantrans@en@dliv{%
And when it is said to them, “Come to what God has revealed, and to the Messenger,” you see the hypocrites shunning you completely.\qt@no{61}}%
\qt@newcmd\qurantrans@en@dlv{%
How about when a disaster strikes them because what their hands have put forward, and then they come to you swearing by God: “We only intended goodwill and reconciliation”?\qt@no{62}}%
\qt@newcmd\qurantrans@en@dlvi{%
They are those whom God knows what is in their hearts. So ignore them, and admonish them, and say to them concerning themselves penetrating words.\qt@no{63}}%
\qt@newcmd\qurantrans@en@dlvii{%
We did not send any messenger except to be obeyed by God’s leave. Had they, when they wronged themselves, come to you, and prayed for God's forgiveness, and the Messenger had prayed for their forgiveness, they would have found God Relenting and Merciful.\qt@no{64}}%
\qt@newcmd\qurantrans@en@dlviii{%
But no, by your Lord, they will not believe until they call you to arbitrate in their disputes, and then find within themselves no resentment regarding your decisions, and submit themselves completely.\qt@no{65}}%
\qt@newcmd\qurantrans@en@dlix{%
Had We decreed for them: “Kill yourselves,” or “Leave your homes,” they would not have done it, except for a few of them. But had they done what they were instructed to do, it would have been better for them, and a firmer confirmation.\qt@no{66}}%
\qt@newcmd\qurantrans@en@dlx{%
And We would have given them from Our presence a rich compensation.\qt@no{67}}%
\qt@newcmd\qurantrans@en@dlxi{%
And We would have guided them on a straight path.\qt@no{68}}%
\qt@newcmd\qurantrans@en@dlxii{%
Whoever obeys God and the Messenger—these are with those whom God has blessed—among the prophets, and the sincere, and the martyrs, and the upright. Excellent are those as companions.\qt@no{69}}%
\qt@newcmd\qurantrans@en@dlxiii{%
That is the grace from God. God suffices as Knower.\qt@no{70}}%
\qt@newcmd\qurantrans@en@dlxiv{%
O you who believe! Take your precautions, and mobilize in groups, or mobilize altogether.\qt@no{71}}%
\qt@newcmd\qurantrans@en@dlxv{%
Among you is he who lags behind. Then, when a calamity befalls you, he says, “God has favored me, that I was not martyred with them.”\qt@no{72}}%
\qt@newcmd\qurantrans@en@dlxvi{%
But when some bounty from God comes to you, he says—as if no affection existed between you and him—“If only I had been with them, I would have achieved a great victory.”\qt@no{73}}%
\qt@newcmd\qurantrans@en@dlxvii{%
Let those who sell the life of this world for the Hereafter fight in the cause of God. Whoever fights in the cause of God, and then is killed, or achieves victory, We will grant him a great compensation.\qt@no{74}}%
\qt@newcmd\qurantrans@en@dlxviii{%
And why would you not fight in the cause of God, and the helpless men, and women, and children, cry out, “Our Lord, deliver us from this town whose people are oppressive, and appoint for us from Your Presence a Protector, and appoint for us from Your Presence a Victor.”\qt@no{75}}%
\qt@newcmd\qurantrans@en@dlxix{%
Those who believe fight in the cause of God, while those who disbelieve fight in the cause of Evil. So fight the allies of the Devil. Surely the strategy of the Devil is weak.\qt@no{76}}%
\qt@newcmd\qurantrans@en@dlxx{%
Have you not considered those who were told, “Restrain your hands, and perform your prayers, and spend in regular charity”? But when fighting was ordained for them, a faction of them feared the people as God is ought to be feared, or even more. And they said, “Our Lord, why did You ordain fighting for us? If only You would postpone it for us for a short while.” Say, “The enjoyments of this life are brief, but the Hereafter is better for the righteous, and you will not be wronged one bit.”\qt@no{77}}%
\qt@newcmd\qurantrans@en@dlxxi{%
Wherever you may be, death will catch up with you, even if you were in fortified towers. When a good fortune comes their way, they say, “This is from God.” But when a misfortune befalls them, they say, “This is from you.” Say, “All is from God.” So what is the matter with these people, that they hardly understand a thing?\qt@no{78}}%
\qt@newcmd\qurantrans@en@dlxxii{%
Whatever good happens to you is from God, and whatever bad happens to you is from your own self. We sent you to humanity as a messenger, and God is Witness enough.\qt@no{79}}%
\qt@newcmd\qurantrans@en@dlxxiii{%
Whoever obeys the Messenger is obeying God. And whoever turns away—We did not send you as a watcher over them.\qt@no{80}}%
\qt@newcmd\qurantrans@en@dlxxiv{%
They profess obedience, but when they leave your presence, some of them conspire something contrary to what you said. But God writes down what they conspire. So avoid them, and put your trust in God. God is Guardian enough.\qt@no{81}}%
\qt@newcmd\qurantrans@en@dlxxv{%
Do they not ponder the Quran? Had it been from any other than God, they would have found in it much discrepancy.\qt@no{82}}%
\qt@newcmd\qurantrans@en@dlxxvi{%
When some news of security or alarm comes their way, they broadcast it. But had they referred it to the Messenger, and to those in authority among them, those who can draw conclusions from it would have comprehended it. Were it not for God’s blessing and mercy upon you, you would have followed the Devil, except for a few.\qt@no{83}}%
\qt@newcmd\qurantrans@en@dlxxvii{%
So fight in the cause of God; you are responsible only for yourself. And rouse the believers. Perhaps God will restrain the might of those who disbelieve. God is Stronger in Might, and More Punishing.\qt@no{84}}%
\qt@newcmd\qurantrans@en@dlxxviii{%
Whoever intercedes for a good cause has a share in it, and whoever intercedes for an evil cause shares in its burdens. God keeps watch over everything.\qt@no{85}}%
\qt@newcmd\qurantrans@en@dlxxix{%
When you are greeted with a greeting, respond with a better greeting, or return it. God keeps count of everything.\qt@no{86}}%
\qt@newcmd\qurantrans@en@dlxxx{%
God—there is no god except He. He will gather you to the Day of Resurrection, in which there is no doubt. And who speaks more truly than God?\qt@no{87}}%
\qt@newcmd\qurantrans@en@dlxxxi{%
What is the matter with you, divided into two factions regarding the hypocrites, when God Himself has overwhelmed them on account of what they did? Do you want to guide those whom God has led astray? Whomever God leads astray—you will never find for him a way.\qt@no{88}}%
\qt@newcmd\qurantrans@en@dlxxxii{%
They would love to see you disbelieve, just as they disbelieve, so you would become equal. So do not befriend any of them, unless they emigrate in the way of God. If they turn away, seize them and execute them wherever you may find them; and do not take from among them allies or supporters.\qt@no{89}}%
\qt@newcmd\qurantrans@en@dlxxxiii{%
Except those who join people with whom you have a treaty, or those who come to you reluctant to fight you or fight their own people. Had God willed, He would have given them power over you, and they would have fought you. If they withdraw from you, and do not fight you, and offer you peace, then God assigns no excuse for you against them.\qt@no{90}}%
\qt@newcmd\qurantrans@en@dlxxxiv{%
You will find others who want security from you, and security from their own people. But whenever they are tempted into civil discord, they plunge into it. So if they do not withdraw from you, nor offer you peace, nor restrain their hands, seize them and execute them wherever you find them. Against these, We have given you clear authorization.\qt@no{91}}%
\qt@newcmd\qurantrans@en@dlxxxv{%
Never should a believer kill another believer, unless by error. Anyone who kills a believer by error must set free a believing slave, and pay compensation to the victim’s family, unless they remit it as charity. If the victim belonged to a people who are hostile to you, but is a believer, then the compensation is to free a believing slave. If he belonged to a people with whom you have a treaty, then compensation should be handed over to his family, and a believing slave set free. Anyone who lacks the means must fast for two consecutive months, by way of repentance to God. God is All-Knowing, Most Wise.\qt@no{92}}%
\qt@newcmd\qurantrans@en@dlxxxvi{%
Whoever kills a believer deliberately, the penalty for him is Hell, where he will remain forever. And God will be angry with him, and will curse him, and will prepare for him a terrible punishment.\qt@no{93}}%
\qt@newcmd\qurantrans@en@dlxxxvii{%
O you who believe! When you journey in the way of God, investigate, and do not say to him who offers you peace, “You are not a believer,” aspiring for the goods of this world. With God are abundant riches. You yourselves were like this before, and God bestowed favor on you; so investigate. God is well aware of what you do.\qt@no{94}}%
\qt@newcmd\qurantrans@en@dlxxxviii{%
Not equal are the inactive among the believers—except the disabled—and the strivers in the cause of God with their possessions and their persons. God prefers the strivers with their possessions and their persons above the inactive, by a degree. But God has promised goodness to both. Yet God favors the strivers, over the inactive, with a great reward.\qt@no{95}}%
\qt@newcmd\qurantrans@en@dlxxxix{%
Degrees from Him, and forgiveness, and mercy. God is Forgiving and Merciful.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dxc{%
While the angels are removing the souls of those who have wronged themselves, they will say, “What was the matter with you?” They will say, “We were oppressed in the land.” They will say, “Was God’s earth not vast enough for you to emigrate in it?” These—their refuge is Hell. What a wretched retreat!\qt@no{97}}%
\qt@newcmd\qurantrans@en@dxci{%
Except for the weak among men, and women, and children who have no means to act, and no means to find a way out.\qt@no{98}}%
\qt@newcmd\qurantrans@en@dxcii{%
These—God may well pardon them. God is Pardoning and Forgiving.\qt@no{99}}%
\qt@newcmd\qurantrans@en@dxciii{%
Anyone who emigrates for the sake of God will find on earth many places of refuge, and plentitude. Anyone who leaves his home, emigrating to God and His Messenger, and then is overtaken by death, his compensation falls on God. God is Forgiver, Most Merciful.\qt@no{100}}%
\qt@newcmd\qurantrans@en@dxciv{%
When you travel in the land, there is no blame on you for shortening the prayers, if you fear that the disbelievers may harm you. The disbelievers are your manifest enemies.\qt@no{101}}%
\qt@newcmd\qurantrans@en@dxcv{%
When you are among them, and you stand to lead them in prayer, let a group of them stand with you, and let them hold their weapons. Then, when they have done their prostrations, let them withdraw to the rear, and let another group, that have not prayed yet, come forward and pray with you; and let them take their precautions and their weapons. Those who disbelieve would like you to neglect your weapons and your equipment, so they can attack you in a single assault. You commit no error, if you are hampered by rain or are sick, by putting down your weapons; but take precautions. Indeed, God has prepared for the disbelievers a demeaning punishment.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dxcvi{%
When you have completed the prayer, remember God, standing, or sitting, or on your sides. And when you feel secure, perform the prayer. The prayer is obligatory for believers at specific times.\qt@no{103}}%
\qt@newcmd\qurantrans@en@dxcvii{%
And do not falter in the pursuit of the enemy. If you are aching, they are aching as you are aching, but you expect from God what they cannot expect. God is Knowledgeable and Wise.\qt@no{104}}%
\qt@newcmd\qurantrans@en@dxcviii{%
We have revealed to you the Scripture, with the truth, so that you judge between people in accordance with what God has shown you. And do not be an advocate for the traitors.\qt@no{105}}%
\qt@newcmd\qurantrans@en@dxcix{%
And ask God for forgiveness. God is Forgiver and Merciful.\qt@no{106}}%
\qt@newcmd\qurantrans@en@dc{%
And do not argue on behalf of those who deceive themselves. God does not love the deceitful sinner.\qt@no{107}}%
\qt@newcmd\qurantrans@en@dci{%
They hide from the people, but they cannot hide from God. He is with them, as they plot by night with words He does not approve. God comprehends what they do.\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcii{%
There you are, arguing on their behalf in the present life, but who will argue with God on their behalf on the Day of Resurrection? Or who will be their representative?\qt@no{109}}%
\qt@newcmd\qurantrans@en@dciii{%
Whoever commits evil, or wrongs his soul, then implores God for forgiveness, will find God Forgiving and Merciful.\qt@no{110}}%
\qt@newcmd\qurantrans@en@dciv{%
And Whoever earns a sin, earns it against himself. God is Aware and Wise.\qt@no{111}}%
\qt@newcmd\qurantrans@en@dcv{%
And whoever commits a mistake, or a sin, and then blames it on an innocent person, has taken a slander and a clear sin.\qt@no{112}}%
\qt@newcmd\qurantrans@en@dcvi{%
Were it not for God’s grace towards you, and His mercy, a faction of them would have managed to mislead you. But they only mislead themselves, and they cannot harm you in any way. God has revealed to you the Scripture and wisdom, and has taught you what you did not know. God’s goodness towards you is great.\qt@no{113}}%
\qt@newcmd\qurantrans@en@dcvii{%
There is no good in much of their private counsels, except for him who advocates charity, or kindness, or reconciliation between people. Whoever does that, seeking God’s approval, We will give him a great compensation.\qt@no{114}}%
\qt@newcmd\qurantrans@en@dcviii{%
Whoever makes a breach with the Messenger, after the guidance has become clear to him, and follows other than the path of the believers, We will direct him in the direction he has chosen, and commit him to Hell—what a terrible destination!\qt@no{115}}%
\qt@newcmd\qurantrans@en@dcix{%
God will not forgive that partners be associated with Him; but will forgive anything less than that, to whomever He wills. Anyone who ascribes partners to God has strayed into far error.\qt@no{116}}%
\qt@newcmd\qurantrans@en@dcx{%
They invoke in His stead only females. In fact, they invoke none but a rebellious devil.\qt@no{117}}%
\qt@newcmd\qurantrans@en@dcxi{%
God has cursed him. And he said, “I will take to myself my due share of Your servants.”\qt@no{118}}%
\qt@newcmd\qurantrans@en@dcxii{%
“And I will mislead them, and I will entice them, and I will prompt them to slit the ears of cattle, and I will prompt them to alter the creation of God.” Whoever takes Satan as a lord, instead of God, has surely suffered a profound loss.\qt@no{119}}%
\qt@newcmd\qurantrans@en@dcxiii{%
He promises them, and he raises their expectations, but Satan promises them nothing but delusions.\qt@no{120}}%
\qt@newcmd\qurantrans@en@dcxiv{%
These—their place is Hell, and they will find no escape from it.\qt@no{121}}%
\qt@newcmd\qurantrans@en@dcxv{%
But as for those who believe and do righteous deeds, We will admit them into gardens beneath which rivers flow, where they will abide forever. The promise of God is true—and who is more truthful in speech than God?\qt@no{122}}%
\qt@newcmd\qurantrans@en@dcxvi{%
It is not in accordance with your wishes, nor in accordance with the wishes of the People of the Scripture. Whoever works evil will pay for it, and will not find for himself, besides God, any protector or savior.\qt@no{123}}%
\qt@newcmd\qurantrans@en@dcxvii{%
But whoever works righteousness, whether male or female, and is a believer—those will enter Paradise, and will not be wronged a whit.\qt@no{124}}%
\qt@newcmd\qurantrans@en@dcxviii{%
And who is better in religion than he who submits himself wholly to God, and is a doer of good, and follows the faith of Abraham the Monotheist? God has chosen Abraham for a friend.\qt@no{125}}%
\qt@newcmd\qurantrans@en@dcxix{%
To God belongs what is in the heavens and what is on earth, and God encompasses everything.\qt@no{126}}%
\qt@newcmd\qurantrans@en@dcxx{%
They ask you for a ruling about women. Say, “God gives you a ruling about them, and so does what is stated to you in the Book about widowed women from whom you withhold what is decreed for them, yet you desire to marry them, and about helpless children: that you should treat the orphans fairly.” Whatever good you do, God knows it.\qt@no{127}}%
\qt@newcmd\qurantrans@en@dcxxi{%
If a woman fears maltreatment or desertion from her husband, there is no fault in them if they reconcile their differences, for reconciliation is best. Souls are prone to avarice; yet if you do what is good, and practice piety—God is Cognizant of what you do.\qt@no{128}}%
\qt@newcmd\qurantrans@en@dcxxii{%
You will not be able to treat women with equal fairness, no matter how much you desire it. But do not be so biased as to leave another suspended. If you make amends, and act righteously—God is Forgiving and Merciful.\qt@no{129}}%
\qt@newcmd\qurantrans@en@dcxxiii{%
And if they separate, God will enrich each from His abundance. God is Bounteous and Wise.\qt@no{130}}%
\qt@newcmd\qurantrans@en@dcxxiv{%
To God belongs everything in the heavens and everything on earth. We have instructed those who were given the Book before you, and you, to be conscious of God. But if you refuse—to God belongs everything in the heavens and everything on earth. God is in no need, Praiseworthy.\qt@no{131}}%
\qt@newcmd\qurantrans@en@dcxxv{%
To God belongs everything in the heavens and everything on earth. God suffices as Manager.\qt@no{132}}%
\qt@newcmd\qurantrans@en@dcxxvi{%
If He wills, He can do away with you, O people, and bring others. God is Able to do that.\qt@no{133}}%
\qt@newcmd\qurantrans@en@dcxxvii{%
Whoever desires the reward of this world—with God is the reward of this world and the next. God is All-Hearing, All-Seeing.\qt@no{134}}%
\qt@newcmd\qurantrans@en@dcxxviii{%
O you who believe! Stand firmly for justice, as witnesses to God, even if against yourselves, or your parents, or your relatives. Whether one is rich or poor, God takes care of both. So do not follow your desires, lest you swerve. If you deviate, or turn away—then God is Aware of what you do.\qt@no{135}}%
\qt@newcmd\qurantrans@en@dcxxix{%
O you who believe! Believe in God and His messenger, and the Book He sent down to His messenger, and the Book He sent down before. Whoever rejects God, His angels, His Books, His messengers, and the Last Day, has strayed far in error.\qt@no{136}}%
\qt@newcmd\qurantrans@en@dcxxx{%
Those who believe, then disbelieve, then believe, then disbelieve, then increase in disbelief, God will not forgive them, nor will He guide them to a way.\qt@no{137}}%
\qt@newcmd\qurantrans@en@dcxxxi{%
Inform the hypocrites that they will have a painful punishment.\qt@no{138}}%
\qt@newcmd\qurantrans@en@dcxxxii{%
Those who ally themselves with the disbelievers instead of the believers. Do they seek glory in them? All glory belongs to God.\qt@no{139}}%
\qt@newcmd\qurantrans@en@dcxxxiii{%
He has revealed to you in the Book that when you hear God’s revelations being rejected, or ridiculed, do not sit with them until they engage in some other subject. Otherwise, you would be like them. God will gather the hypocrites and the disbelievers, into Hell, altogether.\qt@no{140}}%
\qt@newcmd\qurantrans@en@dcxxxiv{%
Those who lie in wait for you: if you attain victory from God, they say, “Were we not with you?” But if the disbelievers get a turn, they say, “Did we not side with you, and defend you from the believers?” God will judge between you on the Day of Resurrection; and God will give the disbelievers no means of overcoming the believers.\qt@no{141}}%
\qt@newcmd\qurantrans@en@dcxxxv{%
The hypocrites try to deceive God, but He is deceiving them. And when they stand for prayer, they stand lazily, showing off in front of people, and remembering God only a little.\qt@no{142}}%
\qt@newcmd\qurantrans@en@dcxxxvi{%
Wavering in between, neither with these, nor with those. Whomever God sends astray, you will never find for him a way.\qt@no{143}}%
\qt@newcmd\qurantrans@en@dcxxxvii{%
O you who believe! Do not befriend disbelievers rather than believers. Do you want to give God a clear case against you?\qt@no{144}}%
\qt@newcmd\qurantrans@en@dcxxxviii{%
The hypocrites will be in the lowest level of the Fire, and you will find no helper for them.\qt@no{145}}%
\qt@newcmd\qurantrans@en@dcxxxix{%
Except those who repent, and reform, and hold fast to God, and dedicate their religion to God alone. These are with the believers; and God will give the believers a great reward.\qt@no{146}}%
\qt@newcmd\qurantrans@en@dcxl{%
What would God accomplish by your punishment, if you have given thanks, and have believed? God is Appreciative and Cognizant.\qt@no{147}}%
\qt@newcmd\qurantrans@en@dcxli{%
God does not like the public uttering of bad language, unless someone was wronged. God is Hearing and Knowing.\qt@no{148}}%
\qt@newcmd\qurantrans@en@dcxlii{%
If you let a good deed be shown, or conceal it, or pardon an offense—God is Pardoning and Capable.\qt@no{149}}%
\qt@newcmd\qurantrans@en@dcxliii{%
Those who disbelieve in God and His messengers, and want to separate between God and His messengers, and say, “We believe in some, and reject some,” and wish to take a path in between.\qt@no{150}}%
\qt@newcmd\qurantrans@en@dcxliv{%
These are the unbelievers, truly. We have prepared for the unbelievers a shameful punishment.\qt@no{151}}%
\qt@newcmd\qurantrans@en@dcxlv{%
As for those who believe in God and His messengers, and make no distinction between any of them—He will give them their rewards. God is Forgiver and Merciful.\qt@no{152}}%
\qt@newcmd\qurantrans@en@dcxlvi{%
The People of the Scripture challenge you to bring down to them a book from the sky. They had asked Moses for something even greater. They said, “Show us God plainly.” The thunderbolt struck them for their wickedness. Then they took the calf for worship, even after the clear proofs had come to them. Yet We pardoned that, and We gave Moses a clear authority.\qt@no{153}}%
\qt@newcmd\qurantrans@en@dcxlvii{%
And We raised the Mount above them in accordance with their covenant, and We said to them, “Enter the gate humbly”, and We said to them, “Do not violate the Sabbath”, and We received from them a solemn pledge.\qt@no{154}}%
\qt@newcmd\qurantrans@en@dcxlviii{%
But for their violation of their covenant, and their denial of God’s revelations, and their killing of the prophets unjustly, and their saying, “Our minds are closed.” In fact, God has sealed them for their disbelief, so they do not believe, except for a few.\qt@no{155}}%
\qt@newcmd\qurantrans@en@dcxlix{%
And for their faithlessness, and their saying against Mary a monstrous slander.\qt@no{156}}%
\qt@newcmd\qurantrans@en@dcl{%
And for their saying, “We have killed the Messiah, Jesus, the son of Mary, the Messenger of God.” In fact, they did not kill him, nor did they crucify him, but it appeared to them as if they did. Indeed, those who differ about him are in doubt about it. They have no knowledge of it, except the following of assumptions. Certainly, they did not kill him.\qt@no{157}}%
\qt@newcmd\qurantrans@en@dcli{%
Rather, God raised him up to Himself. God is Mighty and Wise.\qt@no{158}}%
\qt@newcmd\qurantrans@en@dclii{%
There is none from the People of the Scripture but will believe in him before his death, and on the Day of Resurrection he will be a witness against them.\qt@no{159}}%
\qt@newcmd\qurantrans@en@dcliii{%
Due to wrongdoing on the part of the Jews, We forbade them good things that used to be lawful for them; and for deterring many from God’s path.\qt@no{160}}%
\qt@newcmd\qurantrans@en@dcliv{%
And for their taking usury, although they were forbidden it; and for their consuming people's wealth dishonestly. We have prepared for the faithless among them a painful torment.\qt@no{161}}%
\qt@newcmd\qurantrans@en@dclv{%
But those among them firmly rooted in knowledge, and the believers, believe in what was revealed to you, and in what was revealed before you; and the observers of prayers, and the givers of charity, and the believers in God and the Last Day—upon these We will bestow an immense reward.\qt@no{162}}%
\qt@newcmd\qurantrans@en@dclvi{%
We have inspired you, as We had inspired Noah and the prophets after him. And We inspired Abraham, and Ishmael, and Isaac, and Jacob, and the Patriarchs, and Jesus, and Job, and Jonah, and Aaron, and Solomon. And We gave David the Psalms.\qt@no{163}}%
\qt@newcmd\qurantrans@en@dclvii{%
Some messengers We have already told you about, while some messengers We have not told you about. And God spoke to Moses directly.\qt@no{164}}%
\qt@newcmd\qurantrans@en@dclviii{%
Messengers delivering good news, and bringing warnings; so that people may have no excuse before God after the coming of the messengers. God is Powerful and Wise.\qt@no{165}}%
\qt@newcmd\qurantrans@en@dclix{%
But God bears witness to what He revealed to you. He revealed it with His knowledge. And the angels bear witness. Though God is a sufficient witness.\qt@no{166}}%
\qt@newcmd\qurantrans@en@dclx{%
Those who disbelieve and repel from God’s path have gone far astray.\qt@no{167}}%
\qt@newcmd\qurantrans@en@dclxi{%
Those who disbelieve and transgress; God is not about to forgive them, nor will He guide them to any path.\qt@no{168}}%
\qt@newcmd\qurantrans@en@dclxii{%
Except to the path of Hell, where they will dwell forever. And that is easy for God.\qt@no{169}}%
\qt@newcmd\qurantrans@en@dclxiii{%
O people! The Messenger has come to you with the truth from your Lord, so believe—that is best for you. But if you disbelieve, to God belongs everything in the heavens and the earth. God is Omniscient and Wise.\qt@no{170}}%
\qt@newcmd\qurantrans@en@dclxiv{%
O People of the Scripture! Do not exaggerate in your religion, and do not say about God except the truth. The Messiah, Jesus, the son of Mary, is the Messenger of God, and His Word that He conveyed to Mary, and a Spirit from Him. So believe in God and His messengers, and do not say, “Three.” Refrain—it is better for you. God is only one God. Glory be to Him—that He should have a son. To Him belongs everything in the heavens and the earth, and God is a sufficient Protector.\qt@no{171}}%
\qt@newcmd\qurantrans@en@dclxv{%
The Messiah does not disdain to be a servant of God, nor do the favored angels. Whoever disdains His worship, and is too arrogant—He will round them up to Himself altogether.\qt@no{172}}%
\qt@newcmd\qurantrans@en@dclxvi{%
But as for those who believe and do good works, He will pay them their wages in full, and will increase His grace for them. But as for those who disdain and are too proud, He will punish them with an agonizing punishment. And they will find for themselves, apart from God, no lord and no savior.\qt@no{173}}%
\qt@newcmd\qurantrans@en@dclxvii{%
O people! A proof has come to you from your Lord, and We sent down to you a clear light.\qt@no{174}}%
\qt@newcmd\qurantrans@en@dclxviii{%
As for those who believe in God, and hold fast to Him, He will admit them into mercy and grace from Him, and will guide them to Himself in a straight path.\qt@no{175}}%
\qt@newcmd\qurantrans@en@dclxix{%
They ask you for a ruling. Say, “God gives you a ruling concerning the person who has neither parents nor children.” If a man dies, and leaves no children, and he had a sister, she receives one-half of what he leaves. And he inherits from her if she leaves no children. But if there are two sisters, they receive two-thirds of what he leaves. If the siblings are men and women, the male receives the share of two females.” God makes things clear for you, lest you err. God is Aware of everything.\qt@no{176}}%
\qt@newcmd\qurantrans@en@dclxx{%
\basmalahen O you who believe! Fulfill your commitments. Livestock animals are permitted for you, except those specified to you; but not wild game while you are in pilgrim sanctity. God decrees whatever He wills.\qt@no{1}}%
\qt@newcmd\qurantrans@en@dclxxi{%
O you who believe! Do not violate God’s sacraments, nor the Sacred Month, nor the offerings, nor the garlanded, nor those heading for the Sacred House seeking blessings from their Lord and approval. When you have left the pilgrim sanctity, you may hunt. And let not the hatred of people who barred you from the Sacred Mosque incite you to aggression. And cooperate with one another in virtuous conduct and conscience, and do not cooperate with one another in sin and hostility. And fear God. God is severe in punishment.\qt@no{2}}%
\qt@newcmd\qurantrans@en@dclxxii{%
Prohibited for you are carrion, blood, the flesh of swine, and animals dedicated to other than God; also the flesh of animals strangled, killed violently, killed by a fall, gored to death, mangled by wild animals—except what you rescue, and animals sacrificed on altars; and the practice of drawing lots. For it is immoral. Today, those who disbelieve have despaired of your religion, so do not fear them, but fear Me. Today I have perfected your religion for you, and have completed My favor upon you, and have approved Islam as a religion for you. But whoever is compelled by hunger, with no intent of wrongdoing—God is Forgiving and Merciful.\qt@no{3}}%
\qt@newcmd\qurantrans@en@dclxxiii{%
They ask you what is permitted for them. Say, “Permitted for you are all good things, including what trained dogs and falcons catch for you.” You train them according to what God has taught you. So eat from what they catch for you, and pronounce God’s name over it. And fear God. God is Swift in reckoning.\qt@no{4}}%
\qt@newcmd\qurantrans@en@dclxxiv{%
Today all good things are made lawful for you. And the food of those given the Scripture is lawful for you, and your food is lawful for them. So are chaste believing women, and chaste women from the people who were given the Scripture before you, provided you give them their dowries, and take them in marriage, not in adultery, nor as mistresses. But whoever rejects faith, his work will be in vain, and in the Hereafter he will be among the losers.\qt@no{5}}%
\qt@newcmd\qurantrans@en@dclxxv{%
O you who believe! When you rise to pray, wash your faces and your hands and arms to the elbows, and wipe your heads, and your feet to the ankles. If you had intercourse, then purify yourselves. If you are ill, or travelling, or one of you returns from the toilet, or you had contact with women, and could not find water, then use some clean sand and wipe your faces and hands with it. God does not intend to burden you, but He intends to purify you, and to complete His blessing upon you, that you may be thankful.\qt@no{6}}%
\qt@newcmd\qurantrans@en@dclxxvi{%
And Remember God’s blessings upon you, and His covenant which He covenanted with you; when you said, “We hear and we obey.” And remain conscious of God, for God knows what the hearts contain.\qt@no{7}}%
\qt@newcmd\qurantrans@en@dclxxvii{%
O you who believe! Be upright to God, witnessing with justice; and let not the hatred of a certain people prevent you from acting justly. Adhere to justice, for that is nearer to piety; and fear God. God is informed of what you do.\qt@no{8}}%
\qt@newcmd\qurantrans@en@dclxxviii{%
God has promised those who believe and work righteousness: they will have forgiveness and a great reward.\qt@no{9}}%
\qt@newcmd\qurantrans@en@dclxxix{%
As for those who disbelieve and reject Our revelations—these are the inmates of Hell.\qt@no{10}}%
\qt@newcmd\qurantrans@en@dclxxx{%
O you who believe! Remember God's blessings upon you; when certain people intended to extend their hands against you, and He restrained their hands from you. So reverence God, and in God let the believers put their trust.\qt@no{11}}%
\qt@newcmd\qurantrans@en@dclxxxi{%
God received a pledge from the Children of Israel, and We raised among them twelve chiefs. God said, “I am with you; if you perform the prayer, and pay the alms, and believe in My messengers and support them, and lend God a loan of righteousness; I will remit your sins, and admit you into Gardens beneath which rivers flow. But whoever among you disbelieves afterwards has strayed from the right way.”\qt@no{12}}%
\qt@newcmd\qurantrans@en@dclxxxii{%
Because of their breaking their pledge, We cursed them, and made their hearts hard. They twist the words out of their context, and they disregarded some of what they were reminded of. You will always witness deceit from them, except for a few of them. But pardon them, and overlook. God loves the doers of good.\qt@no{13}}%
\qt@newcmd\qurantrans@en@dclxxxiii{%
And from those who say, “We are Christians,” We received their pledge, but they neglected some of what they were reminded of. So We provoked enmity and hatred among them until the Day of Resurrection; God will then inform them of what they used to craft.\qt@no{14}}%
\qt@newcmd\qurantrans@en@dclxxxiv{%
O People of the Book! Our Messenger has come to you, clarifying for you much of what you kept hidden of the Book, and overlooking much. A light from God has come to you, and a clear Book.\qt@no{15}}%
\qt@newcmd\qurantrans@en@dclxxxv{%
God guides with it whoever follows His approval to the ways of peace, and He brings them out of darkness into light, by His permission, and He guides them in a straight path.\qt@no{16}}%
\qt@newcmd\qurantrans@en@dclxxxvi{%
They disbelieve those who say, “God is the Christ, the son of Mary.” Say, “Who can prevent God, if He willed, from annihilating the Christ son of Mary, and his mother, and everyone on earth?” To God belongs the sovereignty of the heavens and the earth and what is between them. He creates whatever He wills, and God has power over everything.\qt@no{17}}%
\qt@newcmd\qurantrans@en@dclxxxvii{%
The Jews and the Christians say, “We are the children of God, and His beloved.” Say, “Why then does He punish you for your sins?” In fact, you are humans from among those He created. He forgives whom He wills, and He punishes whom He wills. To God belongs the dominion of the heavens and the earth and what lies between them, and to Him is the return.\qt@no{18}}%
\qt@newcmd\qurantrans@en@dclxxxviii{%
O People of the Book! Our Messenger has come to you, making things clear to you—after a cessation of messengers—so that you cannot say, “No preacher has come to us, and no warner.” In fact, a preacher has come to you, and a warner; and God is Capable of everything.\qt@no{19}}%
\qt@newcmd\qurantrans@en@dclxxxix{%
When Moses said to his people, “O my people, remember God’s blessings upon you, when He placed prophets among you, and made you kings, and gave you what He never gave any other people.”\qt@no{20}}%
\qt@newcmd\qurantrans@en@dcxc{%
“O my people, enter the Holy Land which God has assigned for you, and do not turn back, lest you return as losers.”\qt@no{21}}%
\qt@newcmd\qurantrans@en@dcxci{%
They said, “O Moses, there are tyrannical people in it; we will not enter it until they leave it. If they leave it, we will be entering.”\qt@no{22}}%
\qt@newcmd\qurantrans@en@dcxcii{%
Two men of those who feared, but whom God had blessed, said, “Go at them by the gate; and when you have entered it, you will prevail. And put your trust in God, if you are believers.”\qt@no{23}}%
\qt@newcmd\qurantrans@en@dcxciii{%
They said, “O Moses, we will not enter it, ever, as long as they are in it. So go ahead, you and your Lord, and fight. We are staying right here.”\qt@no{24}}%
\qt@newcmd\qurantrans@en@dcxciv{%
He said, “My Lord! I have control only over myself and my brother, so separate between us and between the wicked people.”\qt@no{25}}%
\qt@newcmd\qurantrans@en@dcxcv{%
He said, “It is forbidden for them for forty years. They will wander aimlessly in the land. So do not grieve over the defiant people.”\qt@no{26}}%
\qt@newcmd\qurantrans@en@dcxcvi{%
And relate to them the true story of Adam's two sons: when they offered an offering, and it was accepted from one of them, but it was not accepted from the other. He Said, “I will kill you.” He Said, “God accepts only from the righteous.”\qt@no{27}}%
\qt@newcmd\qurantrans@en@dcxcvii{%
“If you extend your hand to kill me, I will not extend my hand to kill you; for I fear God, Lord of the Worlds.”\qt@no{28}}%
\qt@newcmd\qurantrans@en@dcxcviii{%
“I would rather you bear my sin and your sin, and you become among the inmates of the Fire. Such is the reward for the evildoers.”\qt@no{29}}%
\qt@newcmd\qurantrans@en@dcxcix{%
Then His soul prompted him to kill his brother, so he killed him, and became one of the losers.\qt@no{30}}%
\qt@newcmd\qurantrans@en@dcc{%
Then God sent a raven digging the ground, to show him how to cover his brother's corpse. He said, “Woe to me! I was unable to be like this raven, and bury my brother's corpse.” So he became full of regrets.\qt@no{31}}%
\qt@newcmd\qurantrans@en@dcci{%
Because of that We ordained for the Children of Israel: that whoever kills a person—unless it is for murder or corruption on earth—it is as if he killed the whole of mankind; and whoever saves it, it is as if he saved the whole of mankind. Our messengers came to them with clarifications, but even after that, many of them continue to commit excesses in the land.\qt@no{32}}%
\qt@newcmd\qurantrans@en@dccii{%
The punishment for those who fight God and His Messenger, and strive to spread corruption on earth, is that they be killed, or crucified, or have their hands and feet cut off on opposite sides, or be banished from the land. That is to disgrace them in this life; and in the Hereafter they will have a terrible punishment.\qt@no{33}}%
\qt@newcmd\qurantrans@en@dcciii{%
Except for those who repent before you apprehend them. So know that God is Forgiving and Merciful.\qt@no{34}}%
\qt@newcmd\qurantrans@en@dcciv{%
O you who believe! Be conscious of God, and seek the means of approach to Him, and strive in His cause, so that you may succeed.\qt@no{35}}%
\qt@newcmd\qurantrans@en@dccv{%
As for those who disbelieve, even if they owned everything on earth, and the like of it with it, and they offered it to ransom themselves from the torment of the Day of Resurrection, it will not be accepted from them. For them is a painful punishment.\qt@no{36}}%
\qt@newcmd\qurantrans@en@dccvi{%
They will want to leave the Fire, but they will not leave it. For them is a lasting punishment.\qt@no{37}}%
\qt@newcmd\qurantrans@en@dccvii{%
As for the thief, whether male or female, cut their hands as a penalty for what they have reaped—a deterrent from God. God is Mighty and Wise.\qt@no{38}}%
\qt@newcmd\qurantrans@en@dccviii{%
But whoever repents after his crime, and reforms, God will accept his repentance. God is Forgiving and Merciful.\qt@no{39}}%
\qt@newcmd\qurantrans@en@dccix{%
Do you not know that to God belongs the kingdom of the heavens and the earth? He punishes whom He wills, and He forgives whom He wills. And God is Capable of everything.\qt@no{40}}%
\qt@newcmd\qurantrans@en@dccx{%
O Messenger! Do not let those who are quick to disbelief grieve you—from among those who say with their mouths, “We believe,” but their hearts do not believe; and from among the Jews—listeners to lies, listeners to other people who did not come to you. They distort words from their places, and they say, “If you are given this, accept it; but if you are not given it, beware.” Whomever God has willed to divert, you have nothing for him from God. Those are they whose hearts God does not intend to purify. For them is disgrace in this world, and for them is a great punishment in the Hereafter.\qt@no{41}}%
\qt@newcmd\qurantrans@en@dccxi{%
Listeners to falsehoods, eaters of illicit earnings. If they come to you, judge between them, or turn away from them. If you turn away from them, they will not harm you in the least. But if you judge, judge between them equitably. God loves the equitable.\qt@no{42}}%
\qt@newcmd\qurantrans@en@dccxii{%
But why do they come to you for judgment, when they have the Torah, in which is God’s Law? Yet they turn away after that. These are not believers.\qt@no{43}}%
\qt@newcmd\qurantrans@en@dccxiii{%
We have revealed the Torah, wherein is guidance and light. The submissive prophets ruled the Jews according to it, so did the rabbis and the scholars, as they were required to protect God’s Book, and were witnesses to it. So do not fear people, but fear Me. And do not sell My revelations for a cheap price. Those who do not rule according to what God revealed are the unbelievers.\qt@no{44}}%
\qt@newcmd\qurantrans@en@dccxiv{%
And We wrote for them in it: a life for a life, an eye for an eye, a nose for a nose, an ear for an ear, a tooth for a tooth, and an equal wound for a wound; but whoever forgoes it in charity, it will serve as atonement for him. Those who do not rule according to what God revealed are the evildoers.\qt@no{45}}%
\qt@newcmd\qurantrans@en@dccxv{%
In their footsteps, We sent Jesus son of Mary, fulfilling the Torah that preceded him; and We gave him the Gospel, wherein is guidance and light, and confirming the Torah that preceded him, and guidance and counsel for the righteous.\qt@no{46}}%
\qt@newcmd\qurantrans@en@dccxvi{%
So let the people of the Gospel rule according to what God revealed in it. Those who do not rule according to what God revealed are the sinners.\qt@no{47}}%
\qt@newcmd\qurantrans@en@dccxvii{%
And We revealed to you the Book, with truth, confirming the Scripture that preceded it, and superseding it. So judge between them according to what God revealed, and do not follow their desires if they differ from the truth that has come to you. For each of you We have assigned a law and a method. Had God willed, He could have made you a single nation, but He tests you through what He has given you. So compete in righteousness. To God is your return, all of you; then He will inform you of what you had disputed.\qt@no{48}}%
\qt@newcmd\qurantrans@en@dccxviii{%
And judge between them according to what God revealed, and do not follow their desires. And beware of them, lest they lure you away from some of what God has revealed to you. But if they turn away, know that God intends to strike them with some of their sins. In fact, a great many people are corrupt.\qt@no{49}}%
\qt@newcmd\qurantrans@en@dccxix{%
Is it the laws of the time of ignorance that they desire? Who is better than God in judgment for people who are certain?\qt@no{50}}%
\qt@newcmd\qurantrans@en@dccxx{%
O you who believe! Do not take the Jews and the Christians as allies; some of them are allies of one another. Whoever of you allies himself with them is one of them. God does not guide the wrongdoing people.\qt@no{51}}%
\qt@newcmd\qurantrans@en@dccxxi{%
You will see those in whose hearts is sickness racing towards them. They say, “We fear the wheel of fate may turn against us.” But perhaps God will bring about victory, or some event of His making; thereupon they will regret what they concealed within themselves.\qt@no{52}}%
\qt@newcmd\qurantrans@en@dccxxii{%
Those who believe will say, “Are these the ones who swore by God with their strongest oaths that they are with you?” Their works have failed, so they became losers.\qt@no{53}}%
\qt@newcmd\qurantrans@en@dccxxiii{%
O you who believe! Whoever of you goes back on his religion—God will bring a people whom He loves and who love Him, kind towards the believers, stern with the disbelievers. They strive in the way of God, and do not fear the blame of the critic. That is the grace of God; He bestows it upon whomever He wills. God is Embracing and Knowing.\qt@no{54}}%
\qt@newcmd\qurantrans@en@dccxxiv{%
Your allies are God, and His Messenger, and those who believe—those who pray regularly, and give charity, and bow down.\qt@no{55}}%
\qt@newcmd\qurantrans@en@dccxxv{%
Whoever allies himself with God, and His Messenger, and those who believe—surely the Party of God is the victorious.\qt@no{56}}%
\qt@newcmd\qurantrans@en@dccxxvi{%
O you who believe! Do not befriend those who take your religion in mockery and as a sport, be they from among those who were given the Scripture before you, or the disbelievers. And obey God, if you are believers.\qt@no{57}}%
\qt@newcmd\qurantrans@en@dccxxvii{%
When you call to the prayer, they take it as a joke and a trifle. That is because they are people who do not reason.\qt@no{58}}%
\qt@newcmd\qurantrans@en@dccxxviii{%
Say, “O People of the Scripture! Do you resent us only because we believe in God, and in what was revealed to us, and in what was revealed previously; and most of you are sinners?”\qt@no{59}}%
\qt@newcmd\qurantrans@en@dccxxix{%
Say, “Shall I inform you of worse than that for retribution from God? He whom God has cursed, and with whom He became angry; and He turned some of them into apes, and swine, and idol worshipers. These are in a worse position, and further away from the right way.”\qt@no{60}}%
\qt@newcmd\qurantrans@en@dccxxx{%
When they come to you, they say, “We believe,” though they have entered with disbelief, and they have departed with it. But God is well aware of what they hide.\qt@no{61}}%
\qt@newcmd\qurantrans@en@dccxxxi{%
You see many of them competing with one another in sin and hostility, and their consuming of what is illicit. What they have been doing is truly evil.\qt@no{62}}%
\qt@newcmd\qurantrans@en@dccxxxii{%
Why do the rabbis and the priests not prevent them from speaking sinfully and from consuming forbidden wealth? Evil is what they have been doing.\qt@no{63}}%
\qt@newcmd\qurantrans@en@dccxxxiii{%
The Jews say, “God’s hand is tied.” It is their hands that are tied, and they are cursed for what they say. In fact, His hands are outstretched; He gives as He wills. Certainly, what was revealed to your from your Lord will increase many of them in defiance and blasphemy. And We placed between them enmity and hatred, until the Day of Resurrection. Whenever they kindle the fire of war, God extinguishes it. And they strive to spread corruption on earth. God does not love the corrupters.\qt@no{64}}%
\qt@newcmd\qurantrans@en@dccxxxiv{%
Had the People of the Scriputure believed and been righteous, We would have remitted their sins, and admitted them into the Gardens of Bliss.\qt@no{65}}%
\qt@newcmd\qurantrans@en@dccxxxv{%
Had they observed the Torah, and the Gospel, and what was revealed to them from their Lord, they would have consumed amply from above them, and from beneath their feet. Among them is a moderate community, but evil is what many of them are doing.\qt@no{66}}%
\qt@newcmd\qurantrans@en@dccxxxvi{%
O Messenger, convey what was revealed to you from your Lord. But if you do not, then you would not have delivered His message. And God will protect you from the people. God does not guide the disbelieving people.\qt@no{67}}%
\qt@newcmd\qurantrans@en@dccxxxvii{%
Say, “O People of the Scripture! You have no basis until you uphold the Torah, and the Gospel, and what is revealed to you from your Lord.” But what is revealed to you from your Lord will increase many of them in rebellion and disbelief, so do not be sorry for the disbelieving people.\qt@no{68}}%
\qt@newcmd\qurantrans@en@dccxxxviii{%
Those who believe, and the Jews, and the Sabians, and the Christians—whoever believes in God and the Last Day, and does what is right—they have nothing to fear, nor shall they grieve.\qt@no{69}}%
\qt@newcmd\qurantrans@en@dccxxxix{%
We made a covenant with the Children of Israel, and We sent to them messengers. Whenever a messenger came to them with what their souls did not desire, some of them they accused of lying, and others they put to death.\qt@no{70}}%
\qt@newcmd\qurantrans@en@dccxl{%
They assumed there would be no punishment, so they turned blind and deaf. Then God redeemed them, but then again many of them turned blind and deaf. But God is Seeing of what they do.\qt@no{71}}%
\qt@newcmd\qurantrans@en@dccxli{%
They disbelieve those who say, “God is the Messiah the son of Mary.” But the Messiah himself said, “O Children of Israel, worship God, my Lord and your Lord. Whoever associates others with God, God has forbidden him Paradise, and his dwelling is the Fire. The wrongdoers have no saviors.”\qt@no{72}}%
\qt@newcmd\qurantrans@en@dccxlii{%
They disbelieve those who say, “God is the third of three.” But there is no deity except the One God. If they do not refrain from what they say, a painful torment will befall those among them who disbelieve.\qt@no{73}}%
\qt@newcmd\qurantrans@en@dccxliii{%
Will they not repent to God and ask His forgiveness? God is Forgiving and Merciful.\qt@no{74}}%
\qt@newcmd\qurantrans@en@dccxliv{%
The Messiah son of Mary was only a messenger, before whom other Messengers had passed away, and his mother was a woman of truth. They both used to eat food. Note how We make clear the revelations to them; then note how deluded they are.\qt@no{75}}%
\qt@newcmd\qurantrans@en@dccxlv{%
Say, “Do you worship, besides God, what has no power to harm or benefit you?” But God: He is the Hearer, the Knower.\qt@no{76}}%
\qt@newcmd\qurantrans@en@dccxlvi{%
Say, “O People of the Scripture! Do not exaggerate in your religion beyond the truth; and do not follow the opinions of people who went astray before, and misled many, and themselves strayed off the balanced way.”\qt@no{77}}%
\qt@newcmd\qurantrans@en@dccxlvii{%
Cursed were those who disbelieved from among the Children of Israel by the tongue of David and Jesus son of Mary. That is because they rebelled and used to transgress.\qt@no{78}}%
\qt@newcmd\qurantrans@en@dccxlviii{%
They used not to prevent one another from the wrongs they used to commit. Evil is what they used to do.\qt@no{79}}%
\qt@newcmd\qurantrans@en@dccxlix{%
You will see many of them befriending those who disbelieve. Terrible is what their souls prompts them to do. The wrath of God fell upon them, and in the torment they will remain.\qt@no{80}}%
\qt@newcmd\qurantrans@en@dccl{%
Had they believed in God and the Prophet, and in what was revealed to him, they would not have befriended them. But many of them are immoral.\qt@no{81}}%
\qt@newcmd\qurantrans@en@dccli{%
You will find that the people most hostile towards the believers are the Jews and the polytheists. And you will find that the nearest in affection towards the believers are those who say, “We are Christians.” That is because among them are priests and monks, and they are not arrogant.\qt@no{82}}%
\qt@newcmd\qurantrans@en@dcclii{%
And when they hear what was revealed to the Messenger, you see their eyes overflowing with tears, as they recognize the truth in it. They say, “Our Lord, we have believed, so count us among the witnesses.”\qt@no{83}}%
\qt@newcmd\qurantrans@en@dccliii{%
“And why should we not believe in God, and in the truth that has come to us, and hope that our Lord will include us among the righteous people?”\qt@no{84}}%
\qt@newcmd\qurantrans@en@dccliv{%
God will reward them for what they say—Gardens beneath which rivers flow, where they will stay forever. Such is the reward of the righteous.\qt@no{85}}%
\qt@newcmd\qurantrans@en@dcclv{%
But as for those who disbelieve and deny Our signs—these are the inmates of the Fire.\qt@no{86}}%
\qt@newcmd\qurantrans@en@dcclvi{%
O you who believe! Do not prohibit the good things God has permitted for you, and do not commit aggression. God does not love the aggressors.\qt@no{87}}%
\qt@newcmd\qurantrans@en@dcclvii{%
And eat of the lawful and good things God has provided for you; and be conscious of God, in whom you are believers.\qt@no{88}}%
\qt@newcmd\qurantrans@en@dcclviii{%
God does not hold you accountable for your unintended oaths, but He holds you accountable for your binding oaths. The atonement for it is by feeding ten needy people from the average of what you feed your families, or by clothing them, or by freeing a slave. Anyone who lacks the means shall fast for three days. That is the atonement for breaking your oaths when you have sworn them. So keep your oaths. Thus God makes clear His Revelations to you, that you may be grateful.\qt@no{89}}%
\qt@newcmd\qurantrans@en@dcclix{%
O you who believe! Intoxicants, gambling, idolatry, and divination are abominations of Satan’s doing. Avoid them, so that you may prosper.\qt@no{90}}%
\qt@newcmd\qurantrans@en@dcclx{%
Satan wants to provoke strife and hatred among you through intoxicants and gambling, and to prevent you from the remembrance of God, and from prayer. Will you not desist?\qt@no{91}}%
\qt@newcmd\qurantrans@en@dcclxi{%
Obey God and obey the Messenger, and be cautious. If you turn away—know that the duty of Our Messenger is clear communication.\qt@no{92}}%
\qt@newcmd\qurantrans@en@dcclxii{%
Those who believe and do righteous deeds will not be blamed for what they may have eaten, provided they obey, and believe, and do good deeds, then maintain piety and faith, then remain righteous and charitable. God loves the charitable.\qt@no{93}}%
\qt@newcmd\qurantrans@en@dcclxiii{%
O you who believe! God will test you with something of the game your hands and spears obtain, that God may know who fears Him at heart. Whoever commits aggression after that will have a painful punishment.\qt@no{94}}%
\qt@newcmd\qurantrans@en@dcclxiv{%
O you who believe! do not kill game while you are in pilgrim sanctity. Whoever of you kills any intentionally, its penalty shall be a domestic animal comparable to what he killed, as determined by two honest persons among you—an offering delivered to the Kaabah. Or he may atone by feeding the needy, or its equivalent in fasting, so that he may taste the consequences of his conduct. God forgives what is past. But whoever repeats, God will take revenge on him. God is Almighty, Avenger.\qt@no{95}}%
\qt@newcmd\qurantrans@en@dcclxv{%
Permitted for you is the catch of sea, and its food—as sustenance for you and for travelers. But forbidden for you is the game of land while you are in pilgrim sanctity. And fear God, to whom you will be gathered.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dcclxvi{%
God has appointed the Kaabah, the Sacred House, a sanctuary for the people, and the Sacred Month, and the offerings, and the garlanded. That you may know that God knows everything in the heavens and the earth, and that God is Cognizant of all things.\qt@no{97}}%
\qt@newcmd\qurantrans@en@dcclxvii{%
Know that God is severe in retribution, and that God is Forgiving and Merciful.\qt@no{98}}%
\qt@newcmd\qurantrans@en@dcclxviii{%
The Messenger’s sole duty is to convey. God knows what you reveal and what you conceal.\qt@no{99}}%
\qt@newcmd\qurantrans@en@dcclxix{%
Say: “The bad and the good are not equal, even though the abundance of the bad may impress you. So be conscious of God, O you who possess intelligence, that you may succeed.”\qt@no{100}}%
\qt@newcmd\qurantrans@en@dcclxx{%
O you who believe! Do not ask about things that would trouble you if disclosed to you. But if you were to ask about them while the Quran is being revealed, they will become obvious to you. God forgives that. God is Forgiving and Clement.\qt@no{101}}%
\qt@newcmd\qurantrans@en@dcclxxi{%
A people before you asked about them, but then came to reject them.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dcclxxii{%
God did not institute the superstitions of Bahirah, Saibah, Wasilah, or of Hami; but those who disbelieve fabricate lies about God—most of them do not understand.\qt@no{103}}%
\qt@newcmd\qurantrans@en@dcclxxiii{%
And when it is said to them, “Come to what God has revealed, and to the Messenger,” they say, “Sufficient for us is what we found our forefathers upon.” Even if their forefathers knew nothing, and were not guided?\qt@no{104}}%
\qt@newcmd\qurantrans@en@dcclxxiv{%
O you who believe! You are responsible for your own souls. He who has strayed cannot harm you if you are guided. To God is you return, all of you, and He will inform you of what you used to do.\qt@no{105}}%
\qt@newcmd\qurantrans@en@dcclxxv{%
O you who believe! When death approaches one of you, let two reliable persons from among you act as witnesses to the making of a bequest, or two persons from another people if you are travelling in the land and the event of death approaches you. Engage them after the prayer. If you have doubts, let them swear by God: “We will not sell our testimony for any price, even if he was a near relative, and we will not conceal God’s testimony, for then we would be sinners.”\qt@no{106}}%
\qt@newcmd\qurantrans@en@dcclxxvi{%
If it is discovered that they are guilty of perjury: let two others take their place, two from among those responsible for the claim, and have them swear by God, “Our testimony is more truthful than their testimony, and we will not be biased, for then we would be wrongdoers.”\qt@no{107}}%
\qt@newcmd\qurantrans@en@dcclxxvii{%
That makes it more likely that they will give true testimony, fearing that their oaths might be contradicted by subsequent oaths. So fear God, and listen. God does not guide the disobedient people.\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcclxxviii{%
On the Day when God will gather the messengers, then say, “What response were you given?” They will say, “We have no knowledge; it is you who are the Knower of the unseen.”\qt@no{109}}%
\qt@newcmd\qurantrans@en@dcclxxix{%
When God will say, “O Jesus son of Mary, recall My favor upon you and upon your mother, how I supported you with the Holy Spirit. You spoke to the people from the crib, and in maturity. How I taught you the Scripture and wisdom, and the Torah and the Gospel. And recall that you molded from clay the shape of a bird, by My leave, and then you breathed into it, and it became a bird, by My leave. And you healed the blind and the leprous, by My leave; and you revived the dead, by My leave. And recall that I restrained the Children of Israel from you when you brought them the clear miracles. But those who disbelieved among them said, `This is nothing but obvious sorcery.'“\qt@no{110}}%
\qt@newcmd\qurantrans@en@dcclxxx{%
“And when I inspired the disciples: `Believe in Me and in My Messenger.' They said, `We have believed, so bear witness that We have submitted.'“\qt@no{111}}%
\qt@newcmd\qurantrans@en@dcclxxxi{%
“And when the disciples said, 'O Jesus son of Mary, is your Lord able to bring down for us a feast from heaven?' He said, 'Fear God, if you are believers.'“\qt@no{112}}%
\qt@newcmd\qurantrans@en@dcclxxxii{%
They said, “We wish to eat from it, so that our hearts may be reassured, and know that you have told us the truth, and be among those who witness it.”\qt@no{113}}%
\qt@newcmd\qurantrans@en@dcclxxxiii{%
Jesus son of Mary said, “O God, our Lord, send down for us a table from heaven, to be a festival for us, for the first of us, and the last of us, and a sign from You; and provide for us; You are the Best of providers.”\qt@no{114}}%
\qt@newcmd\qurantrans@en@dcclxxxiv{%
God said, “I will send it down to you. But whoever among you disbelieves thereafter, I will punish him with a punishment the like of which I never punish any other being.”\qt@no{115}}%
\qt@newcmd\qurantrans@en@dcclxxxv{%
And God will say, “O Jesus son of Mary, did you say to the people, `Take me and my mother as gods rather than God?'“ He will say, “Glory be to You! It is not for me to say what I have no right to. Had I said it, You would have known it. You know what is in my soul, and I do not know what is in your soul. You are the Knower of the hidden.\qt@no{116}}%
\qt@newcmd\qurantrans@en@dcclxxxvi{%
I only told them what You commanded me: that you shall worship God, my Lord and your Lord. And I was a witness over them while I was among them; but when You took me to Yourself, you became the Watcher over them—You are Witness over everything.\qt@no{117}}%
\qt@newcmd\qurantrans@en@dcclxxxvii{%
If You punish them, they are Your servants; but if You forgive them, You are the Mighty and Wise.”\qt@no{118}}%
\qt@newcmd\qurantrans@en@dcclxxxviii{%
God will say, “This is a Day when the truthful will benefit from their truthfulness.” They will have Gardens beneath which rivers flow, wherein they will remain forever. God is pleased with them, and they are pleased with Him. That is the great attainment.\qt@no{119}}%
\qt@newcmd\qurantrans@en@dcclxxxix{%
To God belongs the sovereignty of the heavens and the earth and what lies in them, and He has power over everything.\qt@no{120}}%
\qt@newcmd\qurantrans@en@dccxc{%
\basmalahen Praise be to God, Who created the heavens and the earth, and made the darkness and the light. Yet those who disbelieve ascribe equals to their Lord.\qt@no{1}}%
\qt@newcmd\qurantrans@en@dccxci{%
It is He who created you from clay, then decided a term—a term determined by him. Yet you doubt.\qt@no{2}}%
\qt@newcmd\qurantrans@en@dccxcii{%
He is God in the heavens and the earth. He knows what you keep secret and what you make public; and He knows what you earn.\qt@no{3}}%
\qt@newcmd\qurantrans@en@dccxciii{%
Not one of their Lord’s signs comes to them, but they turn away from it.\qt@no{4}}%
\qt@newcmd\qurantrans@en@dccxciv{%
They denied the truth when it has come to them; but soon will reach them the news of what they used to ridicule.\qt@no{5}}%
\qt@newcmd\qurantrans@en@dccxcv{%
Have they not considered how many generations We destroyed before them? We had established them on earth more firmly than We established you, and We sent the clouds pouring down abundant rain on them, and We made rivers flow beneath them. But We destroyed them for their sins, and established other civilizations after them.\qt@no{6}}%
\qt@newcmd\qurantrans@en@dccxcvi{%
Had We sent down upon you a book on paper, and they had touched it with their hands, those who disbelieve would have said, “This is nothing but plain magic.”\qt@no{7}}%
\qt@newcmd\qurantrans@en@dccxcvii{%
And they say, “Why was an angel not sent down to him.” Had We sent down an angel, the matter would have been settled, and they would not have been reprieved.\qt@no{8}}%
\qt@newcmd\qurantrans@en@dccxcviii{%
Had We made him an angel, We would have made him a man, and confused them when they are already confused.\qt@no{9}}%
\qt@newcmd\qurantrans@en@dccxcix{%
Messengers before you were ridiculed, but those who mocked them became besieged by what they ridiculed.\qt@no{10}}%
\qt@newcmd\qurantrans@en@dccc{%
Say, “Travel the earth and observe the final fate of the deniers.”\qt@no{11}}%
\qt@newcmd\qurantrans@en@dccci{%
Say, “To whom belongs what is in the heavens and the earth?” Say, “To God.” He has inscribed for Himself mercy. He will gather you to the Day of Resurrection, in which there is no doubt. Those who lost their souls do not believe.\qt@no{12}}%
\qt@newcmd\qurantrans@en@dcccii{%
To Him belongs whatever rests in the night and the day. He is the Hearing, the Knowing.\qt@no{13}}%
\qt@newcmd\qurantrans@en@dccciii{%
Say, “Shall I take for myself a protector other than God, Originator of the heavens and the earth, and He feeds and is not fed?” Say, “I am instructed to be the first of those who submit.” And do not be among the idolaters.\qt@no{14}}%
\qt@newcmd\qurantrans@en@dccciv{%
Say, “I fear, should I defy my Lord, the punishment of a tremendous Day.”\qt@no{15}}%
\qt@newcmd\qurantrans@en@dcccv{%
Whoever is spared on that Day—He had mercy on him. That is the clear victory.\qt@no{16}}%
\qt@newcmd\qurantrans@en@dcccvi{%
If God touches you with adversity, none can remove it except He. And if He touches you with good—He is Capable of everything.\qt@no{17}}%
\qt@newcmd\qurantrans@en@dcccvii{%
He is the Supreme over His servants. He is the Wise, the Expert.\qt@no{18}}%
\qt@newcmd\qurantrans@en@dcccviii{%
Say, “What thing is more solemn in testimony?” Say, “God is Witness between you and me. This Quran was revealed to me, that I may warn you with it, and whomever it may reach. Do you indeed testify that there are other gods with God?” Say, “I myself do not testify.” Say, “He is but One God, and I am innocent of your idolatry.”\qt@no{19}}%
\qt@newcmd\qurantrans@en@dcccix{%
Those to whom We have given the Book recognize it as they recognize their own children; but those who have lost their souls do not believe.\qt@no{20}}%
\qt@newcmd\qurantrans@en@dcccx{%
Who does greater wrong than someone who fabricates lies against God, or denies His revelations? The wrongdoers will not succeed.\qt@no{21}}%
\qt@newcmd\qurantrans@en@dcccxi{%
On the Day when We gather them all together, then say to the idolaters, “Where are your idols, those you used to claim?”\qt@no{22}}%
\qt@newcmd\qurantrans@en@dcccxii{%
Then their only argument will be to say, “By God, our Lord, we were not idolaters.”\qt@no{23}}%
\qt@newcmd\qurantrans@en@dcccxiii{%
Look how they lied to themselves. And what they invented deserted them.\qt@no{24}}%
\qt@newcmd\qurantrans@en@dcccxiv{%
Among them are those who listen to you; but We place covers over their hearts, to prevent them from understanding it, and heaviness in their ears. Even if they see every sign, they will not believe in it. Until, when they come to you, to argue with you, those who disbelieve will say, “These are nothing but myths of the ancients.”\qt@no{25}}%
\qt@newcmd\qurantrans@en@dcccxv{%
They keep others from it, and avoid it themselves; but they ruin only their own souls, and they do not realize.\qt@no{26}}%
\qt@newcmd\qurantrans@en@dcccxvi{%
If only you could see, when they are made to stand before the Fire; they will say, “If only we could be sent back, and not reject the revelations of our Lord, and be among the faithful.”\qt@no{27}}%
\qt@newcmd\qurantrans@en@dcccxvii{%
What they used to conceal before will become clear to them. And even if they were sent back, they would revert to what they were forbidden. They are liars.\qt@no{28}}%
\qt@newcmd\qurantrans@en@dcccxviii{%
And they say, “There is nothing but our life in this world, and we will not be resurrected.”\qt@no{29}}%
\qt@newcmd\qurantrans@en@dcccxix{%
If only you could see, when they are stationed before their Lord. He will say, “Is this not real?” They will say, “Yes indeed, by our Lord.” He will say, “Then taste the torment for having disbelieved.”\qt@no{30}}%
\qt@newcmd\qurantrans@en@dcccxx{%
Losers are those who deny the encounter with God. Then, when the Hour comes upon them suddenly, they will say, “Alas for us, how we have neglected it.” And they will carry their burdens on their backs—evil is what they carry.\qt@no{31}}%
\qt@newcmd\qurantrans@en@dcccxxi{%
The life of this world is nothing but game and distraction, but the Home of the Hereafter is better for those who are righteous. Do you not understand?\qt@no{32}}%
\qt@newcmd\qurantrans@en@dcccxxii{%
We know that what they say grieves you. It is not you they reject, but it is God's revelations that the wicked deny.\qt@no{33}}%
\qt@newcmd\qurantrans@en@dcccxxiii{%
Other messengers before you were rejected, but they endured rejection and persecution until Our help came to them. There can be no change to God’s words. News of the Messengers has already reached you.\qt@no{34}}%
\qt@newcmd\qurantrans@en@dcccxxiv{%
If you find their rejection hard to bear, then if you can, seek a tunnel into the earth, or a stairway into the heaven, and bring them a sign. Had God willed, He could have gathered them to guidance. So do not be of the ignorant.\qt@no{35}}%
\qt@newcmd\qurantrans@en@dcccxxv{%
Only those who listen will respond. As for the dead, God will resurrect them; then to Him they will be returned.\qt@no{36}}%
\qt@newcmd\qurantrans@en@dcccxxvi{%
And they say, “If only a sign could come down to him from his Lord.” Say, “God is Able to send down a sign, but most of them do not know.”\qt@no{37}}%
\qt@newcmd\qurantrans@en@dcccxxvii{%
There is no animal on land, nor a bird flying with its wings, but are communities like you. We neglected nothing in the Scripture. Then to their Lord they will be gathered.\qt@no{38}}%
\qt@newcmd\qurantrans@en@dcccxxviii{%
Those who reject Our revelations are deaf and dumb, in total darkness. Whomever God wills, He leaves astray; and whomever He wills, He sets on a straight path.\qt@no{39}}%
\qt@newcmd\qurantrans@en@dcccxxix{%
Say, “Have you considered? if God's punishment came upon you, or the Hour overtook you, would you call upon any other than God, if you are sincere?”\qt@no{40}}%
\qt@newcmd\qurantrans@en@dcccxxx{%
In fact, it is Him you will call upon; and if He wills, he will remove what you called Him for, and you will forget what you idolized.\qt@no{41}}%
\qt@newcmd\qurantrans@en@dcccxxxi{%
We sent messengers to communities before you, and We afflicted them with suffering and hardship, that they may humble themselves.\qt@no{42}}%
\qt@newcmd\qurantrans@en@dcccxxxii{%
If only, when Our calamity came upon them, they humbled themselves. But their hearts hardened, and Satan made their deeds appear good to them.\qt@no{43}}%
\qt@newcmd\qurantrans@en@dcccxxxiii{%
Then, when they disregarded what they were reminded of, We opened for them the gates of all things. Until, when they delighted in what they were given, We seized them suddenly; and at once, they were in despair.\qt@no{44}}%
\qt@newcmd\qurantrans@en@dcccxxxiv{%
Thus the last remnant of the people who did wrong was cut off. And praise be to God, Lord of the Worlds.\qt@no{45}}%
\qt@newcmd\qurantrans@en@dcccxxxv{%
Say, “Have you considered? If God took away your hearing and your sight, and set a seal on your hearts, what god other than God would restore them to you?” Note how We explain the revelations in various ways, yet they still turn away.\qt@no{46}}%
\qt@newcmd\qurantrans@en@dcccxxxvi{%
Say, “Have you considered? if God's punishment descended on you suddenly or gradually, would any be destroyed except the wrongdoing people?”\qt@no{47}}%
\qt@newcmd\qurantrans@en@dcccxxxvii{%
We sent the messengers only as bearers of good news and as warners. Those who believe and reform have nothing to fear, nor shall they grieve.\qt@no{48}}%
\qt@newcmd\qurantrans@en@dcccxxxviii{%
But as for those who reject Our revelations, torment will afflict them because of their defiance.\qt@no{49}}%
\qt@newcmd\qurantrans@en@dcccxxxix{%
Say, “I do not say to you that I possess the treasuries of God, nor do I know the future, nor do I say to you that I am an angel. I only follow what is inspired to me.” Say, “Are the blind and the seeing alike? Do you not think?”\qt@no{50}}%
\qt@newcmd\qurantrans@en@dcccxl{%
And warn with it those who fear to be gathered before their Lord—they have no protector or intercessor apart from him—perhaps they will grow in piety.\qt@no{51}}%
\qt@newcmd\qurantrans@en@dcccxli{%
And do not drive away those who call upon their Lord, morning and evening, seeking His attention. You are not accountable for them in any way, nor are they accountable for you in any way. If you drive them away, you would be one of the unjust.\qt@no{52}}%
\qt@newcmd\qurantrans@en@dcccxlii{%
Thus We try some of them by means of others, that they may say, “Are these the ones whom God has favored from among us?” Is God not aware of the appreciative?\qt@no{53}}%
\qt@newcmd\qurantrans@en@dcccxliii{%
When those who believe in Our revelations come to you, say, “Peace be upon you, your Lord has prescribed mercy for Himself. Whoever among you does wrong out of ignorance, and then repents afterwards and reforms—He is Forgiving and Merciful.”\qt@no{54}}%
\qt@newcmd\qurantrans@en@dcccxliv{%
Thus We explain the revelations, and expose the path of the unrighteous.\qt@no{55}}%
\qt@newcmd\qurantrans@en@dcccxlv{%
Say, “I am forbidden from worshiping those you pray to besides God.” Say, “I will not follow your desires; else I would be lost and not be of those guided.”\qt@no{56}}%
\qt@newcmd\qurantrans@en@dcccxlvi{%
Say, “I stand on clear evidence from my Lord, and you have rejected Him. I do not possess what you seek me to hasten; the decision belongs solely to God. He states the truth, and He is the Best of Judges.”\qt@no{57}}%
\qt@newcmd\qurantrans@en@dcccxlvii{%
Say, “If I possessed what you seek me to hasten, the matter between you and me would have been settled. God is well aware of the unjust.”\qt@no{58}}%
\qt@newcmd\qurantrans@en@dcccxlviii{%
With Him are the keys of the unseen; none knows them except He. And He knows everything on land and in the sea. Not a leaf falls but He knows it; and there is not a single grain in the darkness of earth, nor is there anything wet or dry, but is in a clear record.\qt@no{59}}%
\qt@newcmd\qurantrans@en@dcccxlix{%
It is He Who takes you by night, and He knows what you earn by day. Then He raises you up in it, until a fixed term is fulfilled. Then to Him is your return, then He will inform you of what you used to do.\qt@no{60}}%
\qt@newcmd\qurantrans@en@dcccl{%
He is the Conqueror over His servants, and He sends guardians over you, until, when death overtakes one of you, Our envoys take him away, and they never fail.\qt@no{61}}%
\qt@newcmd\qurantrans@en@dcccli{%
Then they are brought back to God, their True Master. Unquestionably, His is the judgment, and He is the Swiftest of reckoners.\qt@no{62}}%
\qt@newcmd\qurantrans@en@dccclii{%
Say, “Who delivers you from the darkness of land and sea?” You call upon Him humbly and inwardly: “If He delivers us from this, We will surely be among the thankful.”\qt@no{63}}%
\qt@newcmd\qurantrans@en@dcccliii{%
Say, “It is God who delivers you from it, and from every disaster. Yet then you associate others with Him.”\qt@no{64}}%
\qt@newcmd\qurantrans@en@dcccliv{%
Say, “He is Able to send upon you an affliction, from above you, or from under your feet. Or He can divide you into factions, and make you taste the violence of one another. Note how We explain the revelations, so that they may understand.”\qt@no{65}}%
\qt@newcmd\qurantrans@en@dccclv{%
But your people rejected it, though it is the truth. Say, “I am not responsible for you.”\qt@no{66}}%
\qt@newcmd\qurantrans@en@dccclvi{%
For every happening is a finality, and you will surely know.\qt@no{67}}%
\qt@newcmd\qurantrans@en@dccclvii{%
When you encounter those who gossip about Our revelations, turn away from them, until they engage in another topic. But should Satan make you forget, do not sit after the recollection with the wicked people.\qt@no{68}}%
\qt@newcmd\qurantrans@en@dccclviii{%
The righteous are in no way accountable for them; it is only a reminder, that they may be careful.\qt@no{69}}%
\qt@newcmd\qurantrans@en@dccclix{%
So leave alone those who take their religion for play and pastime, and whom the worldly life has deceived. But remind with it, lest a soul becomes damned on account of what it has earned. It has no helper or intercessor besides God. Even if it offers every equivalent, none will be accepted from it. These are the ones who are delivered to perdition by their actions. They will have a drink of scalding water, and a painful punishment, because they used to disbelieve.\qt@no{70}}%
\qt@newcmd\qurantrans@en@dccclx{%
Say, “Shall we invoke besides God something that can neither benefit us nor harm us, and turn back on our heels after God has guided us; like someone seduced by the devils and confused on earth, who has friends calling him to guidance: 'Come to us'?” Say, “The guidance of God is the guidance, and we are commanded to surrender to the Lord of the Universe.”\qt@no{71}}%
\qt@newcmd\qurantrans@en@dccclxi{%
“And to perform the prayers, and to revere Him; it is to Him that you will be gathered.”\qt@no{72}}%
\qt@newcmd\qurantrans@en@dccclxii{%
It is He who created the heavens and the earth in truth. On the Day when He says: “Be,” it will be. His saying is the truth, and His is the sovereignty on the Day when the trumpet is blown. The Knower of secrets and declarations. He is the Wise, the Expert.\qt@no{73}}%
\qt@newcmd\qurantrans@en@dccclxiii{%
Abraham said to his father Azar, “Do you take idols for gods? I see that you and your people are in evident error.”\qt@no{74}}%
\qt@newcmd\qurantrans@en@dccclxiv{%
Thus We showed Abraham the empire of the heavens and the earth, that he might be one of those with certainty.\qt@no{75}}%
\qt@newcmd\qurantrans@en@dccclxv{%
When the night fell over him, he saw a planet. He said, “This is my lord.” But when it set, he said, “I do not love those that set.”\qt@no{76}}%
\qt@newcmd\qurantrans@en@dccclxvi{%
Then, when he saw the moon rising, he said, “This is my lord.” But when it set, he said, “If my Lord does not guide me, I will be one of the erring people.”\qt@no{77}}%
\qt@newcmd\qurantrans@en@dccclxvii{%
Then, when he saw the sun rising, he said, “This is my lord, this is bigger.” But when it set, he said, “O my people, I am innocent of your idolatry.\qt@no{78}}%
\qt@newcmd\qurantrans@en@dccclxviii{%
I have directed my attention towards Him Who created the heavens and the earth—a monotheist—and I am not of the idolaters.”\qt@no{79}}%
\qt@newcmd\qurantrans@en@dccclxix{%
And his people argued with him. He said, “Do you argue with me about God, when He has guided me? I do not fear what you associate with Him, unless my Lord wills it. My Lord comprehends all things in knowledge. Will you not reconsider?\qt@no{80}}%
\qt@newcmd\qurantrans@en@dccclxx{%
And why should I fear those you associate with Him, and you do not fear associating others with God for which He sent down to you no authority? Which side is more entitled to security, if you are aware?”\qt@no{81}}%
\qt@newcmd\qurantrans@en@dccclxxi{%
Those who believe, and do not obscure their faith with wrongdoing—those will have security, and they are guided.\qt@no{82}}%
\qt@newcmd\qurantrans@en@dccclxxii{%
That was Our argument which We gave to Abraham against his people. We elevate by degrees whomever We will. Your Lord is Wise and Informed.\qt@no{83}}%
\qt@newcmd\qurantrans@en@dccclxxiii{%
And We gave him Isaac and Jacob—each of them We guided. And We guided Noah previously; and from his descendants David, and Solomon, and Job, and Joseph, and Moses, and Aaron. Thus We reward the righteous.\qt@no{84}}%
\qt@newcmd\qurantrans@en@dccclxxiv{%
And Zechariah, and John, and Jesus, and Elias—every one of them was of the upright.\qt@no{85}}%
\qt@newcmd\qurantrans@en@dccclxxv{%
And Ishmael, and Elijah, and Jonah, and Lot—We favored each one of them over all other people.\qt@no{86}}%
\qt@newcmd\qurantrans@en@dccclxxvi{%
And of their ancestors, and their descendants, and their siblings—We chose them, and guided them to a straight path.\qt@no{87}}%
\qt@newcmd\qurantrans@en@dccclxxvii{%
Such is God’s guidance. He guides with it whomever He wills of His servants. Had they associated, their deeds would have gone in vain.\qt@no{88}}%
\qt@newcmd\qurantrans@en@dccclxxviii{%
Those are they to whom We gave the Book, and wisdom, and prophethood. If these reject them, We have entrusted them to others who do not reject them.\qt@no{89}}%
\qt@newcmd\qurantrans@en@dccclxxix{%
Those are they whom God has guided, so follow their guidance. Say, “I ask of you no compensation for it; it is just a reminder for all mankind.”\qt@no{90}}%
\qt@newcmd\qurantrans@en@dccclxxx{%
They do not value God as He should be valued, when they say, “God did not reveal anything to any human being.” Say, “Who revealed the Scripture which Moses brought—a light and guidance for humanity?” You put it on scrolls, displaying them, yet concealing much. And you were taught what you did not know—neither you, nor your ancestors. Say, “God;” then leave them toying away in their speculation.\qt@no{91}}%
\qt@newcmd\qurantrans@en@dccclxxxi{%
This too is a Scripture that We revealed—blessed—verifying what preceded it, that you may warn the Mother of Cities and all around it. Those who believe in the Hereafter believe in it, and are dedicated to their prayers.\qt@no{92}}%
\qt@newcmd\qurantrans@en@dccclxxxii{%
Who does greater wrong than someone who invents falsehood against God, or says, “It was revealed to me,” when nothing was revealed to him, or says, “I will reveal the like of what God revealed”? If only you could see the wrongdoers in the floods of death, as the angels with arms outstretched: “Give up your souls. Today you are being repaid with the torment of shame for having said about God other than the truth, and for being too proud to accept His revelations.”\qt@no{93}}%
\qt@newcmd\qurantrans@en@dccclxxxiii{%
“You have come to Us individually, just as We created you the first time, leaving behind you everything We gave you. We do not see with you your intercessors—those you claimed were your partners. The link between you is cut, and what you had asserted has failed you.”\qt@no{94}}%
\qt@newcmd\qurantrans@en@dccclxxxiv{%
It is God Who splits the grain and the seed. He brings the living from the dead, and He brings the dead from the living. Such is God. So how could you deviate?\qt@no{95}}%
\qt@newcmd\qurantrans@en@dccclxxxv{%
It is He Who breaks the dawn. And He made the night for rest, and the sun and the moon for calculation. Such is the disposition of the Almighty, the All-Knowing.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dccclxxxvi{%
And it is He Who created the stars for you, that you may be guided by them in the darkness of land and sea. We thus explain the revelations for people who know.\qt@no{97}}%
\qt@newcmd\qurantrans@en@dccclxxxvii{%
And it is He who produced you from a single person, then a repository, then a depository. We have detailed the revelations for people who understand.\qt@no{98}}%
\qt@newcmd\qurantrans@en@dccclxxxviii{%
And it is He who sends down water from the sky. With it We produce vegetation of all kinds, from which We bring greenery, from which We produce grains in clusters. And palm-trees with hanging clusters, and vineyards, and olives, and pomegranates—similar and dissimilar. Watch their fruits as they grow and ripen. Surely in this are signs for people who believe.\qt@no{99}}%
\qt@newcmd\qurantrans@en@dccclxxxix{%
Yet they attributed to God partners—the sprites—although He created them. And they invented for Him sons and daughters, without any knowledge. Glory be to Him. He is exalted, beyond what they describe.\qt@no{100}}%
\qt@newcmd\qurantrans@en@dcccxc{%
Originator of the heavens and the earth—how can He have a son when He never had a companion? He created all things, and He has knowledge of all things.\qt@no{101}}%
\qt@newcmd\qurantrans@en@dcccxci{%
Such is God, your Lord. There is no god except He, the Creator of all things; so worship Him. He is responsible for everything.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dcccxcii{%
No vision can grasp Him, but His grasp is over all vision. He is the Subtle, the Expert.\qt@no{103}}%
\qt@newcmd\qurantrans@en@dcccxciii{%
“Insights have come to you from your Lord. Whoever sees, it is to the benefit of his soul; and whoever remains blind, it is to its detriment. I am not a guardian over you.”\qt@no{104}}%
\qt@newcmd\qurantrans@en@dcccxciv{%
We thus diversify the revelations, lest they say, “You have studied,” and to clarify them for people who know.\qt@no{105}}%
\qt@newcmd\qurantrans@en@dcccxcv{%
Follow what was revealed to you from your Lord. There is no god but He. And turn away from the polytheists.\qt@no{106}}%
\qt@newcmd\qurantrans@en@dcccxcvi{%
Had God willed, they would not have practiced idolatry. We did not appoint you as a guardian over them, and you are not a manager over them.\qt@no{107}}%
\qt@newcmd\qurantrans@en@dcccxcvii{%
Do not insult those they call upon besides God, lest they insult God out of hostility and ignorance. We made attractive to every community their deeds. Then to their Lord is their return, and He will inform them of what they used to do.\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcccxcviii{%
They swear by God, with their most solemn oaths, that if a miracle were to come to them, they would believe in it. Say, “The miracles are only with God.” But how do you know? Even if it did come, they still would not believe.\qt@no{109}}%
\qt@newcmd\qurantrans@en@dcccxcix{%
And We turn away their hearts and their visions, as they refused to believe in it the first time, and We leave them blundering in their rebellion.\qt@no{110}}%
\qt@newcmd\qurantrans@en@cm{%
Even if We sent down the angels to them, and the dead spoke to them, and We gathered all things before them, they still would not believe, unless God wills; but most of them are ignorant.\qt@no{111}}%
\qt@newcmd\qurantrans@en@cmi{%
Likewise, We have assigned for every prophet an enemy—human and jinn devils—inspiring one another with fancy words in order to deceive. But had your Lord willed, they would not have done it. So leave them to their fabrications.\qt@no{112}}%
\qt@newcmd\qurantrans@en@cmii{%
So that the hearts of those who do not believe in the Hereafter may incline to it, and be content with it, and that they may perpetrate whatever they perpetrate.\qt@no{113}}%
\qt@newcmd\qurantrans@en@cmiii{%
“Shall I seek a judge other than God, when He is the One who revealed to you the Book, explained in detail?” Those to whom We gave the Book know that it is the truth revealed from your Lord. So do not be of those who doubt.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cmiv{%
The Word of your Lord has been completed, in truth and justice. There is no changing to His words. He is the Hearer, the Knower.\qt@no{115}}%
\qt@newcmd\qurantrans@en@cmv{%
If you were to obey most of those on earth, they would divert you from God’s path. They follow nothing but assumptions, and they only conjecture.\qt@no{116}}%
\qt@newcmd\qurantrans@en@cmvi{%
Your Lord knows best who strays from His path, and He knows best the guided ones.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cmvii{%
So eat of that over which the Name of God was pronounced, if you indeed believe in His revelations.\qt@no{118}}%
\qt@newcmd\qurantrans@en@cmviii{%
And why should you not eat of that over which the Name of God is pronounced, when He has detailed for you what is prohibited for you, unless you are compelled by necessity? Many lead astray with their opinions, through lack of knowledge. Your Lord knows best the transgressors.\qt@no{119}}%
\qt@newcmd\qurantrans@en@cmix{%
So abandon sin, outward and inward. Those who commit sins will be repaid for what they used to perpetrate.\qt@no{120}}%
\qt@newcmd\qurantrans@en@cmx{%
And do not eat from that over which the Name of God was not pronounced, for it is abomination. The devils inspire their followers to argue with you; but if you obey them, you would be polytheists.\qt@no{121}}%
\qt@newcmd\qurantrans@en@cmxi{%
Is he who was dead, then We gave him life, and made for him a light by which he walks among the people, like he who is in total darkness, and cannot get out of it? Thus the doings of disbelievers are made to appear good to them.\qt@no{122}}%
\qt@newcmd\qurantrans@en@cmxii{%
And thus We set up in every city its leading wicked sinners, to conspire in it, but they conspire only against themselves, and they do not realize it.\qt@no{123}}%
\qt@newcmd\qurantrans@en@cmxiii{%
When a sign comes to them, they say, “We will not believe unless we are given the like of what was given to God’s messengers.” God knows best where to place His message. Humiliation from God and severe torment will afflict the criminals for their scheming.\qt@no{124}}%
\qt@newcmd\qurantrans@en@cmxiv{%
Whomever God desires to guide, He spreads open his heart to Islam; and whomever He desires to misguide, He makes his heart narrow, constricted, as though he were climbing up the sky. God thus lays defilement upon those who do not believe.\qt@no{125}}%
\qt@newcmd\qurantrans@en@cmxv{%
This is the straight path of your Lord. We have explained the revelations in detail for people who recollect.\qt@no{126}}%
\qt@newcmd\qurantrans@en@cmxvi{%
For them is the Home of Peace with their Lord, and He is their Master—because of what they used to do.\qt@no{127}}%
\qt@newcmd\qurantrans@en@cmxvii{%
On the Day when He gathers them all together: “O assembly of jinn, you have exploited multitudes of humans.” Their adherents among mankind will say, “Our Lord, we have profited from one another, but we have reached the term that you have assigned for us.” He will say, “The Fire is your dwelling, wherein you will remain, except as God wills. Your Lord is Wise and Informed.\qt@no{128}}%
\qt@newcmd\qurantrans@en@cmxviii{%
Thus We make some of the wrongdoers befriend one another, because of what they used to do.\qt@no{129}}%
\qt@newcmd\qurantrans@en@cmxix{%
“O assembly of jinn and humans, did there not come to you messengers from among you, relating to you My revelations, and warning you of the meeting of this Day of yours?” They will say, “We testify against ourselves.” The life of the world seduced them. They will testify against themselves that they were disbelievers.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cmxx{%
That is because your Lord would not destroy towns for injustice while their inhabitants are unaware.\qt@no{131}}%
\qt@newcmd\qurantrans@en@cmxxi{%
They all have ranks according to what they did; and your Lord is not unaware of what they do.\qt@no{132}}%
\qt@newcmd\qurantrans@en@cmxxii{%
Your Lord is the Rich Beyond Need, the Possessor of Mercy. If He wills, he can do away with you, and substitute whomever He wills in your place, just as He produced you from the descendants of another people.\qt@no{133}}%
\qt@newcmd\qurantrans@en@cmxxiii{%
What you are promised is coming, and you cannot thwart it.\qt@no{134}}%
\qt@newcmd\qurantrans@en@cmxxiv{%
Say, “O my people! Work according to your ability, and so will I.” You will come to know to whom will belong the sequel of the abode.” The wrongdoers will not prevail.\qt@no{135}}%
\qt@newcmd\qurantrans@en@cmxxv{%
And they set aside for God a share of the crops and the livestock He created, and they say, “This is for God,” according to their claim, “and this is for our idols.” But the share of their idols does not reach God, yet the share of God reaches their idols. Evil is their judgment.\qt@no{136}}%
\qt@newcmd\qurantrans@en@cmxxvi{%
Likewise, their idols entice many idolaters to kill their children, in order to lead them to their ruin, and confuse them in their religion. Had God willed, they would not have done it; so leave them to their fraud.\qt@no{137}}%
\qt@newcmd\qurantrans@en@cmxxvii{%
And they say, “These animals and crops are restricted; none may eat them except those we permit,” by their claims, and animals whose backs are forbidden, and animals over which they do not pronounce the name of God—fabricating lies against Him. He will repay them for what they used to invent.\qt@no{138}}%
\qt@newcmd\qurantrans@en@cmxxviii{%
And they say, “What lies in the wombs of these animals is exclusively for our males, and prohibited to our wives.” But if it is stillborn, they can share in it. He will surely punish them for their allegations. He is Wise and Knowing.\qt@no{139}}%
\qt@newcmd\qurantrans@en@cmxxix{%
Lost are those who kill their children foolishly, with no basis in knowledge, and forbid what God has provided for them—innovations about God. They have gone astray. They are not guided.\qt@no{140}}%
\qt@newcmd\qurantrans@en@cmxxx{%
It is He who produces gardens, both cultivated and wild, and date-palms, and crops of diverse tastes, and olives and pomegranates, similar and dissimilar. Eat of its fruit when it yields, and give its due on the day of its harvest, and do not waste. He does not love the wasteful.\qt@no{141}}%
\qt@newcmd\qurantrans@en@cmxxxi{%
Among the livestock are some for transportation, and some for clothing. Eat of what God has provided for you, and do not follow the footsteps of Satan. He is to you an outright enemy.\qt@no{142}}%
\qt@newcmd\qurantrans@en@cmxxxii{%
Eight pairs: two of the sheep, and two of the goats. Say, “Did He forbid the two males, or the two females, or what the wombs of the two females contain? Inform me with knowledge, if you are truthful.”\qt@no{143}}%
\qt@newcmd\qurantrans@en@cmxxxiii{%
And two of the camels, and two of the cattle. Say, “Did He forbid the two males, or the two females, or what the wombs of the two females contain? Were you present when God enjoined this upon you?” Who does greater wrong than he who invents lies and attributes them to God, in order to mislead people without knowledge? God does not guide the wicked people.\qt@no{144}}%
\qt@newcmd\qurantrans@en@cmxxxiv{%
Say, “In what was revealed to me, I find nothing forbidden to a consumer who eats it, except carrion, or spilled blood, or the flesh of swine—because it is impure—or a sinful offering dedicated to other than God. But if someone is compelled by necessity, without being deliberate or malicious—your Lord is Forgiving and Merciful.\qt@no{145}}%
\qt@newcmd\qurantrans@en@cmxxxv{%
For the Jews We forbade everything with claws. As of cattle and sheep: We forbade them their fat, except what adheres to their backs, or the entrails, or what is mixed with bone. This is how We penalized them for their inequity. We are indeed truthful.\qt@no{146}}%
\qt@newcmd\qurantrans@en@cmxxxvi{%
If they accuse you of lying, say, “Your Lord is Possessor of infinite mercy, but His wrath cannot be averted from the guilty people.”\qt@no{147}}%
\qt@newcmd\qurantrans@en@cmxxxvii{%
The polytheists will say, “Had God willed, we would not have practiced idolatry, nor would have our forefathers, nor would we have prohibited anything.” Likewise those before them lied, until they tasted Our might. Say, “Do you have any knowledge that you can produce for us? You follow nothing but conjecture, and you only guess.”\qt@no{148}}%
\qt@newcmd\qurantrans@en@cmxxxviii{%
Say, “To God belongs the conclusive argument. Had He willed, He would have guided you all.”\qt@no{149}}%
\qt@newcmd\qurantrans@en@cmxxxix{%
Say, “Produce your witnesses who would testify that God has prohibited this.” If they testify, do not testify with them. And do not follow the whims of those who deny Our revelation, and those who do not believe in the Hereafter, and those who equate others with their Lord.\qt@no{150}}%
\qt@newcmd\qurantrans@en@cmxl{%
Say, “Come, let me tell you what your Lord has forbidden you: that you associate nothing with Him; that you honor your parents; that you do not kill your children because of poverty—We provide for you and for them; that you do not come near indecencies, whether outward or inward; and that you do not kill the soul which God has sanctified—except in the course of justice. All this He has enjoined upon you, so that you may understand.”\qt@no{151}}%
\qt@newcmd\qurantrans@en@cmxli{%
And do not come near the property of the orphan, except with the best intentions, until he reaches maturity. And give full weight and full measure, equitably. We do not burden any soul beyond its capacity. And when you speak, be fair, even if it concerns a close relative. And fulfill your covenant with God. All this He has enjoined upon you, so that you may take heed.\qt@no{152}}%
\qt@newcmd\qurantrans@en@cmxlii{%
This is My path, straight, so follow it. And do not follow the other paths, lest they divert you from His path. All this He has enjoined upon you, that you may refrain from wrongdoing.\qt@no{153}}%
\qt@newcmd\qurantrans@en@cmxliii{%
Then We gave Moses the Scripture, perfect for the righteous, and explaining everything clearly, and a beacon, and mercy, that they may believe in the encounter with their Lord.\qt@no{154}}%
\qt@newcmd\qurantrans@en@cmxliv{%
This too is a blessed Scripture that We revealed; so follow it, and be righteous, that you may receive mercy.\qt@no{155}}%
\qt@newcmd\qurantrans@en@cmxlv{%
Lest you say, “The Scripture was revealed to two parties before us, and we were unaware of their teachings.”\qt@no{156}}%
\qt@newcmd\qurantrans@en@cmxlvi{%
Or lest you say, “Had the Scripture been revealed to us, we would have been better guided than they.” Clarification has come to you from your Lord, and guidance, and mercy. Who then does greater wrong than he who gives the lie to God's messages, and turns away from them? We will repay those who turn away from Our messages with the worst kind of punishment, because of their turning away.\qt@no{157}}%
\qt@newcmd\qurantrans@en@cmxlvii{%
Are they waiting for anything but for the angels to come to them, or for your Lord to arrive, or for some of your Lord’s signs to come? On the Day when some of your Lord’s signs come, no soul will benefit from its faith unless it had believed previously, or had earned goodness through its faith. Say, “Wait, we too are waiting.”\qt@no{158}}%
\qt@newcmd\qurantrans@en@cmxlviii{%
As for those who divided their religion and became sects—you have nothing to do with them. Their case rests with God; then He will inform them of what they used to do.\qt@no{159}}%
\qt@newcmd\qurantrans@en@cmxlix{%
Whoever comes up with a good deed will have ten times its like; and whoever comes up with an evil deed will be repaid only with its equivalent—they will not be wronged.\qt@no{160}}%
\qt@newcmd\qurantrans@en@cml{%
Say, “My Lord has guided me to a straight path, an upright religion, the creed of Abraham the Monotheist, who was not a polytheist.”\qt@no{161}}%
\qt@newcmd\qurantrans@en@cmli{%
Say, “My prayer and my worship, and my life and my death, are devoted to God, the Lord of the Worlds.\qt@no{162}}%
\qt@newcmd\qurantrans@en@cmlii{%
No associate has He. Thus I am commanded, and I am the first of those who submit.\qt@no{163}}%
\qt@newcmd\qurantrans@en@cmliii{%
Say, “Am I to seek a Lord other than God, when He is the Lord of all things?” No soul gets except what it is due, and no soul bears the burdens of another. Then to your Lord is your return, then He will inform you regarding your disputes.\qt@no{164}}%
\qt@newcmd\qurantrans@en@cmliv{%
It is He who made you successors on the earth, and raised some of you in ranks over others, in order to test you through what He has given you. Your Lord is Quick in retribution, and He is Forgiving and Merciful.\qt@no{165}}%
\qt@newcmd\qurantrans@en@cmlv{%
\basmalahen Alif, Lam, Meem, Saad.\qt@no{1}}%
\qt@newcmd\qurantrans@en@cmlvi{%
A Scripture was revealed to you, so let there be no anxiety in your heart because of it. You are to warn with it—and a reminder for the believers.\qt@no{2}}%
\qt@newcmd\qurantrans@en@cmlvii{%
Follow what is revealed to you from your Lord, and do not follow other masters beside Him. Little you recollect.\qt@no{3}}%
\qt@newcmd\qurantrans@en@cmlviii{%
How many a town have We destroyed? Our might came upon them by night, or while they were napping.\qt@no{4}}%
\qt@newcmd\qurantrans@en@cmlix{%
When Our might came upon them, their only cry was, “We were indeed wrongdoers.”\qt@no{5}}%
\qt@newcmd\qurantrans@en@cmlx{%
We will question those to whom messengers were sent, and We will question the messengers.\qt@no{6}}%
\qt@newcmd\qurantrans@en@cmlxi{%
We will narrate to them with knowledge, for We were never absent.\qt@no{7}}%
\qt@newcmd\qurantrans@en@cmlxii{%
The scales on that Day will be just. Those whose weights are heavy—it is they who are the successful.\qt@no{8}}%
\qt@newcmd\qurantrans@en@cmlxiii{%
But as for those whose weights are light—it is they who have lost their souls, because they used to mistreat Our revelations.\qt@no{9}}%
\qt@newcmd\qurantrans@en@cmlxiv{%
We have established you firmly on earth, and made for you in it livelihood—but rarely do you give thanks.\qt@no{10}}%
\qt@newcmd\qurantrans@en@cmlxv{%
We created you, then We shaped you, then We said to the angels, “Bow down before Adam;” so they bowed down, except for Satan; he was not of those who bowed down.\qt@no{11}}%
\qt@newcmd\qurantrans@en@cmlxvi{%
He said, “What prevented you from bowing down when I have commanded you?” He said, “I am better than he; You created me from fire, and You created him from mud.”\qt@no{12}}%
\qt@newcmd\qurantrans@en@cmlxvii{%
He said, “Get down from it! It is not for you to act arrogantly in it. Get out! You are one of the lowly!”\qt@no{13}}%
\qt@newcmd\qurantrans@en@cmlxviii{%
He said, “Give me respite, until the Day they are resurrected.”\qt@no{14}}%
\qt@newcmd\qurantrans@en@cmlxix{%
He said, “You are of those given respite.”\qt@no{15}}%
\qt@newcmd\qurantrans@en@cmlxx{%
He said, “Because you have lured me, I will waylay them on Your straight path.\qt@no{16}}%
\qt@newcmd\qurantrans@en@cmlxxi{%
Then I will come at them from before them, and from behind them, and from their right, and from their left; and you will not find most of them appreciative.”\qt@no{17}}%
\qt@newcmd\qurantrans@en@cmlxxii{%
He said, “Get out of it, despised and vanquished. Whoever among them follows you—I will fill up Hell with you all.\qt@no{18}}%
\qt@newcmd\qurantrans@en@cmlxxiii{%
And you, Adam, inhabit the Garden, you and your wife, and eat whatever you wish; but do not approach this tree, lest you become sinners.”\qt@no{19}}%
\qt@newcmd\qurantrans@en@cmlxxiv{%
But Satan whispered to them, to reveal to them their nakedness, which was invisible to them. He said, “Your Lord has only forbidden you this tree, lest you become angels, or become immortals.”\qt@no{20}}%
\qt@newcmd\qurantrans@en@cmlxxv{%
And he swore to them, “I am a sincere advisor to you.”\qt@no{21}}%
\qt@newcmd\qurantrans@en@cmlxxvi{%
So he lured them with deceit. And when they tasted the tree, their nakedness became evident to them, and they began covering themselves with the leaves of the Garden. And their Lord called out to them, “Did I not forbid you from this tree, and say to you that Satan is a sworn enemy to you?”\qt@no{22}}%
\qt@newcmd\qurantrans@en@cmlxxvii{%
They said, “Our Lord, we have done wrong to ourselves. Unless You forgive us, and have mercy on us, we will be among the losers.”\qt@no{23}}%
\qt@newcmd\qurantrans@en@cmlxxviii{%
He said, “Fall, some of you enemies to one another. On earth you will have residence and livelihood for a while.”\qt@no{24}}%
\qt@newcmd\qurantrans@en@cmlxxix{%
He said, “In it you will live, and in it you will die, and from it you will be brought out.”\qt@no{25}}%
\qt@newcmd\qurantrans@en@cmlxxx{%
O children of Adam! We have provided you with clothing to cover your bodies, and for luxury. But the clothing of piety—that is best. These are some of God’s revelations, so that they may take heed.\qt@no{26}}%
\qt@newcmd\qurantrans@en@cmlxxxi{%
O Children of Adam! Do not let Satan seduce you, as he drove your parents out of the Garden, stripping them of their garments, to show them their nakedness. He sees you, him and his clan, from where you cannot see them. We have made the devils friends of those who do not believe.\qt@no{27}}%
\qt@newcmd\qurantrans@en@cmlxxxii{%
And when they commit an indecency, they say, “We found our parents doing this, and God has commanded us to do it.” Say, “God does not command indecencies. Are you attributing to God what you do not know?”\qt@no{28}}%
\qt@newcmd\qurantrans@en@cmlxxxiii{%
Say, “My Lord commands justice, and to stand devoted at every place of worship. So call upon Him, and dedicate your faith to Him alone. Just as He originated you, so you will return.”\qt@no{29}}%
\qt@newcmd\qurantrans@en@cmlxxxiv{%
Some He has guided, and some have deserved misguidance. They have adopted the devils for patrons rather than God, and they assume that they are guided.\qt@no{30}}%
\qt@newcmd\qurantrans@en@cmlxxxv{%
O Children of Adam! Dress properly at every place of worship, and eat and drink, but do not be excessive. He does not love the excessive.\qt@no{31}}%
\qt@newcmd\qurantrans@en@cmlxxxvi{%
Say, “Who forbade God’s finery which He has produced for His servants, and the delights of livelihood?” Say, “They are for those who believe, in this present world, but exclusively theirs on the Day of Resurrection.” We thus detail the revelations for people who know.\qt@no{32}}%
\qt@newcmd\qurantrans@en@cmlxxxvii{%
Say, “My Lord has forbidden immoralities—both open and secret—and sin, and unjustified aggression, and that you associate with God anything for which He revealed no sanction, and that you say about God what you do not know.”\qt@no{33}}%
\qt@newcmd\qurantrans@en@cmlxxxviii{%
For every nation is an appointed time. When their time has come, they cannot delay it by one hour, nor can they advance it.\qt@no{34}}%
\qt@newcmd\qurantrans@en@cmlxxxix{%
O Children of Adam! When messengers from among you come to you, relating to you My revelations—whoever practices piety and reforms—upon them shall be no fear, nor shall they grieve.\qt@no{35}}%
\qt@newcmd\qurantrans@en@cmxc{%
But as for those who reject Our revelations, and are too proud to accept them—these are the inmates of the Fire, where they will remain forever.\qt@no{36}}%
\qt@newcmd\qurantrans@en@cmxci{%
Who does greater wrong than he who invents lies about God, or denies His revelations? These—their share of the decree will reach them. Until, when Our envoys come to them, to take their souls away, they will say, “Where are they whom you used to pray to besides God?” They will say, “They have abandoned us,” and they will testify against themselves that they were faithless.\qt@no{37}}%
\qt@newcmd\qurantrans@en@cmxcii{%
He will say, “Join the crowds of jinn and humans who have gone into the Fire before you.” Every time a crowd enters, it will curse its sister-crowd. Until, when they are all in it, the last of them will say to the first of them, “Our Lord, these are the ones who misled us, so inflict on them a double punishment in the Fire.” He will say, “Each will have a double, but you do not know.”\qt@no{38}}%
\qt@newcmd\qurantrans@en@cmxciii{%
The first of them will say to the last of them, “You have no advantage over us, so taste the torment for what you used to earn.”\qt@no{39}}%
\qt@newcmd\qurantrans@en@cmxciv{%
Those who reject Our revelations and are too arrogant to uphold them—the doors of Heaven will not be opened for them, nor will they enter Paradise, until the camel passes through the eye of the needle. Thus We repay the guilty.\qt@no{40}}%
\qt@newcmd\qurantrans@en@cmxcv{%
For them is a couch of hell, and above them are sheets of fire. Thus We repay the wrongdoers.\qt@no{41}}%
\qt@newcmd\qurantrans@en@cmxcvi{%
As for those who believe and do righteous works—We never burden any soul beyond its capacity—these are the inhabitants of the Garden; abiding therein eternally.\qt@no{42}}%
\qt@newcmd\qurantrans@en@cmxcvii{%
We will remove whatever rancor is in their hearts. Rivers will flow beneath them. And they will say, “Praise be to God, who has guided us to this. Had God not guided us, we would never be guided. The messengers of our Lord did come with the truth.” And it will be proclaimed to them, “This is the Garden you are made to inherit, on account of what you used to do.”\qt@no{43}}%
\qt@newcmd\qurantrans@en@cmxcviii{%
And the inhabitants of the Garden will call out to the inmates of the Fire, “We found what our Lord promised us to be true; did you find what your Lord promised you to be true?” They will say, “Yes.” Thereupon a caller will announce in their midst, “The curse of God is upon the wrongdoers.”\qt@no{44}}%
\qt@newcmd\qurantrans@en@cmxcix{%
“Those who hinder from the path of God, and seek to distort it, and who deny the Hereafter.”\qt@no{45}}%
\qt@newcmd\qurantrans@en@m{%
And between them is a partition, and on the Elevations are men who recognize everyone by their features. They will call to the inhabitants of the Garden, “Peace be upon you.” They have not entered it, but they are hoping.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mi{%
And when their eyes are directed towards the inmates of the Fire, they will say, “Our Lord, do not place us among the wrongdoing people.”\qt@no{47}}%
\qt@newcmd\qurantrans@en@mii{%
And the dwellers of the Elevations will call to men they recognize by their features, saying, “Your hoardings did not avail you, nor did your arrogance.”\qt@no{48}}%
\qt@newcmd\qurantrans@en@miii{%
“Are these the ones you swore God will not touch with mercy?” “Enter the Garden; you have nothing to fear, and you will not grieve.”\qt@no{49}}%
\qt@newcmd\qurantrans@en@miv{%
The inmates of the Fire will call on the inhabitants of the Garden, “Pour some water over us, or some of what God has provided for you.” They will say, “God has forbidden them for the disbelievers.”\qt@no{50}}%
\qt@newcmd\qurantrans@en@mv{%
Those who took their religion lightly, and in jest, and whom the worldly life deceived. Today We will ignore them, as they ignored the meeting on this Day of theirs, and they used to deny Our revelations.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mvi{%
We have given them a Scripture, which We detailed with knowledge—guidance and mercy for people who believe.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mvii{%
Are they waiting for anything but its fulfillment? The Day its fulfillment comes true, those who disregarded it before will say, “The messengers of our Lord did come with the truth. Have we any intercessors to intercede for us? Or, could we be sent back, to behave differently from the way we behaved before?” They ruined their souls, and what they used to invent has failed them.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mviii{%
Your Lord is God; He who created the heavens and the earth in six days, then established Himself on the Throne. The night overtakes the day, as it pursues it persistently; and the sun, and the moon, and the stars are subservient by His command. His is the creation, and His is the command. Blessed is God, Lord of all beings.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mix{%
Call upon your Lord humbly and privately. He does not love the aggressors.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mx{%
And do not corrupt on earth after its reformation, and pray to Him with fear and hope. God’s mercy is close to the doers of good.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mxi{%
It is He who sends the wind ahead of His mercy. Then, when they have gathered up heavy clouds, We drive them to a dead land, where We make water come down, and with it We bring out all kinds of fruits. Thus We bring out the dead—perhaps you will reflect.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mxii{%
As for the good land, it yields its produce by the leave of its Lord. But as for the bad, it produces nothing but hardship and misery. Thus We explain the revelations in various ways for people who are thankful.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mxiii{%
We sent Noah to his people. He said, “O my people! Worship God; you have no god other than Him. I fear for you the punishment of a tremendous Day.”\qt@no{59}}%
\qt@newcmd\qurantrans@en@mxiv{%
The dignitaries among his people said, “We see that you are in obvious error.”\qt@no{60}}%
\qt@newcmd\qurantrans@en@mxv{%
He said, “O my people, I am not in error, but I am a messenger from the Lord of the Worlds.”\qt@no{61}}%
\qt@newcmd\qurantrans@en@mxvi{%
“I deliver to you the messages of my Lord, and I advise you, and I know from God what you do not know.”\qt@no{62}}%
\qt@newcmd\qurantrans@en@mxvii{%
“Do you wonder that a reminder has come to you from your Lord, through a man from among you, to warn you, and to lead you to righteousness, so that you may attain mercy?”\qt@no{63}}%
\qt@newcmd\qurantrans@en@mxviii{%
But they called him a liar. So We saved him and those with him in the Ark, and We drowned those who rejected Our revelations. They were blind people.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mxix{%
And to Aad, their brother Hud. He said, “O my people! Worship God; you have no god other than Him. Will you not take heed?”\qt@no{65}}%
\qt@newcmd\qurantrans@en@mxx{%
The elite of his people who disbelieved said, “We see foolishness in you, and we think that you are a liar.”\qt@no{66}}%
\qt@newcmd\qurantrans@en@mxxi{%
He said, “O my people! There is no foolishness in me, but I am a messenger from the Lord of the Worlds.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mxxii{%
“I convey to you the messages of my Lord, and I am a trustworthy adviser to you.”\qt@no{68}}%
\qt@newcmd\qurantrans@en@mxxiii{%
“Are you surprised that a reminder has come to you from your Lord, through a man from among you, to warn you? Remember how He made you successors after the people of Noah, and increased you greatly in stature. And remember God’s blessings, so that you may prosper.”\qt@no{69}}%
\qt@newcmd\qurantrans@en@mxxiv{%
They said, “Did you come to us to make us worship God alone, and abandon what our ancestors used to worship? Then bring us what you threaten us with, if you are truthful.”\qt@no{70}}%
\qt@newcmd\qurantrans@en@mxxv{%
He said, “Condemnation and wrath have befallen you from your Lord. Are you arguing with me over names, which you and your ancestors invented, for which God sent down no authority? Just wait; I am waiting with you.”\qt@no{71}}%
\qt@newcmd\qurantrans@en@mxxvi{%
So We saved him and those with him, by mercy from Us, and We cut off the roots of those who rejected Our revelations and were not believers.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mxxvii{%
And to Thamood, their brother Saleh. He said, “O my people! Worship God; you have no god other than Him. Clarification has come to you from your Lord. This she-camel of God is a sign for you. So leave her to graze on God’s earth, and do her no harm, lest a painful penalty seizes you.”\qt@no{73}}%
\qt@newcmd\qurantrans@en@mxxviii{%
“And remember how He made you successors after Aad, and settled you in the land. You make for yourselves mansions on its plains, and carve out dwellings in the mountains. So remember God’s benefits, and do not roam the earth corruptingly.”\qt@no{74}}%
\qt@newcmd\qurantrans@en@mxxix{%
The elite of his people, who were arrogant, said to the common people who had believed, “Do you know that Saleh is sent from his Lord?” They said, “We are believers in what he was sent with.”\qt@no{75}}%
\qt@newcmd\qurantrans@en@mxxx{%
Those who were arrogant said, “We reject what you believe in.”\qt@no{76}}%
\qt@newcmd\qurantrans@en@mxxxi{%
So they hamstrung the she-camel, and defied the command of their Lord, and said, “O Saleh, bring upon us what you threaten us with, if you are one of the messengers.”\qt@no{77}}%
\qt@newcmd\qurantrans@en@mxxxii{%
Whereupon the quake overtook them, and they became lifeless bodies in their homes.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mxxxiii{%
Then he turned away from them, and said, “O my people, I have delivered to you the message of my Lord, and I have advised you, but you do not like those who give advice.”\qt@no{79}}%
\qt@newcmd\qurantrans@en@mxxxiv{%
And Lot, when he said to his people, “Do you commit lewdness no people anywhere have ever committed before you?”\qt@no{80}}%
\qt@newcmd\qurantrans@en@mxxxv{%
“You lust after men rather than women. You are an excessive people.”\qt@no{81}}%
\qt@newcmd\qurantrans@en@mxxxvi{%
And his people's only answer was to say, “Expel them from your town; they are purist people.”\qt@no{82}}%
\qt@newcmd\qurantrans@en@mxxxvii{%
But We saved him and his family, except for his wife; she was of those who lagged behind.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mxxxviii{%
And We rained down on them a rain; note the consequences for the sinners.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mxxxix{%
And to Median, their brother Shuaib. He said, “O my people, worship God; you have no god other than Him. A clear proof has come to you from your Lord. Give full measure and weight, and do not cheat people out of their rights, and do not corrupt the land once it has been set right. This is better for you, if you are believers.”\qt@no{85}}%
\qt@newcmd\qurantrans@en@mxl{%
“And do not lurk on every path, making threats and turning away from the path of God those who believe in Him, seeking to distort it. And remember how you were few, and how He made you numerous. So note the consequences for the corrupters.”\qt@no{86}}%
\qt@newcmd\qurantrans@en@mxli{%
“Since some of you believed in what I was sent with, and some did not believe, be patient until God judges between us; for He is the Best of Judges.”\qt@no{87}}%
\qt@newcmd\qurantrans@en@mxlii{%
The arrogant elite among his people said, “O Shuaib, We will evict you from our town, along with those who believe with you, unless you return to our religion.” He said, “Even if we are unwilling?”\qt@no{88}}%
\qt@newcmd\qurantrans@en@mxliii{%
“We would be fabricating falsehood against God, if we were to return to your religion, after God has saved us from it. It is not for us to return to it, unless God, our Lord, wills. Our Lord embraces all things in knowledge. In God we place our trust. Our Lord, decide between us and our people in truth, for You are the Best of Deciders.”\qt@no{89}}%
\qt@newcmd\qurantrans@en@mxliv{%
The elite of his people who disbelieved said, “If you follow Shuaib, you will be losers.”\qt@no{90}}%
\qt@newcmd\qurantrans@en@mxlv{%
Thereupon, the quake struck them; and they became lifeless bodies in their homes.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mxlvi{%
Those who rejected Shuaib—as if they never prospered therein. Those who rejected Shuaib—it was they who were the losers.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mxlvii{%
So he turned away from them, and said, “O my people, I have delivered to you the messages of my Lord, and I have advised you, so why should I grieve over a disbelieving people?”\qt@no{93}}%
\qt@newcmd\qurantrans@en@mxlviii{%
We did not send any prophet to any town but We afflicted its people with misery and adversity, so that they may humble themselves.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mxlix{%
Then We substituted prosperity in place of hardship. Until they increased in number, and said, “Adversity and prosperity has touched our ancestors.” Then We seized them suddenly, while they were unaware.\qt@no{95}}%
\qt@newcmd\qurantrans@en@ml{%
Had the people of the towns believed and turned righteous, We would have opened for them the blessings of the heaven and the earth; but they rejected the truth, so We seized them by what they were doing.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mli{%
Do the people of the towns feel secure that Our might will not come upon them by night, while they sleep?\qt@no{97}}%
\qt@newcmd\qurantrans@en@mlii{%
Do the people of the towns feel secure that Our might will not come upon them by day, while they play?\qt@no{98}}%
\qt@newcmd\qurantrans@en@mliii{%
Do they feel safe from God’s plan? None feel safe from God’s plan except the losing people.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mliv{%
Is it not guidance for those who inherit the land after its inhabitants, that if We willed, We could strike them for their sins? And seal up their hearts, so that they would not hear?\qt@no{100}}%
\qt@newcmd\qurantrans@en@mlv{%
These towns—We narrate to you some of their tales. Their messengers came to them with the clear signs, but they would not believe in what they had rejected previously. Thus God seals the hearts of the disbelievers.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mlvi{%
We found most of them untrue to their covenants; We found most of them corrupt.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mlvii{%
Then, after them, We sent Moses with Our miracles to Pharaoh and his establishment, but they denounced them. So consider the end of the evildoers.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mlviii{%
Moses said, “O Pharaoh, I am a messenger from the Lord of the Worlds.”\qt@no{104}}%
\qt@newcmd\qurantrans@en@mlix{%
“It is only proper that I should not say about God anything other than the truth. I have come to you with clear evidence from your Lord, so let the Children of Israel go with me.”\qt@no{105}}%
\qt@newcmd\qurantrans@en@mlx{%
He said, “If you brought a miracle, then present it, if you are truthful.”\qt@no{106}}%
\qt@newcmd\qurantrans@en@mlxi{%
So he threw his staff, and it was an apparent serpent.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mlxii{%
And He pulled out his hand, and it was white to the onlookers.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mlxiii{%
The notables among Pharaoh’s people said, “This is really a skilled magician.”\qt@no{109}}%
\qt@newcmd\qurantrans@en@mlxiv{%
“He wants to evict you from your land, so what do you recommend?”\qt@no{110}}%
\qt@newcmd\qurantrans@en@mlxv{%
They said, “Put him off, and his brother, and send heralds to the cities.”\qt@no{111}}%
\qt@newcmd\qurantrans@en@mlxvi{%
“And let them bring you every skillful magician.”\qt@no{112}}%
\qt@newcmd\qurantrans@en@mlxvii{%
The magicians came to Pharaoh, and said, “Surely there is a reward for us, if we are the victors.”\qt@no{113}}%
\qt@newcmd\qurantrans@en@mlxviii{%
He said, “Yes, and you will be among my favorites.”\qt@no{114}}%
\qt@newcmd\qurantrans@en@mlxix{%
They said, “O Moses! Either you throw, or we are the ones to throw.”\qt@no{115}}%
\qt@newcmd\qurantrans@en@mlxx{%
He said, “You throw!” And when they threw, they beguiled the eyes of the people, and intimidated them, and produced a mighty magic.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mlxxi{%
And We inspired Moses: “Throw your staff.” And at once, it swallowed what they were faking.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mlxxii{%
So the truth came to pass, and what they were producing came to nothing.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mlxxiii{%
There they were defeated, and utterly reduced.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mlxxiv{%
And the magicians fell to their knees.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mlxxv{%
They said, “We have believed in the Lord of the Worlds.”\qt@no{121}}%
\qt@newcmd\qurantrans@en@mlxxvi{%
“The Lord of Moses and Aaron.”\qt@no{122}}%
\qt@newcmd\qurantrans@en@mlxxvii{%
Pharaoh said, “Did you believe in Him before I have given you permission? This is surely a conspiracy you schemed in the city, in order to expel its people from it. You will surely know.”\qt@no{123}}%
\qt@newcmd\qurantrans@en@mlxxviii{%
“I will cut off your hands and your feet on opposite sides; then I will crucify you all.”\qt@no{124}}%
\qt@newcmd\qurantrans@en@mlxxix{%
They said, “It is to our Lord that we will return.”\qt@no{125}}%
\qt@newcmd\qurantrans@en@mlxxx{%
“You are taking vengeance on us only because we have believed in the signs of our Lord when they have come to us.” “Our Lord! Pour out patience upon us, and receive our souls in submission.”\qt@no{126}}%
\qt@newcmd\qurantrans@en@mlxxxi{%
The chiefs of Pharaoh's people said, “Will you let Moses and his people cause trouble in the land, and forsake you and your gods?” He said, “We will kill their sons, and spare their women. We have absolute power over them.”\qt@no{127}}%
\qt@newcmd\qurantrans@en@mlxxxii{%
Moses said to his people, “Seek help in God, and be patient. The earth belongs to God. He gives it in inheritance to whomever He wills of His servants, and the future belongs to the righteous.”\qt@no{128}}%
\qt@newcmd\qurantrans@en@mlxxxiii{%
They said, “We were persecuted before you came to us, and after you came to us.” He said, “Perhaps your Lord will destroy your enemy, and make you successors in the land; then He will see how you behave.”\qt@no{129}}%
\qt@newcmd\qurantrans@en@mlxxxiv{%
And We afflicted the people of Pharaoh with barren years, and with shortage of crops, that they may take heed.\qt@no{130}}%
\qt@newcmd\qurantrans@en@mlxxxv{%
When something good came their way, they said, “This is ours.” And when something bad happened to them, they ascribed the evil omen to Moses and those with him. In fact, their omen is with God, but most of them do not know.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mlxxxvi{%
And they said, “No matter what sign you bring us, to bewitch us with, we will not believe in you.”\qt@no{132}}%
\qt@newcmd\qurantrans@en@mlxxxvii{%
So We let loose upon them the flood, and the locusts, and the lice, and the frogs, and blood—all explicit signs—but they were too arrogant. They were a sinful people.\qt@no{133}}%
\qt@newcmd\qurantrans@en@mlxxxviii{%
Whenever a plague befell them, they would say, “O Moses, pray to your Lord for us, according to the covenant He made with you. If you lift the plague from us, we will believe in you, and let the Children of Israel go with you.”\qt@no{134}}%
\qt@newcmd\qurantrans@en@mlxxxix{%
But when We lifted the plague from them, for a term they were to fulfill, they broke their promise.\qt@no{135}}%
\qt@newcmd\qurantrans@en@mxc{%
So We took vengeance on them, and drowned them in the sea—because they rejected Our signs, and paid no heed to them.\qt@no{136}}%
\qt@newcmd\qurantrans@en@mxci{%
And We made the oppressed people inherit the eastern and western parts of the land, which We had blessed. Thus the fair promise of your Lord to the Children of Israel was fulfilled, because of their endurance. And We destroyed what Pharaoh and his people had built, and what they had harvested.\qt@no{137}}%
\qt@newcmd\qurantrans@en@mxcii{%
And We delivered the Children of Israel across the sea. And when they came upon a people who were devoted to some statues of theirs, they said, “O Moses, make for us a god, as they have gods.” He said, “You are truly an ignorant people.”\qt@no{138}}%
\qt@newcmd\qurantrans@en@mxciii{%
“What these people are concerned with is perdition, and their deeds are based on falsehoods.”\qt@no{139}}%
\qt@newcmd\qurantrans@en@mxciv{%
He said, “Shall I seek for you a god other than God, when He has favored you over all other people?”\qt@no{140}}%
\qt@newcmd\qurantrans@en@mxcv{%
Remember how We saved you from Pharaoh’s people, who subjected you to the worst of sufferings—killing your sons and sparing your women. In that was a tremendous trial from your Lord.\qt@no{141}}%
\qt@newcmd\qurantrans@en@mxcvi{%
And We appointed to Moses thirty nights, and completed them with ten; and thus the time appointed by his Lord was forty nights. And Moses said to his brother Aaron: “Take my place among my people, and be upright, and do not follow the way of the mischief-makers.”\qt@no{142}}%
\qt@newcmd\qurantrans@en@mxcvii{%
And when Moses came to Our appointment, and his Lord spoke to him, he said, “My Lord, allow me to look and see You.” He said, “You will not see Me, but look at the mountain; if it stays in its place, you will see Me.” But when his Lord manifested Himself to the mountain, He turned it into dust, and Moses fell down unconscious. Then, when he recovered, he said, “Glory be to you, I repent to you, and I am the first of the believers.”\qt@no{143}}%
\qt@newcmd\qurantrans@en@mxcviii{%
He said, “O Moses, I have chosen you over all people for My messages and for My Words. So take what I have given you, and be one of the thankful.”\qt@no{144}}%
\qt@newcmd\qurantrans@en@mxcix{%
And We inscribed for him in the Tablets all kinds of enlightenments, and decisive explanation of all things. “Hold fast to them, and exhort your people to adopt the best of them. I will show you the fate of the sinners.”\qt@no{145}}%
\qt@newcmd\qurantrans@en@mc{%
I will turn away from My revelations those who behave proudly on earth without justification. Even if they see every sign, they will not believe in it; and if they see the path of rectitude, they will not adopt it for a path; and if they see the path of error, they will adopt it for a path. That is because they denied Our revelations, and paid no attention to them.\qt@no{146}}%
\qt@newcmd\qurantrans@en@mci{%
Those who deny Our revelations and the meeting of the Hereafter—their deeds will come to nothing. Will they be repaid except according to what they used to do?\qt@no{147}}%
\qt@newcmd\qurantrans@en@mcii{%
In his absence, the people of Moses adopted a calf made from their ornaments—a body which lowed. Did they not see that it could not speak to them, nor guide them in any way? They took it for worship. They were in the wrong.\qt@no{148}}%
\qt@newcmd\qurantrans@en@mciii{%
Then, when they regretted, and realized that they had erred, they said, “Unless our Lord extends His mercy to us, and forgives us, we will be among the losers.”\qt@no{149}}%
\qt@newcmd\qurantrans@en@mciv{%
And when Moses returned to his people, angry and disappointed, he said, “What an awful thing you did in my absence. Did you forsake the commandments of your Lord so hastily?” And he threw down the tablets; and he took hold of his brother’s head, dragging him towards himself. He said, “Son of my mother, the people have overpowered me, and were about to kill me; so do not allow the enemies to gloat over me, and do not count me among the unjust people.”\qt@no{150}}%
\qt@newcmd\qurantrans@en@mcv{%
He said, “My Lord, forgive me and my brother, and admit us into Your mercy; for you are the Most Merciful of the merciful.”\qt@no{151}}%
\qt@newcmd\qurantrans@en@mcvi{%
Those who idolized the calf have incurred wrath from their Lord, and humiliation in this life. We thus requite the innovators.\qt@no{152}}%
\qt@newcmd\qurantrans@en@mcvii{%
As for those who commit sins, and then repent afterwards and believe—your Lord, thereafter, is Forgiving and Merciful.\qt@no{153}}%
\qt@newcmd\qurantrans@en@mcviii{%
When the anger abated in Moses, he took up the tablets. In their transcript is guidance and mercy for those in awe of their Lord.\qt@no{154}}%
\qt@newcmd\qurantrans@en@mcix{%
And Moses chose from his people seventy men for Our appointment. When the tremor shook them, he said, “My Lord, had You willed, You could have destroyed them before, and me too. Will you destroy us for what the fools among us have done? This is but Your test—with it You misguide whomever You will, and guide whomever You will. You are our Protector, so forgive us, and have mercy on us. You are the Best of Forgivers.”\qt@no{155}}%
\qt@newcmd\qurantrans@en@mcx{%
“And inscribe for us goodness in this world, and in the Hereafter. We have turned to You.” He said, “My punishment—I inflict it upon whomever I will, but My mercy encompasses all things. I will specify it for those who act righteously and practice regular charity, and those who believe in Our signs.”\qt@no{156}}%
\qt@newcmd\qurantrans@en@mcxi{%
Those who follow the Messenger, the Unlettered Prophet, whom they find mentioned in the Torah and the Gospel in their possession. He directs them to righteousness, and deters them from evil, and allows for them all good things, and prohibits for them wickedness, and unloads the burdens and the shackles that are upon them. Those who believe in him, and respect him, and support him, and follow the light that came down with him—these are the successful.\qt@no{157}}%
\qt@newcmd\qurantrans@en@mcxii{%
Say, “O people, I am the Messenger of God to you all—He to whom belongs the kingdom of the heavens and the earth. There is no god but He. He gives life and causes death.” So believe in God and His Messenger, the Unlettered Prophet, who believes in God and His words. And follow him, that you may be guided.\qt@no{158}}%
\qt@newcmd\qurantrans@en@mcxiii{%
Among the people of Moses is a community that guides by truth, and thereby does justice.\qt@no{159}}%
\qt@newcmd\qurantrans@en@mcxiv{%
We divided them into twelve tribal communities. And We inspired Moses, when his people asked him for something to drink: “Strike the rock with your staff.” Whereupon twelve springs gushed from it. Each group recognized its drinking-place. And We shaded them with clouds, and We sent down upon them manna and quails: “Eat of the good things We have provided for you.” They did not wrong Us, but they used to wrong their own selves.\qt@no{160}}%
\qt@newcmd\qurantrans@en@mcxv{%
And it was said to them, “Settle this town, and eat therein whatever you wish, and speak modestly, and enter the gate in humility—We will forgive your sins, and will promote the righteous.”\qt@no{161}}%
\qt@newcmd\qurantrans@en@mcxvi{%
But the wicked among them substituted other words for the words given to them; so We sent down upon them a plague from the sky, because of their wrongdoing.\qt@no{162}}%
\qt@newcmd\qurantrans@en@mcxvii{%
Ask them about the town by the sea, when they violated the Sabbath. When they observed the Sabbath, their fish would come to them abundantly. But when they violated the Sabbath, their fish would not come to them. Thus We tried them because they disobeyed.\qt@no{163}}%
\qt@newcmd\qurantrans@en@mcxviii{%
And when a group of them said, “Why do you counsel a people whom God will annihilate, or punish with a severe punishment?” They said, “As an excuse to your Lord, and so that they may become righteous.”\qt@no{164}}%
\qt@newcmd\qurantrans@en@mcxix{%
Then, when they neglected what they were reminded of, We saved those who prohibited evil, and We seized those who did wrong with a terrible punishment, because of their sinfulness.\qt@no{165}}%
\qt@newcmd\qurantrans@en@mcxx{%
Then, when they rebelled against the commands to refrain, We said to them, “Be despicable apes.”\qt@no{166}}%
\qt@newcmd\qurantrans@en@mcxxi{%
Your Lord has announced that, He would send against them, until the Day of Resurrection, those who would inflict terrible suffering upon them. Your Lord is swift in retribution, yet He is Forgiving and Merciful.\qt@no{167}}%
\qt@newcmd\qurantrans@en@mcxxii{%
And We scattered them into communities on earth. Some of them righteous, and some of them short of that. And We tested them with fortunes and misfortunes, so that they may return.\qt@no{168}}%
\qt@newcmd\qurantrans@en@mcxxiii{%
They were succeeded by generations who inherited the Scripture and chose the materials of this world, saying, “We will be forgiven.” And should similar materials come their way, they would again seize them. Did they not make a covenant to uphold the Scripture, and to not say about God except the truth? Did they not study its contents? But the Home of the Hereafter is better for the cautious; will you not understand?\qt@no{169}}%
\qt@newcmd\qurantrans@en@mcxxiv{%
Those who adhere to the Scripture, and practice prayer—We will not waste the reward of the reformers.\qt@no{170}}%
\qt@newcmd\qurantrans@en@mcxxv{%
And when We suspended the mountain over them, as if it was an umbrella, and they thought it would fall on them: “Hold fast to what We have given you, and remember what it contains, so that you may be saved.”\qt@no{171}}%
\qt@newcmd\qurantrans@en@mcxxvi{%
And when Your Lord summoned the descendants of Adam, and made them testify about themselves. “Am I not your Lord?” They said, “Yes, we testify.” Thus you cannot say on the Day of Resurrection, “We were unaware of this.”\qt@no{172}}%
\qt@newcmd\qurantrans@en@mcxxvii{%
Nor can you Say, “Our ancestors practiced idolatry before; and we are their descendants who came after them; will you destroy us for what the falsifiers did?”\qt@no{173}}%
\qt@newcmd\qurantrans@en@mcxxviii{%
We thus elaborate the revelations, so that they may return.\qt@no{174}}%
\qt@newcmd\qurantrans@en@mcxxix{%
And relate to them the story of him to whom We delivered Our signs, but he detached himself from them, so Satan went after him, and he became one of the perverts.\qt@no{175}}%
\qt@newcmd\qurantrans@en@mcxxx{%
Had We willed, We could have elevated him through them; but he clung to the ground, and followed his desires. His metaphor is that of a dog: if you chase it, it pants; and if you leave it alone, it pants. Such is the metaphor of the people who deny Our signs. So tell the tale, so that they may ponder.\qt@no{176}}%
\qt@newcmd\qurantrans@en@mcxxxi{%
Evil is the metaphor of the people who reject Our signs and wrong themselves.\qt@no{177}}%
\qt@newcmd\qurantrans@en@mcxxxii{%
Whomever God guides is the guided one. And whomever He sends astray—these are the losers.\qt@no{178}}%
\qt@newcmd\qurantrans@en@mcxxxiii{%
We have destined for Hell multitudes of jinn and humans. They have hearts with which they do not understand. They have eyes with which they do not see. They have ears with which they do not hear. These are like cattle. In fact, they are further astray. These are the heedless.\qt@no{179}}%
\qt@newcmd\qurantrans@en@mcxxxiv{%
To God belong the Most Beautiful Names, so call Him by them, and disregard those who blaspheme His names. They will be repaid for what they used to do.\qt@no{180}}%
\qt@newcmd\qurantrans@en@mcxxxv{%
Among those We created is a community—they guide by truth, and do justice thereby.\qt@no{181}}%
\qt@newcmd\qurantrans@en@mcxxxvi{%
As for those who reject Our messages, We will gradually lead them from where they do not know.\qt@no{182}}%
\qt@newcmd\qurantrans@en@mcxxxvii{%
And I will encourage them. My plan is firm.\qt@no{183}}%
\qt@newcmd\qurantrans@en@mcxxxviii{%
Do they not think? There is no madness in their friend. He is but a plain warner.\qt@no{184}}%
\qt@newcmd\qurantrans@en@mcxxxix{%
Have they not observed the government of the heavens and the earth, and all the things that God created, and that their time may have drawn near? Which message, besides this, will they believe in?\qt@no{185}}%
\qt@newcmd\qurantrans@en@mcxl{%
Whomever God misguides has no guide. And He leaves them blundering in their transgression.\qt@no{186}}%
\qt@newcmd\qurantrans@en@mcxli{%
They ask you about the Hour, “When will it come?” Say, “Knowledge of it rests with my Lord. None can reveal its coming except He. It weighs heavily on the heavens and the earth. It will not come upon you except suddenly.” They ask you as if you are responsible for it. Say, “Knowledge of it rests with God,” but most people do not know.\qt@no{187}}%
\qt@newcmd\qurantrans@en@mcxlii{%
Say, “I have no control over any benefit or harm to myself, except as God wills. Had I known the future, I would have acquired much good, and no harm would have touched me. I am only a warner, and a herald of good news to a people who believe.”\qt@no{188}}%
\qt@newcmd\qurantrans@en@mcxliii{%
It is He who created you from a single person, and made from it its mate, that he may find comfort with her. Then, when he has covered her, she conceives a light load, and she carries it around. But when she has grown heavy, they pray to God their Lord, “if You give us a good child, we will be among the thankful.”\qt@no{189}}%
\qt@newcmd\qurantrans@en@mcxliv{%
But when He has given them a good child, they attribute partners to Him in what He has given them. God is exalted above what they associate.\qt@no{190}}%
\qt@newcmd\qurantrans@en@mcxlv{%
Do they idolize those who create nothing, and are themselves created?\qt@no{191}}%
\qt@newcmd\qurantrans@en@mcxlvi{%
And can neither help them, nor help their own selves?\qt@no{192}}%
\qt@newcmd\qurantrans@en@mcxlvii{%
And if you invite them to guidance, they will not follow you. It is the same for you, whether you invite them, or remain silent.\qt@no{193}}%
\qt@newcmd\qurantrans@en@mcxlviii{%
Those you call upon besides God are servants like you. So call upon them, and let them answer you, if you are truthful.\qt@no{194}}%
\qt@newcmd\qurantrans@en@mcxlix{%
Do they have feet with which they walk? Or do they have hands with which they strike? Or do they have eyes with which they see? Or do they have ears with which they hear? Say, “Call upon your partners, then plot against me, and do not wait.”\qt@no{195}}%
\qt@newcmd\qurantrans@en@mcl{%
“My Master is God, He Who sent down the Book, and He takes care of the righteous.”\qt@no{196}}%
\qt@newcmd\qurantrans@en@mcli{%
Those you call upon besides Him cannot help you, nor can they help themselves.\qt@no{197}}%
\qt@newcmd\qurantrans@en@mclii{%
And if you call them to guidance, they will not hear. And you see them looking at you, yet they do not see.\qt@no{198}}%
\qt@newcmd\qurantrans@en@mcliii{%
Be tolerant, and command decency, and avoid the ignorant.\qt@no{199}}%
\qt@newcmd\qurantrans@en@mcliv{%
And when a suggestion from Satan assails you, take refuge with God. He is Hearing and Knowing.\qt@no{200}}%
\qt@newcmd\qurantrans@en@mclv{%
Those who are righteous—when an impulse from Satan strikes them, they remind themselves, and immediately see clearly.\qt@no{201}}%
\qt@newcmd\qurantrans@en@mclvi{%
But their brethren lead them relentlessly into error, and they never stop short.\qt@no{202}}%
\qt@newcmd\qurantrans@en@mclvii{%
If you do not produce a miracle for them, they say, “Why don’t you improvise one.” Say, “I only follow what is inspired to me from my Lord.” These are insights from your Lord, and guidance, and mercy, for a people who believe.\qt@no{203}}%
\qt@newcmd\qurantrans@en@mclviii{%
When the Quran is recited, listen to it, and pay attention, so that you may experience mercy.\qt@no{204}}%
\qt@newcmd\qurantrans@en@mclix{%
And remember your Lord within yourself, humbly and fearfully, and quietly, in the morning and the evening, and do not be of the neglectful.\qt@no{205}}%
\qt@newcmd\qurantrans@en@mclx{%
Those who are in the presence of your Lord are not too proud to worship Him. They recite His praises, and to Him they bow down.\qt@no{206}}%
\qt@newcmd\qurantrans@en@mclxi{%
\basmalahen They ask you about the bounties. Say, “The bounties are for God and the Messenger.” So be mindful of God, and settle your differences, and obey God and His Messenger, if you are believers.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mclxii{%
The believers are those whose hearts tremble when God is mentioned, and when His revelations are recited to them, they strengthen them in faith, and upon their Lord they rely.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mclxiii{%
Those who perform the prayer; and from Our provisions to them, they spend.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mclxiv{%
These are the true believers. They have high standing with their Lord, and forgiveness, and a generous provision.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mclxv{%
Even as your Lord brought you out of your home with the truth, some believers were reluctant.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mclxvi{%
Arguing with you about the truth after it was made clear, as if they were being driven to death as they looked on.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mclxvii{%
God has promised you one of the two groups—that it would be yours—but you wanted the unarmed group to be yours. God intends to prove the truth with His words, and to uproot the disbelievers.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mclxviii{%
In order to confirm the truth and nullify falsehood, even though the guilty dislike it.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mclxix{%
When you appealed to your Lord for help, He answered you, “I am reinforcing you with one thousand angels in succession.”\qt@no{9}}%
\qt@newcmd\qurantrans@en@mclxx{%
God only made it a message of hope, and to set your hearts at rest. Victory comes only from God. God is Mighty and Wise.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mclxxi{%
He made drowsiness overcome you, as a security from Him. And He sent down upon you water from the sky, to cleanse you with it, and to rid you of Satan’s pollution, and to fortify your hearts, and to strengthen your foothold.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mclxxii{%
Your Lord inspired the angels: “I am with you, so support those who believe. I will cast terror into the hearts of those who disbelieve. So strike above the necks, and strike off every fingertip of theirs.”\qt@no{12}}%
\qt@newcmd\qurantrans@en@mclxxiii{%
That is because they opposed God and His Messenger. Whoever opposes God and His Messenger—God is severe in retribution.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mclxxiv{%
“Here it is; so taste it.” For the disbelievers there is the suffering of the Fire.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mclxxv{%
O you who believe! When you meet those who disbelieve on the march, never turn your backs on them.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mclxxvi{%
Anyone who turns his back on them on that Day, except while maneuvering for battle, or to join another group, has incurred wrath from God, and his abode is Hell—what a miserable destination!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mclxxvii{%
It was not you who killed them, but it was God who killed them. And it was not you who launched when you launched, but it was God who launched. That He may bestow upon the believers an excellent reward. God is Hearing and Knowing.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mclxxviii{%
Such is the case. God will undermine the strategy of the disbelievers.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mclxxix{%
If you desire a verdict, the verdict has come to you. And if you desist, it would be best for you. And if you return, We will return; and your troops, however numerous, will not benefit you. God is with the believers.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mclxxx{%
O you who believe! Obey God and His Messenger, and do not turn away from him when you hear.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mclxxxi{%
And be not like those who say, “We hear,” when they do not hear.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mclxxxii{%
The worst of animals to God are the deaf and dumb—those who do not reason.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mclxxxiii{%
Had God recognized any good in them, He would have made them hear; and had He made them hear, they would have turned away defiantly.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mclxxxiv{%
O you who believe! Respond to God and to the Messenger when He calls you to what will revive you. And know that God stands between a man and his heart, and that to Him you will be gathered.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mclxxxv{%
And beware of discord which does not afflict the wrongdoers among you exclusively; and know that God is severe in retribution.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mclxxxvi{%
And remember when you were few, oppressed in the land, fearing that people may capture you; but He sheltered you, and supported you with His victory, and provided you with good things—so that you may be thankful.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mclxxxvii{%
O you who believe! Do not betray God and the Messenger, nor betray your trusts, while you know.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mclxxxviii{%
And know that your possessions and your children are a test, and that God possesses an immense reward.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mclxxxix{%
O you who believe! If you remain conscious of God, He will give you a criterion, and will remit from you your sins, and will forgive you. God is possessor of infinite grace.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcxc{%
When the disbelievers plotted against you, to imprison you, or kill you, or expel you. They planned, and God planned, but God is the Best of planners.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcxci{%
And when Our revelations are recited to them, they say, “We have heard. Had we wanted, we could have said the like of this; these are nothing but myths of the ancients.”\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcxcii{%
And they said, “Our God, if this is the truth from You, then rain down on us stones from the sky, or visit us with a painful affliction.”\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcxciii{%
But God would not punish them while you are amongst them. And God would not punish them as long as they seek forgiveness.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcxciv{%
Yet why should God not punish them, when they are turning others away from the Sacred Mosque, although they are not its custodians? Its rightful custodians are the pious; but most of them do not know.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcxcv{%
Their prayer at the House was nothing but whistling and clapping—so taste the punishment for your blasphemy.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcxcvi{%
Those who disbelieve spend their wealth to repel from God’s path. They will spend it, then it will become a source of sorrow for them, and then they will be defeated. Those who disbelieve will be herded into Hell.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcxcvii{%
That God may distinguish the bad from the good, and heap the bad on top of one another, and pile them together, and throw them in Hell. These are the losers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcxcviii{%
Say to those who disbelieve: if they desist, their past will be forgiven. But if they persist—the practice of the ancients has passed away.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcxcix{%
Fight them until there is no more persecution, and religion becomes exclusively for God. But if they desist—God is Seeing of what they do.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcc{%
And if they turn away, know that God is your Protector. The Best Protector, and the Best Supporter.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcci{%
And know that whatever spoils you gain, to God belongs its fifth, and to the Messenger, and the relatives, and the orphans, and the poor, and to the wayfarer, provided you believe in God and in what We revealed to Our servant on the Day of Distinction, the day when the two armies met. God is Capable of everything.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mccii{%
Recall when you were on the nearer bank, and they were on the further bank, and the caravan was below you. Had you planned for this meeting, you would have disagreed on the timing, but God was to carry out a predetermined matter, so that those who perish would perish by clear evidence, and those who survive would survive by clear evidence. God is Hearing and Knowing.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcciii{%
God made them appear in your dream as few. Had He made them appear as many, you would have lost heart, and disputed in the matter. But God saved the situation. He knows what the hearts contain.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcciv{%
When you met, He made them appear as few in your eyes, and made you appear fewer in their eyes, so that God may conclude a predetermined matter. To God all matters revert.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mccv{%
O you who believe! When you meet a force, stand firm, and remember God much, so that you may prevail.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mccvi{%
And obey God and His Messenger, and do not dispute, lest you falter and lose your courage. And be steadfast. God is with the steadfast.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mccvii{%
And do not be like those who left their homes boastfully, showing off before the people, and barring others from the path of God. God comprehends what they do.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mccviii{%
Satan made their deeds appear good to them, and said, “You cannot be defeated by any people today, and I am at your side.” But when the two armies came in sight of one another, he turned on his heels, and said, “I am innocent of you; I see what you do not see; I fear God; God is severe in punishment.”\qt@no{48}}%
\qt@newcmd\qurantrans@en@mccix{%
The hypocrites and those in whose hearts is sickness said, “Their religion has deluded these people.” But whoever puts his trust in God—God is Mighty and Wise.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mccx{%
If only you could see, as the angels take away those who disbelieve, striking their faces and their backs: “Taste the agony of the Burning.”\qt@no{50}}%
\qt@newcmd\qurantrans@en@mccxi{%
“That is because of what your hands have committed, and because God is not unjust to the servants.”\qt@no{51}}%
\qt@newcmd\qurantrans@en@mccxii{%
Like the behavior of the people of Pharaoh, and those before them. They rejected the signs of God, so God seized them for their sins. God is Powerful, Severe in punishment.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mccxiii{%
That is because God would never change a blessing He has bestowed on a people unless they change what is within themselves, and because God is Hearing and Knowing.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mccxiv{%
Such was the case with the people of Pharaoh, and those before them. They denied the signs of their Lord, so We annihilated them for their wrongs, and We drowned the people of Pharaoh—they were all evildoers.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mccxv{%
The worst of creatures in God's view are those who disbelieve. They have no faith.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mccxvi{%
Those of them with whom you made a treaty, but they violate their agreement every time. They are not righteous.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mccxvii{%
If you confront them in battle, make of them a fearsome example for those who follow them, that they may take heed.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mccxviii{%
If you fear treachery on the part of a people, break off with them in a like manner. God does not like the treacherous.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mccxix{%
Let not the disbelievers assume that they are ahead. They will not escape.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mccxx{%
And prepare against them all the power you can muster, and all the cavalry you can mobilize, to terrify thereby God’s enemies and your enemies, and others besides them whom you do not know, but God knows them. Whatever you spend in God’s way will be repaid to you in full, and you will not be wronged.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mccxxi{%
But if they incline towards peace, then incline towards it, and put your trust in God. He is the Hearer, the Knower.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mccxxii{%
If they intend to deceive you—God is sufficient for you. It is He who supported you with His aid, and with the believers.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mccxxiii{%
And He united their hearts. Had you spent everything on earth, you would not have united their hearts, but God united them together. He is Mighty and Wise.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mccxxiv{%
O prophet! Count on God, and on the believers who have followed you.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mccxxv{%
O prophet! Rouse the believers to battle. If there are twenty steadfast among you, they will defeat two hundred; and if there are a hundred of you, they will defeat a thousand of those who disbelieve; because they are a people who do not understand.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mccxxvi{%
God has now lightened your burden, knowing that there is weakness in you. If there are a hundred steadfast among you, they will defeat two hundred; and if there are a thousand of you, they will defeat two thousand by God’s leave. God is with the steadfast.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mccxxvii{%
It is not for a prophet to take prisoners before he has subdued the land. You desire the materials of this world, but God desires the Hereafter. God is Strong and Wise.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mccxxviii{%
Were it not for a predetermined decree from God, an awful punishment would have afflicted you for what you have taken.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mccxxix{%
So consume what you have gained, legitimate and wholesome; and remain conscious of God. God is Forgiving and Merciful.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mccxxx{%
O prophet! Say to those you hold prisoners, “If God finds any good in your hearts, He will give you better than what was taken from you, and He will forgive you. God is Forgiving and Merciful.”\qt@no{70}}%
\qt@newcmd\qurantrans@en@mccxxxi{%
But if they intend to betray you, they have already betrayed God, and He has overpowered them. God is Knowing and Wise.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mccxxxii{%
Those who believed, and emigrated, and struggled in God’s cause with their possessions and their persons, and those who provided shelter and support—these are allies of one another. As for those who believed, but did not emigrate, you owe them no protection, until they have emigrated. But if they ask you for help in religion, you must come to their aid, except against a people with whom you have a treaty. God is Seeing of what you do.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mccxxxiii{%
As for those who disbelieve, they are allies of one another. Unless you do this, there will be turmoil in the land, and much corruption.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mccxxxiv{%
Those who believed, and emigrated, and struggled for God’s cause, and those who gave shelter and support—these are the true believers. They will have forgiveness, and a bountiful provision.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mccxxxv{%
As for those who believed afterwards, and emigrated and struggled with you—these belong with you. But family members are nearer to one another in the Book of God. God is Cognizant of everything.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mccxxxvi{%
\basmalahen A declaration of immunity from God and His Messenger to the polytheists with whom you had made a treaty.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mccxxxvii{%
So travel the land for four months, and know that you cannot escape God, and that God will disgrace the disbelievers.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mccxxxviii{%
And a proclamation from God and His Messenger to the people on the day of the Greater Pilgrimage, that God has disowned the polytheists, and so did His Messenger. If you repent, it will be better for you. But if you turn away, know that you cannot escape God. And announce to those who disbelieve a painful punishment.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mccxxxix{%
Except for those among the polytheists with whom you had made a treaty, and did not violate any of its terms, nor aided anyone against you. So fulfill the treaty with them to the end of its term. God loves the righteous.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mccxl{%
When the Sacred Months have passed, kill the polytheists wherever you find them. And capture them, and besiege them, and lie in wait for them at every ambush. But if they repent, and perform the prayers, and pay the alms, then let them go their way. God is Most Forgiving, Most Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mccxli{%
And if anyone of the polytheists asks you for protection, give him protection so that he may hear the Word of God; then escort him to his place of safety. That is because they are a people who do not know.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mccxlii{%
How can there be a treaty with the polytheists on the part of God and His Messenger, except for those with whom you made a treaty at the Sacred Mosque? As long as they are upright with you, be upright with them. God loves the pious.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mccxliii{%
How? Whenever they overcome you, they respect neither kinship nor treaty with you. They satisfy you with lip service, but their hearts refuse, and most of them are immoral.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mccxliv{%
They traded away God's revelations for a cheap price, so they barred others from His path. How evil is what they did.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mccxlv{%
Towards a believer they respect neither kinship nor treaty. These are the transgressors.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mccxlvi{%
But if they repent, and perform the prayers, and give the obligatory charity, then they are your brethren in faith. We detail the revelations for a people who know.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mccxlvii{%
But if they violate their oaths after their pledge, and attack your religion, then fight the leaders of disbelief—they have no faith—so that they may desist.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mccxlviii{%
Will you not fight a people who violated their oaths, and planned to exile the Messenger, and initiated hostilities against you? Do you fear them? It is God you should fear, if you are believers.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mccxlix{%
Fight them. God will punish them at your hands, and humiliate them, and help you against them, and heal the hearts of a believing people.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mccl{%
And He will remove the anger of their hearts. God redeems whomever He wills. God is Knowledgeable and Wise.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mccli{%
Or do you think that you will be left alone, without God identifying which of you will strive, and take no supporters apart from God, His Messenger, and the believers? God is well Aware of what you do.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcclii{%
It is not for the polytheists to attend God’s places of worship while professing their disbelief. These—their works are in vain, and in the Fire they will abide.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mccliii{%
The only people to attend God’s places of worship are those who believe in God and the Last Day, and pray regularly, and practice regular charity, and fear none but God. These are most likely to be guided.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mccliv{%
Do you consider giving water to pilgrims and maintaining the Sacred Mosque the same as believing in God and the Last Day and striving in God’s path? They are not equal in God’s sight. God does not guide the unjust people.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcclv{%
Those who believe, and emigrate, and strive in God’s path with their possessions and their persons, are of a higher rank with God. These are the winners.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcclvi{%
Their Lord announces to them good news of mercy from Him, and acceptance, and gardens wherein they will have lasting bliss.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcclvii{%
Abiding therein forever. With God is a great reward.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcclviii{%
O you who believe! Do not ally yourselves with your parents and your siblings if they prefer disbelief to belief. Whoever of you allies himself with them—these are the wrongdoers.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcclix{%
Say, “If your parents, and your children, and your siblings, and your spouses, and your relatives, and the wealth you have acquired, and a business you worry about, and homes you love, are more dear to you than God, and His Messenger, and the struggle in His cause, then wait until God executes His judgment.” God does not guide the sinful people.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcclx{%
God has given you victory in numerous regions; but on the day of Hunayn, your great number impressed you, but it availed you nothing; and the land, as spacious as it was, narrowed for you; and you turned your backs in retreat.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcclxi{%
Then God sent down His serenity upon His Messenger, and upon the believers; and He sent down troops you did not see; and He punished those who disbelieved. Such is the recompense of the disbelievers.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcclxii{%
Then, after that, God will relent towards whomever He wills. God is Forgiving and Merciful.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcclxiii{%
O you who believe! The polytheists are polluted, so let them not approach the Sacred Mosque after this year of theirs. And if you fear poverty, God will enrich you from His grace, if He wills. God is Aware and Wise.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcclxiv{%
Fight those who do not believe in God, nor in the Last Day, nor forbid what God and His Messenger have forbidden, nor abide by the religion of truth—from among those who received the Scripture—until they pay the due tax, willingly or unwillingly.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcclxv{%
The Jews said, “Ezra is the son of God,” and the Christians said, “The Messiah is the son of God.” These are their statements, out of their mouths. They emulate the statements of those who blasphemed before. May God assail them! How deceived they are!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcclxvi{%
They have taken their rabbis and their priests as lords instead of God, as well as the Messiah son of Mary. Although they were commanded to worship none but The One God. There is no god except He. Glory be to Him; High above what they associate with Him.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcclxvii{%
They want to extinguish God’s light with their mouths, but God refuses except to complete His light, even though the disbelievers dislike it.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcclxviii{%
It is He who sent His Messenger with the guidance and the religion of truth, in order to make it prevail over all religions, even though the idolaters dislike it.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcclxix{%
O you who believe! Many of the rabbis and priests consume people's wealth illicitly, and hinder from God’s path. Those who hoard gold and silver, and do not spend them in God’s cause, inform them of a painful punishment.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcclxx{%
On the Day when they will be heated in the Fire of Hell, then their foreheads, and their sides, and their backs will be branded with them: “This is what you hoarded for yourselves; so taste what you used to hoard.”\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcclxxi{%
The number of months, according to God, is twelve months—in the decree of God—since the Day He created the heavens and the earth, of which four are sacred. This is the correct religion. So do not wrong yourselves during them. And fight the polytheists collectively, as they fight you collectively, and know that God is with the righteous.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcclxxii{%
Postponement is an increase in disbelief—by which those who disbelieve are led astray. They allow it one year, and forbid it another year, in order to conform to the number made sacred by God, thus permitting what God has forbidden. The evil of their deeds seems good to them. God does not guide the disbelieving people.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcclxxiii{%
O you who believe! What is the matter with you, when it is said to you, “Mobilize in the cause of God,” you cling heavily to the earth? Do you prefer the present life to the Hereafter? The enjoyment of the present life, compared to the Hereafter, is only a little.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcclxxiv{%
Unless you mobilize, He will punish you most painfully, and will replace you with another people, and you will not harm Him at all. God has power over all things.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcclxxv{%
If you do not help him, God has already helped him, when those who disbelieved expelled him, and he was the second of two in the cave. He said to his friend, “Do not worry, God is with us.” And God made His tranquility descend upon him, and supported him with forces you did not see, and made the word of those who disbelieved the lowest, while the Word of God is the Highest. God is Mighty and Wise.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcclxxvi{%
Mobilize, light or heavy, and strive with your possessions and your lives in the cause of God. That is better for you, if you only knew.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcclxxvii{%
Had the gain been immediate, and the journey shorter, they would have followed you; but the distance seemed too long for them. Still they swear by God: “Had we been able, we would have marched out with you.” They damn their own souls, and God knows that they are lying.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcclxxviii{%
May God pardon you! Why did you give them permission before it became clear to you who are the truthful ones, and who are the liars?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcclxxix{%
Those who believe in God and the Last Day do not ask you for exemption from striving with their possessions and their lives. God is fully aware of the righteous.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcclxxx{%
Only those who do not believe in God and the Last Day ask you for exemption. Their hearts are full of doubts, so they waver in their doubts.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcclxxxi{%
Had they wanted to mobilize, they would have made preparations for it; but God disliked their participation, so he held them back, and it was said, “Stay behind with those who stay behind.”\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcclxxxii{%
Had they mobilized with you, they would have added only to your difficulties, and they would have spread rumors in your midst, trying to sow discord among you. Some of you are avid listeners to them. God is Aware of the wrongdoers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcclxxxiii{%
They tried to cause conflict before, and they hatched plots against you, until the truth prevailed, and the command of God became evident—in spite of their dislike.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcclxxxiv{%
Among them is he who says, “Excuse me, and do not trouble me.” In fact, they sunk into trouble. In fact, Hell will engulf the disbelievers.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcclxxxv{%
If something good happens to you, it upsets them; and if a calamity befalls you, they say, “We took our precautions in advance,” and they depart, happy.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcclxxxvi{%
Say, “Nothing will happen to us except what God has ordained for us; He is our Protector.” In God let the faithful put their trust.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcclxxxvii{%
Say, “Are you expecting for us anything other than one of the two excellences? As for us: we are expecting that God will afflict you with a punishment from Himself, or at our hands. So wait, we are waiting with you.”\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcclxxxviii{%
Say, “Whether you spend willingly or unwillingly, it will not be accepted from you. You are evil people.”\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcclxxxix{%
What prevents the acceptance of their contributions is nothing but the fact that they disbelieved in God and His Messenger, and that they do not approach the prayer except lazily, and that they do not spend except grudgingly.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mccxc{%
Let neither their possessions nor their children impress you. God intends to torment them through them in this worldly life, and that their souls depart while they are disbelievers.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mccxci{%
They swear by God that they are of you. But they are not of you. They are divisive people.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mccxcii{%
Were they to find a shelter, or a cave, or a hideout, they would go to it, rushing.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mccxciii{%
And among them are those who criticize you in regard to charities. If they are given some of it, they become pleased; but if they are not given any, they grow resentful.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mccxciv{%
If only they were content with what God and His Messenger have given them, and said, “God is sufficient for us; God will give us of His bounty, and so will His Messenger; to God we eagerly turn.”\qt@no{59}}%
\qt@newcmd\qurantrans@en@mccxcv{%
Charities are for the poor, and the destitute, and those who administer them, and for reconciling hearts, and for freeing slaves, and for those in debt, and in the path of God, and for the traveler in need—an obligation from God. God is All-Knowing, Most Wise.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mccxcvi{%
And among them are those who insult the Prophet, and say, “He is all ears.” Say, “He listens for your own good. He believes in God, and trusts the believers, and is mercy for those of you who believe.” Those who insult the Messenger of God will have a painful penalty.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mccxcvii{%
They swear to you by God to please you. But it is more proper for them to please God and His Messenger, if they are believers.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mccxcviii{%
Do they not know that whoever opposes God and His Messenger, will have the Fire of Hell, abiding in it forever? That is the supreme disgrace.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mccxcix{%
The hypocrites worry lest a chapter may be revealed about them, informing them of what is in their hearts. Say, “Go on mocking; God will bring out what you fear.”\qt@no{64}}%
\qt@newcmd\qurantrans@en@mccc{%
If you ask them, they will say, “We were just joking and playing.” Say, “Were you making jokes about God, His revelations, and His Messenger?”\qt@no{65}}%
\qt@newcmd\qurantrans@en@mccci{%
Do not apologize. You have disbelieved after your belief. If We pardon some of you, We will punish others, because they are guilty.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcccii{%
The hypocrite men and hypocrite women are of one another. They advocate evil, and prohibit righteousness, and withhold their hands. They forgot God, so He forgot them. The hypocrites are the sinners.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mccciii{%
God has promised the hypocrite men and hypocrite women, and the disbelievers, the Fire of Hell, abiding therein forever. It is their due. And God has cursed them. They will have a lasting punishment.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mccciv{%
Like those before you. They were more powerful than you, and had more wealth and children. They enjoyed their share, and you enjoyed your share, as those before you enjoyed their share. And you indulged, as they indulged. It is they whose works will fail in this world and in the Hereafter. It is they who are the losers.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcccv{%
Have they not heard the stories of those before them? The people of Noah, and Aad, and Thamood; and the people of Abraham, and the inhabitants of Median, and the Overturned Cities? Their messengers came to them with the clear proofs. God never wronged them, but they used to wrong their own selves.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcccvi{%
The believing men and believing women are friends of one another. They advocate virtue, forbid evil, perform the prayers, practice charity, and obey God and His Messenger. These—God will have mercy on them. God is Noble and Wise.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcccvii{%
God promises the believers, men and women, gardens beneath which rivers flow, abiding therein forever, and fine homes in the Gardens of Eden. But approval from God is even greater. That is the supreme achievement.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcccviii{%
O Prophet! Strive against the disbelievers and the hypocrites, and be stern with them. Their abode is Hell—what a miserable destination!\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcccix{%
They swear by God that they said nothing; but they did utter the word of blasphemy, and they renounced faith after their submission. And they plotted what they could not attain. They were resentful only because God and His Messenger have enriched them out of His grace. If they repent, it would be best for them; but if they turn away, God will afflict them with a painful punishment—in this life and in the Hereafter—and they will have on earth no protector and no savior.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcccx{%
Among them are those who promised God: “If He gives us of His bounty, we will donate and be among the upright.”\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcccxi{%
But when He has given them of His bounty, they became stingy with it, and turned away in aversion.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcccxii{%
So He penalized them with hypocrisy in their hearts, until the Day they face Him—because they broke their promise to God, and because they used to lie.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcccxiii{%
Do they not know that God knows their secrets and their conspiracies? And that God is the Knower of the unseen?\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcccxiv{%
Those who criticize the believers who give charity voluntarily, and ridicule those who find nothing to give except their own efforts—God ridicules them. They will have a painful punishment.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcccxv{%
Whether you ask forgiveness for them, or do not ask forgiveness for them—even if you ask forgiveness for them seventy times, God will not forgive them. That is because they disbelieved in God and His Messenger. God does not guide the immoral people.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcccxvi{%
Those who stayed behind rejoiced at their staying behind the Messenger of God. And they hated to strive with their wealth and their lives in God’s way. And they said, “Do not venture out in the heat.” Say, “The Fire of Hell is much hotter, if they only understood.”\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcccxvii{%
Let them laugh a little, and weep much; in recompense for what they used to earn.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcccxviii{%
If God brings you back to a party of them, and they ask your permission to go out, say, “You will not go out with me, ever, nor will you ever fight an enemy with me. You were content to sit back the first time, so sit back with those who stay behind.”\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcccxix{%
You are never to pray over anyone of them who dies, nor are you to stand at his graveside. They rejected God and His Messenger, and died while they were sinners.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcccxx{%
Do not let their possessions and their children impress you. God desires to torment them through them in this world, and their souls expire while they are disbelievers.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcccxxi{%
When a chapter is revealed, stating: “Believe in God and strive with His Messenger,” the prominent among them ask you for exemption. They say, “Allow us to stay with those who stay behind.”\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcccxxii{%
They prefer to be with those who stay behind. Their hearts were sealed, so they do not understand.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcccxxiii{%
But the Messenger and those who believe with him struggle with their possessions and their lives. These have deserved the good things. These are the successful.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcccxxiv{%
God has prepared for them gardens beneath which rivers flow, wherein they will abide forever. That is the great victory.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcccxxv{%
Some of the Desert-Arabs came to make excuses, asking to be granted exemption, while those who were untrue to God and His Messenger stayed behind. A painful punishment will afflict those among them who disbelieved.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcccxxvi{%
There is no blame on the weak, nor on the sick, nor on those who have nothing to give, provided they are true to God and His Messenger. In no way can the righteous be blamed. God is Forgiving and Merciful.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcccxxvii{%
Nor on those who approach you, wishing to ride with you, and you said, “I have nothing to carry you on.” So they went away, with their eyes overflowing with tears, sorrowing for not finding the means to spend.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcccxxviii{%
But blame is on those who ask you for exemption, although they are rich. They are content to be with those who stay behind. God has sealed their hearts, so they do not know.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcccxxix{%
They present excuses to you when you return to them. Say, “Do not offer excuses; we do not trust you; God has informed us of you. And God will watch your actions, and so will the Messenger; then you will be returned to the Knower of the Invisible and the Visible, and He will inform you of what you used to do.”\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcccxxx{%
They will swear to you by God, when you return to them, that you may leave them alone. So leave them alone. They are a disgrace, and their destiny is Hell; a reward for what they used to earn.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcccxxxi{%
They will swear to you that you may accept them. But even if you accept them, God does not accept the wicked people.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcccxxxii{%
The Desert-Arabs are the most steeped in disbelief and hypocrisy, and the most likely to ignore the limits that God revealed to His Messenger. God is Knowing and Wise.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcccxxxiii{%
And among the Desert-Arabs are those who consider their contribution to be a fine. And they wait for a reversal of your fortunes. Upon them will fall the cycle of misfortune. God is Hearing and Knowing.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcccxxxiv{%
Yet among the Desert-Arabs are those who believe in God and the Last Day, and consider their contribution to be a means towards God, and the prayers of the Messenger. Surely it will draw them closer, and God will admit them into His mercy. God is Forgiving and Compassionate.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcccxxxv{%
The Pioneers—The first of the Migrants and the Supporters, and those who followed them in righteousness. God is pleased with them, and they are pleased with Him. He has prepared for them Gardens beneath which rivers flow, where they will abide forever. That is the sublime triumph.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mcccxxxvi{%
Among the Desert-Arabs around you there are some hypocrites, and among the inhabitants of Medina too. They have become adamant in hypocrisy. You do not know them, but We know them. We will punish them twice; then they will be returned to a severe torment.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mcccxxxvii{%
Others have confessed their sins, having mixed good deeds with bad deeds. Perhaps God will redeem them. God is Forgiving and Merciful.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mcccxxxviii{%
Receive contributions from their wealth, to purify them and sanctify them with it; and pray for them. Your prayer is comfort for them. God is Hearing and Knowing.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mcccxxxix{%
Do they not know that God accepts the repentance of His servants, and that He receives the contributions, and that God is the Acceptor of Repentance, the Merciful?\qt@no{104}}%
\qt@newcmd\qurantrans@en@mcccxl{%
Say, “Work. God will see your work, and so will His Messenger, and the believers. Then you will be returned to the Knower of secrets and declarations, and He will inform you of what you used to do.”\qt@no{105}}%
\qt@newcmd\qurantrans@en@mcccxli{%
Others are held in suspense, awaiting God’s decree, as to whether He will punish them, or accept their repentance. God is Aware and Wise.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mcccxlii{%
Then there are those who establish a mosque to cause harm, and disbelief, and disunity among the believers, and as an outpost for those who fight God and His Messenger. They will swear: “Our intentions are nothing but good.” But God bears witness that they are liars.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mcccxliii{%
Do not stand in it, ever. A mosque founded upon piety from the first day is worthier of your standing in it. In it are men who love to be purified. God loves those who purify themselves.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mcccxliv{%
Is he who founds his structure upon piety and acceptance from God better, or he who founds his structure on the brink of a cliff that is about to tumble, so it tumbles with him into the Fire of Hell? God does not guide the unjust people.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mcccxlv{%
The structure which they built will remain questionable in their hearts, until their hearts are stopped. God is Knowing and Wise.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mcccxlvi{%
God has purchased from the believers their lives and their properties in exchange for Paradise. They fight in God’s way, and they kill and get killed. It is a promise binding on Him in the Torah, and the Gospel, and the Quran. And who is more true to his promise than God? So rejoice in making such an exchange—that is the supreme triumph.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mcccxlvii{%
Those who repent, those who worship, those who praise, those who journey, those who kneel, those who bow down, those who advocate righteousness and forbid evil, and those who keep God’s limits—give good news to the believers.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mcccxlviii{%
It is not for the Prophet and those who believe to ask forgiveness for the polytheists, even if they are near relatives, after it has become clear to them that they are people of Hellfire.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mcccxlix{%
Abraham asked forgiveness for his father only because of a promise he had made to him. But when it became clear to him that he was an enemy of God, he disowned him. Abraham was kind and clement.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mcccl{%
God would never lead a people astray, after He had guided them, until He makes clear to them what they should guard against. God has knowledge of all things.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mcccli{%
To God belongs the dominion of the heavens and the earth. He gives life, and He causes death. And besides God, you have neither protector, nor supporter.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mccclii{%
God has redeemed the Prophet, and the Emigrants, and the Supporters—those who followed him in the hour of difficulty—after the hearts of some of them almost swerved. Then He pardoned them. He is Kind towards them, Compassionate.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mcccliii{%
Also towards the three who were left behind. Then, when the earth, as vast as it is, closed in on them, and their very souls closed in on them, and they realized that there was no refuge from God, except in Him, He redeemed them, so that they may repent. God is the Redeemer, the Merciful.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mcccliv{%
O you who believe! Be conscious of God, and be with the sincere.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mccclv{%
It is not for the inhabitants of Medina and the Desert-Arabs around them to stay behind the Messenger of God, nor to prefer themselves to him. That is because they never suffer any thirst, nor fatigue, nor hunger in the cause of God, nor do they take one step that enrages the disbelievers, nor do they gain anything from an enemy, but it is recorded to their credit as a righteous deed. God does not waste the reward of the righteous.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mccclvi{%
Nor do they spend any expenditure, small or large, nor do they cross any valley, but it is recorded to their credit. That God may reward them in accordance with the best of their deeds.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mccclvii{%
It is not advisable for the believers to march out altogether. Of every division that marches out, let a group remain behind, to gain understanding of the religion, and to notify their people when they have returned to them, that they may beware.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mccclviii{%
O you who believe! Fight those of the disbelievers who attack you, and let them find severity in you, and know that God is with the righteous.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mccclix{%
Whenever a chapter is revealed, some of them say, “Which of you has this increased in faith?” As for those who believe: it increases them in faith, and they rejoice.\qt@no{124}}%
\qt@newcmd\qurantrans@en@mccclx{%
But as for those in whose hearts is sickness: it adds disgrace to their disgrace, and they die as unbelievers.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mccclxi{%
Do they not see that they are tested once or twice every year? Yet they do not repent, and they do not learn.\qt@no{126}}%
\qt@newcmd\qurantrans@en@mccclxii{%
And whenever a chapter is revealed, they look at one another, “Does anyone see you?” Then they slip away. God has diverted their hearts, because they are a people who do not understand.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mccclxiii{%
There has come to you a messenger from among yourselves, concerned over your suffering, anxious over you. Towards the believers, he is compassionate and merciful.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mccclxiv{%
If they turn away, say, “God is enough for me; there is no god except He; in Him I have put my trust; He is the Lord of the Sublime Throne.”\qt@no{129}}%
\qt@newcmd\qurantrans@en@mccclxv{%
\basmalahen Alif, Lam, Ra. These are the Verses of the Wise Book.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mccclxvi{%
Is it a wonder to the people that We inspired a man from among them: “Warn mankind, and give good news to those who believe that they are on a sound footing with their Lord”? The disbelievers said, “This is a manifest sorcerer.”\qt@no{2}}%
\qt@newcmd\qurantrans@en@mccclxvii{%
Your Lord is God, who created the heavens and the earth in six days, then settled over the Throne, governing all things. There is no intercessor except after His permission. Such is God, your Lord—so serve Him. Will you not reflect?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mccclxviii{%
To Him is your return, altogether. The promise of God is true. He originates creation, and then He repeats it, to reward those who believe and do good deeds with equity. As for those who disbelieve, for them is a drink of boiling water, and agonizing torment, on account of their disbelief.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mccclxix{%
It is He who made the sun radiant, and the moon a light, and determined phases for it—that you may know the number of years and the calculation. God did not create all this except with truth. He details the revelations for a people who know.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mccclxx{%
In the alternation of night and day, and in what God created in the heavens and the earth, are signs for people who are aware.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mccclxxi{%
Those who do not hope to meet Us, and are content with the worldly life, and are at ease in it, and those who pay no heed to Our signs.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mccclxxii{%
These—their dwelling is the Fire—on account of what they used to do.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mccclxxiii{%
As for those who believe and do good deeds, their Lord guides them in their faith. Rivers will flow beneath them in the Gardens of Bliss.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mccclxxiv{%
Their call therein is, “Glory be to You, our God.” And their greeting therein is, “Peace.” And the last of their call is, “Praise be to God, Lord of the Worlds.”\qt@no{10}}%
\qt@newcmd\qurantrans@en@mccclxxv{%
If God were to accelerate the ill for the people, as they wish to accelerate the good, their term would have been fulfilled. But We leave those who do not expect Our encounter to blunder in their excesses.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mccclxxvi{%
Whenever adversity touches the human being, he prays to Us—reclining on his side, or sitting, or standing. But when We have relieved his adversity from him, he goes away, as though he had never called on Us for trouble that had afflicted him. Thus the deeds of the transgressors appear good to them.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mccclxxvii{%
We destroyed generations before you when they did wrong. Their messengers came to them with clear signs, but they would not believe. Thus We requite the sinful people.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mccclxxviii{%
Then We made you successors on earth after them, to see how you would behave.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mccclxxix{%
And when Our clear revelations are recited to them, those who do not hope to meet Us say, “Bring a Quran other than this, or change it.” Say, “It is not for me to change it of my own accord. I only follow what is revealed to me. I fear, if I disobeyed my Lord, the torment of a terrible Day.”\qt@no{15}}%
\qt@newcmd\qurantrans@en@mccclxxx{%
Say, “Had God willed, I would not have recited it to you, and He would not have made it known to you. I have lived among you for a lifetime before it. Do you not understand?”\qt@no{16}}%
\qt@newcmd\qurantrans@en@mccclxxxi{%
Who does greater wrong than someone who fabricates lies about God, or denies His revelations? The guilty will never prosper.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mccclxxxii{%
And they worship, besides God, what neither harms them nor benefits them. And they say, “These are our intercessors with God.” Say, “Are you informing God about what He does not know in the heavens or on earth?” Glorified be He, High above the associations they make.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mccclxxxiii{%
Mankind was a single community; then they differed. Were it not for a prior decree from your Lord, the matters over which they had disputed would have been settled.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mccclxxxiv{%
And they say, “If only a miracle was sent down to him from his Lord.” Say, “The realm of the unseen belongs to God; so wait, I am waiting with you.”\qt@no{20}}%
\qt@newcmd\qurantrans@en@mccclxxxv{%
When We make the people taste mercy after some adversity has touched them, they begin to scheme against Our revelations. Say, “God is swifter in scheming.” Our envoys are writing down what you scheme.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mccclxxxvi{%
It is He who transports you across land and sea. Until, when you are on ships, sailing in a favorable wind, and rejoicing in it, a raging wind arrives. The waves surge over them from every side, and they realize that they are besieged. Thereupon they pray to God, professing sincere devotion to Him: “If You save us from this, we will be among the appreciative.”\qt@no{22}}%
\qt@newcmd\qurantrans@en@mccclxxxvii{%
But then, when He has saved them, they commit violations on earth, and oppose justice. O people! Your violations are against your own souls. It is the enjoyment of the present life. Then to Us is your return, and We will inform you of what you used to do.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mccclxxxviii{%
The likeness of the present life is this: water that We send down from the sky is absorbed by the plants of the earth, from which the people and the animals eat. Until, when the earth puts on its fine appearance, and is beautified, and its inhabitants think that they have mastered it, Our command descends upon it by night or by day, and We turn it into stubble, as if it had not flourished the day before. We thus clarify the revelations for people who reflect.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mccclxxxix{%
God invites to the Home of Peace, and guides whomever He wills to a straight path.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcccxc{%
For those who have done good is goodness, and more. Neither gloom nor shame will come over their faces. These are the inhabitants of Paradise, abiding therein forever.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcccxci{%
As for those who have earned evil deeds: a reward of similar evil, and shame will cover them. They will have no defense against God—as if their faces are covered with dark patches of night. These are the inmates of the Fire, abiding therein forever.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcccxcii{%
On the Day when We will gather them altogether, then say to those who ascribed partners, “To your place, you and your partners.” Then We will separate between them, and their partners will say, “It was not us you were worshiping.”\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcccxciii{%
“God is sufficient witness between us and you. We were unaware of your worshiping us.”\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcccxciv{%
There, every soul will experience what it had done previously; and they will be returned to God, their True Master; and what they used to invent will fail them.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcccxcv{%
Say, “Who provides for you from the heaven and the earth? And who controls the hearing and the sight? And who produces the living from the dead, and produces the dead from the living? And who governs the Order?” They will say, “God.” Say, “Will you not be careful?”\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcccxcvi{%
Such is God, your Lord—the True. What is there, beyond the truth, except falsehood? How are you turned away?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcccxcvii{%
Thus your Lord’s Word proved true against those who disobeyed, for they do not believe.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcccxcviii{%
Say, “Can any of your partners initiate creation, and then repeat it?” Say, “God initiates creation, and then repeats it. How are you so deluded?”\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcccxcix{%
Say, “Can any of your partners guide to the truth?” Say, “God guides to the truth. Is He who guides to the truth more worthy of being followed, or he who does not guide, unless he himself is guided? What is the matter with you? How do you judge?”\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcd{%
Most of them follow nothing but assumptions; and assumptions avail nothing against the truth. God is fully aware of what they do.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcdi{%
This Quran could not have been produced by anyone other than God. In fact, it is a confirmation of what preceded it, and an elaboration of the Book. There is no doubt about it—it is from the Lord of the Universe.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcdii{%
Or do they say, “He has forged it”? Say, “Then produce a single chapter like it, and call upon whomever you can, apart from God, if you are truthful.”\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcdiii{%
In fact, they deny what is beyond the limits of their knowledge, and whose explanation has not yet reached them. Thus those before them refused to believe. So note the consequences for the wrongdoers.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcdiv{%
Among them are those who believe in it, and among them are those who do not believe in it. Your Lord is fully aware of the mischief-makers.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcdv{%
If they accuse you of lying, say, “I have my deeds, and you have your deeds. You are quit of what I do, and I am quit of what you do.”\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcdvi{%
And among them are those who listen to you. But can you make the deaf hear, even though they do not understand?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcdvii{%
And among them are those who look at you. But can you guide the blind, even though they do not see?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcdviii{%
God does not wrong the people in the least, but the people wrong their own selves.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcdix{%
On the Day when He rounds them up—as if they had tarried only one hour of a day—they will recognize one another. Those who denied the meeting with God will be the losers. They were not guided.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcdx{%
Whether We show you some of what We promise them, or take you, to Us is their return. God is witness to everything they do.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcdxi{%
Every community has a messenger. When their messenger has come, judgment will be passed between them with fairness, and they will not be wronged.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcdxii{%
And they say, “When will this promise be fulfilled, if you are truthful?”\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcdxiii{%
Say, “I have no power to harm or benefit myself, except as God wills. To every nation is an appointed time. Then, when their time arrives, they can neither postpone it by one hour, nor advance it.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcdxiv{%
Say, “Have you considered? If His punishment overtakes you by night or by day, what part of it will the guilty seek to hasten?”\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcdxv{%
“Then, when it falls, will you believe in it? Now? When before you tried to hasten it?”\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcdxvi{%
Then it will be said to those who did wrong, “Taste the torment of eternity. Will you be rewarded except for what you used to do?”\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcdxvii{%
And they inquire of you, “Is it true?” Say, “Yes, by my Lord, it is true, and you cannot evade it.”\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcdxviii{%
Had every soul which had done wrong possessed everything on earth, it would offer it as a ransom. They will hide the remorse when they witness the suffering, and it will be judged between them equitably, and they will not be wronged.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mcdxix{%
Assuredly, to God belongs everything in the heavens and the earth. Assuredly, the promise of God is true. But most of them do not know.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mcdxx{%
He gives life and causes death, and to Him you will be returned.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mcdxxi{%
O people! There has come to you advice from your Lord, and healing for what is in the hearts, and guidance and mercy for the believers.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mcdxxii{%
Say, “In God’s grace and mercy let them rejoice. That is better than what they hoard.”\qt@no{58}}%
\qt@newcmd\qurantrans@en@mcdxxiii{%
Say, “Have you considered the sustenance God has sent down for you, some of which you made unlawful, and some lawful?” Say, “Did God give you permission, or do you fabricate lies and attribute them to God?”\qt@no{59}}%
\qt@newcmd\qurantrans@en@mcdxxiv{%
What will they think—those who fabricate lies and attribute them to God—on the Day of Resurrection? God is bountiful towards the people, but most of them do not give thanks.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mcdxxv{%
You do not get into any situation, nor do you recite any Quran, nor do you do anything, but We are watching over you as you undertake it. Not even the weight of an atom, on earth or in the sky, escapes your Lord, nor is there anything smaller or larger, but is in a clear record.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mcdxxvi{%
Unquestionably, God’s friends have nothing to fear, nor shall they grieve.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mcdxxvii{%
Those who believe and are aware.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mcdxxviii{%
For them is good news in this life, and in the Hereafter. There is no alteration to the words of God. That is the supreme triumph.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mcdxxix{%
And let not their sayings dishearten you. All power is God’s. He is the Hearer, the Knower.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mcdxxx{%
Certainly, to God belongs everyone in the heavens and everyone on earth. Those who invoke other than God do not follow partners; they follow only assumptions, and they only guess.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcdxxxi{%
It is He who made the night for your rest, and the daylight for visibility. Surely in that are signs for people who listen.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mcdxxxii{%
And they said, “God has taken a son.” Be He glorified. He is the Self-Sufficient. His is everything in the heavens and everything on earth. Do you have any proof for this? Or are you saying about God what you do not know?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mcdxxxiii{%
Say, “Those who fabricate lies about God will not succeed.”\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcdxxxiv{%
Some enjoyment in this world; then to Us is their return; then We will make them taste the severe punishment on account of their disbelief.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcdxxxv{%
And relate to them the story of Noah, when he said to his people, “O my people, if my presence among you and my reminding you of God’s signs is too much for you, then in God I have put my trust. So come to a decision, you and your partners, and do not let the matter perplex you; then carry out your decision on me, and do not hold back.”\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcdxxxvi{%
“But if you turn away, I have not asked you for any wage. My wage falls only on God, and I was commanded to be of those who submit.”\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcdxxxvii{%
But they denounced him, so We saved him and those with him in the Ark, and We made them successors, and We drowned those who rejected Our signs. So consider the fate of those who were warned.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcdxxxviii{%
Then, after him, We sent messengers to their people. They came to them with the clear proofs, but they would not believe in anything they had already rejected. Thus We set a seal on the hearts of the hostile.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcdxxxix{%
Then, after them, We sent Moses and Aaron with Our proofs to Pharaoh and his dignitaries. But they acted arrogantly. They were sinful people.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcdxl{%
And when the truth came to them from Us, they said, “This is clearly sorcery.”\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcdxli{%
Moses said, “Is this what you say of the truth when it has come to you? Is this sorcery? Sorcerers do not succeed.”\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcdxlii{%
They said, “Did you come to us to divert us from what we found our ancestors following, and so that you become prominent in the land? We will never believe in you.”\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcdxliii{%
Pharaoh said, “Bring me every experienced sorcerer.”\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcdxliv{%
And when the sorcerers came, Moses said to them, “Throw whatever you have to throw.”\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcdxlv{%
And when they threw, Moses said, “What you produced is sorcery, and God will make it fail. God does not foster the efforts of the corrupt.”\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcdxlvi{%
“And God upholds the truth with His words, even though the sinners detest it.”\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcdxlvii{%
But none believed in Moses except some children of his people, for fear that Pharaoh and his chiefs would persecute them. Pharaoh was high and mighty in the land. He was a tyrant.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcdxlviii{%
Moses said, “O my people, if you have believed in God, then put your trust in Him, if you have submitted.”\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcdxlix{%
They said, “In God we have put our trust. Our Lord, do not make us victims of the oppressive people.”\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcdl{%
“And deliver us, by Your mercy, from the disbelieving people.”\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcdli{%
And We inspired Moses and his brother, “Settle your people in Egypt, and make your homes places of worship, and perform the prayer, and give good news to the believers.”\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcdlii{%
Moses said, “Our Lord, you have given Pharaoh and his chiefs splendor and wealth in the worldly life. Our Lord, for them to lead away from Your path. Our Lord, obliterate their wealth, and harden their hearts, they will not believe until they see the painful torment.”\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcdliii{%
He said, “Your prayer has been answered, so go straight, and do not follow the path of those who do not know.”\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcdliv{%
And We delivered the Children of Israel across the sea. Pharaoh and his troops pursued them, defiantly and aggressively. Until, when he was about to drown, he said, “I believe that there is no god except the One the Children of Israel believe in, and I am of those who submit.”\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcdlv{%
Now? When you have rebelled before, and been of the mischief-makers?\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcdlvi{%
Today We will preserve your body, so that you become a sign for those after you. But most people are heedless of Our signs.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcdlvii{%
And We settled the Children of Israel in a position of honor, and provided them with good things. They did not differ until knowledge came to them. Your Lord will judge between them on the Day of Resurrection regarding their differences.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcdlviii{%
If you are in doubt about what We revealed to you, ask those who read the Scripture before you. The truth has come to you from your Lord, so do not be of those who doubt.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcdlix{%
And do not be of those who deny God’s revelations, lest you become one of the losers.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcdlx{%
Those against whom your Lord’s Word is justified will not believe.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcdlxi{%
Even if every sign comes to them—until they see the painful punishment.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcdlxii{%
If only there was one town that believed and benefited by its belief. Except for the people of Jonah. When they believed, We removed from them the suffering of disgrace in the worldly life, and We gave them comfort for a while.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcdlxiii{%
Had your Lord willed, everyone on earth would have believed. Will you compel people to become believers?\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcdlxiv{%
No soul can believe except by God’s leave; and He lays disgrace upon those who refuse to understand.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mcdlxv{%
Say, “Look at what is in the heavens and the earth.” But signs and warnings are of no avail for people who do not believe.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mcdlxvi{%
Do they expect anything but the likes of the days of those who passed away before them? Say, “Then wait, I will be waiting with you.”\qt@no{102}}%
\qt@newcmd\qurantrans@en@mcdlxvii{%
Then We save Our messengers and those who believe. It is binding on Us to save the believers.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mcdlxviii{%
Say, “O people, if you are in doubt about my religion—I do not serve those you serve apart from God. But I serve God, the one who will terminate your lives. And I was commanded to be of the believers.”\qt@no{104}}%
\qt@newcmd\qurantrans@en@mcdlxix{%
And dedicate yourself to the true religion—a monotheist—and never be of the polytheists.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mcdlxx{%
And do not call, apart from God, on what neither benefits you nor harms you. If you do, you are then one of the wrongdoers.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mcdlxxi{%
If God afflicts you with harm, none can remove it except He. And if He wants good for you, none can repel His grace. He makes it reach whomever He wills of His servants. He is the Forgiver, the Merciful.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mcdlxxii{%
Say, “O people, the truth has come to you from your Lord. Whoever accepts guidance is guided for his own soul; and whoever strays only strays to its detriment. I am not a guardian over you.”\qt@no{108}}%
\qt@newcmd\qurantrans@en@mcdlxxiii{%
And follow what is revealed to you, and be patient until God issues His judgment, for He is the Best of judges.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mcdlxxiv{%
\basmalahen Alif, Lam, Ra. A Scripture whose Verses were perfected, then elaborated, from One who is Wise and Informed.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mcdlxxv{%
That you shall worship none but God. “I am a warner to you from Him, and a bearer of good news.”\qt@no{2}}%
\qt@newcmd\qurantrans@en@mcdlxxvi{%
“And ask your Lord for forgiveness, and repent to Him. He will provide you with good sustenance until a stated term, and will bestow His grace on every possessor of virtue. But if you turn away, then I fear for you the punishment of a grievous Day.”\qt@no{3}}%
\qt@newcmd\qurantrans@en@mcdlxxvii{%
“To God is your return, and He is Capable of all things.”\qt@no{4}}%
\qt@newcmd\qurantrans@en@mcdlxxviii{%
They wrap their chests to hide from Him. But even as they cover themselves with their clothes, He knows what they conceal and what they reveal. He knows what lies within the hearts.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mcdlxxix{%
There is no moving creature on earth but its sustenance depends on God. And He knows where it lives and where it rests. Everything is in a Clear Book.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mcdlxxx{%
It is He who created the heavens and the earth in six days—and His Throne was upon the waters—in order to test you—which of you is best in conduct. And if you were to say, “You will be resurrected after death,” those who disbelieve would say, “This is nothing but plain witchcraft.”\qt@no{7}}%
\qt@newcmd\qurantrans@en@mcdlxxxi{%
And if We postponed their punishment until a stated time, they would say, “What holds it back?” On the Day when it reaches them, it will not be averted from them, and what they used to ridicule will besiege them.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mcdlxxxii{%
If We give the human being a taste of mercy from Us, and then withdraw it from him, he becomes despairing and ungrateful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mcdlxxxiii{%
And if We give him a taste of prosperity, after some adversity has afflicted him, he will say, “Troubles have gone away from me.” He becomes excited and proud.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mcdlxxxiv{%
Except those who are patient and do good deeds—these will have forgiveness and a great reward.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mcdlxxxv{%
Perhaps you wish to disregard some of what is revealed to you, and you may be stressed because of it, since they say, “If only a treasure was sent down to him, or an angel came with him.” You are only a warner, and God is Responsible for all things.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mcdlxxxvi{%
Or do they say, “He invented it?” Say, “Then produce ten chapters like it, invented, and call upon whomever you can, besides God, if you are truthful.”\qt@no{13}}%
\qt@newcmd\qurantrans@en@mcdlxxxvii{%
But if they fail to answer you, know that it was revealed with God’s knowledge, and that there is no god but He. Will you then submit?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mcdlxxxviii{%
Whoever desires the worldly life and its glitter—We will fully recompense them for their deeds therein, and therein they will not be defrauded.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mcdlxxxix{%
These—they will have nothing but the Fire in the Hereafter. Their deeds are in vain therein, and their works are null.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcdxc{%
Is he who possesses a clear proof from his Lord, recited by a witness from Him, and before it the Book of Moses, a guide and a mercy? These believe in it. But whoever defies it from among the various factions, the Fire is his promise. So have no doubt about it. It is the truth from your Lord, but most people do not believe.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mcdxci{%
Who does greater wrong than he who fabricates lies about God? These will be presented before their Lord, and the witnesses will say, “These are they who lied about their Lord.” Indeed, the curse of God is upon the wrongdoers.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mcdxcii{%
Those who hinder others from the path of God, and seek to make it crooked; and regarding the Hereafter, they are in denial.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcdxciii{%
These will not escape on earth, and they have no protectors besides God. The punishment will be doubled for them. They have failed to hear, and they have failed to see.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcdxciv{%
Those are the ones who lost their souls, and what they had invented has strayed away from them.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcdxcv{%
Without a doubt, in the Hereafter, they will be the biggest losers.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcdxcvi{%
As for those who believe and do good deeds, and humble themselves before their Lord—these are the inhabitants of Paradise, where they will abide forever.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcdxcvii{%
The parable of the two groups is that of the blind and the deaf, and the seeing and the hearing. Are they equal in comparison? Will you not reflect?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcdxcviii{%
We sent Noah to his people, “I am to you a clear warner.”\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcdxcix{%
“That you shall worship none but God. I fear for you the agony of a painful Day.”\qt@no{26}}%
\qt@newcmd\qurantrans@en@md{%
The notables who disbelieved among his people said, “We see in you nothing but a man like us, and we see that only the worst among us have followed you, those of immature judgment. And we see that you have no advantage over us. In fact, we think you are liars.”\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdi{%
He said, “O my people, Have you considered? If I stand on clear evidence from my Lord, and He has given me a mercy from Himself, but you were blind to it, can we compel you to accept it, even though you dislike it?”\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdii{%
“O my people! I ask of you no money for it. My reward lies only with God. And I am not about to dismiss those who believed; they will surely meet their Lord. And I see that you are ignorant people.”\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdiii{%
“O my people! Who will support me against God, if I dismiss them? Will you not give a thought?”\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdiv{%
“I do not say to you that I possess the treasures of God, nor do I know the future, nor do I say that I am an angel. Nor do I say of those who are despicable in your eyes that God will never give them any good. God is Aware of what lies in their souls. If I did, I would be one of the wrongdoers.”\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdv{%
They said, “O Noah, you have argued with us, and argued a great deal. Now bring upon us what you threaten us with, if you are truthful.”\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdvi{%
He said, “It is God who will bring it upon you, if He wills, and you will not be able to escape.”\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdvii{%
“My advice will not benefit you, much as I may want to advise you, if God desires to confound you. He is your Lord, and to Him you will be returned.”\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdviii{%
Or do they say, “He made it up?” Say, “If I made it up, upon me falls my crime, and I am innocent of the crimes you commit.”\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdix{%
And it was revealed to Noah: “None of your people will believe, except those who have already believed, so do not grieve over what they do.”\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdx{%
“And build the Ark, under Our eyes, and with Our inspiration, and do not address Me regarding those who did wrong; they are to be drowned.”\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdxi{%
As he was building the ark, whenever some of his people passed by him, they ridiculed him. He said, “If you ridicule us, we will ridicule you, just as you ridicule.”\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdxii{%
“You will surely know upon whom will come a torment that will abase him, and upon whom will fall a lasting torment.”\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdxiii{%
Until, when Our command came, and the volcano erupted, We said, “Board into it a pair of every kind, and your family—except those against whom the sentence has already been passed—and those who have believed.” But those who believed with him were only a few.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdxiv{%
He said, “Embark in it. In the name of God shall be its sailing and its anchorage. My Lord is indeed Forgiving and Merciful.”\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdxv{%
And so it sailed with them amidst waves like hills. And Noah called to his son, who had kept away, “On my son! Embark with us, and do not be with the disbelievers.”\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdxvi{%
He said, “I will take refuge on a mountain—it will protect me from the water.” He said, “There is no protection from God’s decree today, except for him on whom He has mercy.” And the waves surged between them, and he was among the drowned.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdxvii{%
And it was said, “O earth, swallow your waters,” and “O heaven, clear up.” And the waters receded, and the event was concluded, and it settled on Judi, and it was proclaimed: “Away with the wicked people.”\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdxviii{%
And Noah called to his Lord. He said, “O My Lord, my son is of my family, and Your promise is true, and You are the Wisest of the wise.”\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdxix{%
He said, “O Noah, he is not of your family. It is an unrighteous deed. So do not ask Me about something you know nothing about. I admonish you, lest you be one of the ignorant.”\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdxx{%
He said, “O My Lord, I seek refuge with You, from asking You about what I have no knowledge of. Unless You forgive me, and have mercy on me, I will be one of the losers.”\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdxxi{%
It was said, “O Noah, disembark with peace from Us; and with blessings upon you, and upon communities from those with you. And other communities We will grant prosperity, and then a painful torment from Us will befall them.”\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdxxii{%
These are some stories from the past that we reveal to you. Neither you, nor your people knew them before this. So be patient. The future belongs to the pious.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdxxiii{%
And to Aad, their brother Hud. He said, “O my people, worship God, you have no other god besides Him. You do nothing but invent lies.”\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdxxiv{%
“O my people, I ask you no wage for it; my wage lies with Him who originated me. Do you not understand?”\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdxxv{%
“O my people, ask forgiveness from your Lord, and repent to Him. He will release the sky pouring down upon you, and will add strength to your strength. And do not turn away and be wicked.”\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdxxvi{%
They said, “O Hud, you did not bring us any evidence, and we are not about to abandon our gods at your word, and we are not believers in you.”\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdxxvii{%
“We only say that some of our gods have possessed you with evil.” He said, “I call God to witness, and you to witness, that I am innocent of what you associate.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdxxviii{%
Besides Him. So scheme against me, all of you, and do not hesitate.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdxxix{%
I have placed my trust in God, my Lord and your Lord. There is not a creature but He holds it by the forelock. My Lord is on a straight path.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdxxx{%
If you turn away, I have conveyed to you what I was sent to you with; and my Lord will replace you with another people, and you will not cause Him any harm. My Lord is Guardian over all things.”\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdxxxi{%
And when Our decree came, We saved Hud and those who believed with him, by a mercy from Us, and We delivered them from a harsh punishment.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdxxxii{%
That was Aad; they denied the signs of their Lord, and defied His messengers, and followed the lead of every stubborn tyrant.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdxxxiii{%
And they were pursued by a curse in this world, and on the Day of Resurrection. Indeed, Aad blasphemed against their Lord—so away with Aad, the people of Hud.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdxxxiv{%
And to Thamood, their brother Saleh. He said, “O my people, worship God, you have no god other than Him. He initiated you from the earth, and settled you in it. So seek His forgiveness, and repent to Him. My Lord is Near and Responsive.”\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdxxxv{%
They said, “O Saleh, we had hopes in you before this. Are you trying to prevent us from worshiping what our parents worship? We are in serious doubt regarding what you are calling us to.”\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdxxxvi{%
He said, “O my people, have you considered? If I stand upon clear evidence from my Lord, and He has given me mercy from Him, who would protect me from God, if I disobeyed Him? You add nothing for me except loss.”\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdxxxvii{%
“O my people, this is the she-camel of God, a sign for you. Let her graze on God’s land, and do not harm her, lest an imminent punishment overtakes you.”\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdxxxviii{%
But they hamstrung her, and so He said, “Enjoy yourselves in your homes for three days. This is a prophecy that is infallible.”\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdxxxix{%
Then, when Our command came, We saved Saleh and those who believed with him, by a mercy from Us, from the disgrace of that day. Your Lord is the Strong, the Mighty.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdxl{%
And the Scream struck those who transgressed, and they became motionless bodies in their homes.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdxli{%
As if they had never prospered therein. Indeed, Thamood rejected their Lord, so away with Thamood.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdxlii{%
Our messengers came to Abraham with good news. They said, “Peace.” He said, “Peace.” Soon after, he came with a roasted calf.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdxliii{%
But when he saw their hands not reaching towards it, he became suspicious of them, and conceived a fear of them. They said, “Do not fear, we were sent to the people of Lot.”\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdxliv{%
His wife was standing by, so she laughed. And We gave her good news of Isaac; and after Isaac, Jacob.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdxlv{%
She said, “Alas for me. Shall I give birth, when I am an old woman, and this, my husband, is an old man? This is truly a strange thing.”\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdxlvi{%
They said, “Do you marvel at the decree of God? The mercy and blessings of God are upon you, O people of the house. He is Praiseworthy and Glorious.”\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdxlvii{%
When Abraham's fear subsided, and the good news had reached him, he started pleading with Us concerning the people of Lot.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdxlviii{%
Abraham was gentle, kind, penitent.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdxlix{%
“O Abraham, refrain from this. The command of your Lord has come; they have incurred an irreversible punishment.”\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdl{%
And when Our envoys came to Lot, he was anxious for them, and concerned for them. He said, “This is a dreadful day.”\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdli{%
And his people came rushing towards him—they were in the habit of committing sins. He said, “O my people, these are my daughters; they are purer for you. So fear God, and do not embarrass me before my guests. Is there not one reasonable man among you?”\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdlii{%
They said, “You know well that we have no right to your daughters, and you know well what we want.”\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdliii{%
He said, “If only I had the strength to stop you, or could rely on some strong support.”\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdliv{%
They said, “O Lot, we are the envoys of your Lord; they will not reach you. So set out with your family during the cover of the night, and let none of you look back, except for your wife. She will be struck by what will strike them. Their appointed time is the morning. Is not the morning near?”\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdlv{%
And when Our command came about, We turned it upside down, and We rained down on it stones of baked clay.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdlvi{%
Marked from your Lord, and never far from the wrongdoers.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdlvii{%
And to Median, their brother Shuaib. He said, “O my people, worship God; you have no god other than Him. And do not short measure or short weight. I see you in good circumstances, but I fear for you the agony of an encompassing Day.”\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdlviii{%
“O my people! Give full measure and full weight, in all fairness, and do not cheat the people out of their rights, and do not spread corruption in the land.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdlix{%
What is left by God is best for you, if you are believers. And I am not a guardian over you.”\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdlx{%
They said, “O Shuaib, does your prayer command you that we abandon what our ancestors worshiped, or doing with our wealth what we want? You are the one who is intelligent and wise.”\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdlxi{%
He said, “O my people, have you considered? What if I have clear evidence from my Lord, and He has given me good livelihood from Himself? I have no desire to do what I forbid you from doing. I desire nothing but reform, as far as I can. My success lies only with God. In Him I trust, and to Him I turn.”\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdlxii{%
“O my people, let not your hostility towards me cause you to suffer what was suffered by the people of Noah, or the people of Hud, or the people of Saleh. The people of Lot are not far away from you.”\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdlxiii{%
“And ask your Lord for forgiveness, and repent to Him. My Lord is Merciful and Loving.”\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdlxiv{%
They said, “O Shuaib, we do not understand much of what you say, and we see that you are weak among us. Were it not for your tribe, we would have stoned you. You are of no value to us.”\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdlxv{%
He said, “O my people, is my tribe more important to you than God? And you have turned your backs on Him? My Lord comprehends everything you do.”\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdlxvi{%
“O my people, do as you may, and so will I. You will know to whom will come a punishment that will shame him, and who is a liar. So look out; I am on the lookout with you.”\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdlxvii{%
And when Our command came, We saved Shuaib and those who believed with him, by mercy from Us, and the Blast struck the wrongdoers, and they became motionless bodies in their homes.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdlxviii{%
As though they never flourished therein. Away with Median, as was done away with Thamood.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdlxix{%
And We sent Moses with Our signs and a clear mandate.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mdlxx{%
To Pharaoh and his nobles, but they followed the command of Pharaoh, and the command of Pharaoh was not wise.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mdlxxi{%
He will precede his people on the Day of Resurrection, and will lead them into the Fire. Miserable is the place he placed them in.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mdlxxii{%
They were followed by a curse in this, and on the Day of Resurrection. Miserable is the path they followed.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mdlxxiii{%
These are of the reports of the towns—We relate them to you. Some are still standing, and some have withered away.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mdlxxiv{%
We did not wrong them, but they wronged themselves. Their gods, whom they invoked besides God, availed them nothing when the command of your Lord arrived. In fact, they added only to their ruin.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mdlxxv{%
Such is the grip of your Lord when He seizes the towns in the midst of their sins. His grip is most painful, most severe.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mdlxxvi{%
In that is a sign for whoever fears the punishment of the Hereafter. That is a Day for which humanity will be gathered together—that is a Day to be witnessed.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mdlxxvii{%
We only postpone it until a predetermined time.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mdlxxviii{%
On the Day when it arrives, no soul will speak without His permission. Some will be miserable, and some will be happy.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mdlxxix{%
As for those who are miserable, they will be in the Fire. They will have therein sighing and wailing.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mdlxxx{%
Remaining therein for as long as the heavens and the earth endure, except as your Lord wills. Your Lord is Doer of whatever He wills.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mdlxxxi{%
And as for those who are happy, they will be in Paradise, remaining therein for as long as the heavens and the earth endure, except as your Lord wills—a reward without end.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mdlxxxii{%
So be not in doubt regarding what these people worship. They worship only as their ancestors worshiped before. We will pay them their due in full, without any reduction.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mdlxxxiii{%
We gave Moses the Scripture, but it was disputed. Were it not for a prior word from your Lord, it would have been settled between them. They are in serious doubt concerning it.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mdlxxxiv{%
Your Lord will repay each one of them in full for their deeds. He is Aware of everything they do.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mdlxxxv{%
So be upright, as you are commanded, along with those who repented with you, and do not transgress. He is Seeing of everything you do.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mdlxxxvi{%
And do not incline towards those who do wrong, or the Fire may touch you; and you will have no protectors besides God, and you will not be saved.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mdlxxxvii{%
Perform the prayer at the borders of the day, and during the approaches of the night. The good deeds take away the bad deeds. This is a reminder for those who remember.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mdlxxxviii{%
And be patient. God will not waste the reward of the virtuous.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mdlxxxix{%
If only there were, among the generations before you, people with wisdom, who spoke against corruption on earth—except for the few whom We saved. But the wrongdoers pursued the luxuries they were indulged in, and thus became guilty.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mdxc{%
Your Lord would never destroy the towns wrongfully, while their inhabitants are righteous.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mdxci{%
Had your Lord willed, He could have made humanity one community, but they continue to differ.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mdxcii{%
Except those on whom your Lord has mercy—for that reason He created them. The Word of your Lord is final: “I will fill Hell with jinn and humans, altogether.”\qt@no{119}}%
\qt@newcmd\qurantrans@en@mdxciii{%
Everything We narrate to you of the history of the messengers is to strengthen your heart therewith. The truth has come to you in this, and a lesson, and a reminder for the believers.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mdxciv{%
And say to those who do not believe, “Act according to your ability; and so will we.”\qt@no{121}}%
\qt@newcmd\qurantrans@en@mdxcv{%
“And wait; we too are waiting.”\qt@no{122}}%
\qt@newcmd\qurantrans@en@mdxcvi{%
To God belongs the future of the heavens and the earth, and to Him all authority goes back. So worship Him, and rely on Him. Your Lord is never unaware of what you do.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mdxcvii{%
\basmalahen Alif, Lam, Ra. These are the Verses of the Clear Book.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdxcviii{%
We have revealed it an Arabic Quran, so that you may understand.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdxcix{%
We narrate to you the most accurate history, by revealing to you this Quran. Although, prior to it, you were of the unaware.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdc{%
When Joseph said to his father, “O my father, I saw eleven planets, and the sun, and the moon; I saw them bowing down to me.”\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdci{%
He said, “O my son, do not relate your vision to your brothers, lest they plot and scheme against you. Satan is man's sworn enemy.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcii{%
And thus your Lord will choose you, and will teach you the interpretation of events, and will complete His blessing upon you and upon the family of Jacob, as He has completed it before upon your forefathers Abraham and Isaac. Your Lord is Knowing and Wise.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdciii{%
In Joseph and his brothers are lessons for the seekers.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdciv{%
When they said, “Joseph and his brother are dearer to our father than we are, although we are a whole group. Our father is obviously in the wrong.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcv{%
“Kill Joseph, or throw him somewhere in the land, and your father‘s attention will be yours. Afterwards, you will be decent people.”\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcvi{%
One of them said, “Do not kill Joseph, but throw him into the bottom of the well; some caravan may pick him up—if you must do something.”\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcvii{%
They said, “Father, why do you not trust us with Joseph, although we care for him?”\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcviii{%
“Send him with us tomorrow, that he may roam and play; we will take care of him.”\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcix{%
He said, “It worries me that you would take him away. And I fear the wolf may eat him while you are careless of him.”\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcx{%
They said, “If the wolf ate him, and we are many, we would be good for nothing.”\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcxi{%
So they went away with him, and agreed to put him at the bottom of the well. And We inspired him, “You will inform them of this deed of theirs when they are unaware.”\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcxii{%
And they came to their father in the evening weeping.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcxiii{%
They said, “O father, we went off racing one another, and left Joseph by our belongings; and the wolf ate him. But you will not believe us, even though we are being truthful.”\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcxiv{%
And they brought his shirt, with fake blood on it. He said, “Your souls enticed you to do something. But patience is beautiful, and God is my Help against what you describe.”\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcxv{%
A caravan passed by, and they sent their water-carrier. He lowered his bucket, and said, “Good news. Here is a boy.” And they hid him as merchandise. But God was aware of what they did.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcxvi{%
And they sold him for a cheap price—a few coins—they considered him to be of little value.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcxvii{%
The Egyptian who bought him said to his wife, “Take good care of him; he may be useful to us, or we may adopt him as a son.” We thus established Joseph in the land, to teach him the interpretation of events. God has control over His affairs, but most people do not know.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcxviii{%
When he reached his maturity, We gave him wisdom and knowledge. We thus reward the righteous.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcxix{%
She in whose house he was living tried to seduce him. She shut the doors, and said, “I am yours.” He said, “God forbid! He is my Lord. He has given me a good home. Sinners never succeed.”\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcxx{%
She desired him, and he desired her, had he not seen the proof of his Lord. It was thus that We diverted evil and indecency away from him. He was one of Our loyal servants.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcxxi{%
As they raced towards the door, she tore his shirt from behind. At the door, they ran into her husband. She said, “What is the penalty for him who desired to dishonor your wife, except imprisonment or a painful punishment?”\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcxxii{%
He said, “It was she who tried to seduce me.” A witness from her household suggested: “If his shirt is torn from the front: then she has told the truth, and he is the liar.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcxxiii{%
But if his shirt is torn from the back: then she has lied, and he is the truthful.”\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcxxiv{%
And when he saw that his shirt was torn from the back, he said, “This is a woman's scheme. Your scheming is serious indeed.”\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcxxv{%
“Joseph, turn away from this. And you, woman, ask forgiveness for your sin; you are indeed in the wrong.”\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcxxvi{%
Some ladies in the city said, “The governor's wife is trying to seduce her servant. She is deeply in love with him. We see she has gone astray.”\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcxxvii{%
And when she heard of their gossip, she invited them, and prepared for them a banquet, and she gave each one of them a knife. She said, “Come out before them.” And when they saw him, they marveled at him, and cut their hands. They said, “Good God, this is not a human, this must be a precious angel.”\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcxxviii{%
She said, “Here he is, the one you blamed me for. I did try to seduce him, but he resisted. But if he does not do what I tell him to do, he will be imprisoned, and will be one of the despised.”\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcxxix{%
He said, “My Lord, prison is more desirable to me than what they call me to. Unless You turn their scheming away from me, I may yield to them, and become one of the ignorant.”\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcxxx{%
Thereupon his Lord answered him, and diverted their scheming away from him. He is the Hearer, the Knower.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcxxxi{%
Then it occurred to them, after they had seen the signs, to imprison him for a while.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcxxxii{%
Two youth entered the prison with him. One of them said, “I see myself pressing wine.” The other said, “I see myself carrying bread on my head, from which the birds are eating. Tell us their interpretation—we see that you are one of the righteous.”\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcxxxiii{%
He said, “No food is served to you, but I have informed you about it before you have received it. That is some of what my Lord has taught me. I have forsaken the tradition of people who do not believe in God; and regarding the Hereafter, they are deniers.”\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcxxxiv{%
“And I have followed the faith of my forefathers, Abraham, and Isaac, and Jacob. It is not for us to associate anything with God. This is by virtue of God’s grace upon us and upon the people, but most people do not give thanks.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcxxxv{%
“O My fellow inmates, are diverse lords better, or God, the One, the Supreme?”\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdcxxxvi{%
“You do not worship, besides Him, except names you have named, you and your ancestors, for which God has sent down no authority. Judgment belongs to none but God. He has commanded that you worship none but Him. This is the right religion, but most people do not know.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdcxxxvii{%
“O my fellow inmates! One of you will serve his master wine; while the other will be crucified, and the birds will eat from his head. Thus the matter you are inquiring about is settled.”\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdcxxxviii{%
And he said to the one he thought would be released, “Mention me to your master.” But Satan caused him to forget mentioning him to his master, so he remained in prison for several years.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdcxxxix{%
The king said, “I see seven fat cows being eaten by seven lean ones, and seven green spikes, and others dried up. O elders, explain to me my vision, if you are able to interpret visions.”\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdcxl{%
They said, “Jumbles of dreams, and we know nothing of the interpretation of dreams.”\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdcxli{%
The one who was released said, having remembered after a time, “I will inform you of its interpretation, so send me out.”\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdcxlii{%
“Joseph, O man of truth, inform us concerning seven fat cows being eaten by seven lean ones, and seven green spikes, and others dried up, so that I may return to the people, so that they may know.”\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdcxliii{%
He said, “You will farm for seven consecutive years. But whatever you harvest, leave it in its spikes, except for the little that you eat.”\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdcxliv{%
Then after that will come seven difficult ones, which will consume what you have stored for them, except for the little that you have preserved.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdcxlv{%
Then after that will come a year that brings relief to the people, and during which they will press.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdcxlvi{%
The king said, “Bring him to me.” And when the envoy came to him, he said, “Go back to your master, and ask him about the intentions of the women who cut their hands; my Lord is well aware of their schemes.”\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdcxlvii{%
He said, “What was the matter with you, women, when you tried to seduce Joseph?” They said, “God forbid! We knew of no evil committed by him.” The governor’s wife then said, “Now the truth is out. It was I who tried to seduce him, and he is telling the truth.”\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcxlviii{%
“This is that he may know that I did not betray him in secret, and that God does not guide the scheming of the betrayers.”\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdcxlix{%
“Yet I do not claim to be innocent. The soul commands evil, except those on whom my Lord has mercy. Truly my Lord is Forgiving and Merciful.”\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdcl{%
The king said, “Bring him to me, and I will reserve him for myself.” And when he spoke to him, he said, “This day you are with us established and secure.”\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdcli{%
He said, “Put me in charge of the storehouses of the land; I am honest and knowledgeable.”\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdclii{%
And thus We established Joseph in the land, to live therein wherever he wished. We touch with Our mercy whomever We will, and We never waste the reward of the righteous.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdcliii{%
But the reward of the Hereafter is better for those who believe and observed piety.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdcliv{%
And Joseph's brothers came, and entered into his presence. He recognized them, but they did not recognize him.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdclv{%
When he provided them with their provisions, he said, “Bring me a brother of yours from your father. Do you not see that I fill up the measure, and I am the best of hosts?”\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdclvi{%
“But if you do not bring him to me, you will have no measure from me, and you will not come near me.”\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdclvii{%
They said, “We will solicit him from his father. We will surely do.”\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdclviii{%
He said to his servants, “Put their goods in their saddlebags; perhaps they will recognize them when they return to their families, and maybe they will come back.”\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdclix{%
When they returned to their father, they said, “O father, we were denied measure, but send our brother with us, and we will obtain measure. We will take care of him.”\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdclx{%
He said, “Shall I trust you with him, as I trusted you with his brother before? God is the Best Guardian, and He is the Most Merciful of the merciful.”\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdclxi{%
And when they opened their baggage, they found that their goods were returned to them. They said, “Father, what more do we want? Here are our goods, returned to us. We will provide for our family, and protect our brother, and have an additional camel-load. This is easy commerce.”\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdclxii{%
He said, “I will not send him with you, unless you give me a pledge before God that you will bring him back to me, unless you get trapped.” And when they gave him their pledge, he said, “God is witness to what we say.”\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdclxiii{%
And he said, “O my sons, do not enter by one gate, but enter by different gates. I cannot avail you anything against God. The decision rests only with God. On Him I rely, and on Him let the reliant rely.”\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdclxiv{%
And when they entered as their father had instructed them, it did not avail them anything against God; it was just a need in the soul of Jacob, which he carried out. He was a person of knowledge inasmuch as We had taught him, but most people do not know.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdclxv{%
And when they entered into the presence of Joseph, he embraced his brother, and said, “I am your brother; do not be saddened by what they used to do.”\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdclxvi{%
Then, when he provided them with their provisions, he placed the drinking-cup in his brother’s saddlebag. Then an announcer called out, “O people of the caravan, you are thieves.”\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdclxvii{%
They said, as they came towards them, “What are you missing?”\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdclxviii{%
They said, “We are missing the king’s goblet. Whoever brings it will have a camel-load; and I personally guarantee it.”\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdclxix{%
They said, “By God, you know we did not come to cause trouble in the land, and we are not thieves.”\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdclxx{%
They said, “What shall be his punishment, if you are lying?”\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdclxxi{%
They said, “His punishment, if it is found in his bag: he will belong to you. Thus we penalize the guilty.”\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdclxxii{%
So he began with their bags, before his brother's bag. Then he pulled it out of his brother’s bag. Thus We devised a plan for Joseph; he could not have detained his brother under the king’s law, unless God so willed. We elevate by degrees whomever We will; and above every person of knowledge, there is one more learned.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdclxxiii{%
They said, “If he has stolen, a brother of his has stolen before.” But Joseph kept it to himself, and did not reveal it to them. He said, “You are in a worse situation, and God is Aware of what you allege.”\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdclxxiv{%
They said, “O noble prince, he has a father, a very old man, so take one of us in his place. We see that you are a good person.”\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdclxxv{%
He said, “God forbid that we should arrest anyone except him in whose possession we found our property; for then we would be unjust.”\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdclxxvi{%
And when they despaired of him, they conferred privately. Their eldest said, “Don’t you know that your father received a pledge from you before God, and in the past you failed with regard to Joseph? I will not leave this land until my father permits me, or God decides for me; for He is the Best of Deciders.”\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdclxxvii{%
“Go back to your father, and say, ‘Our father, your son has stolen. We testify only to what we know, and we could not have prevented the unforeseen.’”\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdclxxviii{%
“Ask the town where we were, and the caravan in which we came. We are being truthful.”\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdclxxix{%
He said, “Rather, your souls have contrived something for you. Patience is a virtue. Perhaps God will bring them all back to me. He is the Knowing, the Wise.”\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdclxxx{%
Then he turned away from them, and said, “O my bitterness for Joseph.” And his eyes turned white from sorrow, and he became depressed.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdclxxxi{%
They said, “By God, you will not stop remembering Joseph, until you have ruined your health, or you have passed away.”\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdclxxxii{%
He said, “I only complain of my grief and sorrow to God, and I know from God what you do not know.”\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdclxxxiii{%
“O my sons, go and inquire about Joseph and his brother, and do not despair of God's comfort. None despairs of God's comfort except the disbelieving people.”\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdclxxxiv{%
Then, when they entered into his presence, they said, “Mighty governor, adversity has befallen us, and our family. We have brought scant merchandise. But give us full measure, and be charitable towards us—God rewards the charitable.”\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdclxxxv{%
He said, “Do you realize what you did with Joseph and his brother, in your ignorance?”\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdclxxxvi{%
They said, “Is that you, Joseph?” He said, “I am Joseph, and this is my brother. God has been gracious to us. He who practices piety and patience—God never fails to reward the righteous.”\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdclxxxvii{%
They said, “By God, God has preferred you over us. We were definitely in the wrong.”\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdclxxxviii{%
He said, “There is no blame upon you today. God will forgive you. He is the Most Merciful of the merciful.”\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdclxxxix{%
“Take this shirt of mine, and lay it over my father’s face, and he will recover his sight. And bring your whole family to me.”\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdcxc{%
As the caravan set out, their father said, “I sense the presence of Joseph, though you may think I am senile.”\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdcxci{%
They said, “By God, you are still in your old confusion.”\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdcxcii{%
Then, when the bearer of good news arrived, he laid it over his face, and he regained his sight. He said, “Did I not say to you that I know from God what you do not know?”\qt@no{96}}%
\qt@newcmd\qurantrans@en@mdcxciii{%
They said, “Father, pray for the forgiveness of our sins; we were indeed at fault.”\qt@no{97}}%
\qt@newcmd\qurantrans@en@mdcxciv{%
He said, “I will ask my Lord to forgive you. He is the Forgiver, the Most Merciful.”\qt@no{98}}%
\qt@newcmd\qurantrans@en@mdcxcv{%
Then, when they entered into the presence of Joseph, he embraced his parents, and said, “Enter Egypt, God willing, safe and secure.”\qt@no{99}}%
\qt@newcmd\qurantrans@en@mdcxcvi{%
And he elevated his parents on the throne, and they fell prostrate before him. He said, “Father, this is the fulfillment of my vision of long ago. My Lord has made it come true. He has blessed me, when he released me from prison, and brought you out of the wilderness, after the devil had sown conflict between me and my brothers. My Lord is Most Kind towards whomever He wills. He is the All-knowing, the Most Wise.”\qt@no{100}}%
\qt@newcmd\qurantrans@en@mdcxcvii{%
“My Lord, You have given me some authority, and taught me some interpretation of events. Initiator of the heavens and the earth; You are my Protector in this life and in the Hereafter. Receive my soul in submission, and unite me with the righteous.”\qt@no{101}}%
\qt@newcmd\qurantrans@en@mdcxcviii{%
This is news from the past that We reveal to you. You were not present with them when they plotted and agreed on a plan.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mdcxcix{%
But most people, for all your eagerness, are not believers.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mdcc{%
You ask them no wage for it. It is only a reminder for all mankind.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mdcci{%
How many a sign in the heavens and the earth do they pass by, paying no attention to them?\qt@no{105}}%
\qt@newcmd\qurantrans@en@mdccii{%
And most of them do not believe in God unless they associate others.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mdcciii{%
Do they feel secure that a covering of God’s punishment will not come upon them, or that the Hour will not come upon them suddenly, while they are unaware?\qt@no{107}}%
\qt@newcmd\qurantrans@en@mdcciv{%
Say, “This is my way; I invite to God, based on clear knowledge—I and whoever follows me. Glory be to God; and I am not of the polytheists.”\qt@no{108}}%
\qt@newcmd\qurantrans@en@mdccv{%
We did not send before you except men, whom We inspired, from the people of the towns. Have they not roamed the earth and seen the consequences for those before them? The Home of the Hereafter is better for those who are righteous. Do you not understand?\qt@no{109}}%
\qt@newcmd\qurantrans@en@mdccvi{%
Until, when the messengers have despaired, and thought that they were rejected, Our help came to them. We save whomever We will, and Our severity is not averted from the guilty people.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mdccvii{%
In their stories is a lesson for those who possess intelligence. This is not a fabricated tale, but a confirmation of what came before it, and a detailed explanation of all things, and guidance, and mercy for people who believe.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mdccviii{%
\basmalahen Alif, Lam, Meem, Ra. These are the signs of the Scripture. What is revealed to you from your Lord is the truth, but most people do not believe.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdccix{%
God is He who raised the heavens without pillars that you can see, and then settled on the Throne. And He regulated the sun and the moon, each running for a specified period. He manages all affairs, and He explains the signs, that you may be certain of the meeting with your Lord.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdccx{%
And it is He who spread the earth, and placed in it mountains and rivers. And He placed in it two kinds of every fruit. He causes the night to overlap the day. In that are signs for people who reflect.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdccxi{%
On earth are adjacent terrains, and gardens of vines, and crops, and date-palms, from the same root or from distinct roots, irrigated with the same water. We make some taste better than others. In that are proofs for people who reason.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdccxii{%
Should you wonder—the real wonder is their saying: “When we have become dust, will we be in a new creation?” Those are they who defied their Lord. Those are they who will have yokes around their necks. Those are the inhabitants of the Fire, where they will remain forever.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdccxiii{%
And they urge you to hasten evil before good, though examples have passed away before them. Your Lord is full of forgiveness towards the people for their wrongdoings, yet your Lord is severe in retribution.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdccxiv{%
Those who disbelieve say, “Why was a miracle not sent down to him from his Lord?” You are only a warner, and to every community is a guide.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdccxv{%
God knows what every female bears, and every increase and decrease of the wombs. With Him, everything is by measure.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdccxvi{%
The Knower of the Invisible and the Visible; the Grand, the Supreme.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdccxvii{%
It is the same; whether one of you conceals his speech, or declares it; whether he goes into hiding by night, or goes out by day.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdccxviii{%
He has a succession; before him and behind him, protecting him by God’s command. God does not change the condition of a people until they change what is within themselves. And if God wills any hardship for a people, there is no turning it back;, and apart from Him they have no protector.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdccxix{%
It is He who shows you the lightening, causing fear and hope. And He produces the heavy clouds.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdccxx{%
The thunder praises His glory, and so do the angels, in awe of Him. And He sends the thunderbolts, striking with them whomever He wills. Yet they argue about God, while He is Tremendous in might.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdccxxi{%
To Him belongs the call to truth. Those they call upon besides Him do not respond to them with anything—except as someone who stretches his hands towards water, so that it may reach his mouth, but it does not reach it. The prayers of the unbelievers are only in vain.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdccxxii{%
To God prostrates everyone in the heavens and the earth, willingly or unwillingly, as do their shadows, in the morning and in the evening.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdccxxiii{%
Say, “Who is the Lord of the heavens and the earth?” Say, “God.” Say, “Have you taken besides Him protectors, who have no power to profit or harm even themselves?” Say, “Are the blind and the seeing equal? Or are darkness and light equal? Or have they assigned to God associates, who created the likes of His creation, so that the creations seemed to them alike? Say, “God is the Creator of all things, and He is The One, the Irresistible.”\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdccxxiv{%
He sends down water from the sky, and riverbeds flow according to their capacity. The current carries swelling froth. And from what they heat in fire of ornaments or utensils comes a similar froth. Thus God exemplifies truth and falsehood. As for the froth, it is swept away, but what benefits the people remains in the ground. Thus God presents the analogies.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdccxxv{%
For those who respond to their Lord is the best. But as for those who do not respond to Him, even if they possessed everything on earth, and twice as much, they could not redeem themselves with it. Those will have the worst reckoning; and their home is Hell—a miserable destination.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdccxxvi{%
Is he who knows that what was revealed to your from your Lord is the truth, like him who is blind? Only those who reason will remember.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdccxxvii{%
Those who fulfill the promise to God, and do not violate the agreement.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdccxxviii{%
And those who join what God has commanded to be joined, and fear their Lord, and dread the dire reckoning.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdccxxix{%
And those who patiently seek the presence of their Lord, and pray regularly, and spend from Our provisions to them, secretly and openly, and repel evil with good. These will have the Ultimate Home.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdccxxx{%
Everlasting Gardens, which they will enter, along with the righteous among their parents, and their spouses, and their descendants. And the angels will enter upon them from every gate.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdccxxxi{%
“Peace be upon you, because you endured patiently. How excellent is the Final Home.”\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdccxxxii{%
As for those who violate the promise to God, after pledging to keep it, and sever what God has commanded to be joined, and spread corruption on earth—these, the curse will be upon them, and they will have the Worst Home.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdccxxxiii{%
God dispenses the provisions to whomever He wills, and restricts. And they delight in the worldly life; yet the worldly life, compared to the Hereafter, is only enjoyment.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdccxxxiv{%
Those who disbelieve say, “If only a miracle was sent down to him from his Lord.” Say, “God leads astray whomever He wills, and He guides to Himself whoever repents.”\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdccxxxv{%
Those who believe, and whose hearts find comfort in the remembrance of God. Surely, it is in the remembrance of God that hearts find comfort.”\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdccxxxvi{%
For those who believe and do righteous deeds—for them is happiness and a beautiful return.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdccxxxvii{%
Thus We sent you among a community before which other communities have passed away, that you may recite to them what We revealed to you. Yet they deny the Benevolent One. Say, “He is my Lord; there is no god but He; in Him I trust, and to Him is my repentance.”\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdccxxxviii{%
Even if there were a Quran, by which mountains could be set in motion, or by which the earth could be shattered, or by which the dead could be made to speak. In fact, every decision rests with God. Did the believers not give up and realize that had God willed, He would have guided all humanity? Disasters will continue to strike those who disbelieve, because of their deeds, or they fall near their homes, until God’s promise comes true. God never breaks a promise.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdccxxxix{%
Messengers before you were ridiculed, but I granted the disbelievers respite, and then I seized them. What a punishment it was!\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdccxl{%
Is He who is watchful over the deeds of every soul? Yet they ascribe associates to God. Say, “Name them! Or are you informing Him of something on earth He does not know, or is it a show of words?” In fact, the scheming of those who disbelieve is made to appear good to them, and they are averted from the path. Whomever God misguides has no guide.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdccxli{%
There is for them torment in the worldly life, but the torment of the Hereafter is harsher. And they have no defender against God.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdccxlii{%
The likeness of the Garden promised to the righteous: rivers flowing beneath it; its food is perpetual, and so is its shade. Such is the sequel for those who guard against evil, but the sequel of the disbelievers is the Fire.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdccxliii{%
Those to whom We gave the Scripture rejoice in what was revealed to you, while some factions reject parts of it. Say, “I am commanded to worship God, and to never associate anything with Him. To Him I invite, and to Him is my return.”\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdccxliv{%
Thus We revealed it an Arabic code of law. Were you to follow their desires, after the knowledge that has come to you, you would have neither ally nor defender against God.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdccxlv{%
We sent messengers before you, and We assigned for them wives and offspring. No messenger could bring a sign except with the permission of God. For every era is a scripture.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdccxlvi{%
God abolishes whatever He wills, and He affirms. With Him is the source of the Scripture.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdccxlvii{%
Whether We show you some of what We have promised them, or We cause you to die—your duty is to inform, and Ours is the reckoning.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdccxlviii{%
Do they not see how We deal with the earth, diminishing it at its edges? God judges; and nothing can hold back His judgment. And He is quick to settle accounts.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdccxlix{%
Those before them planned, but the entire plan is up to God. He knows what every soul earns. Those who disbelieve will know to whom the Ultimate Home is.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdccl{%
Those who disbelieve say, “You are not a messenger.” Say, “God is a sufficient witness between me and you, and whoever has knowledge of the Scripture.”\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdccli{%
\basmalahen Alif, Lam, Ra. A Scripture that We revealed to you, that you may bring humanity from darkness to light—with the permission of their Lord—to the path of the Almighty, the Praiseworthy.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdcclii{%
God—to whom belongs what is in the heavens and the earth. And woe to the disbelievers from a severe torment.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdccliii{%
Those who prefer the present life to the Hereafter, and repel from the path of God, and seek to make it crooked—these are far astray.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdccliv{%
We never sent any messenger except in the language of his people, to make things clear for them. God leads astray whom He wills, and guides whom He wills. He is the Mighty, the Wise.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdcclv{%
We sent Moses with Our signs: “Bring your people out of darkness into light, and remind them of the Days of God.” In that are signs for every patient and thankful person.”\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcclvi{%
Moses said to his people, “Remember God’s blessings upon you, as He delivered you from the people of Pharaoh, who inflicted on you terrible suffering, slaughtering your sons while sparing your daughters. In that was a serious trial from your Lord.”\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdcclvii{%
And when your Lord proclaimed: “If you give thanks, I will grant you increase; but if you are ungrateful, My punishment is severe.”\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdcclviii{%
And Moses said, “Even if you are ungrateful, together with everyone on earth—God is in no need, Worthy of Praise.”\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcclix{%
Has not the story reached you, of those before you, the people of Noah, and Aad, and Thamood—and those after them? None knows them except God. Their messengers came to them with the clear proofs, but they tried to silence them, and said, “We reject what you are sent with, and we are in serious doubt regarding what you are calling us to.”\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcclx{%
Their messengers said, “Is there any doubt about God, Maker of the heavens and the earth? He calls you to forgive you your sins, and to defer you until a stated term.” They said, “You are only humans like us; you want to turn us away from what our ancestors worshiped; so bring us a clear proof.”\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcclxi{%
Their messengers said to them, “We are only humans like you, but God favors whomever He wills from among His servants. We cannot possibly show you any proof, except by leave of God. In God let the faithful put their trust.”\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcclxii{%
“And why should we not trust in God, when He has guided us in our ways? We will persevere in the face of your persecution. And upon God the reliant should rely.”\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcclxiii{%
Those who disbelieved said to their messengers, “We will expel you from our land, unless you return to our religion.” And their Lord inspired them: “We will destroy the wrongdoers.”\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcclxiv{%
“And We will settle you in the land after them. That is for him who fears My Majesty, and fears My threats.”\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcclxv{%
And they prayed for victory, and every stubborn tyrant came to disappointment.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcclxvi{%
Beyond him lies Hell, and he will be given to drink putrid water.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcclxvii{%
He will guzzle it, but he will not swallow it. Death will come at him from every direction, but he will not die. And beyond this is relentless suffering.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcclxviii{%
The likeness of those who disbelieve in their Lord: their works are like ashes, in a fierce wind, on a stormy day. They have no control over anything they have earned. That is the utmost misguidance.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcclxix{%
Do you not see that God created the heavens and the earth with truth? If He wills, He can do away with you, and bring a new creation.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcclxx{%
And that is not difficult for God.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcclxxi{%
They will emerge before God, altogether. The weak will say to those who were proud, “We were your followers, can you protect us at all against God’s punishment?” They will say, “Had God guided us, we would have guided you. It is the same for us; whether we mourn, or are patient; there is no asylum for us.”\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcclxxii{%
And Satan will say, when the issue is settled, “God has promised you the promise of truth, and I promised you, but I failed you. I had no authority over you, except that I called you, and you answered me. So do not blame me, but blame yourselves. I cannot come to your aid, nor can you come to my aid. I reject your associating with me in the past. The wrongdoers will have a torment most painful.”\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcclxxiii{%
But those who believed and did good deeds will be admitted into gardens beneath which rivers flow, to remain therein forever, by leave of their Lord. Their greeting therein will be: “Peace.”\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcclxxiv{%
Do you not see how God presents a parable? A good word is like a good tree—its root is firm, and its branches are in the sky.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcclxxv{%
It yields its fruits every season by the will of its Lord. God presents the parables to the people, so that they may reflect.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcclxxvi{%
And the parable of a bad word is that of a bad tree—it is uprooted from the ground; it has no stability.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcclxxvii{%
God gives firmness to those who believe, with the firm word, in this life, and in the Hereafter. And God leads the wicked astray. God does whatever He wills.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcclxxviii{%
Have you not seen those who exchanged the blessing of God with blasphemy, and landed their people into the house of perdition?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcclxxix{%
Hell—they will roast in it. What a miserable settlement.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcclxxx{%
And they set up rivals to God, in order to lead away from His path. Say, “Enjoy yourselves; your destination is the Fire.”\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcclxxxi{%
Tell My servants who have believed to perform the prayers, and to give from what We have given them, secretly and publicly, before a Day comes in which there is neither trading nor friendship.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcclxxxii{%
God is He Who created the heavens and the earth, and sends down water from the sky, and with it produces fruits for your sustenance. And He committed the ships to your service, sailing through the sea by His command, and He committed the rivers to your service.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcclxxxiii{%
And He committed the sun and the moon to your service, both continuously pursuing their courses, and He committed the night and the day to your service.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcclxxxiv{%
And He has given you something of all what you asked. And if you were to count God’s blessings, you would not be able to enumerate them. The human being is unfair and ungrateful.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcclxxxv{%
Recall that Abraham said, “O my Lord, make this land peaceful, and keep me and my sons from worshiping idols.”\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcclxxxvi{%
“My Lord, they have led many people astray. Whoever follows me belongs with me; and whoever disobeys me—You are Forgiving and Merciful.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcclxxxvii{%
“Our Lord, I have settled some of my offspring in a valley of no vegetation, by Your Sacred House, our Lord, so that they may perform the prayers. So make the hearts of some people incline towards them, and provide them with fruits, that they may be thankful.”\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcclxxxviii{%
“Our Lord, You know what we conceal and what we reveal. And nothing is hidden from God, on earth or in the heaven.”\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcclxxxix{%
“Praise be to God, Who has given me, in my old age, Ishmael and Isaac. My Lord is the Hearer of Prayers.”\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdccxc{%
“My Lord, make me one who performs the prayer, and from my offspring. Our Lord, accept my supplication.”\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdccxci{%
“Our Lord, forgive me, and my parents, and the believers, on the Day the Reckoning takes place.”\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdccxcii{%
Do not ever think that God is unaware of what the wrongdoers do. He only defers them until a Day when the sights stare.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdccxciii{%
Their necks outstretched, their heads upraised, their gaze unblinking, their hearts void.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdccxciv{%
And warn mankind of the Day when the punishment will come upon them, and the wicked will say, “Our Lord, defer us for a little while, and we will answer Your call and follow the messengers.” Did you not swear before that there will be no passing away for you?\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdccxcv{%
And you inhabited the homes of those who wronged themselves, and it became clear to you how We dealt with them, and We cited for you the examples.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdccxcvi{%
They planned their plans, but their plans are known to God, even if their plans can eliminate mountains.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdccxcvii{%
Do not ever think that God will break His promise to His messengers. God is Strong, Able to Avenge.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdccxcviii{%
On the Day when the earth is changed into another earth, and the heavens, and they will emerge before God, the One, the Irresistible.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdccxcix{%
On that Day, you will see the sinners bound together in chains.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdccc{%
Their garments made of tar, and the Fire covering their faces.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdccci{%
That God may repay each soul according to what it has earned. God is Quick in reckoning.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcccii{%
This is a proclamation for mankind, that they may be warned thereby, and know that He is One God, and that people of understanding may remember.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdccciii{%
\basmalahen Alif, Lam, Ra. These are the Verses of the Book; a Quran that makes things clear.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdccciv{%
Perhaps those who disbelieve would like to become Muslims.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdcccv{%
Leave them to eat, and enjoy, and be lulled by hope. They will find out.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdcccvi{%
We have never destroyed a town unless it had a set time.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdcccvii{%
No nation can bring its time forward, nor can they delay it.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcccviii{%
And they said, “O you who received the message, you are insane.”\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdcccix{%
Why do you not bring us the angels, if you are truthful?”\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdcccx{%
We do not send the angels down except with reason, and they will not be held back.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcccxi{%
Surely We revealed the Message, and We will surely preserve it.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcccxii{%
We sent others before you, to the former communities.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcccxiii{%
But no messenger came to them, but they ridiculed him.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcccxiv{%
Thus We slip it into the hearts of the guilty.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcccxv{%
They do not believe in it, though the ways of the ancients have passed away.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcccxvi{%
Even if We opened for them a gateway into the sky, and they began to ascend through it.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcccxvii{%
They would still say, “Our eyes are hallucinating; in fact, we are people bewitched.”\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcccxviii{%
We placed constellations in the sky, and made them beautiful to the beholders.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcccxix{%
And We guarded them from every outcast devil.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcccxx{%
Except one who steals a hearing, and is followed by a visible projectile.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcccxxi{%
We spread the earth, and placed stabilizers in it, and in it We grew all things in proper measure.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcccxxii{%
And in it We created livelihoods for you, and for those for whom you are not the providers.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcccxxiii{%
There is not a thing but with Us are its stores, and We send it down only in precise measure.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcccxxiv{%
We send the fertilizing winds; and send down water from the sky, and give it to you to drink, and you are not the ones who store it.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcccxxv{%
It is We who give life and cause death, and We are the Inheritors.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcccxxvi{%
And We know those of you who go forward, and We know those who lag behind.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcccxxvii{%
It is your Lord who will gather them together. He is the Wise, the Knowing.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcccxxviii{%
We created the human being from clay, from molded mud.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcccxxix{%
And the jinn We created before, from piercing fire.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcccxxx{%
Your Lord said to the angels, “I am creating a human being from clay, from molded mud.”\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcccxxxi{%
“When I have formed him, and breathed into him of My spirit, fall down prostrating before him.”\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcccxxxii{%
So the angels prostrated themselves, all together.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcccxxxiii{%
Except for Satan. He refused to be among those who prostrated themselves.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcccxxxiv{%
He said, “O Satan, what kept you from being among those who prostrated themselves?”\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcccxxxv{%
He said, “I am not about to prostrate myself before a human being, whom You created from clay, from molded mud.”\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcccxxxvi{%
He said, “Then get out of here, for you are an outcast”.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcccxxxvii{%
“And the curse will be upon you until the Day of Judgment.”\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcccxxxviii{%
He said, “My Lord, reprieve me until the Day they are resurrected.”\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcccxxxix{%
He said, “You are of those reprieved.”\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcccxl{%
“Until the Day of the time appointed.”\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcccxli{%
He said, “My Lord, since You have lured me away, I will glamorize for them on earth, and I will lure them all away.”\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdcccxlii{%
“Except for Your sincere servants among them.”\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdcccxliii{%
He said, “This is a right way with Me.”\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdcccxliv{%
“Over My servants you have no authority, except for the sinners who follow you.”\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdcccxlv{%
And Hell is the meeting-place for them all.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdcccxlvi{%
“It has seven doors; for each door is an assigned class.”\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdcccxlvii{%
But the righteous will be in gardens with springs.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdcccxlviii{%
“Enter it in peace and security.”\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdcccxlix{%
And We will remove all ill-feelings from their hearts—brothers and sisters, on couches facing one another.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdcccl{%
No fatigue will ever touch them therein, nor will they be asked to leave it.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdcccli{%
Inform My servants that I am the Forgiver, the Merciful.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdccclii{%
And that My punishment is the painful punishment.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdcccliii{%
And inform them of the guests of Abraham.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcccliv{%
When they entered upon him, and said, “Peace.” He said, “We are wary of you.”\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdccclv{%
They said, “Do not fear; we bring you good news of a boy endowed with knowledge.”\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdccclvi{%
He said, “Do you bring me good news, when old age has overtaken me? What good news do you bring?”\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdccclvii{%
They said, “We bring you good news in truth, so do not despair.”\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdccclviii{%
He said, “And who despairs of his Lord’s mercy but the lost?”\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdccclix{%
He said, “So what is your business, O envoys?”\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdccclx{%
They said, “We were sent to a sinful people.”\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdccclxi{%
“Except for the family of Lot; we will save them all.”\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdccclxii{%
“Except for his wife.” We have determined that she will be of those who lag behind.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdccclxiii{%
And when the envoys came to the family of Lot.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdccclxiv{%
He said, “You are a people unknown to me.”\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdccclxv{%
They said, “We bring you what they have doubts about.”\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdccclxvi{%
“We bring you the truth, and we are truthful.”\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdccclxvii{%
“Travel with your family at the dead of the night, and follow up behind them, and let none of you look back, and proceed as commanded.”\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdccclxviii{%
And We informed him of Our decree: the last remnant of these will be uprooted by early morning.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdccclxix{%
And the people of the town came joyfully.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdccclxx{%
He said, “These are my guests, so do not embarrass me.”\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdccclxxi{%
“And fear God, and do not disgrace me.”\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdccclxxii{%
They said, “Did we not forbid you from strangers?”\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdccclxxiii{%
He said, “These are my daughters, if you must.”\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdccclxxiv{%
By your life, they were blundering in their drunkenness.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdccclxxv{%
So the Blast struck them at sunrise.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdccclxxvi{%
And We turned it upside down, and rained down upon them stones of baked clay.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdccclxxvii{%
Surely in that are lessons for those who read signs.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdccclxxviii{%
And it is on an existing road.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdccclxxix{%
Surely in that is a sign for the believers.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdccclxxx{%
The people of the Woods were also wrongdoers.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdccclxxxi{%
So We took revenge upon them. Both are clearly documented.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdccclxxxii{%
The people of the Rock also rejected the messengers.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdccclxxxiii{%
We gave them Our revelations, but they turned away from them.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdccclxxxiv{%
They used to carve homes in the mountains, feeling secure.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdccclxxxv{%
But the Blast struck them in the morning.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdccclxxxvi{%
All they had acquired was of no avail to them.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdccclxxxvii{%
We did not create the heavens and the earth, and what lies between them, except with truth. The Hour is coming, so forgive with gracious forgiveness.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdccclxxxviii{%
Your Lord is the All-Knowing Creator.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdccclxxxix{%
We have given you seven of the pairs, and the Grand Quran.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdcccxc{%
Do not extend your eyes towards what We have bestowed on some couples of them to enjoy, and do not grieve over them, and lower your wing to the believers.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdcccxci{%
And say, “I am the clear warner.”\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdcccxcii{%
Just as We sent down to the separatists.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdcccxciii{%
Those who made the Quran obsolete.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdcccxciv{%
By your Lord, we will question them all.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdcccxcv{%
About what they used to do.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdcccxcvi{%
So proclaim openly what you are commanded, and turn away from the polytheists.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdcccxcvii{%
We are enough for you against the mockers.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdcccxcviii{%
Those who set up another god with God. They will come to know.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mdcccxcix{%
We are aware that your heart is strained by what they say.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcm{%
So glorify the praise of your Lord, and be among those who bow down.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcmi{%
And worship your Lord in order to attain certainty.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcmii{%
\basmalahen The command of God has come, so do not rush it. Glory be to Him; exalted above what they associate.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mcmiii{%
He sends down the angels with the Spirit by His command, upon whom He wills of His servants: “Give warning that there is no god but Me, and fear Me.”\qt@no{2}}%
\qt@newcmd\qurantrans@en@mcmiv{%
He created the heavens and the earth with justice. He is exalted above the associations they attribute.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mcmv{%
He created the human being from a drop of fluid, yet he becomes an open adversary.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mcmvi{%
And the livestock—He created them for you. In them are warmth and benefits for you, and of them you eat.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mcmvii{%
And there is beauty in them for you, when you bring them home, and when you drive them to pasture.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mcmviii{%
And they carry your loads to territory you could not have reached without great hardship. Your Lord is Clement and Merciful.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mcmix{%
And the horses, and the mules, and the donkeys—for you to ride, and for luxury. And He creates what you do not know.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mcmx{%
It is for God to point out the paths, but some of them are flawed. Had He willed, He could have guided you all.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mcmxi{%
It is He Who sends down for you from the sky water. From it is drink, and with it grows vegetation for grazing.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mcmxii{%
And He produces for you grains with it, and olives, and date-palms, and grapes, and all kinds of fruits. Surely in that is a sign for people who think.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mcmxiii{%
And He regulated for you the night and the day; and the sun, and the moon, and the stars are disposed by His command. Surely in that are signs for people who ponder.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mcmxiv{%
And whatsoever He created for you on earth is of diverse colors. Surely in that is a sign for people who are mindful.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mcmxv{%
And it is He who made the sea to serve you, that you may eat from it tender meat, and extract from it ornaments that you wear. And you see the ships plowing through it, as you seek His bounties, so that you may give thanks.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mcmxvi{%
And he cast mountains on the earth, lest it shifts with you; and rivers, and roads, so that you may be guided.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mcmxvii{%
And landmarks. And by the stars they guide themselves.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcmxviii{%
Is He who creates like him who does not create? Will you not take a lesson?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mcmxix{%
And if you tried to enumerate the favors of God, you will not be able to count them. God is Forgiving and Merciful.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mcmxx{%
And God knows what you hide and what you disclose.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcmxxi{%
Those they invoke besides God create nothing, but are themselves created.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcmxxii{%
They are dead, not alive; and they do not know when they will be resurrected.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcmxxiii{%
Your God is one God. As for those who do not believe in the Hereafter, their hearts are in denial, and they are arrogant.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcmxxiv{%
Without a doubt, God knows what they conceal and what they reveal. He does not like the arrogant.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcmxxv{%
And when it is said to them, “What has your Lord sent down?” They say, “Legends of the ancients.”\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcmxxvi{%
So let them carry their loads complete on the Day of Resurrection, and some of the loads of those they misguided without knowledge. Evil is what they carry.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcmxxvii{%
Those before them also schemed, but God took their structures from the foundations, and the roof caved in on them. The punishment came at them from where they did not perceive.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcmxxviii{%
Then, on the Day of Resurrection, He will disgrace them, and say, “Where are My associates for whose sake you used to dispute?” Those who were given knowledge will say, “Today shame and misery are upon the disbelievers.”\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcmxxix{%
Those wronging their souls while the angels are taking them away—they will propose peace: “We did no wrong.” Yes you did. God is aware of what you used to do.”\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcmxxx{%
Enter the gates of Hell, to dwell therein forever. Miserable is the residence of the arrogant.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcmxxxi{%
And it will be said to those who maintained piety, “What has your Lord revealed?” They will say, “Goodness.” To those who do good in this world is goodness, and the Home of the Hereafter is even better. How wonderful is the residence of the pious.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcmxxxii{%
The Gardens of Perpetuity, which they will enter, beneath which rivers flow, where they will have whatever they desire. Thus God rewards the pious.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcmxxxiii{%
Those who are in a wholesome state when the angels take them—will say, “Peace be upon you; enter Paradise, for what you used to do.”\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcmxxxiv{%
Are they but waiting for the angels to come to them, or for the command of your Lord to arrive? Those before them did likewise. God did not wrong them, but they used to wrong their own souls.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcmxxxv{%
So the evils of their deeds assailed them, and what they used to ridicule engulfed them.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcmxxxvi{%
The idolaters say, “Had God willed, we would not have worshiped anything besides Him, neither us, nor our ancestors, nor would we have prohibited anything besides His prohibitions.” Those before them did likewise. Are the messengers responsible for anything but clear communication?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcmxxxvii{%
To every community We sent a messenger: “Worship God, and avoid idolatry.” Some of them God guided, while others deserved misguidance. So travel through the earth, and see what the fate of the deniers was.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcmxxxviii{%
Even though you may be concerned about their guidance, God does not guide those who misguide. And they will have no saviors.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcmxxxix{%
And they swear by God with their most solemn oaths, “God will not resurrect anyone who dies.” Yes indeed, it is a promise binding on Him, but most people do not know.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcmxl{%
To clarify for them what they differed about, and for the faithless to know that they were liars.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcmxli{%
When We intend for something to happen, We say to it, “Be,” and it becomes.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcmxlii{%
Those who emigrate for God’s sake after being persecuted, We will settle them in a good place in this world; but the reward of the Hereafter is greater, if they only knew.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcmxliii{%
Those who endure patiently, and in their Lord they put their trust.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcmxliv{%
We did not send before you except men whom We inspired. So ask the people of knowledge, if you do not know.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcmxlv{%
With the clarifications and the scriptures. And We revealed to you the Reminder, that you may clarify to the people what was revealed to them, and that they may reflect.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcmxlvi{%
Do those who scheme evils feel secure that God will not cause the earth to cave in with them, or that the punishment will not come upon them from where they do not perceive?\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcmxlvii{%
Or that He will not seize them during their activities? And they will not be able to prevent it.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcmxlviii{%
Or that He will not seize them while in dread? Your Lord is Gentle and Merciful.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcmxlix{%
Have they not observed what God has created? Their shadows revolve from the right and the left, bowing to God as they shrink away.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcml{%
To God bows down everything in the heavens and everything on earth—every living creature, and the angels, and without being proud.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcmli{%
They fear their Lord above them, and they do what they are commanded.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcmlii{%
God has said: “Do not take two gods; He is only One God; so fear only Me.”\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcmliii{%
To Him belongs everything in the heavens and the earth; and to Him obedience is due always. Do you, then, fear anyone other than God?\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcmliv{%
Whatever blessing you have is from God. And when harm touches you, it is to Him that you groan.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcmlv{%
But when He lifts the harm from you, some of you associate others with their Lord.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mcmlvi{%
To show ingratitude for what We have given them. Enjoy yourselves. You will soon know.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mcmlvii{%
And they allocate, to something they do not know, a share of what We have provided for them. By God, you will be questioned about what you have been inventing.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mcmlviii{%
And they attribute to God daughters—exalted is He—and for themselves what they desire.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mcmlix{%
And when one of them is given news of a female infant, his face darkens, and he chokes with grief.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mcmlx{%
He hides from the people because of the bad news given to him. Shall he keep it in humiliation, or bury it in the dust? Evil is the decision they make.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mcmlxi{%
Those who do not believe in the Hereafter set a bad example, while God sets the Highest Example. He is the Mighty, the Wise.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mcmlxii{%
If God were to hold mankind for their injustices, He would not leave upon it a single creature, but He postpones them until an appointed time. Then, when their time arrives, they will not delay it by one hour, nor will they advance it.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mcmlxiii{%
And they attribute to God what they themselves dislike, while their tongues utter the lie that theirs is the goodness. Without a doubt, for them is the Fire, and they will be neglected.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mcmlxiv{%
By God, We sent messengers to communities before you, but Satan made their deeds appear alluring to them. He is their master today, and they will have a painful punishment.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mcmlxv{%
We revealed to you the Scripture only to clarify for them what they differ about, and guidance and mercy for people who believe.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mcmlxvi{%
God sends down water from the sky, with which He revives the earth after its death. In this is a sign for people who listen.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mcmlxvii{%
And there is a lesson for you in cattle: We give you a drink from their bellies, from between waste and blood, pure milk, refreshing to the drinkers.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcmlxviii{%
And from the fruits of date-palms and grapevines, you derive sugar and wholesome food. In this is a sign for people who understand.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mcmlxix{%
And your Lord inspired the bee: “Set up hives in the mountains, and in the trees, and in what they construct.”\qt@no{68}}%
\qt@newcmd\qurantrans@en@mcmlxx{%
Then eat of all the fruits, and go along the pathways of your Lord, with precision. From their bellies emerges a fluid of diverse colors, containing healing for the people. Surely in this is a sign for people who reflect.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcmlxxi{%
God created you; then He takes you away. Some of you will be brought back to the worst age, so that he will no longer know anything, after having acquired knowledge. God is Omniscient and Omnipotent.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcmlxxii{%
God has favored some of you over others in livelihood. Those who are favored would not give their properties to their servants, to the extent of making them partners in it. Will they then renounce God’s blessings?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcmlxxiii{%
God has given you mates from among yourselves; and has produced for you, from your mates, children and grandchildren; and has provided you with good things. Will they then believe in falsehood, and refuse God’s favors?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcmlxxiv{%
And yet they serve besides God what possesses no provisions for them in the heavens, nor on earth, nor are they capable.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcmlxxv{%
So do not cite the examples for God. God knows, and you do not know.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcmlxxvi{%
God cites the example of a bonded slave, who has no power over anything; and someone to whom We have given plentiful provision, from which he gives secretly and openly. Are they equal in comparison? All praise belongs to God, but most of them do not know.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcmlxxvii{%
And God cites the example of two men: one of them dumb, unable to do anything, and is a burden on his master; whichever way he directs him, he achieves nothing good. Is he equal to him who commands justice, and is on a straight path?\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcmlxxviii{%
To God belongs the unseen of the heavens and the earth. The coming of the Hour is only as the twinkling of the eye, or even nearer. God has power over everything.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcmlxxix{%
God brought you out of your mothers’ wombs, not knowing anything; and He gave you the hearing, and the eyesight, and the brains; that you may give thanks.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcmlxxx{%
Have they not seen the birds, flying in the midst of the sky? None sustains them except God. In this are signs for people who believe.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcmlxxxi{%
And God has given you in your homes habitats for you, and has provided for you out of the hides of livestock portable homes for you, so you can use them when you travel, and when you camp; and from their wool, and fur, and hair, furnishings and comfort for a while.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcmlxxxii{%
And God has made for you shade out of what He has created, and has given you resorts in the mountains, and has given you garments to protect you from the heat, and garments to protect you from your violence. Thus He completes His blessings upon you, so that you may submit.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcmlxxxiii{%
But if they turn away, your only duty is clear communication.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcmlxxxiv{%
They recognize God’s blessing, but then deny it, as most of them are ungrateful.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcmlxxxv{%
On the Day when We raise up a witness from every community—those who disbelieved will not be permitted, nor will they be excused.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcmlxxxvi{%
When those who did wrong see the punishment, it will not be lightened for them, nor will they be reprieved.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcmlxxxvii{%
And when the idolaters see their associates, they will say, “Our Lord, these are our associates whom we used to invoke besides You.” They will strike back at them with the saying, “Surely you are liars.”\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcmlxxxviii{%
On that Day they will offer their submission to God, and what they had invented will abandon them.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcmlxxxix{%
Those who disbelieve and obstruct from God’s path—We will add punishment to their punishment, on account of the mischief they used to make.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcmxc{%
On the Day when We raise in every community a witness against them, from among them, and bring you as a witness against these. We have revealed to you the Book, as an explanation of all things, and guidance, and mercy and good news for those who submit.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcmxci{%
God commands justice, and goodness, and generosity towards relatives. And He forbids immorality, and injustice, and oppression. He advises you, so that you may take heed.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcmxcii{%
Fulfill God’s covenant when you make a covenant, and do not break your oaths after ratifying them. You have made God your guarantor, and God knows what you do.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcmxciii{%
And do not be like her who unravels her yarn, breaking it into pieces, after she has spun it strongly. Nor use your oaths as means of deception among you, because one community is more prosperous than another. God is testing you thereby. On the Day of Resurrection, He will make clear to you everything you had disputed about.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcmxciv{%
Had God willed, He would have made you one congregation, but He leaves astray whom He wills, and He guides whom He wills. And you will surely be questioned about what you used to do.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcmxcv{%
And do not use your oaths to deceive one another, so that a foot may not slip after being firm, and you taste misery because you hindered from God’s path, and incur a terrible torment.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcmxcvi{%
And do not exchange God’s covenant for a small price. What is with God is better for you, if you only knew.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcmxcvii{%
What you have runs out, but what is with God remains. We will reward those who are patient according to the best of their deeds.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcmxcviii{%
Whoever works righteousness, whether male or female, while being a believer, We will grant him a good life—and We will reward them according to the best of what they used to do.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcmxcix{%
When you read the Quran, seek refuge with God from Satan the outcast.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mm{%
He has no authority over those who believe and trust in their Lord.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmi{%
His authority is only over those who follow him, and those who associate others with Him.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmii{%
When We substitute a verse in place of another verse—and God knows best what He reveals—they say, “You are an impostor.” But most of them do not know.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmiii{%
Say, “The Holy Spirit has brought it down from your Lord, truthfully, in order to stabilize those who believe, and as guidance and good news for those who submit.”\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmiv{%
We are well aware that they say, “It is a human being who is teaching him.” But the tongue of him they allude to is foreign, while this is a clear Arabic tongue.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmv{%
Those who do not believe in God’s revelations—God will not guide them, and for them is a painful punishment.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmvi{%
It is those who do not believe in God’s revelations who fabricate falsehood. These are the liars.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmvii{%
Whoever renounces faith in God after having believed—except for someone who is compelled, while his heart rests securely in faith—but whoever willingly opens up his heart to disbelief—upon them falls wrath from God, and for them is a tremendous torment.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmviii{%
That is because they have preferred the worldly life to the Hereafter, and because God does not guide the people who refuse.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmix{%
It is they whom God has sealed their hearts, and their hearing, and their sight. It is they who are the heedless.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmx{%
There is no doubt that in the Hereafter they will be the losers.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmxi{%
But then your Lord—for those who emigrated after being persecuted, then struggled and persevered—your Lord thereafter is Forgiving and Merciful.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmxii{%
On the Day when every soul will come pleading for itself, and every soul will be paid in full for what it has done, and they will not be wronged.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmxiii{%
And God cites the example of a town that was secure and peaceful, with its livelihood coming to it abundantly from every direction. But then it turned unappreciative of God’s blessings, so God made it taste the robe of hunger and fear, because of what they used to craft.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmxiv{%
A messenger from among them had come to them, but they denounced him, so the punishment seized them in the midst of their wrongdoing.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmxv{%
Eat of the lawful and good things God has provided for you, and be thankful for God’s blessings, if it is Him that you serve.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmxvi{%
He has forbidden you carrion, and blood, and the flesh of swine, and anything consecrated to other than God. But if anyone is compelled by necessity, without being deliberate or malicious, then God is Forgiving and Merciful.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmxvii{%
And do not say of falsehood asserted by your tongues, “This is lawful, and this is unlawful,” in order to invent lies and attribute them to God. Those who invent lies and attribute them to God will not succeed.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmxviii{%
A brief enjoyment—then they will have a painful punishment.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmxix{%
For those who are Jews, We have prohibited what We related to you before. We did not wrong them, but they used to wrong their own selves.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmxx{%
But towards those who do wrongs in ignorance, and then repent afterwards and reform, your Lord thereafter is Forgiving and Merciful.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmxxi{%
Abraham was an exemplary leader, devoted to God, a monotheist, and was not of the polytheists.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmxxii{%
Thankful for His blessings. He chose him, and guided him to a straight path.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmxxiii{%
And We gave him goodness in this world, and in the Hereafter he will be among the righteous.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmxxiv{%
Then We inspired you: “Follow the religion of Abraham, the Monotheist. He was not an idol-worshiper.”\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmxxv{%
The Sabbath was decreed only for those who differed about it. Your Lord will judge between them on the Day of Resurrection regarding their differences.\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmxxvi{%
Invite to the way of your Lord with wisdom and good advice, and debate with them in the most dignified manner. Your Lord is aware of those who stray from His path, and He is aware of those who are guided.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmxxvii{%
If you were to retaliate, retaliate to the same degree as the injury done to you. But if you resort to patience—it is better for the patient.\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmxxviii{%
So be patient. Your patience is solely from God. And do not grieve over them, and do not be stressed by their schemes.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmxxix{%
God is with those who are righteous and those who are virtuous.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmxxx{%
\basmalahen Glory to Him who journeyed His servant by night, from the Sacred Mosque, to the Farthest Mosque, whose precincts We have blessed, in order to show him of Our wonders. He is the Listener, the Beholder.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmxxxi{%
And We gave Moses the Scripture, and made it a guide for the Children of Israel: Take none for protector other than Me.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmxxxii{%
The descendants of those We carried with Noah. He was an appreciative servant.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmxxxiii{%
And We conveyed to the Children of Israel in the Scripture: You will commit evil on earth twice, and you will rise to a great height.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmxxxiv{%
When the first of the two promises came true, We sent against you servants of Ours, possessing great might, and they ransacked your homes. It was a promise fulfilled.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmxxxv{%
Then We gave you back your turn against them, and supplied you with wealth and children, and made you more numerous.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmxxxvi{%
If you work righteousness, you work righteousness for yourselves; and if you commit evil, you do so against yourselves. Then, when the second promise comes true, they will make your faces filled with sorrow, and enter the Temple as they entered it the first time, and utterly destroy all that falls into their power.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmxxxvii{%
Perhaps your Lord will have mercy on you. But if you revert, We will revert. We have made Hell a prison for the disbelievers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmxxxviii{%
This Quran guides to what is most upright; and it gives good news to the believers who do good deeds, that they will have a great reward.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmxxxix{%
And those who do not believe in the Hereafter—We have prepared for them a painful punishment.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmxl{%
The human being prays for evil as he prays for good. The human being is very hasty.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmxli{%
We have made the night and the day two wonders. We erased the wonder of the night, and made the wonder of the day revealing, that you may seek bounty from your Lord, and know the number of years, and the calculation. We have explained all things in detail.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmxlii{%
For every person We have attached his fate to his neck. And on the Day of Resurrection, We will bring out for him a book which he will find spread open.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmxliii{%
“Read your book; today there will be none but yourself to call you to account.”\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmxliv{%
Whoever is guided—is guided for his own good. And whoever goes astray—goes astray to his detriment. No burdened soul carries the burdens of another, nor do We ever punish until We have sent a messenger.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmxlv{%
When We decide to destroy a town, We command its affluent ones, they transgress in it, so the word becomes justified against it, and We destroy it completely.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmxlvi{%
How many generations have We destroyed after Noah? Your Lord is sufficient as Knower and Beholder of the sins of his servants.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmxlvii{%
Whoever desires the fleeting life, We expedite for him what We decide to give him, to whomever We desire. Then We consign him to Hell, where he will roast, condemned and defeated.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmxlviii{%
But whoever desires the Hereafter, and pursues it as it should be pursued, while he is a believer; these—their effort will be appreciated.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmxlix{%
To all—these and those—We extend from the gifts of your Lord. The gifts of your Lord are not restricted.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mml{%
See how We have favored some of them over others; yet the Hereafter is greater in ranks, and greater in favors.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmli{%
Do not set up another god with God, lest you become condemned and damned.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmlii{%
Your Lord has commanded that you worship none but Him, and that you be good to your parents. If either of them or both of them reach old age with you, do not say to them a word of disrespect, nor scold them, but say to them kind words.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmliii{%
And lower to them the wing of humility, out of mercy, and say, “My Lord, have mercy on them, as they raised me when I was a child.”\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmliv{%
Your Lord knows best what is in your minds. If you are righteous—He is Forgiving to the obedient.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmlv{%
And give the relative his rights, and the poor, and the wayfarer, and do not squander wastefully.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmlvi{%
The extravagant are brethren of the devils, and the devil is ever ungrateful to his Lord.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmlvii{%
But if you turn away from them, seeking mercy from your Lord which you hope for, then say to them words of comfort.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmlviii{%
And do not keep your hand tied to your neck, nor spread it out fully, lest you end up liable and regretful.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmlix{%
Your Lord expands the provision for whomever He wills, and restricts it. He is fully Informed, Observant of His servants.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmlx{%
And do not kill your children for fear of poverty. We provide for them, and for you. Killing them is a grave sin.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmlxi{%
And do not come near adultery. It is immoral, and an evil way.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmlxii{%
And do not kill the soul which God has made sacred, except in the course of justice. If someone is killed unjustly, We have given his next of kin certain authority. But he should not be excessive in killing, for he will be supported.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmlxiii{%
And do not go near the orphan’s property, except with the best of intentions, until he has reached his maturity. And honor your pledge, because the pledge involves responsibility.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmlxiv{%
And give full measure when you measure, and weigh with accurate scales. That is fair, and the best determination.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmlxv{%
And do not occupy yourself with what you have no knowledge of. The hearing, and the sight, and the brains—all these will be questioned.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmlxvi{%
And do not walk proudly on earth. You can neither pierce the earth, nor can you match the mountains in height.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmlxvii{%
The evil of all these is disliked by your Lord.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmlxviii{%
That is some of the wisdom your Lord has revealed to you. Do not set up with God another god, or else you will be thrown in Hell, rebuked and banished.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmlxix{%
Has your Lord favored you with sons, while choosing for Himself daughters from among the angels? You are indeed saying a terrible thing.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmlxx{%
We have explained in this Quran in various ways, that they may remember, but it only adds to their rebellion.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmlxxi{%
Say, “If there were other gods with Him, as they say, they would have sought a way to the Lord of the Throne.”\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmlxxii{%
Be He glorified. He is exalted, far above what they say.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmlxxiii{%
Praising Him are the seven heavens, and the earth, and everyone in them. There is not a thing that does not glorify Him with praise, but you do not understand their praises. He is indeed Forbearing and Forgiving.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmlxxiv{%
When you read the Quran, We place between you and those who do not believe in the Hereafter an invisible barrier.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmlxxv{%
And We drape veils over their hearts, preventing them from understanding it, and heaviness in their ears. And when you mention your Lord alone in the Quran, they turn their backs in aversion.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmlxxvi{%
We know well what they listen to, when they listen to you, as they conspire, when the wrongdoers say, “You only follow a man bewitched.”\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmlxxvii{%
Note what they compared you to. They are lost, and unable to find a way.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmlxxviii{%
And they say, “When we have become bones and fragments, shall we really be resurrected as a new creation?”\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmlxxix{%
Say, “Even if you become rocks or iron.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmlxxx{%
Or some substance, which, in your minds, is even harder.” Then they will say, “Who will restore us?” Say, “The One who originated you the first time.” Then they will nod their heads at you, and say, “When will it be?” Say, “Perhaps it will be soon.”\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmlxxxi{%
On the Day when He calls you, you will respond with His praise, and you will realize that you stayed only a little.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmlxxxii{%
Tell My servants to say what is best. Satan sows discord among them. Satan is to man an open enemy.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmlxxxiii{%
Your Lord knows you best. If He wills, He will have mercy on you; and if He wills, He will punish you. We did not send you as their advocate.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmlxxxiv{%
Your Lord knows well everyone in the heavens and the earth. We have given some prophets advantage over others; and to David We gave the Psalms.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmlxxxv{%
Say, “Call upon those you claim besides Him. They have no power to relieve your adversity, nor can they change it.”\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmlxxxvi{%
Those they call upon are themselves seeking means of access to their Lord, vying to be nearer, and hoping for His mercy, and fearing His punishment. The punishment of your Lord is to be dreaded.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmlxxxvii{%
There is no city but We will destroy before the Day of Resurrection, or punish it with a severe punishment. This is inscribed in the Book.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmlxxxviii{%
Nothing prevents Us from sending miraculous signs, except that the ancients called them lies. We gave Thamood the she-camel, a visible sign, but they mistreated her. We do not send the signs except to instill reverence.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmlxxxix{%
We said to you that your Lord encompasses humanity. We did not make the vision We showed you, except as a test for the people, and the tree cursed in the Quran. We frighten them, but that only increases their defiance.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmxc{%
When We said to the angels, “Bow down before Adam,” they bowed down, except for Satan. He said, “Shall I bow down before someone You created from mud?”\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmxci{%
He said, “Do You see this one whom You have honored more than me? If You reprieve me until the Day of Resurrection, I will bring his descendants under my sway, except for a few.”\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmxcii{%
He said, “Begone! Whoever of them follows you—Hell is your reward, an ample reward.”\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmxciii{%
“And entice whomever of them you can with your voice, and rally against them your cavalry and your infantry, and share with them in wealth and children, and make promises to them.” But Satan promises them nothing but delusion.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmxciv{%
“As for My devotees, you have no authority over them.” Your Lord is an adequate Guardian.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmxcv{%
Your Lord is He who propels for you the ships at sea, that you may seek of His bounty. He is towards you Most Merciful.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmxcvi{%
When harm afflicts you at sea, those you pray to vanish, except for Him. But when He saves you to land, you turn away. The human being is ever thankless.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmxcvii{%
Are you confident that He will not cause a track of land to cave in beneath you, or unleash a tornado against you, and then you find no protector?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmxcviii{%
Or are you confident that He will not return you to it once again, and unleash a hurricane against you, and drown you for your ingratitude? Then you will find no helper against Us.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmxcix{%
We have honored the Children of Adam, and carried them on land and sea, and provided them with good things, and greatly favored them over many of those We created.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmc{%
On the Day when We call every people with their leader. Whoever is given his record in his right hand—these will read their record, and they will not be wronged one bit.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmci{%
But whoever is blind in this, he will be blind in the Hereafter, and further astray from the way.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcii{%
They almost lured you away from what We have revealed to you, so that you would invent something else in Our name. In that case, they would have taken you for a friend.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmciii{%
Had We not given you stability, you might have inclined towards them a little.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmciv{%
Then We would have made you taste double in life, and double at death; then you would have found for yourself no helper against Us.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcv{%
They almost provoked you, to expel you from the land. In that case, they would not have lasted after you, except briefly.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcvi{%
The tradition of the messengers We sent before you—you will find no change in Our rules.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcvii{%
Perform the prayer at the decline of the sun, until the darkness of the night; and the Quran at dawn. The Quran at dawn is witnessed.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcviii{%
And keep vigil with it during parts of the night, as an extra prayer. Perhaps your Lord will raise you to a laudable position.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcix{%
And say, “My Lord, lead me in through an entry of truth, and lead me out through an exit of truth, and grant me from You a supporting power.”\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcx{%
And say, “The truth has come, and falsehood has withered away; for falsehood is bound to wither away.”\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcxi{%
We send down in the Quran healing and mercy for the believers, but it increases the wrongdoers only in loss.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcxii{%
When We bless the human being, he turns away and distances himself. But when adversity touches him, he is in despair.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcxiii{%
Say, “Each does according to his disposition. Your Lord knows best who is better guided in the way.”\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcxiv{%
And they ask you about the Spirit. Say, “The Spirit belongs to the domain of my Lord; and you were given only little knowledge.”\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcxv{%
If We willed, We could take away what We revealed to you. Then you will find for yourself no protecting guardian against Us.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcxvi{%
Except through a mercy from your Lord. His favors upon you have been great.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcxvii{%
Say, “If mankind and jinn came together to produce the like of this Quran, they could never produce the like of it, even if they backed up one another.”\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcxviii{%
We have displayed for mankind in this Quran every kind of similitude, but most people insist on denying the truth.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcxix{%
And they said, “We will not believe in you unless you make a spring burst from the ground for us.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcxx{%
Or you have a garden of palms and vines; then cause rivers to gush pouring through them.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcxxi{%
Or make the sky fall on us in pieces, as you claim, or bring God and the angels before us.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcxxii{%
Or you possess a house of gold. Or you ascend into the sky. Even then, we will not believe in your ascension, unless you bring down for us a book that we can read.” Say, “Glory be to my Lord. Am I anything but a human messenger?”\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcxxiii{%
Nothing prevented the people from believing, when guidance has come to them, except that they said, “Did God send a human messenger?”\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcxxiv{%
Say, “If there were angels on earth, walking around in peace, We would have sent down to them from heaven an angel messenger.”\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcxxv{%
Say, “God is enough witness between you and me. He is fully aware of His servants, and He sees them well.”\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcxxvi{%
Whomever God guides is the guided one. And whomever He leaves astray—for them you will find no protectors apart from Him. And We will gather them on the Day of Resurrection, on their faces, blind, dumb, and deaf. Their abode is Hell; whenever it abates, We intensify the blaze for them.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcxxvii{%
This is their repayment for having blasphemed against Our revelations, and having said, “Shall we, when we have become bones and fragments, be resurrected as a new creation?”\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcxxviii{%
Do they not consider that God, Who created the heavens and the earth, is Able to create the likes of them? He has assigned for them a term, in which there is no doubt. But the wrongdoers persist in denying the truth.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmcxxix{%
Say, “If you possessed the treasuries of my Lord’s mercy, you would have withheld them for fear of spending.” The human being has always been stingy.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmcxxx{%
We gave Moses nine clear signs—ask the Children of Israel. When he went to them, Pharaoh said to him, “I think that you, Moses, are bewitched.”\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmcxxxi{%
He said, “You know that none sent these down except the Lord of the heavens and the earth—eye openers; and I think that you, Pharaoh, are doomed.”\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmcxxxii{%
He resolved to scare them off the land, but We drowned him, and those with him, altogether.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmcxxxiii{%
After him, We said to the Children of Israel, “Inhabit the land, and when the promise of the Hereafter arrives, We will bring you all together.”\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmcxxxiv{%
With the truth We sent it down, and with the truth it descended. We sent you only as a bearer of good news and a warner.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmcxxxv{%
A Quran which We unfolded gradually, that you may recite to the people over time. And We revealed it in stages.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmcxxxvi{%
Say, “Believe in it, or do not believe.” Those who were given knowledge before it, when it is recited to them, they fall to their chins, prostrating.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmcxxxvii{%
And they say, “Glory to our Lord. The promise of our Lord is fulfilled.”\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmcxxxviii{%
And they fall to their chins, weeping, and it adds to their humility.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmcxxxix{%
Say, “Call Him God, or call Him the Most Merciful. Whichever name you use, to Him belong the Best Names.” And be neither loud in your prayer, nor silent in it, but follow a course in between.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmcxl{%
And say, “Praise be to God, who has not begotten a son, nor has He a partner in sovereignty, nor has He an ally out of weakness, and glorify Him constantly.”\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmcxli{%
\basmalahen Praise be to God, who revealed the Book to His servant, and allowed in it no distortion.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcxlii{%
Valuable—to warn of severe punishment from Himself; and to deliver good news to the believers who do righteous deeds, that they will have an excellent reward.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcxliii{%
In which they will abide forever.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcxliv{%
And to warn those who say, “God has begotten a son.”\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcxlv{%
They have no knowledge of this, nor did their forefathers. Grave is the word that comes out of their mouths. They say nothing but a lie.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcxlvi{%
Perhaps you may destroy yourself with grief, chasing after them, if they do not believe in this information.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcxlvii{%
We made what is upon the earth an ornament for it, to test them as to which of them is best in conduct.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcxlviii{%
And We will turn what is on it into barren waste.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcxlix{%
Did you know that the People of the Cave and the Inscription were of Our wondrous signs?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcl{%
When the youths took shelter in the cave, they said, “Our Lord, give us mercy from Yourself, and bless our affair with guidance.”\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcli{%
Then We sealed their ears in the cave for a number of years.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmclii{%
Then We awakened them to know which of the two groups could better calculate the length of their stay.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcliii{%
We relate to you their story in truth. They were youths who believed in their Lord, and We increased them in guidance.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcliv{%
And We strengthened their hearts, when they stood up and said, “Our Lord is the Lord of the heavens and the earth; we will not call on any god besides Him, for then we would have spoken an outrage.”\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmclv{%
“These people, our people, have taken to themselves gods other than Him. Why do they not bring a clear proof concerning them? Who, then, does greater wrong than he who invents lies and attributes them to God?”\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmclvi{%
“Now that you have withdrawn from them, and from what they worship besides God, take shelter in the cave. And your Lord will unfold His mercy for you, and will set your affair towards ease.”\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmclvii{%
You would have seen the sun, when it rose, veering away from their cave towards the right, and when it sets, moving away from them to the left, as they lay in the midst of the cave. That was one of God’s wonders. He whom God guides is truly guided; but he whom He misguides, for him you will find no directing friend.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmclviii{%
You would think them awake, although they were asleep. And We turned them over to the right, and to the left, with their dog stretching its paws across the threshold. Had you looked at them, you would have turned away from them in flight, and been filled with fear of them.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmclix{%
Even so, We awakened them, so that they may ask one another. A speaker among them said, “How long have you stayed?” They said, “We have stayed a day, or part of a day.” They said, “Your Lord knows best how long you have stayed.” “Send one of you to the city, with this money of yours, and let him see which food is most suitable, and let him bring you some provision thereof. And let him be gentle, and let no one become aware of you.”\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmclx{%
“If they discover you, they will stone you, or force you back into their religion; then you will never be saved.”\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmclxi{%
So it was, that We caused them to be discovered, that they would know that the promise of God is true, and that of the Hour there is no doubt. As they were disputing their case among themselves, they said, “Build over them a building.” Their Lord knows best about them. Those who prevailed over their case said, “We will set up over them a place of worship.”\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmclxii{%
They will say, “Three, and their fourth being their dog.” And they will say, “Five, and their sixth being their dog,” guessing at the unknown. And they will say, “Seven, and their eighth being their dog.” Say, “My Lord knows best their number.” None knows them except a few. So do not argue concerning them except with an obvious argument, and do not consult any of them about them.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmclxiii{%
And never say about anything, “I will do that tomorrow.”\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmclxiv{%
Without saying, “If God wills.” And remember your Lord if you forget, and say, “Perhaps my Lord will guide me to nearer than this in integrity.”\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmclxv{%
And they stayed in their cave for three hundred years, adding nine.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmclxvi{%
Say, “God knows best how long they stayed.” His is the mystery of the heavens and the earth. By Him you see and hear. They have no guardian apart from Him, and He shares His Sovereignty with no one.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmclxvii{%
And recite what was revealed to you from the Book of your Lord. There is no changing His words, and you will find no refuge except in Him.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmclxviii{%
And content yourself with those who pray to their Lord morning and evening, desiring His Presence. And do not turn your eyes away from them, desiring the glitter of this world. And do not obey him whose heart We have made heedless of Our remembrance—so he follows his own desires—and his priorities are confused.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmclxix{%
And say, “The truth is from your Lord. Whoever wills—let him believe. And whoever wills—let him disbelieve”. We have prepared for the unjust a Fire, whose curtains will hem them in. And when they cry for relief, they will be relieved with water like molten brass, which scalds the faces. What a miserable drink, and what a terrible place.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmclxx{%
As for those who believe and lead a righteous life—We will not waste the reward of those who work righteousness.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmclxxi{%
These will have the Gardens of Eden, beneath which rivers flow. Reclining on comfortable furnishings, they will be adorned with bracelets of gold, and will wear green garments of silk and brocade. What a wonderful reward, and what an excellent resting-place.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmclxxii{%
And cite for them the parable of two men. To one of them We gave two gardens of vine, and We surrounded them with palms-trees, and We placed between them crops.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmclxxiii{%
Both gardens produced their harvest in full, and suffered no loss. And We made a river flow through them.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmclxxiv{%
And thus he had abundant fruits. He said to his friend, as he conversed with him, “I am wealthier than you, and greater in manpower.”\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmclxxv{%
And he entered his garden, wronging himself. He said, “I do not think this will ever perish.”\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmclxxvi{%
“And I do not think the Hour is coming. And even if I am returned to my Lord, I will find something better than this in return.”\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmclxxvii{%
His friend said to him, as he conversed with him, “Are you being ungrateful to Him who created you from dust, then from a sperm-drop, then evolved you into a man?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmclxxviii{%
But as for me, He is God, my Lord, and I never associate with my Lord anyone.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmclxxix{%
When you entered your garden, why did you not say, “As God wills; there is no power except through God”? Although you see me inferior to you in wealth and children.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmclxxx{%
Perhaps my Lord will give me something better than your garden, and release upon it thunderbolts from the sky, so it becomes barren waste.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmclxxxi{%
Or its water will sink into the ground, and you will be unable to draw it.”\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmclxxxii{%
And ruin closed in on his crops, and so he began wringing his hands over what he had invested in it, as it lays fallen upon its trellises. And he was saying, “I wish I never associated anyone with my Lord.”\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmclxxxiii{%
He had no faction to help him besides God, and he was helpless.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmclxxxiv{%
That is because authority belongs to God, the True. He is Best in rewarding, and Best in requiting.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmclxxxv{%
And cite for them the parable of the present life: it is like water that We send down from the sky; the plants of the earth absorb it; but then it becomes debris, scattered by the wind. God has absolute power over everything.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmclxxxvi{%
Wealth and children are the adornments of the present life. But the things that last, the virtuous deeds, are better with your Lord for reward, and better for hope.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmclxxxvii{%
On the Day when We set the mountains in motion; and you see the earth emerging; and We gather them together, and leave none of them behind.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmclxxxviii{%
They will be presented before your Lord in a row. “You have come to Us as We created you the first time. Although you claimed We would not set a meeting for you.”\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmclxxxix{%
And the book will be placed, and you will see the sinners fearful of its contents. And they will say, “Woe to us! What is with this book that leaves nothing, small or big, but it has enumerated it?” They will find everything they had done present. Your Lord does not wrong anyone.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcxc{%
We said to the angels, “Bow down to Adam.” So they bowed down, except for Satan. He was of the jinn, and he defied the command of his Lord. Will you take him and his offspring as lords instead of Me, when they are an enemy to you? Evil is the exchange for the wrongdoers.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcxci{%
I did not call them to witness the creation of the heavens and the earth, nor their own creation; and I do not take the misleaders for assistants.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcxcii{%
On the Day when He will say, “Call on My partners whom you have claimed.” They will call on them, but they will not answer them. And We will place between them a barrier.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcxciii{%
And the sinners will see the Fire, and will realize that they will tumble into it. They will find no deliverance from it.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcxciv{%
We have elaborated in this Quran for the people every kind of example, but the human being is a most argumentative being.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcxcv{%
What prevented people from accepting faith, when guidance has come to them, and from seeking their Lord’s forgiveness? Unless they are waiting for the precedent of the ancients to befall them, or to have the punishment come upon them face to face.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcxcvi{%
We send the messengers only as deliverers of good news and warners. Those who disbelieve argue with false argument, in order to defeat the truth thereby. They take My Verses, and the warnings, for a joke.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcxcvii{%
Who does greater wrong than he, who, when reminded of his Lord’s revelations, turns away from them, and forgets what his hands have put forward? We have placed coverings over their hearts, lest they understand it, and heaviness in their ears. And if you call them to guidance, they will not be guided, ever.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcxcviii{%
Your Lord is the Forgiver, Possessor of Mercy. Were He to call them to account for what they have earned, He would have hastened the punishment for them. But they have an appointment from which they will find no escape.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcxcix{%
And these towns—We destroyed them when they committed injustices, and We set for their destruction an appointed time.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcc{%
Recall when Moses said to his servant, “I will not give up until I reach the junction of the two rivers, even if it takes me years.”\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcci{%
Then, when they reached the junction between them, they forgot about their fish. It found its way into the river, slipping away.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmccii{%
When they went further, he said to his servant, “Bring us our lunch; we were exposed in our travel to much fatigue.”\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcciii{%
He said, “Do you remember when we rested by the rock? I forgot about the fish. It was only the devil who made me forget it. And so it found its way to the river, amazingly.”\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcciv{%
He said, “This is what we were seeking.” And so they turned back retracing their steps.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmccv{%
Then they came upon a servant of Ours, whom We had blessed with mercy from Us, and had taught him knowledge from Our Own.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmccvi{%
Moses said to him, “May I follow you, so that you may teach me some of the guidance you were taught?”\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmccvii{%
He said, “You will not be able to endure with me.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmccviii{%
And how will you endure what you have no knowledge of?”\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmccix{%
He said, “You will find me, God willing, patient; and I will not disobey you in any order of yours.”\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmccx{%
He said, “If you follow me, do not ask me about anything, until I myself make mention of it to you.”\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmccxi{%
So they set out. Until, when they had boarded the boat, he holed it. He said, “Did you hole it, to drown its passengers? You have done something awful.”\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmccxii{%
He said, “Did I not tell you that you will not be able to endure with me?”\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmccxiii{%
He said, “Do not rebuke me for forgetting, and do not make my course difficult for me.”\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmccxiv{%
Then they set out. Until, when they encountered a boy, he killed him. He said, “Did you kill a pure soul, who killed no one? You have done something terrible.”\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmccxv{%
He said, “Did I not tell you that you will not be able to endure with me?”\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmccxvi{%
He said, “If I ask you about anything after this, then do not keep company with me. You have received excuses from me.”\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmccxvii{%
So they set out. Until, when they reached the people of a town, they asked them for food, but they refused to offer them hospitality. There they found a wall about to collapse, and he repaired it. He said, “If you wanted, you could have obtained a payment for it.”\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmccxviii{%
He said, “This is the parting between you and me. I will tell you the interpretation of what you were unable to endure.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmccxix{%
As for the boat, it belonged to paupers working at sea. I wanted to damage it because there was a king coming after them seizing every boat by force.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmccxx{%
As for the boy, his parents were believers, and we feared he would overwhelm them with oppression and disbelief.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmccxxi{%
So we wanted their Lord to replace him with someone better in purity, and closer to mercy.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmccxxii{%
And as for the wall, it belonged to two orphaned boys in the town. Beneath it was a treasure that belonged to them. Their father was a righteous man. Your Lord wanted them to reach their maturity, and then extract their treasure—as a mercy from your Lord. I did not do it of my own accord. This is the interpretation of what you were unable to endure.”\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmccxxiii{%
And they ask you about Zul-Qarnain. Say, “I will tell you something about him.”\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmccxxiv{%
We established him on earth, and gave him all kinds of means.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmccxxv{%
He pursued a certain course.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmccxxvi{%
Until, when he reached the setting of the sun, he found it setting in a murky spring, and found a people in its vicinity. We said, “O Zul-Qarnain, you may either inflict a penalty, or else treat them kindly.”\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmccxxvii{%
He said, “As for him who does wrong, we will penalize him, then he will be returned to his Lord, and He will punish him with an unheard-of torment.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmccxxviii{%
“But as for him who believes and acts righteously, he will have the finest reward, and We will speak to him of Our command with ease.”\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmccxxix{%
Then he pursued a course.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmccxxx{%
Until, when he reached the rising of the sun, he found it rising on a people for whom We had provided no shelter from it.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmccxxxi{%
And so it was. We had full knowledge of what he had.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmccxxxii{%
Then he pursued a course.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmccxxxiii{%
Until, when he reached the point separating the two barriers, he found beside them a people who could barely understand what is said.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmccxxxiv{%
They said, “O Zul-Qarnain, the Gog and Magog are spreading chaos in the land. Can we pay you, to build between us and them a wall?”\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmccxxxv{%
He said, “What my Lord has empowered me with is better. But assist me with strength, and I will build between you and them a dam.”\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmccxxxvi{%
“Bring me blocks of iron.” So that, when he had leveled up between the two cliffs, he said, “Blow.” And having turned it into a fire, he said, “Bring me tar to pour over it.”\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmccxxxvii{%
So they were unable to climb it, and they could not penetrate it.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmccxxxviii{%
He said, “This is a mercy from my Lord. But when the promise of my Lord comes true, He will turn it into rubble, and the promise of my Lord is always true.”\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmccxxxix{%
On that Day, We will leave them surging upon one another. And the Trumpet will be blown, and We will gather them together.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmccxl{%
On that Day, We will present the disbelievers to Hell, all displayed.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmccxli{%
Those whose eyes were screened to My message, and were unable to hear.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmccxlii{%
Do those who disbelieve think that they can take My servants for masters instead of Me? We have prepared Hell for the hospitality of the faithless.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmccxliii{%
Say, “Shall We inform you of the greatest losers in their works?”\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmccxliv{%
“Those whose efforts in this world are misguided, while they assume that they are doing well.”\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmccxlv{%
It is they who rejected the communications of their Lord, and the encounter with Him. So their works are in vain. And on the Day of Resurrection, We will consider them of no weight.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmccxlvi{%
That is their requital—Hell—on account of their disbelief, and their taking My revelations and My messengers in mockery.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmccxlvii{%
As for those who believe and do righteous deeds, they will have the Gardens of Paradise for hospitality.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmccxlviii{%
Abiding therein forever, without desiring any change therefrom.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmccxlix{%
Say, “If the ocean were ink for the words of my Lord, the ocean would run out, before the words of my Lord run out,” even if We were to bring the like of it in addition to it.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmccl{%
Say, “I am only a human being like you, being inspired that your god is One God. Whoever hopes to meet his Lord, let him work righteousness, and never associate anyone with the service of his Lord.”\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmccli{%
\basmalahen Kaf, Ha, Ya, Ayn, Saad.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcclii{%
A mention of the mercy of your Lord towards His servant Zechariah.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmccliii{%
When he called on his Lord, a call in seclusion.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmccliv{%
He said, “My Lord, my bones have become feeble, and my hair is aflame with gray, and never, Lord, have I been disappointed in my prayer to you.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcclv{%
“And I fear for my dependents after me, and my wife is barren. So grant me, from Yourself, an heir.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcclvi{%
To inherit me, and inherit from the House of Jacob, and make him, my Lord, pleasing.”\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcclvii{%
“O Zechariah, We give you good news of a son, whose name is John, a name We have never given before.”\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcclviii{%
He said, “My Lord, how can I have a son, when my wife is barren, and I have become decrepit with old age?”\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcclix{%
He said, “It will be so, your Lord says, ‘it is easy for me, and I created you before, when you were nothing.’”\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcclx{%
He said, “My Lord, give me a sign.” He said, “Your sign is that you will not speak to the people for three nights straight.”\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcclxi{%
And he came out to his people, from the sanctuary, and signaled to them to praise morning and evening.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcclxii{%
“O John, hold on to the Scripture firmly,” and We gave him wisdom in his youth.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcclxiii{%
And tenderness from Us, and innocence. He was devout.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcclxiv{%
And kind to his parents; and he was not a disobedient tyrant.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcclxv{%
And peace be upon him the day he was born, and the day he dies, and the Day he is raised alive.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcclxvi{%
And mention in the Scripture Mary, when she withdrew from her people to an eastern location.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmcclxvii{%
She screened herself away from them, and We sent to her Our spirit, and He appeared to her as an immaculate human.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmcclxviii{%
She said, “I take refuge from you in the Most Merciful, should you be righteous.”\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmcclxix{%
He said, “I am only the messenger of your Lord, to give you the gift of a pure son.”\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmcclxx{%
She said, “How can I have a son, when no man has touched me, and I was never unchaste?”\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmcclxxi{%
He said, “Thus said your Lord, `It is easy for Me, and We will make him a sign for humanity, and a mercy from Us. It is a matter already decided.'“\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmcclxxii{%
So she carried him, and secluded herself with him in a remote place.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmcclxxiii{%
The labor-pains came upon her, by the trunk of a palm-tree. She said, “I wish I had died before this, and been completely forgotten.”\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmcclxxiv{%
Whereupon he called her from beneath her: “Do not worry; your Lord has placed a stream beneath you.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmcclxxv{%
And shake the trunk of the palm-tree towards you, and it will drop ripe dates by you.”\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmcclxxvi{%
“So eat, and drink, and be consoled. And if you see any human, say, ‘I have vowed a fast to the Most Gracious, so I will not speak to any human today.'“\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmcclxxvii{%
Then she came to her people, carrying him. They said, “O Mary, you have done something terrible.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmcclxxviii{%
O sister of Aaron, your father was not an evil man, and your mother was not a whore.”\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmcclxxix{%
So she pointed to him. They said, “How can we speak to an infant in the crib?”\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmcclxxx{%
He said, “I am the servant of God. He has given me the Scripture, and made me a prophet.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmcclxxxi{%
And has made me blessed wherever I may be; and has enjoined on me prayer and charity, so long as I live.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmcclxxxii{%
And kind to my mother, and He did not make me a disobedient rebel.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmcclxxxiii{%
So Peace is upon me the day I was born, and the day I die, and the Day I get resurrected alive.”\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmcclxxxiv{%
That is Jesus son of Mary—the Word of truth about which they doubt.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmcclxxxv{%
It is not for God to have a child—glory be to Him. To have anything done, He says to it, “Be,” and it becomes.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmcclxxxvi{%
“God is my Lord and your Lord, so worship Him. That is a straight path.”\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmcclxxxvii{%
But the various factions differed among themselves. So woe to those who disbelieve from the scene of a tremendous Day.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmcclxxxviii{%
Listen to them and watch for them the Day they come to Us. But the wrongdoers today are completely lost.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmcclxxxix{%
And warn them of the Day of Regret, when the matter will be concluded. Yet they are heedless, and they do not believe.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmccxc{%
It is We who will inherit the earth and everyone on it, and to Us they will be returned.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmccxci{%
And mention in the Scripture Abraham. He was a man of truth, a prophet.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmccxcii{%
He said to his father, “O my father, why do you worship what can neither hear, nor see, nor benefit you in any way?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmccxciii{%
O my father, there has come to me knowledge that never came to you. So follow me, and I will guide you along a straight way.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmccxciv{%
O my father, do not worship the devil. The devil is disobedient to the Most Gracious.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmccxcv{%
O my father, I fear that a punishment from the Most Gracious will afflict you, and you become an ally of the devil.”\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmccxcvi{%
He said, “Are you renouncing my gods, O Abraham? If you do not desist, I will stone you. So leave me alone for a while.”\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmccxcvii{%
He said, “Peace be upon you. I will ask my Lord to forgive you; He has been Kind to me.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmccxcviii{%
And I will withdraw from you, and from what you pray to instead of God. And I will pray to my Lord, and I hope I will not be disappointed in my prayer to my Lord.”\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmccxcix{%
When he withdrew from them, and from what they worship besides God, We granted him Isaac and Jacob. And each We made a prophet.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmccc{%
And We gave them freely of Our mercy, and gave them a noble reputation of truth.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmccci{%
And mention in the Scripture Moses. He was dedicated. He was a messenger and a prophet.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcccii{%
And We called him from the right side of the Mount, and brought him near in communion.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmccciii{%
And We granted him, out of Our mercy, his brother Aaron, a prophet.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmccciv{%
And mention in the Scripture Ishmael. He was true to his promise, and was a messenger, a prophet.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcccv{%
And he used to enjoin on his people prayer and charity, and he was pleasing to his Lord.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcccvi{%
And mention in the Scripture Enoch. He was a man of truth, a prophet.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcccvii{%
And We raised him to a high position.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcccviii{%
These are some of the prophets God has blessed, from the descendants of Adam, and from those We carried with Noah, and from the descendants of Abraham and Israel, and from those We guided and selected. Whenever the revelations of the Most Gracious are recited to them, they would fall down, prostrating and weeping.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcccix{%
But they were succeeded by generations who lost the prayers and followed their appetites. They will meet perdition.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcccx{%
Except for those who repent, and believe, and act righteously. These will enter Paradise, and will not be wronged in the least.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcccxi{%
The Gardens of Eden, promised by the Most Merciful to His servants in the Unseen. His promise will certainly come true.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcccxii{%
They will hear no nonsense therein, but only peace. And they will have their provision therein, morning and evening.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcccxiii{%
Such is Paradise which We will give as inheritance to those of Our servants who are devout.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcccxiv{%
“We do not descend except by the command of your Lord. His is what is before us, and what is behind us, and what is between them. Your Lord is never forgetful.”\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcccxv{%
Lord of the heavens and the earth and what is between them. So worship Him, and persevere in His service. Do you know of anyone equal to Him?\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcccxvi{%
And the human being says, “When I am dead, will I be brought back alive?”\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcccxvii{%
Does the human being not remember that We created him before, when he was nothing?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcccxviii{%
By your Lord, We will round them up, and the devils, then We will bring them around Hell, on their knees.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcccxix{%
Then, out of every sect, We will snatch those most defiant to the Most Merciful.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcccxx{%
We are fully aware of those most deserving to scorch in it.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcccxxi{%
There is not one of you but will go down to it. This has been an unavoidable decree of your Lord.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcccxxii{%
Then We will rescue those who were devout, and leave the wrongdoers in it, on their knees.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcccxxiii{%
When Our clear revelations are recited to them, those who disbelieve say to those who believe, “Which of the two parties is better in position, and superior in influence?”\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcccxxiv{%
How many a generation have We destroyed before them, who surpassed them in riches and splendor?\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcccxxv{%
Say, “Whoever is in error, the Most Merciful will lead him on.” Until, when they see what they were promised—either the punishment, or the Hour. Then they will know who was in worse position and weaker in forces.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcccxxvi{%
God increases in guidance those who accept guidance. And the things that endure—the righteous deeds—have the best reward with your Lord, and the best outcome.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcccxxvii{%
Have you seen him who denied Our revelations, and said, “I will be given wealth and children”?\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcccxxviii{%
Did he look into the future, or did he receive a promise from the Most Merciful?\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcccxxix{%
No indeed! We will write what he says, and will keep extending the agony for him.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcccxxx{%
Then We will inherit from him what he speaks of, and he will come to Us alone.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcccxxxi{%
And they took, besides God, other gods, to be for them a source of strength.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcccxxxii{%
By no means! They will reject their worship of them, and become opponents to them.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcccxxxiii{%
Have you not considered how We dispatch the devils against the disbelievers, exciting them with incitement?\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcccxxxiv{%
So do not hurry against them. We are counting for them a countdown.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcccxxxv{%
On the Day when We will gather the righteous to the Most Merciful, as guests.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcccxxxvi{%
And herd the sinners into hell, like animals to water.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcccxxxvii{%
They will have no power of intercession, except for someone who has an agreement with the Most Merciful.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcccxxxviii{%
And they say, “The Most Merciful has begotten a son.”\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcccxxxix{%
You have come up with something monstrous.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcccxl{%
At which the heavens almost rupture, and the earth splits, and the mountains fall and crumble.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcccxli{%
Because they attribute a son to the Most Merciful.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcccxlii{%
It is not fitting for the Most Merciful to have a son.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcccxliii{%
There is none in the heavens and the earth but will come to the Most Merciful as a servant.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcccxliv{%
He has enumerated them, and counted them one by one.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcccxlv{%
And each one of them will come to Him on the Day of Resurrection alone.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcccxlvi{%
Those who believe and do righteous deeds, the Most Merciful will give them love.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcccxlvii{%
We made it easy in your tongue, in order to deliver good news to the righteous, and to warn with it a hostile people.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcccxlviii{%
How many a generation have We destroyed before them? Can you feel a single one of them, or hear from them the slightest whisper?\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcccxlix{%
\basmalahen Ta, Ha.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcccl{%
We did not reveal the Quran to you to make you suffer.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcccli{%
But only as a reminder for him who fears.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmccclii{%
A revelation from He who created the earth and the high heavens.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcccliii{%
The Most Merciful; on the Throne He settled.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcccliv{%
To Him belongs everything in the heavens and the earth, and everything between them, and everything beneath the soil.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmccclv{%
If you speak aloud—He knows the secret, and the most hidden.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmccclvi{%
God, there is no god but He, His are the Most Beautiful Names.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmccclvii{%
Has the story of Moses reached you?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmccclviii{%
When he saw a fire, he said to his family, “Stay; I have noticed a fire; Perhaps I can bring you a torch therefrom, or find some guidance by the fire.”\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmccclix{%
Then, when he reached it, he was called, “O Moses.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmccclx{%
I—I am your Lord. Take off your shoes. You are in the sacred valley of Tuwa.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmccclxi{%
I have chosen you, so listen to what is revealed.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmccclxii{%
I—I am God. There is no God but I. So serve Me, and practice the prayer for My remembrance.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmccclxiii{%
The Hour is coming—but I keep it almost hidden—so that each soul will be paid for what it endeavors.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmccclxiv{%
And do not let him who denies it and follows his desire turn you away from it, lest you fall.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmccclxv{%
And what is that in your right-hand, O Moses?”\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmccclxvi{%
He said, “This is my staff. I lean on it, and herd my sheep with it, and I have other uses for it.”\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmccclxvii{%
He said, “Throw it, O Moses.”\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmccclxviii{%
So he threw it—thereupon it became a moving serpent.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmccclxix{%
He said, “Take hold of it, and do not fear. We will restore it to its original condition.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmccclxx{%
And press your hand to your side; it will come out white, without a blemish—another sign.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmccclxxi{%
That We may show you some of Our greatest signs.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmccclxxii{%
Go to Pharaoh; He has transgressed.”\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmccclxxiii{%
He said, “My Lord, put my heart at peace for me.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmccclxxiv{%
And ease my task for me.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmccclxxv{%
And untie the knot from my tongue.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmccclxxvi{%
So they can understand my speech.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmccclxxvii{%
And appoint an assistant for me, from my family.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmccclxxviii{%
Aaron, my brother.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmccclxxix{%
Strengthen me with him.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmccclxxx{%
And have him share in my mission.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmccclxxxi{%
That we may glorify You much.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmccclxxxii{%
And remember You much.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmccclxxxiii{%
You are always watching over us.”\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmccclxxxiv{%
He said, “You are granted your request, O Moses.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmccclxxxv{%
We had favored you another time.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmccclxxxvi{%
When We inspired your mother with the inspiration.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmccclxxxvii{%
`Put him in the chest; then cast him into the river. The river will wash him to shore, where an enemy of Mine and an enemy of his will pick him up. And I have bestowed upon you love from Me, so that you may be reared before My eye.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmccclxxxviii{%
When your sister walked along, and said, ‘Shall I tell you about someone who will take care of him?' So We returned you to your mother, that she may be comforted, and not sorrow. And you killed a person, but We saved you from stress; and We tested you thoroughly. And you stayed years among the people of Median. Then you came back, as ordained, O Moses.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmccclxxxix{%
And I made you for Myself.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmcccxc{%
Go, you and your brother, with My signs, and do not neglect My remembrance.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmcccxci{%
Go to Pharaoh. He has tyrannized.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmcccxcii{%
But speak to him nicely. Perhaps he will remember, or have some fear.”\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcccxciii{%
They said, “Lord, we fear he may persecute us, or become violent.”\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcccxciv{%
He said, “Do not fear, I am with you, I hear and I see.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcccxcv{%
Approach him and say, `We are the messengers of your Lord; so let the Children of Israel go with us, and do not torment them. We bring you a sign from your Lord, and peace be upon him who follows guidance.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcccxcvi{%
It was revealed to us that the punishment falls upon him who disbelieves and turns away.'“\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcccxcvii{%
He said, “Who is your Lord, O Moses.”\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcccxcviii{%
He said, “Our Lord is He who gave everything its existence, then guided it.”\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcccxcix{%
He said, “What about the first generations?”\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcd{%
He said, “Knowledge thereof is with my Lord, in a Book. My Lord never errs, nor does He forget.”\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcdi{%
He who made the earth a habitat for you; and traced in it routes for you; and sent down water from the sky, with which We produce pairs of diverse plants.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcdii{%
Eat and pasture your livestock. In that are signs for those with understanding.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcdiii{%
From it We created you, and into it We will return you, and from it We will bring you out another time.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcdiv{%
We showed him Our signs, all of them, but he denied and refused.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcdv{%
He said, “Did you come to us to drive us out of our land with your magic, O Moses?\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcdvi{%
We will produce for you magic like it; so make an appointment between us and you, which we will not miss—neither us, nor you—in a central place.”\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcdvii{%
He said, “Your appointment is the day of the festival, so let the people be gathered together at mid-morning.”\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcdviii{%
Pharaoh turned away, put together his plan, and then came back.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcdix{%
Moses said to them, “Woe to you. Do not fabricate lies against God, or He will destroy you with a punishment. He who invents lies will fail.”\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcdx{%
They disagreed among themselves over their affair, and conferred secretly.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcdxi{%
They said, “These two are magicians who want to drive you out of your land with their magic, and to abolish your exemplary way of life.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcdxii{%
So settle your plan, and come as one front. Today, whoever gains the upper hand will succeed.”\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcdxiii{%
They said, “O Moses, either you throw, or we will be the first to throw.”\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcdxiv{%
He said, “You throw.” And suddenly, their ropes and sticks appeared to him, because of their magic, to be crawling swiftly.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcdxv{%
So Moses felt apprehensive within himself.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcdxvi{%
We said, “Do not be afraid, you are the uppermost.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcdxvii{%
Now throw down what is in your right hand—it will swallow what they have crafted. What they have crafted is only a magician’s trickery. But the magician will not succeed, no matter what he does.”\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcdxviii{%
And the magicians fell down prostrate. They said, “We have believed in the Lord of Aaron and Moses.”\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcdxix{%
He said, “Did you believe in him before I have given you permission? He must be your chief, who has taught you magic. I will cut off your hands and your feet on alternate sides, and I will crucify you on the trunks of the palm-trees. Then you will know which of us is more severe in punishment, and more lasting.”\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcdxx{%
They said, “We will not prefer you to the proofs that have come to us, and Him who created us. So issue whatever judgment you wish to issue. You can only rule in this lowly life.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcdxxi{%
We have believed in our Lord, so that He may forgive us our sins, and the magic you have compelled us to practice. God is Better, and more Lasting.”\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcdxxii{%
Whoever comes to his Lord guilty, for him is Hell, where he neither dies nor lives.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcdxxiii{%
But whoever comes to Him a believer, having worked righteousness—these will have the highest ranks.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcdxxiv{%
The Gardens of Perpetuity, beneath which rivers flow, dwelling therein forever. That is the reward for him who purifies himself.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcdxxv{%
And We inspired Moses: “Travel by night with My servants, and strike for them a dry path across the sea, not fearing being overtaken, nor worrying.”\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcdxxvi{%
Pharaoh pursued them with his troops, but the sea overwhelmed them, and completely engulfed them.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcdxxvii{%
Pharaoh misled his people, and did not guide them.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcdxxviii{%
O Children of Israel! We have delivered you from your enemy, and promised you by the right side of the Mount, and sent down to you manna and quails.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcdxxix{%
Eat of the good things We have provided for you, but do not be excessive therein, lest My wrath descends upon you. He upon whom My wrath descends has fallen.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcdxxx{%
And I am Forgiving towards him who repents, believes, acts righteously, and then remains guided.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcdxxxi{%
“And what made you rush ahead of your people, O Moses?”\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcdxxxii{%
He said, “They are following in my footsteps; and I hurried on to You, my Lord, that you may be pleased.”\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcdxxxiii{%
He said, “We have tested your people in your absence, and the Samarian misled them.”\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcdxxxiv{%
So Moses returned to his people, angry and disappointed. He said, “O my people, did your Lord not promise you a good promise? Was the time too long for you? Or did you want wrath from your Lord to descend upon you, so you broke your promise to me?”\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcdxxxv{%
They said, “We did not break our promise to you by our choice, but we were made to carry loads of the people’s ornaments, and we cast them in. That was what the Samarian suggested.”\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcdxxxvi{%
So he produced for them a calf—a mere body which lowed. And they said, “This is your god, and the god of Moses, but he has forgotten.”\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcdxxxvii{%
Did they not see that it cannot return a word to them, and has no power to harm them or benefit them?\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcdxxxviii{%
Aaron had said to them before, “O my people, you are being tested by this. And your Lord is the Merciful, so follow me, and obey my command.”\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcdxxxix{%
They said, “We will not give up our devotion to it, until Moses returns to us.”\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcdxl{%
He said, “O Aaron, what prevented you, when you saw them going astray.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcdxli{%
From following me? Did you disobey my command?”\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcdxlii{%
He said, “Son of my mother, do not seize me by my beard or my head. I feared you would say, `You have caused division among the Children of Israel, and did not regard my word.'“\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcdxliii{%
He said, “What do you have to say, O Samarian?”\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcdxliv{%
He said, “I saw what they did not see, so I grasped a handful from the Messenger’s traces, and I flung it away. Thus my soul prompted me.”\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcdxlv{%
He said, “Begone! Your lot in this life is to say, ‘No contact.’ And you have an appointment that you will not miss. Now look at your god that you remained devoted to—we will burn it up, and then blow it away into the sea, as powder.”\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcdxlvi{%
Surely your god is God, the One besides whom there is no other god. He comprehends everything in knowledge.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcdxlvii{%
Thus We narrate to you reports of times gone by; and We have given you a message from Our Presence.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmcdxlviii{%
Whoever turns away from it will carry on the Day of Resurrection a burden.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmcdxlix{%
Abiding therein forever. And wretched is their burden on the Day of Resurrection.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmcdl{%
On the Day when the Trumpet is blown—We will gather the sinners on that Day, blue.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmcdli{%
Murmuring among themselves: “You have lingered only for ten.”\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmcdlii{%
We are fully aware of what they say, when the most exemplary of them in conduct will say, “You have lingered only a day.”\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmcdliii{%
And they ask you about the mountains. Say, “My Lord will crumble them utterly.”\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmcdliv{%
And leave them desolate waste.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmcdlv{%
You will see in them neither crookedness, nor deviation.”\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmcdlvi{%
On that Day, they will follow the caller, without any deviation. Voices will be hushed before the Merciful, and you will hear nothing but murmur.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmcdlvii{%
On that Day, intercession will not avail, except for him permitted by the Merciful, and whose words He has approved.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmcdlviii{%
He knows what is before them and what is behind them, and they cannot comprehend Him in their knowledge.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmcdlix{%
Faces will be humbled before the Living, the Eternal. Whoever carries injustice will despair.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmcdlx{%
But whoever has done righteous deeds, while being a believer—will fear neither injustice, nor grievance.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmcdlxi{%
Thus We have revealed it an Arabic Quran, and We have diversified the warnings in it, that perhaps they would become righteous, or it may produce a lesson for them.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmcdlxii{%
Exalted is God, the True King. Do not be hasty with the Quran before its inspiration to you is concluded, and say, “My Lord, increase me in knowledge.”\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmcdlxiii{%
And We covenanted with Adam before, but he forgot, and We found in him no resolve.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmcdlxiv{%
And when We said to the angels, “Bow down to Adam.” They bowed down, except for Satan; he refused.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmcdlxv{%
We said, “O Adam, this is an enemy to you and to your wife. So do not let him make you leave the Garden, for then you will suffer.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmcdlxvi{%
In it you will never go hungry, nor be naked.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmcdlxvii{%
Nor will you be thirsty in it, nor will you swelter.”\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmcdlxviii{%
But Satan whispered to him. He said, “O Adam, shall I show you the Tree of Immortality, and a kingdom that never decays?”\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmcdlxix{%
And so they ate from it; whereupon their bodies became visible to them, and they started covering themselves with the leaves of the Garden. Thus Adam disobeyed his Lord, and fell.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmcdlxx{%
But then his Lord recalled him, and pardoned him, and guided him.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmcdlxxi{%
He said, “Go down from it, altogether; some of you enemies of some others. But whenever guidance comes to you from Me, whoever follows My guidance, will not go astray, nor suffer.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmcdlxxii{%
But whoever turns away from My Reminder, for him is a confined life. And We will raise him on the Day of Resurrection blind.”\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmcdlxxiii{%
He will say, “My Lord, why did You raise me blind, though I was seeing?”\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmcdlxxiv{%
He will say, “Just as Our revelations came to you, and you forgot them, today you will be forgotten.”\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmcdlxxv{%
Thus We recompense him who transgresses and does not believe in the revelations of his Lord. The punishment of the Hereafter is more severe, and more lasting.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmcdlxxvi{%
Is it not instructive to them, how many generations before them We destroyed, in whose settlements they walk? Surely in that are signs for people of understanding.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmcdlxxvii{%
Were it not for a word that issued from your Lord, the inevitable would have happened, but there is an appointed term.\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmcdlxxviii{%
So bear patiently what they say, and celebrate the praises of your Lord before the rising of the sun, and before its setting. And during the hours of the night glorify Him, and at the borders of the day, that you may be satisfied.\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmcdlxxix{%
And do not extend your glance towards what We have given some classes of them to enjoy—the splendor of the life of this world—that We may test them thereby. Your Lord’s provision is better, and more lasting.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmcdlxxx{%
And exhort your people to pray, and patiently adhere to it. We ask of you no sustenance, but it is We who sustain you. The good ending is that for righteousness.\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmcdlxxxi{%
And they say, “Why does he not bring us a miracle from his Lord?” Were they not given enough miracles in the former scriptures?\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmcdlxxxii{%
Had We destroyed them with a punishment before him, they would have said, “Our Lord, if only You had sent us a messenger, we would have followed Your revelations before we were humiliated and disgraced.”\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmcdlxxxiii{%
Say, “Everybody is waiting, so wait. You will know who the people of the straight path are, and who is rightly-guided.\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmcdlxxxiv{%
\basmalahen Mankind’s reckoning has drawn near, but they turn away heedlessly.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcdlxxxv{%
No fresh reminder comes to them from their Lord, but they listen to it playfully.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcdlxxxvi{%
Their hearts distracted, the wrongdoers confer secretly, “Is this anything but a mortal like you? Will you take to sorcery, with open-eyes?”\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcdlxxxvii{%
He said, “My Lord knows what is said in the heaven and the earth; and He is the Hearer, the Knower.”\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcdlxxxviii{%
And they said, “A jumble of dreams,” and, “He made it up,” and, “He is a poet,” “let him bring us a sign, like those sent to the ancients.”\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcdlxxxix{%
None of the towns We destroyed before them had believed. Will they, then, believe?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcdxc{%
We did not send before you except men, whom We inspired. Ask the people of knowledge, if you do not know.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcdxci{%
We did not make them mere bodies that ate no food, nor were they immortal.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcdxcii{%
Then We fulfilled Our promise to them, and We saved them together with whomever We willed, and We destroyed the extravagant.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcdxciii{%
We have sent down to you a Book, containing your message. Do you not understand?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcdxciv{%
How many a guilty town have We crushed, and established thereafter another people?\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcdxcv{%
Then, when they sensed Our might, they started running away from it.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcdxcvi{%
Do not run, but come back to your luxuries, and to your homes, that you may be questioned.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcdxcvii{%
They said, “Woe to us; we were unfair.”\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcdxcviii{%
This continued to be their cry, until We made them silent ashes.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcdxcix{%
We did not create the sky and the earth and what is between them for amusement.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmd{%
If We wanted amusement, We could have found it within Us, were We to do so.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdi{%
In fact, We hurl the truth against falsehood, and it crushes it, so it vanishes. Woe unto you, for what you describe.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdii{%
To Him belongs everyone in the heavens and the earth. Those near Him are not too proud to worship Him, nor do they waver.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdiii{%
They praise night and day, without ever tiring.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdiv{%
Or have they taken to themselves gods from the earth who resurrect?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdv{%
If there were in them gods other than God, they would have gone to ruin. So glory be to God, Lord of the Throne, beyond what they allege.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdvi{%
He will not be questioned about what He does, but they will be questioned.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdvii{%
Or have they taken, besides Him, other gods? Say, “Bring your proof. This is a message for those with me, and a message of those before me.” But most of them do not know the truth, so they turn away.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdviii{%
We never sent a messenger before you without inspiring him that: “There is no god but I, so worship Me.”\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdix{%
And they say, “The Most Merciful has taken to himself a son.” Be He glorified; they are but honored servants.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdx{%
They never speak before He has spoken, and they only act on His command.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdxi{%
He knows what is before them, and what is behind them; and they do not intercede except for him whom He approves; and they tremble in awe of Him.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdxii{%
And whoever of them says, “I am a god besides Him,” We will reward him with Hell. Thus We reward the wrongdoers.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdxiii{%
Do the disbelievers not see that the heavens and the earth were one mass, and We tore them apart? And We made from water every living thing. Will they not believe?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdxiv{%
And We placed on earth stabilizers, lest it sways with them, and We placed therein signposts and passages, that they may be guided.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdxv{%
And We made the sky a protected ceiling; yet they turn away from its wonders.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdxvi{%
It is He who created the night and the day, and the sun and the moon; each floating in an orbit.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdxvii{%
We did not grant immortality to any human being before you. Should you die, are they then the immortal?\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdxviii{%
Every soul will taste death. We burden you with adversity and prosperity—a test. And to Us you will be returned.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdxix{%
When those who disbelieve see you, they treat you only with ridicule: “Is this the one who mentions your gods?” And they reject the mention of the Merciful.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdxx{%
The human being was created of haste. I will show you My signs, so do not seek to rush Me.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdxxi{%
And they say, “When will this promise come true, if you are truthful?”\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdxxii{%
If those who disbelieve only knew, when they cannot keep the fire off their faces and off their backs, and they will not be helped.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdxxiii{%
In fact, it will come upon them suddenly, and bewilder them. They will not be able to repel it, and they will not be reprieved.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdxxiv{%
Messengers before you were also ridiculed, but those who jeered were surrounded by what they had ridiculed.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdxxv{%
Say, “Who guards you against the Merciful by night and by day?” But they turn away from the mention of their Lord.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdxxvi{%
Or do they have gods who can defend them against Us? They cannot help themselves, nor will they be protected from Us.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdxxvii{%
We have given these enjoyments, and their ancestors, until time grew long upon them. Do they not see how We gradually reduce the land from its extremities? Are they then the victors?\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdxxviii{%
Say, “I am warning you through inspiration.” But the deaf cannot hear the call when they are being warned.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdxxix{%
And when a breath of your Lord’s punishment touches them, they say, “Woe to us, we were truly wicked.”\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdxxx{%
We will set up the scales of justice for the Day of Resurrection, so that no soul will suffer the least injustice. And even if it be the weight of a mustard-seed, We will bring it up. Sufficient are We as Reckoners.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdxxxi{%
We gave Moses and Aaron the Criterion, and illumination, and a reminder for the righteous.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdxxxii{%
Those who fear their Lord in private, and are apprehensive of the Hour.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdxxxiii{%
This too is a blessed message that We revealed. Are you going to deny it?\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdxxxiv{%
We gave Abraham his integrity formerly, and We knew him well.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdxxxv{%
When he said to his father and his people, “What are these statues to which you are devoted?”\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdxxxvi{%
They said, “We found our parents worshiping them.”\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdxxxvii{%
He said, “You and your parents are in evident error.”\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdxxxviii{%
They said, “Are you telling us the truth, or are you just playing?”\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdxxxix{%
He said, “Your Lord is the Lord of the heavens and the earth, the One who created them, and I bear witness to that.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdxl{%
“By God, I will have a plan for your statues after you have gone away.”\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdxli{%
So he reduced them into pieces, except for their biggest, that they may return to it.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdxlii{%
They said, “Who did this to our gods? He is certainly one of the wrongdoers.”\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdxliii{%
They said, “We heard a youth mentioning them. He is called Abraham.”\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdxliv{%
They said, “Bring him before the eyes of the people, so that they may witness.”\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdxlv{%
They said, “Are you the one who did this to our gods, O Abraham?”\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdxlvi{%
He said, “But it was this biggest of them that did it. Ask them, if they can speak.”\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdxlvii{%
Then they turned to one another, and said, “You yourselves are the wrongdoers.”\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdxlviii{%
But they reverted to their old ideas: “You certainly know that these do not speak.”\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdxlix{%
He said, “Do you worship, instead of God, what can neither benefit you in anything, nor harm you?\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdl{%
Fie on you, and on what you worship instead of God. Do you not understand?”\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdli{%
They said, “Burn him and support your gods, if you are going to act.”\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdlii{%
We said, “O fire, be coolness and safety upon Abraham.”\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdliii{%
They planned to harm him, but We made them the worst losers.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdliv{%
And We delivered him, and Lot, to the land that We blessed for all people.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdlv{%
And We granted him Isaac and Jacob as a gift; and each We made righteous.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdlvi{%
And We made them leaders, guiding by Our command; and We inspired them to do good works, and to observe the prayer, and to give out charity. They were devoted servants to Us.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdlvii{%
And Lot—We gave him judgment and knowledge, and We delivered him from the town that practiced the abominations. They were wicked and perverted people.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdlviii{%
And We admitted him into Our mercy; for He was one of the righteous.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdlix{%
And Noah, when he called before. So We answered him, and delivered him and his family from the great disaster.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdlx{%
And We supported him against the people who rejected Our signs. They were an evil people, so We drowned them all.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdlxi{%
And David and Solomon, when they gave judgment in the case of the field, when some people’s sheep wandered therein by night; and We were witnesses to their judgment.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdlxii{%
And so We made Solomon understand it, and to each We gave wisdom and knowledge. And We subjected the mountains along with David to sing Our praises, and the birds as well—surely We did.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmdlxiii{%
And We taught him the making of shields for you, to protect you from your violence. Are you, then, appreciative?\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmdlxiv{%
And to Solomon the stormy wind, blowing at His command towards the land that We have blessed. We are aware of everything.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmdlxv{%
And of the devils were some that dived for him, and performed other, lesser tasks. But We kept them restrained.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmdlxvi{%
And Job, when he cried out to his Lord: “Great harm has afflicted me, and you are the Most Merciful of the merciful.”\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmdlxvii{%
So We answered him, lifted his suffering, and restored his family to him, and their like with them—a mercy from Us, and a reminder for the worshipers.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmdlxviii{%
And Ishmael, and Enoch, and Ezekiel; each was one of the steadfast.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmdlxix{%
And We admitted them into Our mercy. They were among the righteous.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmdlxx{%
And Jonah, when he stormed out in fury, thinking We had no power over him. But then He cried out in the darkness, “There is no god but You! Glory to You! I was one of the wrongdoers!”\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmdlxxi{%
So We answered him, and saved him from the affliction. Thus We save the faithful.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmdlxxii{%
And Zechariah, when he called out to his Lord, “My Lord, do not leave me alone, even though you are the Best of heirs.”\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmdlxxiii{%
So We answered him, and gave him John. And We cured his wife for him. They used to vie in doing righteous deeds, and used to call on Us in love and awe, and they used to humble themselves to Us.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmdlxxiv{%
And she who guarded her virginity. We breathed into her of Our spirit, and made her and her son a sign to the world.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmdlxxv{%
This community of yours is one community, and I am your Lord, so worship Me.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmdlxxvi{%
But they splintered themselves into factions. They will all return to Us.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmdlxxvii{%
Whoever does righteous deeds, and is a believer, his effort will not be denied. We are writing it down for him.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmdlxxviii{%
There is a ban on the town that We had destroyed—that they will not return.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmdlxxix{%
Until, when Gog and Magog are let loose, and they swarm down from every mound.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmdlxxx{%
The promise of truth has drawn near. The eyes of those who disbelieved will stare in horror: “Woe to us. We were oblivious to this. In fact, we were wrongdoers.”\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmdlxxxi{%
You and what you worship besides God are fuel for Hell. You will descend into it.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmdlxxxii{%
Had these been gods, they would not have descended into it. All will abide in it.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmdlxxxiii{%
In it they will wail. In it they will not hear.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmdlxxxiv{%
As for those who deserved goodness from Us—these will be kept away from it.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmdlxxxv{%
They will not hear its hissing, and they will forever abide in what their hearts desire.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmdlxxxvi{%
The Supreme Fear will not worry them, and the angels will receive them: “This is your Day which you were promised.”\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmdlxxxvii{%
On the Day when We fold the heaven, like the folding of a book. Just as We began the first creation, We will repeat it—a promise binding on Us. We will act.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmdlxxxviii{%
We have written in the Psalms, after the Reminder, that the earth will be inherited by My righteous servants.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmdlxxxix{%
Indeed, in this is a message for people who worship.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmdxc{%
We did not send you except as mercy to mankind.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmdxci{%
Say, “It is revealed to me that your God is One God. Are you going to submit?”\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmdxcii{%
But if they turn away, say, “I have informed you sufficiently. Although I do not know whether what you are promised is near or far.”\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmdxciii{%
He knows what is said openly, and He knows what you conceal.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmdxciv{%
“And I do not know whether it is perhaps a trial for you, and an enjoyment for a while.”\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmdxcv{%
He said, “My Lord, judge with justice.” And, “Our Lord is the Gracious, Whose help is sought against what you allege.”\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmdxcvi{%
\basmalahen O people, be conscious of your Lord. The quaking of the Hour is a tremendous thing.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdxcvii{%
On the Day when you will see it: every nursing mother will discard her infant, and every pregnant woman will abort her load, and you will see the people drunk, even though they are not drunk—but the punishment of God is severe.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdxcviii{%
Among the people is he who argues about God without knowledge, and follows every defiant devil.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdxcix{%
It was decreed for him, that whoever follows him—he will misguide him, and lead him to the torment of the Blaze.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdc{%
O people! If you are in doubt about the Resurrection—We created you from dust, then from a small drop, then from a clinging clot, then from a lump of flesh, partly developed and partly undeveloped. In order to clarify things for you. And We settle in the wombs whatever We will for a designated term, and then We bring you out as infants, until you reach your full strength. And some of you will pass away, and some of you will be returned to the vilest age, so that he may not know, after having known. And you see the earth still; but when We send down water on it, it vibrates, and swells, and grows all kinds of lovely pairs.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdci{%
That is because God is the truth, and because He gives life to the dead, and because He is Capable of everything.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdcii{%
And because the Hour is coming—there is no doubt about it—and because God will resurrect those in the graves.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdciii{%
And among the people is he who argues about God without knowledge, or guidance, or an enlightening scripture.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdciv{%
Turning aside in contempt, to lead away from the path of God. He will have humiliation in this world, and on the Day of Resurrection We will make him taste the agony of burning.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdcv{%
That is for what your hands have advanced, and because God is not unjust to the servants.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdcvi{%
And among the people is he who worships God on edge. When something good comes his way, he is content with it. But when an ordeal strikes him, he makes a turnaround. He loses this world and the next. That is the obvious loss.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdcvii{%
He invokes, instead of God, what can neither harm him nor benefit him. That is the far straying.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdcviii{%
He invokes one whose harm is closer than his benefit. What a miserable master. What a miserable companion.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdcix{%
God will admit those who believe and do righteous deeds into Gardens beneath which rivers flow. God does whatever He wills.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdcx{%
Whoever thinks that God will not help him in this life and in the Hereafter—let him turn to heaven, then sever, and see if his cunning eliminates what enrages him.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdcxi{%
Thus We revealed it as clarifying signs, and God guides whomever He wills.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcxii{%
Those who believe, and those who are Jewish, and the Sabeans, and the Christians, and the Zoroastrians, and the Polytheists—God will judge between them on the Day of Resurrection. God is witness to all things.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcxiii{%
Do you not realize that to God prostrates everyone in the heavens and everyone on earth, and the sun, and the moon, and the stars, and the mountains, and the trees, and the animals, and many of the people? But many are justly deserving of punishment. Whomever God shames, there is none to honor him. God does whatever He wills.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcxiv{%
Here are two adversaries feuding regarding their Lord. As for those who disbelieve, garments of fire will be tailored for them, and scalding water will be poured over their heads.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcxv{%
Melting their insides and their skins.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcxvi{%
And they will have maces of iron.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcxvii{%
Whenever they try to escape the gloom, they will be driven back to it: “Taste the suffering of burning.”\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcxviii{%
But God will admit those who believe and do good deeds into Gardens beneath which rivers flow. They will be decorated therein with bracelets of gold and pearls, and their garments therein will be of silk.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcxix{%
They were guided to purity of speech. They were guided to the path of the Most Praised.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcxx{%
As for those who disbelieve and repel from God’s path and from the Sacred Mosque—which We have designated for all mankind equally, whether residing therein or passing through—and seek to commit sacrilege therein—We will make him taste of a painful punishment.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcxxi{%
We showed Abraham the location of the House: “Do not associate anything with Me; and purify My House for those who circle around, and those who stand to pray, and those who kneel and prostrate.”\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcxxii{%
And announce the pilgrimage to humanity. They will come to you on foot, and on every transport. They will come from every distant point.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcxxiii{%
That they may witness the benefits for themselves, and celebrate the name of God during the appointed days, for providing them with the animal livestock. So eat from it, and feed the unfortunate poor.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdcxxiv{%
Then let them perform their acts of cleansing, and fulfill their vows, and circle around the Ancient House.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcxxv{%
All that. Whoever venerates the sanctities of God—it is good for him with his Lord. All livestock are permitted to you, except what is recited to you. So stay away from the abomination of idols, and stay away from perjury.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcxxvi{%
Being true to God, without associating anything with Him. Whoever associates anything with God—it is as though he has fallen from the sky, and is snatched by the birds, or is swept away by the wind to a distant abyss.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdcxxvii{%
So it is. Whoever venerates the sacraments of God—it is from the piety of the hearts.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdcxxviii{%
In them are benefits for you until a certain time. Then their place is by the Ancient House.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdcxxix{%
We have appointed a rite for every nation, that they may commemorate God’s name over the livestock He has provided for them. Your God is One God, so to Him submit, and announce good news to the humble.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcxxx{%
Those whose hearts tremble when God is mentioned, and those who endure what has befallen them, and those who perform the prayer and spend from what We have provided for them.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcxxxi{%
We have made the animal offerings emblems of God for you. In them is goodness for you. So pronounce God’s name upon them as they line up. Then, when they have fallen on their sides, eat of them and feed the contented and the beggar. Thus We have subjected them to you, that you may be thankful.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcxxxii{%
Neither their flesh, nor their blood, ever reaches God. What reaches Him is the righteousness from you. Thus He subdued them to you, that you may glorify God for guiding you. And give good news to the charitable.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcxxxiii{%
God defends those who believe. God does not love any ungrateful traitor.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcxxxiv{%
Permission is given to those who are fought against, and God is Able to give them victory.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcxxxv{%
Those who were unjustly evicted from their homes, merely for saying, “Our Lord is God.” Were it not that God repels people by means of others: monasteries, churches, synagogues, and mosques—where the name of God is mentioned much—would have been demolished. God supports whoever supports Him. God is Strong and Mighty.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcxxxvi{%
Those who, when We empower them in the land, observe the prayer, and give regular charity, and command what is right, and forbid what is wrong. To God belongs the outcome of events.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcxxxvii{%
If they deny you—before them the people of Noah, and Aad, and Thamood also denied.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcxxxviii{%
And the people of Abraham, and the people of Lot.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcxxxix{%
And the inhabitants of Median. And Moses was denied. Then I reprieved those who disbelieved, but then I seized them. So how was My rejection?\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdcxl{%
How many a town have We destroyed while it was doing wrong? They lie in ruins; with stilled wells, and lofty mansions.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdcxli{%
Have they not journeyed in the land, and had minds to reason with, or ears to listen with? It is not the eyes that go blind, but it is the hearts, within the chests, that go blind.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdcxlii{%
And they ask you to hasten the punishment. But God never breaks His promise. A day with your Lord is like a thousand years of your count.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdcxliii{%
How many a town have I reprieved, although it was unjust? Then I seized it. To Me is the destination.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdcxliv{%
Say, “O people, I am only a plain warner to you.”\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdcxlv{%
Those who believe and work righteousness—for them is forgiveness and a generous provision.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdcxlvi{%
But those who strive against Our revelations—these are the inmates of Hell.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdcxlvii{%
We never sent a messenger before you, or a prophet, but when he had a desire Satan interfered in his wishes. But God nullifies what Satan interjects, and God affirms His revelations. God is Omniscient and Wise.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdcxlviii{%
In order to make Satan’s suggestions a trial for those whose hearts are diseased, and those whose hearts are hardened. The wrongdoers are in profound discord.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdcxlix{%
And so that those endowed with knowledge may know that it is the truth from your Lord, and so believe in it, and their hearts soften to it. God guides those who believe to a straight path.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdcl{%
Those who disbelieve will continue to be hesitant about it, until the Hour comes upon them suddenly, or there comes to them the torment of a desolate Day.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdcli{%
Sovereignty on that Day belongs to God; He will judge between them. Those who believe and do good deeds will be in the Gardens of Bliss.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdclii{%
But those who disbelieve and reject Our revelations—these will have a humiliating punishment.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdcliii{%
Those who emigrate in God’s cause, then get killed, or die, God will provide them with fine provisions. God is the Best of Providers.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdcliv{%
He will admit them an admittance that will please them. God is Knowing and Clement.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdclv{%
That is so! Whoever retaliates similarly to the affliction he was made to suffer, and then he is wronged again, God will definitely assist him. God is Pardoning and Forgiving.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdclvi{%
That is because God merges the night into the day, and He merges the day into the night, and because God is Hearing and Seeing.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdclvii{%
That is because God is the Reality, and what they invoke besides Him is vanity, and because God is the Sublime, the Grand.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdclviii{%
Do you not see that God sends down water from the sky, and the land becomes green? God is Kind and Aware.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdclix{%
To Him belongs everything in the heavens and everything on earth. God is the Rich, the Praised.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdclx{%
Do you not see that God made everything on earth subservient to you? How the ships sail at sea by His command? That He holds up the sky lest it falls on earth—except by His permission? God is Gracious towards the people, Most Merciful.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdclxi{%
And it is He who gives you life, then makes you die, then revives you. The human being is unappreciative.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdclxii{%
For every congregation We have appointed acts of devotion, which they observe. So do not let them dispute with you in this matter. And invite to your Lord; you are upon a straight guidance.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdclxiii{%
But if they dispute with you, say, “God is fully aware of what you do.”\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdclxiv{%
God will judge between you on the Day of Resurrection regarding what you disagree about.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdclxv{%
Do you not know that God knows everything in the heavens and the earth? This is in a book. That is easy for God.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdclxvi{%
Yet they worship, besides God, things for which He sent down no warrant, and what they have no knowledge of. There is no savior for the transgressors.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdclxvii{%
And when Our Clear Verses are recited to them, you will recognize disgust on the faces of those who disbelieve. They nearly assault those who recite to them Our Verses. Say, “Shall I inform you of something worse than that? The Fire! God has promised it to those who disbelieve. And what a wretched outcome!”\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdclxviii{%
O people! A parable is presented, so listen to it: Those you invoke besides God will never create a fly, even if they banded together for that purpose. And if the fly steals anything from them, they cannot recover it from it. Weak are the pursuer and the pursued.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdclxix{%
They do not value God as He should be valued. God is Strong and Powerful.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdclxx{%
God chooses messengers from among the angels, and from among the people. God is Hearing and Seeing.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdclxxi{%
He knows what is before them, and what is behind them. To God all matters are referred.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdclxxii{%
O you who believe! Kneel, and prostrate, and worship your Lord, and do good deeds, so that you may succeed.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdclxxiii{%
And strive for God, with the striving due to Him. He has chosen you, and has not burdened you in religion—the faith of your father Abraham. It is he who named you Muslims before, and in this. So that the Messenger may be a witness over you, and you may be witnesses over the people. So pray regularly, and give regular charity, and cleave to God. He is your Protector. What an excellent Protector, and what an excellent Helper.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdclxxiv{%
\basmalahen Successful are the believers.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdclxxv{%
Those who are humble in their prayers.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdclxxvi{%
Those who avoid nonsense.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdclxxvii{%
Those who work for charity.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdclxxviii{%
Those who safeguard their chastity.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdclxxix{%
Except from their spouses, or their dependents—for then they are free from blame.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdclxxx{%
But whoever seeks anything beyond that—these are the transgressors.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdclxxxi{%
Those who are faithful to their trusts and pledges.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdclxxxii{%
Those who safeguard their prayers.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdclxxxiii{%
These are the inheritors.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdclxxxiv{%
Who will inherit Paradise, wherein they will dwell forever.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdclxxxv{%
We created man from an extract of clay.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdclxxxvi{%
Then We made him a seed, in a secure repository.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdclxxxvii{%
Then We developed the seed into a clot. Then We developed the clot into a lump. Then We developed the lump into bones. Then We clothed the bones with flesh. Then We produced it into another creature. Most Blessed is God, the Best of Creators.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdclxxxviii{%
Then, after that, you will die.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdclxxxix{%
Then, on the Day of Resurrection, you will be resurrected.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcxc{%
We created above you seven pathways, and We are never heedless of the creation.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcxci{%
And We sent down water from the sky in proper quantity, and settled it in the ground, and We are Able to take it away.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcxcii{%
With it We produce for you gardens of palms and vines, yielding abundant fruit for you to eat.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcxciii{%
And a tree springing out of Mount Sinai, producing oil, and seasoning for those who eat.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcxciv{%
And there is a lesson for you in livestock: We give you to drink from what is in their bellies, and you have many benefits in them, and from them you eat.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcxcv{%
And on them, and on the ships, you are transported.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcxcvi{%
We sent Noah to his people. He said, “O my people, worship God, you have no deity other than Him. Will you not take heed?”\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcxcvii{%
But the notables of his people, who disbelieved, said, “This is nothing but a human like you, who wants to gain superiority over you. Had God willed, He would have sent down angels. We never heard of this from our forefathers of old.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcxcviii{%
He is nothing but a man possessed. Just ignore him for a while.”\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcxcix{%
He said, “My Lord, help me, for they have rejected me.”\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcc{%
So We inspired him: “Build the Ark under Our observation and by Our inspiration. And when Our decree comes to pass, and the oven boils over, load into it two pairs of every kind, together with your family, except those of them against whom the word has already been pronounced. And do not speak to me concerning those who did wrong; for they are to be drowned.”\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcci{%
Then, when you and those with you are settled in the Ark, say, “Praise be to God, who has saved us from the wrongdoing people.”\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdccii{%
And say, “My Lord, land me with a blessed landing, as you are the best of transporters.”\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcciii{%
Surely in that are signs. We are always testing.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcciv{%
Then, after them, We established another generation.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdccv{%
And We sent among them a messenger from themselves: “Serve God. You have no god other than Him. Will you not be cautious?”\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdccvi{%
But the dignitaries of his people, those who disbelieved and denied the meeting of the Hereafter, and We had indulged them in the present life, said, “This is nothing but a human like you; he eats what you eat, and he drinks what you drink.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdccvii{%
If you obey a human being like yourselves, then you will be losers.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdccviii{%
Does he promise you that when you have died and become dust and bones, you will be brought out?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdccix{%
Farfetched, farfetched is what you are promised.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdccx{%
There is nothing but our life in this world. We die, and we live, and we are not resurrected.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdccxi{%
He is nothing but a man, making up lies about God. We have no faith in him.”\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdccxii{%
He said, “My Lord, help me, for they have rejected me.”\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdccxiii{%
He said, “Soon they will be filled with regret.”\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdccxiv{%
Then the Blast struck them, justifiably, and We turned them into scum. So away with the wicked people.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdccxv{%
Then, after them, We raised other generations.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdccxvi{%
No nation can advance its time, nor can they postpone it.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdccxvii{%
Then We sent Our messengers in succession. Every time a messenger came to his community, they called him a liar. So We made them follow one another, and made them history. So away with a people who do not believe.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdccxviii{%
Then We sent Moses and his brother Aaron, with Our signs and a clear authority.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdccxix{%
To Pharaoh and his nobles, but they turned arrogant. They were oppressive people.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdccxx{%
They said, “Are we to believe in two mortals like us, and their people are our slaves?”\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdccxxi{%
So they called them liars, and thus were among those destroyed.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdccxxii{%
And We gave Moses the Scripture, that they may be guided.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdccxxiii{%
And We made Mary’s son and his mother a sign, and We sheltered them on high ground with security and flowing springs.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdccxxiv{%
O messengers, eat of the good things, and act with integrity. I am aware of what you do.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdccxxv{%
This nation of yours is one nation, and I am your Lord, so fear Me.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdccxxvi{%
But they tore themselves into sects; each party happy with what they have.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdccxxvii{%
So leave them in their bewilderment until a time.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdccxxviii{%
Do they assume that, in furnishing them with wealth and children.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdccxxix{%
We race to give them the good things? In fact, they have no idea.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdccxxx{%
Those who, from awe of their Lord, are fearful.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdccxxxi{%
And those who believe in their Lord’s Verses.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdccxxxii{%
And those who associate no partners with their Lord.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdccxxxiii{%
And those who give what they give, while their hearts quake, knowing that to their Lord they will return.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdccxxxiv{%
It is they who race towards goodness. It is they who will reach it first.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdccxxxv{%
We never burden any soul beyond its capacity. And with Us is a record that tells the truth, and they will not be wronged.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdccxxxvi{%
But their hearts are puzzled because of this; and they have deeds that do not conform to this, which they continue to perpetrate.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdccxxxvii{%
Until, when We seize the decadent among them with torment, they begin to groan.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdccxxxviii{%
Do not groan today. You will receive no help from Us.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdccxxxix{%
My Verses were recited to you, but you turned back on your heels.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdccxl{%
Arrogant towards it—talked nonsense about it—disregarded it.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdccxli{%
Have they not pondered the Word? Or has there come to them what came not to their forefathers of old?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdccxlii{%
Or is it that they did not recognize their messenger, so they are denying him?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdccxliii{%
Or do they say, “He is possessed?” In fact, he brought them the truth, but most of them hate the truth.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdccxliv{%
If the truth conformed to their desires, the heavens, the earth, and everyone in them would have gone to ruin. In fact, We have given them their message, but they keep avoiding their message.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdccxlv{%
Or are you asking them for a payment? The revenue from your Lord is better, and He is the Best of providers.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdccxlvi{%
You are inviting them to a straight path.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdccxlvii{%
But those who do not believe in the Hereafter are swerving from the path.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdccxlviii{%
Even if We had mercy on them, and relieved their problems, they would still blindly persist in their defiance.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdccxlix{%
We have already gripped them with suffering, but they did not surrender to their Lord, nor did they humble themselves.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdccl{%
Until, when We have opened before them a gate of intense agony, at once they will despair.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdccli{%
It is He who produced for you the hearing, and the eyesight, and the feelings. But little gratitude you show.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdcclii{%
And it is He who multiplied you on earth, and to Him you will be gathered.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmdccliii{%
And it is He who gives life and brings death, and to Him is the alternation of night and day. Do you not understand?\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmdccliv{%
But they say the like of what the ancients said.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmdcclv{%
They say, “After we have died, and become dust and bones, will we be resurrected?\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmdcclvi{%
We were promised this before—we and our ancestors—these are nothing but legends of the ancients.”\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmdcclvii{%
Say, “To whom does the earth belong, and everyone in it, if you happen to know?”\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmdcclviii{%
They will say, “To God.” Say, “Will you not reflect?”\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmdcclix{%
Say, “Who is the Lord of the seven heavens, and Lord of the Splendid Throne?”\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmdcclx{%
They will say, “To God.” Say, “Will you not become righteous?”\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmdcclxi{%
Say, “In whose hand is the dominion of all things, and He protects and cannot be protected from, if you happen to know?”\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmdcclxii{%
They will say, “To God.” Say, “Then are you bewitched?”\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmdcclxiii{%
In fact, We have given them the truth, and they are liars.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmdcclxiv{%
God has never begotten a son, nor is there any god besides Him. Otherwise, each god would have taken away what it has created, and some of them would have gained supremacy over others. Glory be to God, far beyond what they describe.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmdcclxv{%
The Knower of the hidden and the manifest. He is exalted, far above what they associate.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmdcclxvi{%
Say, “My Lord, if You would show me what they are promised.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmdcclxvii{%
My Lord, do not place me among the wicked people.”\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmdcclxviii{%
We are surely Able to show you what We promise them.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmdcclxix{%
Repel evil by what is better. We are aware of what they describe.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmdcclxx{%
And say, “My Lord, I seek refuge with You from the urgings of the devils.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmdcclxxi{%
And I seek refuge with You, my Lord, lest they become present.”\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmdcclxxii{%
Until, when death comes to one of them, he says, “My Lord, send me back.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmdcclxxiii{%
That I may do right in what I have neglected.” By no means! It is just a word that he utters. And behind them is a barrier, until the Day they are resurrected.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmdcclxxiv{%
When the Horn is blown, no relations between them will exist on that Day, and they will not ask after one another.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmdcclxxv{%
Those whose scales are heavy—those are the successful.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmdcclxxvi{%
But those whose scales are light—those are they who have lost their souls; in Hell they will dwell forever.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmdcclxxvii{%
The Fire lashes their faces, and therein they grimace.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmdcclxxviii{%
“Were not My revelations recited to you, and you kept on rejecting them?”\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmdcclxxix{%
They will say, “Our Lord, our wretchedness prevailed over us, and we were a people astray.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmdcclxxx{%
Our Lord! Bring us out of this. If we ever returned, we would truly be evil.”\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmdcclxxxi{%
He will say, “Be despised therein, and do not speak to Me.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmdcclxxxii{%
There was a group of My servants who would say, `Our Lord, we have believed, so forgive us, and have mercy on us; You are the Best of the merciful.'\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmdcclxxxiii{%
But you made then a target of ridicule, until they made you forget My remembrance; and you used to laugh at them.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmdcclxxxiv{%
Today, I have rewarded them for their endurance. They are the ones who are the triumphant.”\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmdcclxxxv{%
He will say, “How many years did you remain on earth?”\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmdcclxxxvi{%
They will say, “We remained a day, or part of a day; but ask those who keep count.”\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmdcclxxxvii{%
He will say, “You remained only for a little while, if you only knew.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmdcclxxxviii{%
Did you think that We created you in vain, and that to Us you will not be returned?”\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmdcclxxxix{%
So Exalted is God, the Ruler, the Real. There is no god except He, the Lord of the Noble Throne.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmdccxc{%
Whoever invokes another god besides God—he has no proof thereof—his reckoning rests with his Lord. The disbelievers will not succeed.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmdccxci{%
And say, “My Lord, forgive and have mercy, for You are the Best of the merciful.”\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmdccxcii{%
\basmalahen A chapter that We have revealed, and made obligatory, and revealed in it clear Verses, that you may take heed.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdccxciii{%
The adulteress and the adulterer—whip each one of them a hundred lashes, and let no pity towards them overcome you regarding God’s Law, if you believe in God and the Last Day. And let a group of believers witness their punishment.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdccxciv{%
The adulterer shall marry none but an adulteress or an idolatress; and the adulteress shall marry none but an adulterer or an idolater. That has been prohibited for the believers.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdccxcv{%
Those who accuse chaste women, then cannot bring four witnesses, whip them eighty lashes, and do not ever accept their testimony. For these are the immoral.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdccxcvi{%
Except for those who repent afterwards, and reform; for God is Forgiving and Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdccxcvii{%
As for those who accuse their own spouses, but have no witnesses except themselves, the testimony of one of them is equivalent to four testimonies, if he swears by God that he is truthful.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdccxcviii{%
And the fifth time, that God’s curse be upon him, if he is a liar.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdccxcix{%
But punishment shall be averted from her, if she swears four times by God, that he is a liar.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdccc{%
And the fifth time, that God’s wrath be upon her, if he is truthful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdccci{%
Were it not for God’s grace upon you, and His mercy, and that God is Conciliatory and Wise.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdcccii{%
Those who perpetrated the slander are a band of you. Do not consider it bad for you, but it is good for you. Each person among them bears his share in the sin. As for him who played the major role—for him is a terrible punishment.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdccciii{%
Why, when you heard about it, the believing men and women did not think well of one another, and say, “This is an obvious lie”?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdccciv{%
Why did they not bring four witnesses to testify to it? If they fail to bring the witnesses, then in God’s sight, they are liars.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdcccv{%
Were it not for God’s favor upon you, and His mercy, in this world and the Hereafter, you would have suffered a great punishment for what you have ventured into.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdcccvi{%
When you rumored it with your tongues, and spoke with your mouths what you had no knowledge of, and you considered it trivial; but according to God, it is serious.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdcccvii{%
When you heard it, you should have said, “It is not for us to repeat this. By Your glory, this is a serious slander.”\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcccviii{%
God cautions you never to return to the like of it, if you are believers.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcccix{%
God explains the Verses to you. God is Knowing and Wise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcccx{%
Those who love to see immorality spread among the believers—for them is a painful punishment, in this life and in the Hereafter. God knows, and you do not know.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcccxi{%
Were it not for God’s grace upon you, and His mercy, and that God is Clement and Merciful.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcccxii{%
O you who believe! Do not follow Satan’s footsteps. Whoever follows Satan’s footsteps—he advocates obscenity and immorality. Were it not for God’s grace towards you, and His mercy, not one of you would have been pure, ever. But God purifies whomever He wills. God is All-Hearing, All-Knowing.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcccxiii{%
Those of you who have affluence and means should not refuse to give to the relatives, and the needy, and the emigrants for the sake of God. And let them pardon, and let them overlook. Do you not love for God to pardon you? God is All-Forgiving, Most Merciful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcccxiv{%
Those who slander honorable, innocent, believing women are cursed in this life and in the Hereafter. They will have a terrible punishment.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcccxv{%
On the Day when their tongues, and their hands, and their feet will testify against them regarding what they used to do.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcccxvi{%
On that Day, God will pay them their account in full, and they will know that God is the Evident Reality.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcccxvii{%
Bad women are for bad men, and bad men are for bad women, and good women are for good men, and good men are for good women. Those are acquitted of what they say. There is forgiveness for them, and a generous provision.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcccxviii{%
O you who believe! Do not enter homes other than your own, until you have asked permission and greeted their occupants. That is better for you, that you may be aware.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcccxix{%
And if you find no one in them, do not enter them until you are given permission. And if it is said to you, “Turn back,” then turn back. That is more proper for you. God is aware of what you do.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdcccxx{%
There is no blame on you for entering uninhabited houses, in which are belongings of yours. God knows what you reveal and what you conceal.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcccxxi{%
Tell the believing men to restrain their looks, and to guard their privates. That is purer for them. God is cognizant of what they do.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcccxxii{%
And tell the believing women to restrain their looks, and to guard their privates, and not display their beauty except what is apparent thereof, and to draw their coverings over their breasts, and not expose their beauty except to their husbands, their fathers, their husbands' fathers, their sons, their husbands' sons, their brothers, their brothers' sons, their sisters' sons, their women, what their right hands possess, their male attendants who have no sexual desires, or children who are not yet aware of the nakedness of women. And they should not strike their feet to draw attention to their hidden beauty. And repent to God, all of you believers, so that you may succeed.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdcccxxiii{%
And wed the singles among you, and those who are fit among your servants and maids. If they are poor, God will enrich them from His bounty. God is All-Encompassing, All-Knowing.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdcccxxiv{%
And let those who do not find the means to marry abstain, until God enriches them from His bounty. If any of your servants wish to be freed, grant them their wish, if you recognize some good in them. And give them of God’s wealth which he has given you. And do not compel your girls to prostitution, seeking the materials of this life, if they desire to remain chaste. Should anyone compel them—after their compulsion, God is Forgiving and Merciful.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdcccxxv{%
We have sent down to you clarifying revelations, and examples of those who passed on before you, and advice for the righteous.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcccxxvi{%
God is the Light of the heavens and the earth. The allegory of His light is that of a pillar on which is a lamp. The lamp is within a glass. The glass is like a brilliant planet, fueled by a blessed tree, an olive tree, neither eastern nor western. Its oil would almost illuminate, even if no fire has touched it. Light upon Light. God guides to His light whomever He wills. God thus cites the parables for the people. God is cognizant of everything.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcccxxvii{%
In houses which God has permitted to be raised, and His name is celebrated therein. He is glorified therein, morning and evening.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcccxxviii{%
By men who neither trading nor commerce distracts them from God’s remembrance, and from performing the prayers, and from giving alms. They fear a Day when hearts and sights are overturned.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcccxxix{%
God will reward them according to the best of what they did, and He will increase them from His bounty. God provides for whomever He wills without reckoning.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcccxxx{%
As for those who disbelieve, their works are like a mirage in a desert. The thirsty assumes it is to be water. Until, when he has reached it, he finds it to be nothing, but there he finds God, Who settles his account in full. God is swift in reckoning.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcccxxxi{%
Or like utter darkness in a vast ocean, covered by waves, above which are waves, above which is fog. Darkness upon darkness. If he brings out his hand, he will hardly see it. He to whom God has not granted a light has no light.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcccxxxii{%
Do you not realize that God is glorified by whatever is in the heavens and the earth, and even by the birds in formation? Each knows its prayer and its manner of praise. God knows well what they do.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcccxxxiii{%
To God belongs the dominion of the heavens and the earth, and to God is the ultimate return.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcccxxxiv{%
Have you not seen how God propels the clouds, then brings them together, then piles them into a heap, and you see rain drops emerging from its midst? How He brings down loads of hail from the sky, striking with it whomever He wills, and diverting it from whomever He wills? The flash of its lightening almost snatches the sight away.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcccxxxv{%
God alternates the night and the day. In that is a lesson for those who have insight.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdcccxxxvi{%
God created every living creature from water. Some of them crawl on their bellies, and some walk on two feet, and others walk on four. God creates whatever He wills. God is Capable of everything.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdcccxxxvii{%
We sent down enlightening revelations, and God guides whomever He wills to a straight path.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdcccxxxviii{%
And they say, “We have believed in God and the Messenger, and we obey,” but some of them turn away afterwards. These are not believers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdcccxxxix{%
And when they are called to God and His Messenger, in order to judge between them, some of them refuse.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdcccxl{%
But if justice is on their side, they accept it willingly.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdcccxli{%
Is there sickness in their hearts? Or are they suspicious? Or do they fear that God may do them injustice? Or His Messenger? In fact, they themselves are the unjust.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdcccxlii{%
The response of the believers, when they are called to God and His Messenger in order to judge between them, is to say, “We hear and we obey.” These are the successful.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdcccxliii{%
Whoever obeys God and His Messenger, and fears God, and is conscious of Him—these are the winners.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdcccxliv{%
And they swear by God with their solemn oaths, that if you commanded them, they would mobilize. Say, “Do not swear. Obedience will be recognized. God is experienced with what you do.”\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdcccxlv{%
Say, “Obey God and obey the Messenger.” But if they turn away, then he is responsible for his obligations, and you are responsible for your obligations. And if you obey him, you will be guided. It is only incumbent on the Messenger to deliver the Clarifying Message.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdcccxlvi{%
God has promised those of you who believe and do righteous deeds, that He will make them successors on earth, as He made those before them successors, and He will establish for them their religion—which He has approved for them—and He will substitute security in place of their fear. They worship Me, never associating anything with Me. But whoever disbelieves after that—these are the sinners.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdcccxlvii{%
Pray regularly, and give regular charity, and obey the Messenger, so that you may receive mercy.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdcccxlviii{%
Never think that those who disbelieve can escape on earth. Their place is the Fire; a miserable destination.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdcccxlix{%
O you who believe! Permission must be requested by your servants and those of you who have not reached puberty. On three occasions: before the Dawn Prayer, and at noon when you change your clothes, and after the Evening Prayer. These are three occasions of privacy for you. At other times, it is not wrong for you or them to intermingle with one another. God thus clarifies the revelations for you. God is Knowledgeable and Wise.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdcccl{%
When the children among you reach puberty, they must ask permission, as those before them asked permission. God thus clarifies His revelations for you. God is Knowledgeable and Wise.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdcccli{%
Women past the age of childbearing, who have no desire for marriage, commit no wrong by taking off their outer clothing, provided they do not flaunt their finery. But to maintain modesty is better for them. God is Hearing and Knowing.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdccclii{%
There is no blame on the blind, nor any blame on the lame, nor any blame on the sick, nor on yourselves for eating at your homes, or your fathers’ homes, or your mothers’ homes, or your brothers’ homes, or your sisters’ homes, or the homes of your paternal uncles, or the homes of your paternal aunts, or the homes of your maternal uncles, or the homes of your maternal aunts, or those whose keys you own, or the homes of your friends. You commit no wrong by eating together or separately. But when you enter any home, greet one another with a greeting from God, blessed and good. God thus explains the revelations for you, so that you may understand.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdcccliii{%
The believers are those who believe in God and His Messenger, and when they are with him for a matter of common interest, they do not leave until they have asked him for permission. Those who ask your permission are those who believe in God and His Messenger. So when they ask your permission to attend to some affair of theirs, give permission to any of them you wish, and ask God’s forgiveness for them. God is Forgiving and Merciful.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdcccliv{%
Do not address the Messenger in the same manner you address one another. God knows those of you who slip away using flimsy excuses. So let those who oppose his orders beware, lest an ordeal strikes them, or a painful punishment befalls them.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdccclv{%
Surely, to God belongs everything in the heavens and the earth. He knows what you are about. And on the Day they are returned to Him, He will inform them of what they did. God has full knowledge of all things.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdccclvi{%
\basmalahen Blessed is He who sent down the Criterion upon His servant, to be a warning to humanity.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdccclvii{%
He to whom belongs the kingdom of the heavens and the earth, who took to Himself no son, who never had a partner in His kingship; who created everything and determined its measure.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdccclviii{%
And yet, instead of Him, they produce for themselves gods that create nothing, but are themselves created; that have no power to harm or benefit themselves; and no power over life, death, or resurrection.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdccclix{%
Those who disbelieve say, “This is nothing but a lie that he made up, and others have helped him at it.” They have committed an injustice and a perjury.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdccclx{%
And they say, “Tales of the ancients; he wrote them down; they are dictated to him morning and evening.”\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdccclxi{%
Say, “It was revealed by He who knows the Secret in the heavens and the earth. He is always Forgiving and Merciful.”\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdccclxii{%
And they say, “What sort of messenger is this, who eats food, and walks in the marketplaces? If only an angel was sent down with him, to be alongside him a warner.”\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdccclxiii{%
Or, “If only a treasure was dropped on him.” Or, “If only he had a garden from which he eats.” The evildoers also say, “You are following but a man under spell.”\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdccclxiv{%
Look how they invent examples for you. They have gone astray, and cannot find a way.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdccclxv{%
Blessed is He who, if He wills, can provide you with better than that—gardens beneath which rivers flow—and He will give you palaces.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdccclxvi{%
In fact, they have denied the Hour, and We have prepared for those who deny the Hour a Blaze.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdccclxvii{%
When it sees them from a distant place, they will hear it raging and roaring.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdccclxviii{%
And when they are thrown into it, into a tight place, shackled, they will plead there for death.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdccclxix{%
“Do not plead for one death today, but plead for a great many deaths.”\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdccclxx{%
Say, “Is this better, or the Garden of Eternity promised to the righteous? It is for them a reward and a destination.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdccclxxi{%
They will have therein whatever they desire, forever. That is upon your Lord a binding promise.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdccclxxii{%
On the Day when He gathers them, and what they worshiped besides God, He will say, “Was it you who misled these servants of Mine, or was it they who lost the way?”\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdccclxxiii{%
They will say, “Glory be to You. It was not for us to take any lords besides You. But you gave them enjoyments, and their ancestors, until they forgot the Message, and became ruined people.”\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdccclxxiv{%
They have denied you because of what you say; so you can neither avert, nor help. Whoever among you commits injustice, We will make him taste a grievous punishment.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdccclxxv{%
We never sent any messengers before you, but they ate food and walked in the marketplaces. And We made some of you tempters for one another—will you be patient? Your Lord is always Observing.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdccclxxvi{%
Those who do not expect to meet Us say, “If only the angels were sent down to us, or we could see our Lord.” They have grown arrogant within themselves, and have become excessively defiant.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdccclxxvii{%
On the Day when they see the angels—there will be no good news for sinners on that Day; and they will say, “A protective refuge.”\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdccclxxviii{%
We will proceed to the works they did, and will turn them into scattered dust.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdccclxxix{%
The companions of Paradise on that Day will be better lodged, and more fairly accommodated.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdccclxxx{%
The Day when the sky is cleft with clouds, and the angels are sent down in streams.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdccclxxxi{%
On that Day, true sovereignty will belong to the Merciful, and it will be a difficult Day for the disbelievers.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdccclxxxii{%
On that Day, the wrongdoer will bite his hands, and say, “If only I had followed the way with the Messenger.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdccclxxxiii{%
Oh, woe to me; I wish I never took so-and-so for a friend.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdccclxxxiv{%
He led me away from the Message after it had come to me; for Satan has always been a betrayer of man.”\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdccclxxxv{%
And the Messenger will say, “My Lord, my people have abandoned this Quran.”\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdccclxxxvi{%
Likewise, to every prophet We assign enemies from among the wicked. But your Lord suffices as a Guide and Savior.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdccclxxxvii{%
Those who disbelieve say, “Why was the Quran not revealed to him at once?” Thus in order to strengthen your heart thereby, and We revealed it in stages.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdccclxxxviii{%
Whatever argument they come to you with, We provide you with the truth, and a better exposition.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdccclxxxix{%
Those who are herded into Hell on their faces—those are in a worse position, and further astray from the way.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcccxc{%
We gave Moses the Scripture, and appointed his brother Aaron as his assistant.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcccxci{%
We said, “Go to the people who rejected Our signs,” and We destroyed them completely.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcccxcii{%
And the people of Noah: when they rejected the messengers, We drowned them, and made them a lesson for mankind. We have prepared for the wrongdoers a painful retribution.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcccxciii{%
And Aad, and Thamood, and the inhabitants of Arras, and many generations in between.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcccxciv{%
To each We presented the parables; and each We devastated utterly.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcccxcv{%
And they came upon the city that was drenched by the terrible rain. Did they not see it? But they do not expect resurrection.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcccxcvi{%
And when they see you, they take you for nothing but mockery: “Is this the one God sent as a messenger?”\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcccxcvii{%
“He nearly led us away from our gods, had we not patiently adhered to them.” But they will know, when they witness the torment, who is further away from the way.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcccxcviii{%
Have you seen him who chose his desire as his god? Would you be an agent for him?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcccxcix{%
Or do you assume that most of them hear or understand? They are just like cattle, but even more errant in their way.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcm{%
Do you not see how your Lord extends the shadow? Had He willed, He could have made it still. And We made the sun a pointer to it.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcmi{%
Then We withdraw it towards Us gradually.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcmii{%
And it is He who made the night a covering for you, and sleep for rest; and He made the day a revival.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcmiii{%
And it is He who sends the winds, bringing advance news of His mercy; and We send down from the sky pure water.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcmiv{%
To revive dead lands thereby, and to provide drink for the multitude of animals and humans We created.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcmv{%
We have circulated it among them, that they may reflect, but most people persist in thanklessness.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcmvi{%
Had We willed, We could have sent to every town a warner.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcmvii{%
So do not obey the disbelievers, but strive against them with it, a mighty struggle.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcmviii{%
And it is He who merged the two seas; this one fresh and sweet, and that one salty and bitter; and He placed between them a barrier, and an impassable boundary.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcmix{%
And it is He who, from fluid, created the human being. Then He made relationships through marriage and mating. Your Lord is Omnipotent.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcmx{%
And yet, instead of God, they serve what neither profits them nor harms them. The disbeliever has always turned his back on his Lord.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcmxi{%
We sent you only as a herald of good news and a warner.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcmxii{%
Say, “I ask of you no payment for this—only that whoever wills may take a path to his Lord.”\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcmxiii{%
And put your trust in the Living, the One who never dies; and celebrate His praise. He suffices as the All-Informed Knower of the faults of His creatures.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcmxiv{%
He who created the heavens and the earth and everything between them in six days, then settled on the Throne. The Most Merciful. Ask about Him a well-informed.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcmxv{%
And when it is said to them, “Bow down to the Merciful,” they say, “And what is the Merciful? Are we to bow down to whatever you command us?” And it increases their aversion.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcmxvi{%
Blessed is He who placed constellations in the sky, and placed in it a lamp, and an illuminating moon.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcmxvii{%
And it is He who made the night and the day alternate—for whoever desires to reflect, or desires to show gratitude.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcmxviii{%
The servants of the Merciful are those who walk the earth in humility, and when the ignorant address them, they say, “Peace.”\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcmxix{%
And those who pass the night prostrating themselves to their Lord and standing up.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcmxx{%
And those who say, ‘‘Our Lord, avert from us the suffering of Hell, for its suffering is continuous.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcmxxi{%
It is indeed a miserable residence and destination.”\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcmxxii{%
And those who, when they spend, are neither wasteful nor stingy, but choose a middle course between that.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcmxxiii{%
And those who do not implore besides God any other god, and do not kill the soul which God has made sacred—except in the pursuit of justice—and do not commit adultery. Whoever does that will face penalties.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcmxxiv{%
The punishment will be doubled for him on the Day of Resurrection, and he will dwell therein in humiliation forever.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcmxxv{%
Except for those who repent, and believe, and do good deeds. These—God will replace their bad deeds with good deeds. God is ever Forgiving and Merciful.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcmxxvi{%
Whoever repents and acts righteously—has inclined towards God with repentance.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcmxxvii{%
And those who do not bear false witness; and when they come across indecencies, they pass by with dignity.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcmxxviii{%
And those who, when reminded of the revelations of their Lord, do not fall before them deaf and blind.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcmxxix{%
And those who say, “Our Lord, grant us delight in our spouses and our children, and make us a good example for the righteous.”\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcmxxx{%
Those will be awarded the Chamber for their patience, and will be greeted therein with greetings and peace.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcmxxxi{%
Abiding therein forever—it is an excellent residence and destination.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcmxxxii{%
Say, “What are you to my Lord without your prayers? You have denied the truth, and the inevitable will happen.”\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcmxxxiii{%
\basmalahen Ta, Seen, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcmxxxiv{%
These are the Verses of the Clarifying Book.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcmxxxv{%
Perhaps you will destroy yourself with grief, because they do not become believers.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcmxxxvi{%
If We will, We can send down upon them a sign from heaven, at which their necks will stay bent in humility.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcmxxxvii{%
No fresh reminder comes to them from the Most Merciful, but they turn their backs at it.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcmxxxviii{%
They have denied the truth, but soon will come to them the news of what they ridiculed.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcmxxxix{%
Have they not seen the earth, and how many beautiful pairs We produced therein?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcmxl{%
Surely in this is a sign, but most of them are not believers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcmxli{%
Most surely, your Lord is the Almighty, the Merciful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcmxlii{%
Your Lord called to Moses, “Go to the tyrannical people.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcmxliii{%
The people of Pharaoh. Will they not fear?”\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcmxliv{%
He said, “My Lord, I fear they will reject me.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcmxlv{%
And I become stressed, and my tongue is not fluent, so send Aaron too.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcmxlvi{%
And they have a charge against me, so I fear they will kill me.”\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcmxlvii{%
He said, “No. Go, both of you, with Our proofs. We will be with you, listening.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcmxlviii{%
Go to Pharaoh, and say, ‘We are the Messengers of the Lord of the Worlds.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmcmxlix{%
Let the Children of Israel go with us.'“\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmcml{%
He said, “Did we not raise you among us as a child, and you stayed among us for many of your years?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmcmli{%
And you committed that deed you committed, and you were ungrateful.”\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmcmlii{%
He said, “I did it then, when I was of those astray.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmcmliii{%
And I fled from you when I feared you; but my Lord gave me wisdom, and made me one of the messengers.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmcmliv{%
Is that the favor you taunt me with, although you have enslaved the Children of Israel?”\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmcmlv{%
Pharaoh said, “And what is the Lord of the Worlds?”\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmcmlvi{%
He said, “The Lord of the heavens and the earth, and everything between them, if you are aware.”\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmcmlvii{%
He said to those around him, “Do you not hear?”\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmcmlviii{%
He said, “Your Lord and the Lord of your ancestors of old.”\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmcmlix{%
He said, “This messenger of yours, who is sent to you, is crazy.”\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmcmlx{%
He said, “Lord of the East and the West, and everything between them, if you understand.”\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmcmlxi{%
He said, “If you accept any god other than me, I will make you a prisoner.”\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmcmlxii{%
He said, “What if I bring you something convincing?”\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmcmlxiii{%
He said, “Bring it, if you are being truthful.”\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmcmlxiv{%
So he cast his staff; and it was a serpent, plain to see.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmcmlxv{%
And he pulled his hand; and it was white, for all to see.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmcmlxvi{%
He said to the dignitaries around him, “This is a skilled magician.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmcmlxvii{%
He intends to drive you out of your land with his magic, so what do you recommend?”\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmcmlxviii{%
They said, “Delay him and his brother, and send recruiters to the cities.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmcmlxix{%
To bring you every experienced magician.”\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmcmlxx{%
So the magicians were gathered for the appointment on a specified day.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmcmlxxi{%
And it was said to the people, “Are you all gathered?\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmcmlxxii{%
That we may follow the magicians, if they are the winners.”\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmcmlxxiii{%
When the magicians arrived, they said to Pharaoh, “Is there a reward for us, if we are the winners?”\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmcmlxxiv{%
He said, “Yes, and you will be among those favored.”\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmcmlxxv{%
Moses said to them, “Present what you intend to present.”\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmcmlxxvi{%
So they threw their ropes and their sticks, and said, “By the majesty of Pharaoh, we will be the winners.”\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcmlxxvii{%
Then Moses threw his staff, and behold, it began swallowing their trickery.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcmlxxviii{%
And the magicians fell down prostrating.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcmlxxix{%
They said, “We have believed in the Lord of the Worlds.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcmlxxx{%
The Lord of Moses and Aaron.”\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcmlxxxi{%
He said, “Did you believe in Him before I have given you permission? He must be your chief, who taught you magic. You will soon know. I will cut off your hands and feet on opposite sides, and I will crucify you all.”\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcmlxxxii{%
They said, “No problem. To our Lord we will return.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcmlxxxiii{%
We are eager for our Lord to forgive us our sins, since we are the first of the believers.”\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcmlxxxiv{%
And We inspired Moses: “Travel with My servants by night. You will be followed.”\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcmlxxxv{%
Pharaoh sent heralds to the cities.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcmlxxxvi{%
“These are a small gang.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcmlxxxvii{%
And they are enraging us.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcmlxxxviii{%
But we are a vigilant multitude.”\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcmlxxxix{%
So We drove them out of gardens and springs.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcmxc{%
And treasures and noble dwellings.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcmxci{%
So it was. And We made the Children of Israel inherit them.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcmxcii{%
And they pursued them at sunrise.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcmxciii{%
When the two groups sighted each other, the followers of Moses said, “We are being overtaken.”\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcmxciv{%
He said, “No; my Lord is with me, He will guide me.”\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcmxcv{%
We inspired Moses: “Strike the sea with your staff.” Whereupon it parted, and each part was like a huge hill.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcmxcvi{%
And there We brought the others near.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcmxcvii{%
And We saved Moses and those with him, all together.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcmxcviii{%
Then We drowned the others.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcmxcix{%
In that there is a sign, but most of them are not believers.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmm{%
Surely, your Lord is the Almighty, the Merciful.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmi{%
And relate to them the story of Abraham.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmii{%
When he said to his father and his people, “What do you worship?”\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmiii{%
They said, “We worship idols, and we remain devoted to them.”\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmiv{%
He said, “Do they hear you when you pray?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmv{%
Or do they benefit you, or harm you?”\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmvi{%
They said, “But we found our ancestors doing so.”\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmvii{%
He said, “Have you considered what you worship.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmviii{%
You and your ancient ancestors?\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmix{%
They are enemies to me, but not so the Lord of the Worlds.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmx{%
He who created me, and guides me.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmxi{%
He who feeds me, and waters me.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmxii{%
And when I get sick, He heals me.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmxiii{%
He who makes me die, and then revives me.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmxiv{%
He who, I hope, will forgive my sins on the Day of the Reckoning.”\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmxv{%
“My Lord! Grant me wisdom, and include me with the righteous.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmxvi{%
And give me a reputation of truth among the others.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmxvii{%
And make me of the inheritors of the Garden of Bliss.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmxviii{%
And forgive my father—he was one of the misguided.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmxix{%
And do not disgrace me on the Day they are resurrected.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmxx{%
The Day when neither wealth nor children will help.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmxxi{%
Except for him who comes to God with a sound heart.”\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmxxii{%
And Paradise will be brought near for the righteous.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmxxiii{%
And the Blaze will be displayed to the deviators.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmxxiv{%
And it will be said to them, “Where are those you used to worship?”\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmxxv{%
Besides God? Can they help you, or help themselves?”\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmxxvi{%
Then they will be toppled into it, together with the seducers.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmxxvii{%
And the soldiers of Satan, all of them.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmxxviii{%
They will say, as they feud in it.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmxxix{%
“By God, We were in evident error.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmmxxx{%
For equating you with the Lord of the Worlds.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmmxxxi{%
No one misled us except the sinners.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmmxxxii{%
Now we have no intercessors.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmmxxxiii{%
And no sincere friend.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmmxxxiv{%
If only we could have another chance, we would be among the faithful.”\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmmxxxv{%
Surely in this is a sign, but most of them are not believers.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmmxxxvi{%
Your Lord is the Almighty, the Merciful.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmmxxxvii{%
The people of Noah disbelieved the messengers.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmmxxxviii{%
Their brother Noah said to them, “Do you not fear?\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmmxxxix{%
I am to you a faithful messenger.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmmxl{%
So fear God, and obey me.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmmxli{%
I ask of you no payment for this. My payment is only from the Lord of the Worlds.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmmxlii{%
So fear God, and obey me.”\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmmxliii{%
They said, “Shall we believe in you, when it is the lowliest who follow you?”\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmmxliv{%
He said, “What do I know about what they do?\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmmxlv{%
Their account rests only with my Lord, if you have sense.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmmxlvi{%
And I am not about to drive away the believers.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmmxlvii{%
I am only a clear warner.”\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmmxlviii{%
They said, “If you do not refrain, O Noah, you will be stoned.”\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmmxlix{%
He said, “My Lord, my people have denied me.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmml{%
So judge between me and them decisively, and deliver me and the believers who are with me.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmmli{%
So We delivered him and those with him in the laden Ark.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmmlii{%
Then We drowned the rest.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmmliii{%
In that is a sign, but most of them are not believers.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmmliv{%
Your Lord is the Almighty, the Merciful.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmmlv{%
Aad disbelieved the messengers.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmmlvi{%
When their brother Hud said to them, “Do you not fear?\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmmlvii{%
I am to you a faithful messenger.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmmlviii{%
So fear God, and obey me.\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmmlix{%
I ask of you no payment for this. My payment is only from the Lord of the Worlds.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmmlx{%
Do you build a monument on every height for vanity's sake?\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmmlxi{%
And you set up fortresses, hoping to live forever?\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmmlxii{%
And when you strike, you strike mercilessly?\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmmlxiii{%
So fear God, and obey me.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmmlxiv{%
And reverence Him, who supplied you with everything you know.\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmmlxv{%
He supplied you with livestock and children.\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmmlxvi{%
And gardens and springs.\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmmlxvii{%
I fear for you the punishment of an awesome Day.”\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmmlxviii{%
They said, “It is the same for us, whether you lecture us, or do not lecture.\qt@no{136}}%
\qt@newcmd\qurantrans@en@mmmlxix{%
This is nothing but morals of the ancients.\qt@no{137}}%
\qt@newcmd\qurantrans@en@mmmlxx{%
And we will not be punished.”\qt@no{138}}%
\qt@newcmd\qurantrans@en@mmmlxxi{%
So they denied him, and We destroyed them. Surely in this is a sign, but most of them are not believers.\qt@no{139}}%
\qt@newcmd\qurantrans@en@mmmlxxii{%
Your Lord is the Almighty, the Merciful.\qt@no{140}}%
\qt@newcmd\qurantrans@en@mmmlxxiii{%
Thamood disbelieved the messengers.\qt@no{141}}%
\qt@newcmd\qurantrans@en@mmmlxxiv{%
When their brother Saleh said to them, “Do you not fear?\qt@no{142}}%
\qt@newcmd\qurantrans@en@mmmlxxv{%
I am to you a faithful messenger.\qt@no{143}}%
\qt@newcmd\qurantrans@en@mmmlxxvi{%
So fear God, and obey me.\qt@no{144}}%
\qt@newcmd\qurantrans@en@mmmlxxvii{%
I ask of you no payment for it. My payment is only from the Lord of the Worlds.\qt@no{145}}%
\qt@newcmd\qurantrans@en@mmmlxxviii{%
Will you be left secure in what is here?\qt@no{146}}%
\qt@newcmd\qurantrans@en@mmmlxxix{%
In gardens and springs?\qt@no{147}}%
\qt@newcmd\qurantrans@en@mmmlxxx{%
And fields, and palm-trees whose fruits are delicious?\qt@no{148}}%
\qt@newcmd\qurantrans@en@mmmlxxxi{%
And you skillfully carve houses in the mountains?\qt@no{149}}%
\qt@newcmd\qurantrans@en@mmmlxxxii{%
So fear God, and obey me.\qt@no{150}}%
\qt@newcmd\qurantrans@en@mmmlxxxiii{%
And do not obey the command of the extravagant.\qt@no{151}}%
\qt@newcmd\qurantrans@en@mmmlxxxiv{%
Who spread turmoil on earth, and do not reform.”\qt@no{152}}%
\qt@newcmd\qurantrans@en@mmmlxxxv{%
They said, “You are surely one of the bewitched.\qt@no{153}}%
\qt@newcmd\qurantrans@en@mmmlxxxvi{%
You are nothing but a man like us. So bring us a sign, if you are truthful.\qt@no{154}}%
\qt@newcmd\qurantrans@en@mmmlxxxvii{%
He said, “This is a she-camel; she has her turn of drinking, and you have your turn of drinking—on a specified day.\qt@no{155}}%
\qt@newcmd\qurantrans@en@mmmlxxxviii{%
And do not touch her with harm, lest the punishment of a great day seizes you.”\qt@no{156}}%
\qt@newcmd\qurantrans@en@mmmlxxxix{%
But they slaughtered her, and became full of remorse.\qt@no{157}}%
\qt@newcmd\qurantrans@en@mmmxc{%
So the punishment overtook them. Surely in this is a sign, but most of them are not believers.\qt@no{158}}%
\qt@newcmd\qurantrans@en@mmmxci{%
Your Lord is the Almighty, the Merciful.\qt@no{159}}%
\qt@newcmd\qurantrans@en@mmmxcii{%
The people of Lot disbelieved the messengers.\qt@no{160}}%
\qt@newcmd\qurantrans@en@mmmxciii{%
When their brother Lot said to them, “Do you not fear?\qt@no{161}}%
\qt@newcmd\qurantrans@en@mmmxciv{%
I am to you a faithful messenger.\qt@no{162}}%
\qt@newcmd\qurantrans@en@mmmxcv{%
So fear God, and obey me.\qt@no{163}}%
\qt@newcmd\qurantrans@en@mmmxcvi{%
I ask of you no payment for it. My payment is only from the Lord of the Worlds.\qt@no{164}}%
\qt@newcmd\qurantrans@en@mmmxcvii{%
Do you approach the males of the world?\qt@no{165}}%
\qt@newcmd\qurantrans@en@mmmxcviii{%
And forsake the wives your Lord created for you? Indeed, you are intrusive people.”\qt@no{166}}%
\qt@newcmd\qurantrans@en@mmmxcix{%
They said, “Unless you refrain, O Lot, you will be expelled.”\qt@no{167}}%
\qt@newcmd\qurantrans@en@mmmc{%
He said, “I certainly deplore your conduct.”\qt@no{168}}%
\qt@newcmd\qurantrans@en@mmmci{%
“My Lord, save me and my family from what they do.”\qt@no{169}}%
\qt@newcmd\qurantrans@en@mmmcii{%
So We saved him and his family, altogether.\qt@no{170}}%
\qt@newcmd\qurantrans@en@mmmciii{%
Except for an old woman among those who tarried.\qt@no{171}}%
\qt@newcmd\qurantrans@en@mmmciv{%
Then We destroyed the others.\qt@no{172}}%
\qt@newcmd\qurantrans@en@mmmcv{%
And We rained down on them a rain. Dreadful is the rain of those forewarned.\qt@no{173}}%
\qt@newcmd\qurantrans@en@mmmcvi{%
Surely in this is a sign, but most of them are not believers.\qt@no{174}}%
\qt@newcmd\qurantrans@en@mmmcvii{%
Your Lord is the Almighty, the Merciful.\qt@no{175}}%
\qt@newcmd\qurantrans@en@mmmcviii{%
The People of the Woods disbelieved the messengers.\qt@no{176}}%
\qt@newcmd\qurantrans@en@mmmcix{%
When Shuaib said to them, “Do you not fear?\qt@no{177}}%
\qt@newcmd\qurantrans@en@mmmcx{%
I am to you a trustworthy messenger.\qt@no{178}}%
\qt@newcmd\qurantrans@en@mmmcxi{%
So fear God, and obey me.\qt@no{179}}%
\qt@newcmd\qurantrans@en@mmmcxii{%
I ask of you no payment for it. My payment is only from the Lord of the Worlds.\qt@no{180}}%
\qt@newcmd\qurantrans@en@mmmcxiii{%
Give full measure, and do not cheat.\qt@no{181}}%
\qt@newcmd\qurantrans@en@mmmcxiv{%
And weigh with accurate scales.\qt@no{182}}%
\qt@newcmd\qurantrans@en@mmmcxv{%
And do not defraud people of their belongings, and do not work corruption in the land.\qt@no{183}}%
\qt@newcmd\qurantrans@en@mmmcxvi{%
And fear Him who created you and the masses of old.”\qt@no{184}}%
\qt@newcmd\qurantrans@en@mmmcxvii{%
They said, “You are one of those bewitched.\qt@no{185}}%
\qt@newcmd\qurantrans@en@mmmcxviii{%
And you are nothing but a man like us; and we think that you are a liar.\qt@no{186}}%
\qt@newcmd\qurantrans@en@mmmcxix{%
So bring down on us pieces from the sky, if you are truthful.”\qt@no{187}}%
\qt@newcmd\qurantrans@en@mmmcxx{%
He said, “My Lord is Well Aware of what you do.”\qt@no{188}}%
\qt@newcmd\qurantrans@en@mmmcxxi{%
But they denied him. So the punishment of the day of gloom gripped them. It was the punishment of a great day.\qt@no{189}}%
\qt@newcmd\qurantrans@en@mmmcxxii{%
Surely in this is a sign, but most of them are not believers.\qt@no{190}}%
\qt@newcmd\qurantrans@en@mmmcxxiii{%
Your Lord is the Almighty, the Merciful.\qt@no{191}}%
\qt@newcmd\qurantrans@en@mmmcxxiv{%
It is a revelation from the Lord of the Worlds.\qt@no{192}}%
\qt@newcmd\qurantrans@en@mmmcxxv{%
The Honest Spirit came down with it.\qt@no{193}}%
\qt@newcmd\qurantrans@en@mmmcxxvi{%
Upon your heart, that you may be one of the warners.\qt@no{194}}%
\qt@newcmd\qurantrans@en@mmmcxxvii{%
In a clear Arabic tongue.\qt@no{195}}%
\qt@newcmd\qurantrans@en@mmmcxxviii{%
And it is in the scriptures of the ancients.\qt@no{196}}%
\qt@newcmd\qurantrans@en@mmmcxxix{%
Is it not a sign for them that the scholars of the Children of Israel recognized it?\qt@no{197}}%
\qt@newcmd\qurantrans@en@mmmcxxx{%
Had We revealed it to one of the foreigners.\qt@no{198}}%
\qt@newcmd\qurantrans@en@mmmcxxxi{%
And he had recited it to them, they still would not have believed in it.\qt@no{199}}%
\qt@newcmd\qurantrans@en@mmmcxxxii{%
Thus We make it pass through the hearts of the guilty.\qt@no{200}}%
\qt@newcmd\qurantrans@en@mmmcxxxiii{%
They will not believe in it until they witness the painful punishment.\qt@no{201}}%
\qt@newcmd\qurantrans@en@mmmcxxxiv{%
It will come to them suddenly, while they are unaware.\qt@no{202}}%
\qt@newcmd\qurantrans@en@mmmcxxxv{%
Then they will say, “Are we given any respite?”\qt@no{203}}%
\qt@newcmd\qurantrans@en@mmmcxxxvi{%
Do they seek to hasten Our punishment?\qt@no{204}}%
\qt@newcmd\qurantrans@en@mmmcxxxvii{%
Have you considered: if We let them enjoy themselves for some years.\qt@no{205}}%
\qt@newcmd\qurantrans@en@mmmcxxxviii{%
Then there comes to them what they were promised.\qt@no{206}}%
\qt@newcmd\qurantrans@en@mmmcxxxix{%
Of what avail to them will be their past enjoyments?\qt@no{207}}%
\qt@newcmd\qurantrans@en@mmmcxl{%
Never did We destroy a town, but it had warners.\qt@no{208}}%
\qt@newcmd\qurantrans@en@mmmcxli{%
As a reminder—We are never unjust.\qt@no{209}}%
\qt@newcmd\qurantrans@en@mmmcxlii{%
It was not the devils that revealed it.\qt@no{210}}%
\qt@newcmd\qurantrans@en@mmmcxliii{%
It is not in their interests, nor in their power.\qt@no{211}}%
\qt@newcmd\qurantrans@en@mmmcxliv{%
They are barred from hearing.\qt@no{212}}%
\qt@newcmd\qurantrans@en@mmmcxlv{%
So do not pray to another god with God, else you will be of those tormented.\qt@no{213}}%
\qt@newcmd\qurantrans@en@mmmcxlvi{%
And warn your close relatives.\qt@no{214}}%
\qt@newcmd\qurantrans@en@mmmcxlvii{%
And lower your wing to those of the believers who follow you.\qt@no{215}}%
\qt@newcmd\qurantrans@en@mmmcxlviii{%
And if they disobey you, say, “I am innocent of what you do.”\qt@no{216}}%
\qt@newcmd\qurantrans@en@mmmcxlix{%
And put your trust in the Almighty, the Merciful.\qt@no{217}}%
\qt@newcmd\qurantrans@en@mmmcl{%
He Who sees you when you rise.\qt@no{218}}%
\qt@newcmd\qurantrans@en@mmmcli{%
And your devotions amidst the worshipers.\qt@no{219}}%
\qt@newcmd\qurantrans@en@mmmclii{%
He is indeed the Hearer, the Aware.\qt@no{220}}%
\qt@newcmd\qurantrans@en@mmmcliii{%
Shall I inform you upon whom the devils descend?\qt@no{221}}%
\qt@newcmd\qurantrans@en@mmmcliv{%
They descend upon every sinful liar.\qt@no{222}}%
\qt@newcmd\qurantrans@en@mmmclv{%
They give ear, and most of them are liars.\qt@no{223}}%
\qt@newcmd\qurantrans@en@mmmclvi{%
And as for the poets—the deviators follow them.\qt@no{224}}%
\qt@newcmd\qurantrans@en@mmmclvii{%
Do you not see how they ramble in every style?\qt@no{225}}%
\qt@newcmd\qurantrans@en@mmmclviii{%
And how they say what they do not do?\qt@no{226}}%
\qt@newcmd\qurantrans@en@mmmclix{%
Except for those who believe, and do good deeds, and remember God frequently, and defend themselves after they are wronged. As for those who do wrong, they will know by what overturning they will be overturned.\qt@no{227}}%
\qt@newcmd\qurantrans@en@mmmclx{%
\basmalahen Ta, Seen. These are the Signs of the Quran—a book that makes things clear.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmclxi{%
Guidance and good news for the believers.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmclxii{%
Those who observe the prayers, and give charity regularly, and are certain of the Hereafter.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmclxiii{%
As for those who do not believe in the Hereafter: We made their deeds appear good to them, so they wander aimlessly.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmclxiv{%
It is they who will receive the grievous punishment—and in the Hereafter they will be the greatest losers.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmclxv{%
You are receiving the Quran from an All-Wise, All-Knowing.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmclxvi{%
When Moses said to his family, “I have glimpsed a fire. I will bring you some news from it; or bring you a firebrand, that you may warm yourselves.”\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmclxvii{%
Then, when he reached it, he was called: “Blessed is He who is within the fire, and He who is around it, and glorified be God, Lord of the Worlds.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmclxviii{%
O Moses, it is I, God, the Almighty, the Wise.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmclxix{%
Throw down your staff.” But when he saw it quivering, as though it were a demon, he turned around not looking back. “O Moses, do not fear; the messengers do not fear in My presence.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmclxx{%
But whoever has done wrong, and then substituted goodness in place of evil. I am Forgiving and Merciful.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmclxxi{%
Put your hand inside your pocket, and it will come out white, without blemish—among nine miracles to Pharaoh and his people, for they are immoral people.”\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmclxxii{%
Yet when Our enlightening signs came to them, they said, “This is obvious witchcraft.”\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmclxxiii{%
And they rejected them, although their souls were certain of them, out of wickedness and pride. So see how the outcome was for the mischief-makers.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmclxxiv{%
And We gave David and Solomon knowledge. They said, “Praise God, who has favored us over many of His believing servants.”\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmclxxv{%
And Solomon succeeded David. He said, “O people, we were taught the language of birds, and we were given from everything. This is indeed a real blessing.”\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmclxxvi{%
To the service of Solomon were mobilized his troops of sprites, and men, and birds—all held in strict order.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmclxxvii{%
Until, when they came upon the Valley of Ants, an ant said, “O ants! Go into your nests, lest Solomon and his troops crush you without noticing.”\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmclxxviii{%
He smiled and laughed at her words, and said, “My Lord, direct me to be thankful for the blessings you have bestowed upon me and upon my parents, and to do good works that please You. And admit me, by Your grace, into the company of Your virtuous servants.”\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmclxxix{%
Then he inspected the birds, and said, “Why do I not see the hoopoe? Or is he among the absentees?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmclxxx{%
I will punish him most severely, or slay him, unless he gives me a valid excuse.”\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmclxxxi{%
But he did not stay for long. He said, “I have learnt something you did not know. I have come to you from Sheba, with reliable information.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmclxxxii{%
I found a woman ruling over them, and she was given of everything, and she has a magnificent throne.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmclxxxiii{%
I found her and her people worshiping the sun, instead of God. Satan made their conduct appear good to them, and diverted them from the path, so they are not guided.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmclxxxiv{%
If only they would worship God, who brings to light the mysteries of the heavens and the earth, and knows what you conceal and what you reveal.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmclxxxv{%
God—There is no god but He, the Lord of the Sublime Throne.”\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmclxxxvi{%
He said, “We will see, whether you have spoken the truth, or whether you are a liar.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmclxxxvii{%
Go with this letter of mine, and deliver it to them; then withdraw from them, and see how they respond.”\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmclxxxviii{%
She said, “O Counselors, a gracious letter was delivered to me.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmclxxxix{%
It is from Solomon, and it is, ‘In the Name of God, the Gracious, the Merciful.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcxc{%
Do not defy me, and come to me submissively.’”\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcxci{%
She said, “O counselors, advise me in this matter of mine. I never make a decision unless you are present.”\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcxcii{%
They said, “We are a people of might and great courage, but the decision is yours, so consider what you wish to command.”\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcxciii{%
She said, “When kings enter a city, they devastate it, and subjugate its dignified people. Thus they always do.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcxciv{%
I am sending them a gift, and will see what the envoys bring back.”\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcxcv{%
When he came to Solomon, he said, “Are you supplying me with money? What God has given me is better than what He has given you. It is you who delight in your gift.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcxcvi{%
Go back to them. We will come upon them with troops they cannot resist; and we will expel them from there, disgraced and humiliated.”\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmcxcvii{%
He said, “O notables, which one of you will bring me her throne before they come to me in submission?”\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmcxcviii{%
An imp of the sprites said, “I will bring it to you before you rise from your seat. I am strong and reliable enough to do it.”\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmcxcix{%
He who had knowledge from the Book said, “I will bring it to you before your glance returns to you.” And when he saw it settled before him, he said, “This is from the grace of my Lord, to test me, whether I am grateful or ungrateful. He who is grateful, his gratitude is to his own credit; but he who is ungrateful—my Lord is Independent and Generous.”\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmcc{%
He said, “Disguise her throne for her, and we shall see whether she will be guided, or remains one of the misguided.”\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmcci{%
When she arrived, it was said, “Is your throne like this?” She said, “As if this is it.” “We were given knowledge before her, and we were submissive.”\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccii{%
But she was prevented by what she worshiped besides God; she belonged to a disbelieving people.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmcciii{%
It was said to her, “Go inside the palace.” And when she saw it, she thought it was a deep pond, and she bared her legs. He said, “It is a palace paved with glass.” She said, “My Lord, I have done wrong to myself, and I have submitted with Solomon, to God, Lord of the Worlds.”\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmcciv{%
And We sent to Thamood their brother Saleh: “Worship God.” But they became two disputing factions.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccv{%
He said, “O my people, why are you quick to do evil rather than good? If only you would seek God’s forgiveness, so that you may be shown mercy.”\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccvi{%
They said, “We consider you an ill omen, and those with you.” He said, “Your omen is with God. In fact, you are a people being tested.”\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccvii{%
In the city was a gang of nine who made mischief in the land and did no good.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccviii{%
They said, “Swear by God to one another that we will attack him and his family by night, and then tell his guardian, 'We did not witness the murder of his family, and we are being truthful.'“\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmccix{%
They planned a plan, and We planned a plan, but they did not notice.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmccx{%
So note the outcome of their planning; We destroyed them and their people, altogether.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmccxi{%
Here are their homes, in ruins, on account of their iniquities. Surely in this is a sign for people who know.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmccxii{%
And We saved those who believed and were pious.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmccxiii{%
And Lot, when he said to his people, “Do you commit lewdness with open eyes?\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmccxiv{%
Do you lust after men instead of women? You are truly ignorant people.”\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmccxv{%
But the only response of his people was to say, “Expel the family of Lot from your town. They are purist people.”\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmccxvi{%
So We saved him and his family, except for his wife, whom We destined to be among the laggards.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmccxvii{%
And We rained upon them a rain. Miserable was the rain of those forewarned.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmccxviii{%
Say, “Praise God, and peace be upon His servants whom He has selected. Is God better, or what they associate?”\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmccxix{%
Or, who created the heavens and the earth, and rains down water from the sky for you? With it We produce gardens full of beauty, whose trees you could not have produced. Is there another god with God? But they are a people who equate.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmccxx{%
Or, who made the earth habitable, and made rivers flow through it, and set mountains on it, and placed a partition between the two seas? Is there another god with God? But most of them do not know.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmccxxi{%
Or, who answers the one in need when he prays to Him, and relieves adversity, and makes you successors on earth? Is there another god with God? How hardly you pay attention.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmccxxii{%
Or, who guides you through the darkness of land and sea, and who sends the winds as heralds of His mercy? Is there another god with God? Most exalted is God, above what they associate.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmccxxiii{%
Or, who originates the creation and then repeats it, and who gives you livelihood from the sky and the earth? Is there another god with God? Say, “Produce your evidence, if you are truthful.”\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmccxxiv{%
Say, “No one in the heavens or on earth knows the future except God; and they do not perceive when they will be resurrected.”\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmccxxv{%
In fact, their knowledge of the Hereafter is confused. In fact, they are in doubt about it. In fact, they are blind to it.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmccxxvi{%
Those who disbelieve say, “When we have become dust, and our ancestors, shall we be brought out?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmccxxvii{%
We were promised that before, we and our ancestors—these are nothing but legends of the ancients.”\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmccxxviii{%
Say, travel through the earth, and observe the fate of the guilty.”\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmccxxix{%
But do not grieve over them, and do not be troubled by what they plot.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmccxxx{%
And they say, “When is this promise, if you are truthful?”\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmccxxxi{%
Say, “Perhaps some of what you are impatient for has drawn near.”\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmccxxxii{%
Your Lord is gracious towards humanity, but most of them are not thankful.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmccxxxiii{%
And your Lord knows what their hearts conceal, and what they reveal.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmccxxxiv{%
There is no mystery in the heaven and the earth, but it is in a Clear Book.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmccxxxv{%
This Quran relates to the Children of Israel most of what they differ about.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmccxxxvi{%
And it is guidance and mercy for the believers.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmccxxxvii{%
Your Lord will judge between them by His wisdom. He is the Almighty, the All-Knowing.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmccxxxviii{%
So rely on God. You are upon the clear truth.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmccxxxix{%
You cannot make the dead hear, nor can you make the deaf hear the call if they turn their backs and flee.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmccxl{%
Nor can you guide the blind out of their straying. You can make no one listen, except those who believe in Our verses; for they are Muslims.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmccxli{%
And when the Word has fallen on them, We will bring out for them from the earth a creature which will say to them that the people are uncertain of Our revelations.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmccxlii{%
On the Day when We gather from every community a group of those who rejected Our revelations; and they will be restrained.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmccxliii{%
Until, when they arrive, He will say, “Did you reject My revelations without comprehending them? Or what is it you were doing?”\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmccxliv{%
The Word will come down upon them for their wrongdoing, and they will not speak.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmccxlv{%
Do they not see that We made the night for them to rest therein, and the day for visibility? Surely in that are signs for people who believe.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmccxlvi{%
On the Day when the Trumpet is blown, everyone in the heavens and the earth will be horrified, except whomever God wills; and everyone will come before Him in humility.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmccxlvii{%
And you see the mountains, and imagine them fixed, yet they pass, as the passing of the clouds—the making of God, who has perfected everything. He is fully Informed of what you do.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmccxlviii{%
Whoever brings a virtue will receive better than it—and they will be safe from the horrors of that Day.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmccxlix{%
But whoever brings evil—their faces will be tumbled into the Fire. Will you be rewarded except for what you used to do?\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmccl{%
“I was commanded to worship the Lord of this town, who has sanctified it, and to Whom everything belongs; and I was commanded to be of those who submit.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmccli{%
And to recite the Quran.” Whoever is guided—is guided to his own advantage. And whoever goes astray, then say, “I am one of the warners.”\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmcclii{%
And say, “Praise belongs to God; He will show you His signs, and you will recognize them. Your Lord is not heedless of what you do.”\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmccliii{%
\basmalahen Ta, Seen, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmccliv{%
These are the Verses of the Clear Book.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcclv{%
We narrate to you from the history of Moses and Pharaoh—in truth—for people who believe.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcclvi{%
Pharaoh exalted himself in the land, and divided its people into factions. He persecuted a group of them, slaughtering their sons, while sparing their daughters. He was truly a corrupter.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcclvii{%
But We desired to favor those who were oppressed in the land, and to make them leaders, and to make them the inheritors.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcclviii{%
And to establish them in the land; and to show Pharaoh, Hamaan, and their troops, the very thing they feared.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcclix{%
We inspired the mother of Moses: “Nurse him; then, when you fear for him, cast him into the river, and do not fear, nor grieve; We will return him to you, and make him one of the messengers.”\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcclx{%
Pharaoh’s household picked him up, to be an opponent and a sorrow for them. Pharaoh, Hamaan, and their troops were sinners.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcclxi{%
Pharaoh’s wife said, “An eye's delight for me and for you. Do not kill him; perhaps he will be useful to us, or we may adopt him as a son.” But they did not foresee.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcclxii{%
The heart of Moses’ mother became vacant. She was about to disclose him, had We not steadied her heart, that she may remain a believer.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcclxiii{%
She said to his sister, “Trail him.” So she watched him from afar, and they were unaware.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcclxiv{%
We forbade him breastfeeding at first. So she said, “Shall I tell you about a family that can raise him for you, and will look after him?”\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcclxv{%
Thus We returned him to his mother, that she may be comforted, and not grieve, and know that God’s promise is true. But most of them do not know.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcclxvi{%
And when he reached his maturity, and became established, We gave him wisdom and knowledge. Thus do We reward the virtuous.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcclxvii{%
Once he entered the city, unnoticed by its people. He found in it two men fighting—one of his own sect, and one from his enemies. The one of his sect solicited his assistance against the one from his enemies; so Moses punched him, and put an end to him. He said, “This is of Satan's doing; he is an enemy that openly misleads.”\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcclxviii{%
He said, “My Lord, I have wronged myself, so forgive me.” So He forgave him. He is the Forgiver, the Merciful.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcclxix{%
He said, “My Lord, in as much as you have favored me, I will never be a supporter of the criminals.”\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcclxx{%
The next morning, he went about in the city, fearful and vigilant, when the man who had sought his assistance the day before was shouting out to him. Moses said to him, “You are clearly a troublemaker.”\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcclxxi{%
As he was about to strike the one who was their enemy, he said, “O Moses, do you intend to kill me, as you killed someone yesterday? You only want to be a bully in the land, and do not want to be a peacemaker.”\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcclxxii{%
And a man came from the farthest part of the city running. He said, “O Moses, the authorities are considering killing you, so leave; I am giving you good advice.”\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcclxxiii{%
So he left, fearful and vigilant. He said, “My Lord, deliver me from the wrongdoing people.”\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcclxxiv{%
As he headed towards Median, he said, “Perhaps my Lord will guide me to the right way.”\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcclxxv{%
And when he arrived at the waters of Median, he found there a crowd of people drawing water, and he noticed two women waiting on the side. He said, “What is the matter with you?” They said, “We cannot draw water until the shepherds depart, and our father is a very old man.”\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcclxxvi{%
So he drew water for them, and then withdrew to the shade, and said, “My Lord, I am in dire need of whatever good you might send down to me.”\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcclxxvii{%
Then, one of the two women approached him, walking bashfully. She said, “My father is calling you, to reward you for drawing water for us.” And when he came to him, and told him the story, he said, “Do not fear, you have escaped from the wrongdoing people.”\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcclxxviii{%
One of the two women said, “Father, hire him; the best employee for you is the strong and trustworthy.”\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcclxxix{%
He said, “I want to marry you to one of these two daughters of mine, provided you work for me for eight years. But if you complete ten, that is up to you. I do not intend to impose any hardship on you. You will find me, God willing, one of the righteous.”\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcclxxx{%
He said, “Let this be an agreement between you and me. Whichever of the two terms I fulfill, there shall be no reprisal against me; and God is witness over what we say.”\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcclxxxi{%
When Moses had completed the term, and departed with his family, he noticed a fire by the side of the Mount. He said to his family, “Stay here, I have glimpsed a fire. Perhaps I can bring you some information from there, or an ember from the fire, that you may warm yourselves.”\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcclxxxii{%
When he reached it, he was called from the right side of the valley, at the Blessed Spot, from the bush: “O Moses, it is I, God, the Lord of the Worlds.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcclxxxiii{%
Throw down your staff.” And when he saw it wiggling, as if it were possessed, he turned his back to flee, and did not look back. “O Moses, come forward, and do not fear, you are perfectly safe.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcclxxxiv{%
Put your hand inside your pocket, and it will come out white, without blemish. And press your arm to your side, against fear. These are two proofs from your Lord, to Pharaoh and his dignitaries. They are truly sinful people.”\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcclxxxv{%
He said, “My Lord, I have killed one of them, and I fear they will kill me.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcclxxxvi{%
And my brother Aaron, he is more eloquent than me, so send him with me, to help me, and to confirm my words, for I fear they will reject me.”\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcclxxxvii{%
He said, “We will strengthen your arm with your brother, and We will give you authority, so they will not touch you. By virtue of Our signs, you and those who follow you will be the triumphant.”\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcclxxxviii{%
But when Moses came to them with Our signs, clear and manifest, they said, “This is nothing but fabricated magic, and We never heard of this from our ancestors of old.”\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcclxxxix{%
Moses said, “My Lord is well aware of him who brings guidance from Him, and him who will have the sequel of the abode. The wrongdoers will not succeed.”\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmccxc{%
Pharaoh said, “O nobles, I know of no god for you other than me. So fire-up the bricks for me O Hamaan, and build me a tower, that I may ascend to the God of Moses, though I think he is a liar.”\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmccxci{%
He and his troops acted arrogantly in the land, with no justification. They thought they would not be returned to Us.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmccxcii{%
So We seized him, and his troops, and We threw them into the sea. Observe, therefore, what was the end of the oppressors.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmccxciii{%
And We made them leaders calling to the Fire. And on Resurrection Day, they will not be saved.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmccxciv{%
And We pursued them in this world with a curse. And on Resurrection Day, they will be among the despised.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccxcv{%
We gave Moses the Scripture after We had annihilated the previous generations; as an illumination for mankind, and guidance, and mercy, so that they may remember.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmccxcvi{%
You were not on the Western Side when We decreed the command to Moses, nor were you among the witnesses.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmccxcvii{%
But We established many generations, and time took its toll on them. Nor were you among the people of Median, reciting Our revelations to them. But We kept sending messengers.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccxcviii{%
Nor were you by the side of the Mount when We proclaimed. Rather, it was a mercy from your Lord, that you may warn people who received no warner before you, so that they may take heed.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccxcix{%
Otherwise, if a calamity befell them as a result of what their hands have perpetrated, they would say, “Our Lord, if only You had sent us a messenger, we would have followed Your revelations, and been among the believers.”\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccc{%
But when the truth came to them from Us, they said, “If only he was given the like of what was given to Moses.” Did they not disbelieve in what was given to Moses in the past? They said, “Two works of magic backing one another.” And they said, “We are disbelieving in both.”\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccci{%
Say, “Then bring a scripture from God, more conductive to guidance than both, and I will follow it, if you are truthful.”\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcccii{%
But if they fail to respond to you, know that they follow their fancies. And who is more lost than him who follows his fancy without guidance from God? God does not guide the unjust people.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmccciii{%
We have delivered the Word to them, that they may remember.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmccciv{%
Those to whom We gave the Scripture before it believe in it.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcccv{%
When it is recited to them, they say, “We have believed in it; it is the truth from our Lord; we were Muslims prior to it.”\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcccvi{%
These will be given their reward twice, because they persevered; and they counter evil with good; and from Our provisions to them, they give.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcccvii{%
And when they hear vain talk, they avoid it, and say, “We have our deeds, and you have your deeds; peace be upon you; we do not desire the ignorant.”\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcccviii{%
You cannot guide whom you love, but God guides whom He wills, and He knows best those who are guided.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcccix{%
And they say, “If we follow the guidance with you, we will be snatched from our land.” Did We not establish for them a Safe Sanctuary, to which are brought all kinds of fruits, as provision from Ourselves? But most of them do not know.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcccx{%
And how many a city did We destroy for turning unappreciative of its livelihood? Here are their homes, uninhabited after them, except for a few. And We became the Inheritors.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcccxi{%
Your Lord never destroys cities without first sending a messenger in their midst, reciting to them Our revelations. And We never destroy the cities, unless their people are wrongdoers.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcccxii{%
Whatever thing you are given is but the material of this world, and its glitter. But what is with God is better, and longer lasting. Do you not comprehend?\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcccxiii{%
Can someone to whom We have made a fine promise—which he will attain—be equal to someone to whom We have given enjoyments in this world, but who will be, on Resurrection Day, among the arraigned?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmcccxiv{%
On the Day when He will call to them, and say, “Where are My associates whom you used to claim?”\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmcccxv{%
Those against whom the sentence is justified will say, “Our Lord, these are they whom we misled. We misled them, as we were misled. We beg Your forgiveness; it was not us they used to worship.”\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmcccxvi{%
And it will be said, “Call on your partners.” And they will call on them, but they will not respond to them. And they will see the suffering. If only they were guided.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmcccxvii{%
On the Day when He will call to them, and say, “What did you answer the Messengers?”\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmcccxviii{%
They will be blinded by the facts on that Day, and they will not question each other.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmcccxix{%
But he who repents, and believes, and does righteous deeds, may well be among the winners.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmcccxx{%
Your Lord creates whatever He wills, and He chooses. The choice is not theirs. Glory be to God, and exalted be He above the associations they make.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmcccxxi{%
And your Lord knows what their hearts conceal, and what they reveal.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmcccxxii{%
And He is God. There is no god but He. To Him belongs all praise in this life, and in the next. And His is the decision, and to Him you will be returned.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmcccxxiii{%
Say, “Have you considered? Had God made the night perpetual over you until the Day of Resurrection, which god other than God will bring you illumination? Do you not hear?”\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmcccxxiv{%
Say, “Have you considered? Had God made the day perpetual over you until the Day of Resurrection, which god other than God will bring you night to rest in? Do you not see?”\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmcccxxv{%
It is out of His mercy that He made for you the night and the day, that you may rest in it, and seek some of His bounty; and that you may give thanks.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmcccxxvi{%
On the Day when He will call to them, and say, “Where are My associates whom you used to claim?”\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmcccxxvii{%
And We will draw out from every community a witness, and say, “Produce your evidence.” Then they will realize that the truth is God’s, and those they used to invent have forsaken them.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmcccxxviii{%
Quaroon belonged to the clan of Moses, but he oppressed them. We had given him treasures, the keys of which would weigh down a group of strong men. His people said to him, “Do not exult; God does not love the exultant.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmcccxxix{%
But seek, with what God has given you, the Home of the Hereafter, and do not neglect your share of this world. And be charitable, as God has been charitable to you. And do not seek corruption in the land. God does not like the seekers of corruption.”\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmcccxxx{%
He said, “I was given all this on account of knowledge I possess.” Did he not know that God destroyed many generations before him, who were stronger than he, and possessed greater riches? But the guilty will not be asked about their sins.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmcccxxxi{%
And he went out before his people in his splendor. Those who desired the worldly life said, “If only we possessed the likes of what Quaroon was given. He is indeed very fortunate.”\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmcccxxxii{%
But those who were given knowledge said, “Woe to you! The reward of God is better for those who believe and do righteous deeds.” Yet none attains it except the steadfast.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmcccxxxiii{%
So We caused the earth to cave in on him and his mansion. He had no company to save him from God, and he could not defend himself.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmcccxxxiv{%
Those who had wished they were in his position the day before were saying, “Indeed, it is God who spreads the bounty to whomever He wills of His servants, and restricts it. Had God not been gracious to us, He would have caved in on us. No wonder the ungrateful never prosper.”\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmcccxxxv{%
That Home of the Hereafter—We assign it for those who seek no superiority on earth, nor corruption. And the outcome is for the cautious.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmcccxxxvi{%
Whoever brings a virtue will receive better than it. But whoever brings evil—the evildoers will be rewarded only according to what they used to do.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmcccxxxvii{%
He Who ordained the Quran for you will return you Home. Say, “My Lord knows best who comes with guidance, and who is in manifest error.”\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmcccxxxviii{%
You did not expect the Scripture to be transmitted to you, except as mercy from your Lord. Therefore, do not be a supporter of the disbelievers.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmcccxxxix{%
And do not let them divert you from God’s revelations after they have been revealed to you. And pray to your Lord, and never be of the polytheists.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmcccxl{%
And do not invoke with God any other god. There is no god but He. All things perish, except His presence. His is the judgment, and to Him you will be returned.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmcccxli{%
\basmalahen Alif, Lam, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcccxlii{%
Have the people supposed that they will be left alone to say, “We believe,” without being put to the test?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcccxliii{%
We have tested those before them. God will surely know the truthful, and He will surely know the liars.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcccxliv{%
Or do those who commit sins think they can fool Us? Terrible is their opinion!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcccxlv{%
Whoever looks forward to the meeting with God—the appointed time of God is coming. He is the All-Hearing, the All-Knowing.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcccxlvi{%
Whoever strives, strives only for himself. God is Independent of the beings.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcccxlvii{%
Those who believe and do righteous deeds—We will remit their sins, and We will reward them according to the best of what they used to do.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcccxlviii{%
We have advised the human being to be good to his parents. But if they urge you to associate with Me something you have no knowledge of, do not obey them. To Me is your return; and I will inform you of what you used to do.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcccxlix{%
Those who believe and do good works—We will admit them into the company of the righteous.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcccl{%
Among the people is he who says, “We have believed in God.” Yet when he is harmed on God’s account, he equates the people's persecution with God’s retribution. And if help comes from your Lord, he says, “We were actually with you.” Is not God aware of what is inside the hearts of the people?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcccli{%
God certainly knows those who believe, and He certainly knows the hypocrites.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmccclii{%
Those who disbelieve say to those who believe, “Follow our way, and we will carry your sins.” In no way can they carry any of their sins. They are liars.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcccliii{%
They will carry their own loads, and other loads with their own. And they will be questioned on the Day of Resurrection concerning what they used to fabricate.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcccliv{%
We sent Noah to his people, and He stayed among them for a thousand years minus fifty years. Then the Deluge swept them; for they were wrongdoers.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmccclv{%
But We saved him, together with the company of the Ark, and We made it a sign for all peoples.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmccclvi{%
And Abraham, when he said to his people, “Worship God, and fear Him. That is better for you, if you only knew.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmccclvii{%
You worship idols besides God, and you fabricate falsehoods. Those you worship, instead of God, cannot provide you with livelihood. So seek your livelihood from God, and worship Him, and thank Him. To Him you will be returned.”\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmccclviii{%
If you disbelieve, communities before you have also disbelieved. The Messenger is only responsible for clear transmission.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmccclix{%
Have they not seen how God originates the creation, and then reproduces it? This is easy for God.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmccclx{%
Say, “Roam the earth, and observe how He originated the creation.” Then God will bring about the next existence. God has power over all things.”\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmccclxi{%
He punishes whom He wills, and He grants mercy to whom He wills, and to Him you will be restored.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmccclxii{%
You cannot escape, on earth or in the heaven; and you have no protector and no savior besides God.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmccclxiii{%
Those who disbelieved in God’s signs and His encounter—these have despaired of My mercy. For them is a painful torment.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmccclxiv{%
But the only response from his people was their saying, “Kill him, or burn him.” But God saved him from the fire. Surely in that are signs for people who believe.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmccclxv{%
And he said, “You have chosen idols instead of God, out of affection for one another in the worldly life. But then, on the Day of Resurrection, you will disown one another, and curse one another. Your destiny is Hell, and you will have no saviors.”\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmccclxvi{%
Then Lot believed in him, and said, “I am emigrating to my Lord. He is the Noble, the Wise.”\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmccclxvii{%
And We granted him Isaac and Jacob, and conferred on his descendants the Prophethood and the Book, and gave him his reward in this life; and in the Hereafter he will be among the upright.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmccclxviii{%
And Lot, when he said to his people, “You are committing an obscenity not perpetrated before you by anyone in the whole world.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmccclxix{%
You approach men, and cut off the way, and commit lewdness in your gatherings.” But the only response from his people was to say, “Bring upon us God’s punishment, if you are truthful.”\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmccclxx{%
He said, “My Lord, help me against the people of corruption.”\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmccclxxi{%
And when Our envoys brought Abraham the good news, they said, “We are going to destroy the people of this town; its people are wrongdoers.”\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmccclxxii{%
He said, “Yet Lot is in it.” They said, “We are well aware of who is in it. We will save him, and his family, except for his wife, who will remain behind.”\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmccclxxiii{%
Then, when Our envoys came to Lot, they were mistreated, and he was troubled and distressed on their account. They said, “Do not fear, nor grieve. We will save you and your family, except for your wife, who will remain behind.”\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmccclxxiv{%
“We will bring down upon the people of this town a scourge from heaven, because of their wickedness.”\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmccclxxv{%
And We left behind a clear trace of it, for people who understand.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmccclxxvi{%
And to Median, their brother Shuaib. He said, “O my people, worship God and anticipate the Last Day, and do not spread corruption in the land.”\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmccclxxvii{%
But they rejected him, so the tremor overtook them, and they were left motionless in their homes.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmccclxxviii{%
And Aad and Thamood. It has become clear to you from their dwellings. Satan embellished for them their deeds, barring them from the path, even though they could see.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmccclxxix{%
And Quaroon, and Pharaoh, and Hamaan—Moses went to them with clear arguments, but they acted arrogantly in the land. And they could not get ahead.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmccclxxx{%
Each We seized by his sin. Against some We sent a sandstorm. Some were struck by the Blast. Some We caused the ground to cave in beneath them. And some We drowned. It was not God who wronged them, but it was they who wronged their own selves.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmccclxxxi{%
The likeness of those who take to themselves protectors other than God is that of the spider. It builds a house. But the most fragile of houses is the spider’s house. If they only knew.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmccclxxxii{%
God knows what they invoke besides Him. He is the Almighty, the Wise.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccclxxxiii{%
These examples—We put them forward to the people; but none grasps them except the learned.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmccclxxxiv{%
God created the heavens and the earth with truth. Surely in that is a sign for the believers.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmccclxxxv{%
Recite what is revealed to you of the Scripture, and perform the prayer. The prayer prevents indecencies and evils. And the remembrance of God is greater. And God knows what you do.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccclxxxvi{%
And do not argue with the People of the Scripture except in the best manner possible, except those who do wrong among them. And say, “We believe in what was revealed to us, and in what was revealed to you; and our God and your God is One; and to Him we are submissive.”\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccclxxxvii{%
Likewise, We revealed to you the Scripture. Those to whom We gave the Scripture believe in it, and some of these believe in it. None renounce Our communications except the disbelievers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccclxxxviii{%
You did not read any scripture before this, nor did you write it down with your right hand; otherwise the falsifiers would have doubted.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccclxxxix{%
In fact, it is clear signs in the hearts of those given knowledge. No one renounce Our signs except the unjust.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcccxc{%
And they said, “If only a miracle from his Lord was sent down to him.” Say, “Miracles are only with God, and I am only a clear warner.”\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmcccxci{%
Does it not suffice them that We revealed to you the Scripture, which is recited to them? In that is mercy and a reminder for people who believe.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmcccxcii{%
Say, “God suffices as witness between you and me. He knows everything in the heavens and the Earth. Those who believe in vanity and reject God—it is they who are the losers.”\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcccxciii{%
And they urge you to hasten the punishment. Were it not for a specified time, the punishment would have come to them. But it will come upon them suddenly, while they are unaware.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcccxciv{%
They urge you to hasten the punishment. But Hell will engulf the disbelievers.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcccxcv{%
On the Day when the punishment will envelop them, from above them, and from beneath their feet, He will say, “Taste what you used to do!”\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcccxcvi{%
O My servants who have believed: My earth is vast, so worship Me alone.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcccxcvii{%
Every soul will taste death. Then to Us you will be returned.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcccxcviii{%
Those who believe and work righteousness—We will settle them in Paradise, in mansions under which rivers flow, dwelling therein forever. Excellent is the compensation for the workers.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcccxcix{%
Those who endure patiently, and in their Lord they trust.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcd{%
How many a creature there is that does not carry its provision? God provides for them, and for you. He is the Hearer, the Knowledgeable.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcdi{%
And if you asked them, “Who created the heavens and the earth and regulated the sun and the moon?” They would say, “God.” Why then do they deviate?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmcdii{%
God expands the provision for whomever He wills of His servants, and restricts it. God is Cognizant of all things.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmcdiii{%
And if you asked them, “Who sends water down from the sky, with which He revives the earth after it had died?” They would say, “God.” Say, “Praise be to God.” But most of them do not understand.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmcdiv{%
The life of this world is nothing but diversion and play, and the Home of the Hereafter is the Life, if they only knew.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmcdv{%
When they embark on a vessel, they pray to God, devoting their faith to Him; but once He has delivered them safely to land, they attribute partners to Him.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmcdvi{%
To be ungrateful for what We have given them, and to enjoy themselves. They will surely come to know.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmcdvii{%
Do they not see that We established a Secure Sanctuary, while all around them the people are being carried away? Do they believe in falsehood, and reject the blessings of God?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmcdviii{%
And who does greater wrong than he who fabricates lies and attributes them to God, or calls the truth a lie when it has come to him? Is there not in Hell a dwelling for the blasphemers?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmcdix{%
As for those who strive for Us—We will guide them in Our ways. God is with the doers of good.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmcdx{%
\basmalahen Alif, Lam, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcdxi{%
The Romans have been defeated.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcdxii{%
In a nearby territory. But following their defeat, they will be victorious.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcdxiii{%
In a few years. The matter is up to God, in the past, and in the future. On that day, the believers will rejoice.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcdxiv{%
In God’s support. He supports whomever He wills. He is the Almighty, the Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcdxv{%
The promise of God—God never breaks His promise, but most people do not know.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcdxvi{%
They know an outer aspect of the worldly life, but they are heedless of the Hereafter.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcdxvii{%
Do they not reflect within themselves? God did not create the heavens and the earth, and what is between them, except with reason, and for a specific duration. But most people, regarding meeting their Lord, are disbelievers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcdxviii{%
Have they not travelled the earth and seen how those before them ended up? They were more powerful than them, and they cultivated the land and developed it more than they developed it, and their messengers came to them with clear signs. God would never wrong them, but they used to wrong themselves.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcdxix{%
Then, evil was the end of those who committed evil. That is because they rejected God’s revelations, and used to ridicule them.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcdxx{%
God originates creation, and then repeats it. Then to Him you will be returned.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcdxxi{%
On the Day when the Hour takes place, the guilty will despair.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcdxxii{%
They will have no intercessors from among their idols, and they will disown their partners.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcdxxiii{%
On the Day when the Hour takes place—on that Day they will separate.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcdxxiv{%
As for those who believed and did good deeds—they will be delighted in meadows.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcdxxv{%
But as for those who disbelieved, and rejected Our signs and the encounter of the Hereafter—those will be hauled into the torment.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcdxxvi{%
So glorify God when you retire at night, and when you rise in the morning.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcdxxvii{%
His is the praise in the heavens and on earth, and in the evening, and when you reach midday.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcdxxviii{%
He brings the living out of the dead, and He brings the dead out of the living, and He revives the land after it had died. Likewise you will be resurrected.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcdxxix{%
And of His signs is that He created you from dust; and behold, you become humans spreading out.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcdxxx{%
And of His signs is that He created for you mates from among yourselves, so that you may find tranquility in them; and He planted love and compassion between you. In this are signs for people who reflect.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcdxxxi{%
And of His signs is the creation of the heavens and the earth, and the diversity of your languages and colors. In this are signs for those who know.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcdxxxii{%
And of His signs are your sleep by night and day, and your pursuit of His bounty. In this are signs for people who listen.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcdxxxiii{%
And of His signs is that He shows you the lightning, causing fear and hope. And He brings down water from the sky, and with it He revives the earth after it was dead. In this are signs for people who understand.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcdxxxiv{%
And of His signs is that the heaven and the earth stand at His disposal. And then, when He calls you out of the earth, you will emerge at once.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcdxxxv{%
To Him belongs everyone in the heavens and the earth. All are submissive to Him.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcdxxxvi{%
It is He who initiates creation, and then repeats it, something easy for Him. His is the highest attribute, in the heavens and the earth. He is the Almighty, the Wise.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcdxxxvii{%
He illustrates an example for you, from your own selves: do you make your servants full partners in the wealth We have given you? Do you revere them as you revere one another? We thus explain the revelations for a people who understand.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcdxxxviii{%
Yet the wrongdoers follow their desires without knowledge. But who can guide whom God leaves astray? They will have no helpers.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcdxxxix{%
So devote yourself to the religion of monotheism—the natural instinct God has instilled in mankind. There is no altering God’s creation. This is the true religion, but most people do not know.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcdxl{%
Turning towards Him—and be conscious of Him, and perform the prayer, and do not be of the idolaters.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcdxli{%
Of those who divided their religion, and became sects; each faction pleased with what they have.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcdxlii{%
When affliction touches the people, they call on their Lord, turning to Him in repentance. But then, when He gives them a taste of His mercy, some of them attribute partners to their Lord.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcdxliii{%
To show ingratitude for what We have given them. Indulge yourselves—you will surely know.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcdxliv{%
Have We sent down to them any authority, which speaks in support of their idols?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcdxlv{%
When We give people a taste of mercy, they rejoice in it. But when adversity befalls them, because of what their hands have perpetrated, they begin to despair.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcdxlvi{%
Do they not see that God expands the provision for whomever He wills, or restricts it? Surely in this are signs for people who believe.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmcdxlvii{%
So give the relative his rights, and the destitute, and the wayfarer. That is best for those who seek God’s presence. Those are the prosperous.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmcdxlviii{%
The usury you practice, seeking thereby to multiply people’s wealth, will not multiply with God. But what you give in charity, desiring God’s approval—these are the multipliers.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmcdxlix{%
God is He who created you, then provides for you, then makes you die, then brings you back to life. Can any of your idols do any of that? Glorified is He, and Exalted above what they associate.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmcdl{%
Corruption has appeared on land and sea, because of what people’s hands have earned, in order to make them taste some of what they have done, so that they might return.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmcdli{%
Say, “Roam the earth, and observe the fate of those who came before. Most of them were idolaters.”\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmcdlii{%
So devote yourself to the upright religion, before there comes from God a Day that cannot be averted. On that Day, they will be shocked.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmcdliii{%
Whoever disbelieves, upon him falls his disbelief. And whoever acts righteously—they are preparing for themselves.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmcdliv{%
So that He may reward those who have believed and done the righteous deeds out of His bounty. Indeed, He does not love the ungrateful.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmcdlv{%
And of His signs is that He sends the winds bearing good news, to give you a taste of His mercy, and so that the ships may sail by His command, and so that you may seek of His bounty, and so that you may give thanks.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmcdlvi{%
Before you, We sent messengers to their people. They came to them with clear proofs. Then We took revenge on those who sinned. It is incumbent on Us to help the believers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmcdlvii{%
God is He who sends the winds. They stir up clouds. Then He spreads them in the sky as He wills. And He breaks them apart. Then you see rain drops issuing from their midst. Then, when He makes it fall upon whom He wills of His servants, behold, they rejoice.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmcdlviii{%
Although they were before this—before it was sent down upon them—in despair.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcdlix{%
So observe the effects of God’s mercy—how He revives the earth after it was dead. Indeed, He is the Reviver of the dead. He is Capable of everything.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmcdlx{%
But if We send a wind, and they see it turning things yellow, they would continue thereafter to disbelieve.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmcdlxi{%
You cannot make the dead hear, nor can you make the deaf hear the call when they turn away.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcdlxii{%
Nor can you guide the blind out of their error. You can make hear only those who believe in Our signs, and so have submitted.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcdlxiii{%
God is He Who created you weak, then after weakness gave you strength, then after strength gave you weakness and gray hair. He creates whatever He wills. He is the Omniscient, the Omnipotent.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcdlxiv{%
On the Day when the Hour takes place, the sinners will swear they had stayed but an hour. Thus they were deluded.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcdlxv{%
But those endowed with knowledge and faith will say, “You remained in God’s Book until the Day of Resurrection. This is the Day of Resurrection, but you did not know.”\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcdlxvi{%
On that Day, the sinners’ excuses will not benefit them, nor will they be excused.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcdlxvii{%
We have cited in this Quran for the people every sort of parable. But even if you bring them a miracle, those who disbelieve will say, “You are nothing but fakers.”\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcdlxviii{%
God thus seals the hearts of those who do not know.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcdlxix{%
So be patient. The promise of God is true. And do not let those who lack certainty belittle you.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcdlxx{%
\basmalahen Alif, Lam, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcdlxxi{%
These are the Verses of the Wise Book.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcdlxxii{%
A guide and a mercy for the righteous.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcdlxxiii{%
Those who observe the prayer, and pay the obligatory charity, and are certain of the Hereafter.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcdlxxiv{%
These are upon guidance from their Lord. These are the successful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcdlxxv{%
Among the people is he who trades in distracting tales; intending, without knowledge, to lead away from God’s way, and to make a mockery of it. These will have a humiliating punishment.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcdlxxvi{%
And when Our Verses are recited to him, he turns away in pride, as though he did not hear them, as though there is deafness in his ears. So inform him of a painful punishment.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcdlxxvii{%
As for those who believe and do good deeds—for them are the Gardens of Bliss.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcdlxxviii{%
Dwelling therein forever. The promise of God is true. He is the Mighty, the Wise.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcdlxxix{%
He created the heavens without pillars that you can see, and placed stabilizers on earth lest it shifts with you, and scattered throughout it all kinds of creatures. And from the sky We sent down water, and caused to grow therein of every noble pair.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcdlxxx{%
Such is God’s creation. Now show me what those besides Him have created. In fact, the wicked are in obvious error.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxi{%
We endowed Luqman with wisdom: “Give thanks to God.” Whoever is appreciative—is appreciative for the benefit of his own soul. And whoever is unappreciative—God is Sufficient and Praiseworthy.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxii{%
When Luqman said to his son, as he advised him, “O my son, do not associate anything with God, for idolatry is a terrible wrong.”\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxiii{%
We have entrusted the human being with the care of his parents. His mother carried him through hardship upon hardship, weaning him in two years. So give thanks to Me, and to your parents. To Me is the destination.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxiv{%
But if they strive to have you associate with Me something of which you have no knowledge, do not obey them. But keep them company in this life, in kindness, and follow the path of him who turns to Me. Then to Me is your return; and I will inform you of what you used to do.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxv{%
“O my son, even if it were the weight of a mustard-seed, in a rock, or in the heavens, or on earth, God will bring it to light. God is Kind and Expert.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxvi{%
O my son, observe the prayer, advocate righteousness, forbid evil, and be patient over what has befallen you. These are of the most honorable traits.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxvii{%
And do not treat people with arrogance, nor walk proudly on earth. God does not love the arrogant showoffs.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxviii{%
And moderate your stride, and lower your voice. The most repulsive of voices is the donkey’s voice.”\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxix{%
Do you not see how God placed at your service everything in the heavens and the earth? How He showered you with His blessings, both outward and inward? Yet among the people is he who argues about God without knowledge, without guidance, and without an enlightening Scripture.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcdxc{%
And when it is said to them, “Follow what God has revealed,” they say, “Rather, we follow what we found our parents devoted to.” Even if Satan is calling them to the suffering of the Blaze?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcdxci{%
Whoever submits himself wholly to God, and is a doer of good, has grasped the most trustworthy handle. With God rests the outcome of all events.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcdxcii{%
Whoever disbelieves—let not his disbelief sadden you. To Us is their return. Then We will inform them of what they did. God knows what lies within the hearts.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcdxciii{%
We give them a little comfort; then We compel them to a harsh torment.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcdxciv{%
And if you ask them, “Who created the heavens and the earth?” They will say, “God.” Say, “Praise be to God.” But most of them do not know.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcdxcv{%
To God belongs everything in the heavens and the earth. God is the Rich, the Praised.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcdxcvi{%
If all the trees on earth were pens, filled by the ocean, with seven more oceans besides, the Words of God would not run out. God is Majestic and Wise.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcdxcvii{%
Your creation and your resurrection are only as a single soul. God is Hearing and Seeing.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcdxcviii{%
Have you not seen how God merges the night into the day, and merges the day into the night? That He subjected the sun and the moon, each running for a stated term? And that God is Cognizant of everything you do?\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcdxcix{%
That is because God is the Reality, and what they worship besides Him is falsehood, and because God is the Exalted, the Supreme.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmd{%
Have you not seen how the ships sail through the sea, by the grace of God, to show you of His wonders? In that are signs for every persevering, thankful person.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdi{%
When waves, like canopies, cover them, they call upon God, devoting their religion to Him. But when He has delivered them to dry land, some of them waver. No one renounces Our revelations except the treacherous blasphemer.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdii{%
O people! Be conscious of your Lord, and dread a Day when no parent can avail his child, nor can a child avail his parent, in anything. The promise of God is true. Therefore, do not let this life deceive you, nor let illusions deceive you regarding God.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdiii{%
With God rests the knowledge of the Hour. He sends down the rain, and He knows what the wombs contain. No soul knows what it will reap tomorrow, and no soul knows in what land it will die. God is All-Knowing, Well-Informed.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdiv{%
\basmalahen Alif, Lam, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdv{%
The revelation of the Book, without a doubt, is from the Lord of the Universe.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdvi{%
Yet they say, “He made it up.” In fact, it is the Truth from your Lord, to warn a people who received no warner before you, that they may be guided.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdvii{%
God is He who created the heavens and the earth and everything between them in six days, and then established Himself on the Throne. Apart from Him, you have no master and no intercessor. Will you not reflect?\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdviii{%
He regulates all affairs, from the heavens, to the earth. Then it ascends to Him on a Day the length of which is a thousand years by your count.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdix{%
That is the Knower of the Invisible and the Visible, the Powerful, the Merciful.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdx{%
He who perfected everything He created, and originated the creation of man from clay.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdxi{%
Then made his reproduction from an extract of an insignificant fluid.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdxii{%
Then He proportioned him, and breathed into him of His Spirit. Then He gave you the hearing, and the eyesight, and the brains—but rarely do you give thanks.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdxiii{%
And they say, “When we are lost into the earth, shall we be in a new creation?” In fact, they deny the meeting with their Lord.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdxiv{%
Say, “The angel of death put in charge of you will reclaim you. Then to your Lord you will be returned.”\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdxv{%
If only you could see the guilty, bowing their heads before their Lord: “Our Lord, we have seen and we have heard, so send us back, and we will act righteously; we are now convinced.”\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdxvi{%
Had We willed, We could have given every soul its guidance, but the declaration from Me will come true: “I will fill Hell with jinn and humans, altogether.”\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdxvii{%
So taste, because you forgot the meeting of this Day of yours; We have forgotten you; so taste the eternal torment for what you used to do.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdxviii{%
They believe in Our communications, those who, when reminded of them, fall down prostrate, and glorify their Lord with praise, and are not proud.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdxix{%
Their sides shun their beds, as they pray to their Lord, out of reverence and hope; and from Our provisions to them, they give.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdxx{%
No soul knows what eye’s delight awaits them—a reward for what they used to do.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdxxi{%
Is someone who is faithful like someone who is a sinner? They are not equal.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdxxii{%
As for those who believe and do righteous deeds, for them are the Gardens of Shelter—hospitality for what they used to do.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdxxiii{%
But as for those who transgressed, their shelter is the Fire. Every time they try to get out of it, they will be brought back into it, and it will be said to them, “Taste the suffering of the Fire which you used to deny.”\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdxxiv{%
We will make them taste the lesser torment, prior to the greater torment, so that they may return.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdxxv{%
Who is more wrong than he, who, when reminded of his Lord’s revelations, turns away from them? We will certainly wreak vengeance upon the criminals.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdxxvi{%
We gave Moses the Book; so do not be in doubt regarding His encounter; and We made it a guidance for the Children of Israel.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdxxvii{%
And We appointed leaders from among them, guiding by Our command, as long as they persevered and were certain of Our communications.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdxxviii{%
Your Lord will judge between them on the Day of Resurrection regarding everything they had disputed.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdxxix{%
Is it not a lesson for them, how many generations We have destroyed before them, in whose habitations they walk? Surely in that are signs. Do they not hear?\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdxxx{%
Do they not see how We conduct the water to a dry land, and with it We produce vegetation, from which their livestock eat, and themselves? Do they not see?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdxxxi{%
And they say, “When is this victory, if you are truthful?”\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdxxxii{%
Say, “On the day of victory, the faith of those who disbelieved will be of no avail to them, and they will not be granted respite.”\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdxxxiii{%
So turn away from them, and wait. They too are waiting.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdxxxiv{%
\basmalahen O Prophet! Fear God, and do not obey the unbelievers and the hypocrites. God is Knowledgeable and Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdxxxv{%
And follow what is revealed to you from your Lord. God is fully aware of what you do.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdxxxvi{%
And put your trust in God. God is enough as a trustee.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdxxxvii{%
God did not place two hearts inside any man's body. Nor did He make your wives whom you equate with your mothers, your actual mothers. Nor did He make your adopted sons, your actual sons. These are your words coming out of your mouths. God speaks the truth, and guides to the path.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdxxxviii{%
Call them after their fathers; that is more equitable with God. But if you do not know their fathers, then your brethren in faith and your friends. There is no blame on you if you err therein, barring what your hearts premeditates. God is Forgiving and Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdxxxix{%
The Prophet is more caring of the believers than they are of themselves, and his wives are mothers to them. And blood-relatives are closer to one another in God’s Book than the believers or the emigrants, though you should do good to your friends. That is inscribed in the Book.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdxl{%
Recall that We received a pledge from the prophets, and from you, and from Noah, and Abraham, and Moses, and Jesus son of Mary. We received from them a solemn pledge.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdxli{%
That He may ask the sincere about their sincerity. He has prepared for the disbelievers a painful punishment.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdxlii{%
O you who believe! Remember God’s blessings upon you, when forces came against you, and We sent against them a wind, and forces you did not see. God is Observant of what you do.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdxliii{%
When they came upon you, from above you, and from beneath you; and the eyes became dazed, and the hearts reached the throats, and you harbored doubts about God.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdxliv{%
There and then the believers were tested, and were shaken most severely.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdxlv{%
When the hypocrites and those in whose hearts is sickness said, “God and His Messenger promised us nothing but illusion.”\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdxlvi{%
And when a group of them said, “O people of Yathrib, you cannot make a stand, so retreat.” And a faction of them asked the Prophet to excuse them, saying, “Our homes are exposed,” although they were not exposed. They only wanted to flee.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdxlvii{%
Had it been invaded from its sides, and they were asked to dissent, they would have done so with little hesitation.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdxlviii{%
Although they had made a pledged to God, in the past, that they will not turn their backs. A pledge to God is a responsibility.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdxlix{%
Say, “Flight will not benefit you, if you flee from death or killing, even then you will be given only brief enjoyment.”\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdl{%
Say, “Who is it who will shield you from God, if He intends adversity for you, or intends mercy for you?” Besides God, they will find for themselves neither friend nor helper.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdli{%
God already knows the hinderers among you, and those who say to their brethren, “Come and join us.” Rarely do they mobilize for battle.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdlii{%
Being stingy towards you. And when fear approaches, you see them staring at you—their eyes rolling—like someone fainting at death. Then, when panic is over, they whip you with sharp tongues. They resent you any good. These have never believed, so God has nullified their works; a matter easy for God.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdliii{%
They assumed that the confederates had not withdrawn. But were the confederates to advance, they would wish they were in the desert with the Bedouins, inquiring about your news. And if they were among you, they would have done little fighting.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdliv{%
You have an excellent example in the Messenger of God; for anyone who seeks God and the Last Day, and remembers God frequently.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdlv{%
And when the believers saw the confederates, they said, “This is what God and His messenger have promised us; and God and His messenger have told the truth.” And it only increased them in faith and submission.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdlvi{%
Of the believers are men who are true to what they pledged to God. Some of them have fulfilled their vows; and some are still waiting, and never wavering.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdlvii{%
That God may reward the truthful for their truthfulness; and punish the hypocrites, if He wills, or pardon them. God is Forgiving and Merciful.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdlviii{%
God repelled the disbelievers in their rage; they gained no advantage. God thus spared the believers combat. God is Strong and Mighty.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdlix{%
And He brought down from their strongholds those of the People of the Book who backed them, and He threw terror into their hearts. Some of them you killed, and others you took captive.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdlx{%
And He made you inherit their land, and their homes, and their possessions, and a region you have never stepped on. God has power over all things.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdlxi{%
O Prophet! Say to your wives, “If you desire the life of this world and its finery, then let me compensate you, and release you kindly.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdlxii{%
But if you desire God, His Messenger, and the Home of the Hereafter, then God has prepared for the righteous among you a magnificent compensation.”\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdlxiii{%
O wives of the Prophet! Whoever of you commits a proven indecency, the punishment for her will be doubled. And that would be easy for God.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdlxiv{%
But whoever of you remains obedient to God and His Messenger, and acts righteously, We will give her a double reward; and We have prepared for her a generous provision.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdlxv{%
O wives of the Prophet! You are not like any other women, if you observe piety. So do not speak too softly, lest the sick at heart lusts after you, but speak in an appropriate manner.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdlxvi{%
And settle in your homes; and do not display yourselves, as in the former days of ignorance. And perform the prayer, and give regular charity, and obey God and His Messenger. God desires to remove all impurity from you, O People of the Household, and to purify you thoroughly.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdlxvii{%
And remember what is recited in your homes of God's revelations and wisdom. God is Kind and Informed.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdlxviii{%
Muslim men and Muslim women, believing men and believing women, obedient men and obedient women, truthful men and truthful women, patient men and patient women, humble men and humble women, charitable men and charitable women, fasting men and fasting women, men who guard their chastity and women who guard, men who remember God frequently and women who remember—God has prepared for them a pardon, and an immense reward.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdlxix{%
It is not for any believer, man or woman, when God and His Messenger have decided a matter, to have liberty of choice in their decision. Whoever disobeys God and His Messenger has gone far astray.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdlxx{%
When you said to him whom God had blessed, and you had favored, “Keep your wife to yourself, and fear God.” But you hid within yourself what God was to reveal. And you feared the people, but it was God you were supposed to fear. Then, when Zaid ended his relationship with her, We gave her to you in marriage, that there may be no restriction for believers regarding the wives of their adopted sons, when their relationship has ended. The command of God was fulfilled.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdlxxi{%
There is no blame on the Prophet regarding what God has ordained for him. Such is the pattern of God among those who passed before. The command of God is an absolute decree.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdlxxii{%
Those who deliver the messages of God, and fear Him, and never fear anyone except God. God is sufficient as a reckoner.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdlxxiii{%
Muhammad is not the father of any of your men; but he is the Messenger of God, and the seal of the prophets. God is Cognizant of everything.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdlxxiv{%
O you who believe, remember God with frequent remembrance.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdlxxv{%
And glorify Him morning and evening.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdlxxvi{%
It is He who reaches out to you, and His angels, to bring you out of darkness into the light. And He is Ever-Merciful towards the believers.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdlxxvii{%
Their greeting on the Day they meet Him is, “Peace,” and He has prepared for them a generous reward.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdlxxviii{%
O prophet! We have sent you as a witness, and a bearer of good news, and a warner.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdlxxix{%
And a caller towards God by His leave, and an illuminating beacon.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdlxxx{%
And give the believers the good news that for them is a great reward.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdlxxxi{%
And do not obey the blasphemers and the hypocrites, and ignore their insults, and rely on God. God is a sufficient protector.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdlxxxii{%
O you who believe! When you marry believing women, but then divorce them before you have touched them, there is no waiting period for you to observe in respect to them; but compensate them, and release them in a graceful manner.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdlxxxiii{%
O Prophet! We have permitted to you your wives to whom you have given their dowries, and those you already have, as granted to you by God, and the daughters of your paternal uncle, and the daughters of your paternal aunts, and the daughters of your maternal uncle, and the daughters of your maternal aunts who emigrated with you, and a believing woman who has offered herself to the Prophet, if the Prophet desires to marry her, exclusively for you, and not for the believers. We know what We have ordained for them regarding their wives and those their right-hands possess. This is to spare you any difficulty. God is Forgiving and Merciful.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdlxxxiv{%
You may defer any of them you wish, and receive any of them you wish. Should you desire any of those you had deferred, there is no blame on you. This is more proper, so that they will be comforted, and not be grieved, and be content with what you have given each one of them. God knows what is within your hearts. God is Omniscient and Clement.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdlxxxv{%
Beyond that, no other women are permissible for you, nor can you exchange them for other wives, even if you admire their beauty, except those you already have. God is Watchful over all things.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdlxxxvi{%
O you who believe! Do not enter the homes of the Prophet, unless you are given permission to come for a meal; and do not wait for its preparation. And when you are invited, go in. And when you have eaten, disperse, without lingering for conversation. This irritates the Prophet, and he shies away from you, but God does not shy away from the truth. And when you ask his wives for something, ask them from behind a screen; that is purer for your hearts and their hearts. You must never offend the Messenger of God, nor must you ever marry his wives after him, for that would be an enormity with God.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdlxxxvii{%
Whether you declare a thing, or hide it, God is Aware of all things.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdlxxxviii{%
There is no blame on them concerning their fathers, or their sons, or their brothers, or their brothers’ sons, or their sisters’ sons, or their women, or their female servants. But they should remain conscious of God. God is Witness over all things.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdlxxxix{%
God and His angels give blessings to the Prophet. O you who believe, call for blessings on him, and greet him with a prayer of peace.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdxc{%
Those who insult God and His Messenger, God has cursed them in this life and in the Hereafter, and has prepared for them a demeaning punishment.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdxci{%
Those who harm believing men and believing women, for acts they did not commit, bear the burden of perjury and a flagrant sin.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdxcii{%
O Prophet! Tell your wives, and your daughters, and the women of the believers, to lengthen their garments. That is more proper, so they will be recognized and not harassed. God is Forgiving and Merciful.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdxciii{%
If the hypocrites, and those with sickness in their hearts, and the rumormongers in the City, do not desist, We will incite you against them; then they will not be your neighbors there except for a short while.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdxciv{%
They are cursed; wherever they are found, they should be captured and killed outright.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdxcv{%
Such has been God’s precedent with those who passed away before. You will find no change in God’s system.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdxcvi{%
The people ask you about the Hour. Say, “The knowledge thereof rests with God. But what do you know? Perhaps the hour is near.”\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdxcvii{%
God has cursed the disbelievers, and has prepared for them a Blaze.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdxcviii{%
Dwelling therein forever, not finding a protector or a savior.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdxcix{%
The Day when their faces are flipped into the Fire, they will say, “If only we had obeyed God and obeyed the Messenger.”\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdc{%
And they will say, “Lord, we have obeyed our superiors and our dignitaries, but they led us away from the way.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdci{%
Lord, give them double the punishment, and curse them with a great curse.”\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdcii{%
O you who believe! Do not be like those who abused Moses; but God cleared him of what they said. He was distinguished with God.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdciii{%
O you who believe! Be conscious of God, and speak in a straightforward manner.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdciv{%
He will rectify your conduct for you, and will forgive you your sins. Whoever obeys God and His Messenger has won a great victory.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdcv{%
We offered the Trust to the heavens, and the earth, and the mountains; but they refused to bear it, and were apprehensive of it; but the human being accepted it. He was unfair and ignorant.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdcvi{%
God will punish the hypocrites, men and women, and the idolaters, men and women. And God will redeem the believers, men and women. God is Ever-Forgiving, Most Merciful.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdcvii{%
\basmalahen Praise be to God, to Whom belongs everything in the heavens and the earth; and praise be to Him in the Hereafter. He is the Wise, the Expert.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdcviii{%
He knows what penetrates into the earth, and what comes out of it, and what descends from the sky, and what ascends to it. He is the Merciful, the Forgiving.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdcix{%
Those who disbelieve say, “The Hour will not come upon us.” Say, “Yes indeed, by my Lord, it will come upon you. He is the Knower of the unseen.” Not an atom's weight in the heavens and the earth, or anything smaller or larger, escapes His knowledge. All are in a Clear Record.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdcx{%
That He may recompense those who believe and do good works. Those will have forgiveness, and a generous provision.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdcxi{%
As for those who strive against Our revelations, seeking to undermine them—for them is a punishment of a painful plague.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdcxii{%
Those who received knowledge know that what is revealed to you from your Lord is the truth; and it guides to the path of the Majestic, the Praiseworthy.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdcxiii{%
Those who disbelieved said, “Shall we point out to you a man, who will tell you that, once torn into shreds, you will be in a new creation?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdcxiv{%
Did he invent a lie about God, or is there madness in him?” Indeed, those who do not believe in the Hereafter are in torment, and far astray.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdcxv{%
Do they not reflect upon what lies before them and behind them, of the heaven and the earth? If We will, We can make the earth cave in beneath them, or make pieces of the sky fall down on them. In that is a sign for every devout servant.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdcxvi{%
We bestowed upon David favor from Us: “O mountains, and birds: echo with him.” And We softened iron for him.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdcxvii{%
“Make coats of armor, and measure the links well; and work righteousness. I am Observant of everything you do.”\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdcxviii{%
And for Solomon the wind—its outward journey was one month, and its return journey was one month. And We made a spring of tar flow for him. And there were sprites that worked under him, by the leave of his Lord. But whoever of them swerved from Our command, We make him taste of the punishment of the Inferno.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdcxix{%
They made for him whatever he wished: sanctuaries, statues, bowls like pools, and heavy cauldrons. “O House of David, work with appreciation,” but a few of My servants are appreciative.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdcxx{%
Then, when We decreed death for him, nothing indicated his death to them except an earthworm eating at his staff. Then, when he fell down, it became clear to the sprites that, had they known the unseen, they would not have remained in the demeaning torment.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdcxxi{%
In Sheba’s homeland there used to be a wonder: two gardens, on the right, and on the left. “Eat of your Lord’s provision, and give thanks to Him.” A good land, and a forgiving Lord.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdcxxii{%
But they turned away, so We unleashed against them the flood of the dam; and We substituted their two gardens with two gardens of bitter fruits, thorny shrubs, and meager harvest.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdcxxiii{%
We thus penalized them for their ingratitude. Would We penalize any but the ungrateful?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdcxxiv{%
Between them and the towns We had blessed, We placed prominent towns, and We made the travel between them easy. “Travel between them by night and day, in safety.”\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdcxxv{%
But they said, “Our Lord, lengthen the distances of our journeys.” They wronged themselves; so We made them history, and We scattered them in every direction. In this are lessons for every steadfast and appreciative person.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdcxxvi{%
Satan was correct in his assessment of them. They followed him, except for a group of believers.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdcxxvii{%
He had no authority over them; except that We willed to distinguish him who believes in the Hereafter, from him who is doubtful about it. Your Lord is Guardian over all things.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdcxxviii{%
Say, “Call upon those whom you claim besides God. They possess not an atom's weight in the heavens or the earth, and they possess no share of either, and He has no backers from among them.”\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdcxxix{%
Intercession with Him is of no value, except for someone He has permitted. Until, when fear has subsided from their hearts, they will say, “What did your Lord say?” They will say, “The truth, and He is the High, the Great.”\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdcxxx{%
Say, “Who provides for you from the heavens and the earth?” Say, “God. And Either you, or we, are rightly guided, or in evident error.”\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdcxxxi{%
Say, “You will not be asked about our misdeeds, nor will we be asked about what you do.”\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdcxxxii{%
Say, “Our Lord will bring us together; then He will judge between us equitably. He is the All-Knowing Judge.”\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdcxxxiii{%
Say, “Show me those you have attached to Him as associates. No indeed! But He is God, the Powerful, the Wise.”\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdcxxxiv{%
We sent you only universally to all people, a herald and warner, but most people do not know.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdcxxxv{%
And they say, “When is this promise due, if you are truthful?”\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcxxxvi{%
Say, “You are promised a Day, which you cannot postpone by one hour, nor bring forward.”\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcxxxvii{%
Those who disbelieve say, “We will never believe in this Quran, nor in what came before it.” If you could only see the wrongdoers, captive before their Lord, throwing back allegations at one another. Those who were oppressed will say to those who were arrogant, “Were it not for you, we would have been believers.”\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcxxxviii{%
Those who were arrogant will say to those who were oppressed, “Was it us who turned you away from guidance when it came to you? No indeed, you yourselves were sinful.”\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcxxxix{%
And those who were oppressed will say to those who were arrogant, “It was your scheming by night and day; as you instructed us to reject God, and to set up rivals to Him.” They will hide their remorse when they see the retribution. We will put yokes around the necks of those who disbelieved. Will they be repaid for anything other than what they used to do?\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcxl{%
We sent no warner to any town, without its affluent saying, “We reject what you are sent with.”\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcxli{%
And they say, “We have more wealth and more children, and we will not be punished.”\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcxlii{%
Say, “My Lord spreads out His bounty to whomever He wills, or restricts it; but most people do not know.”\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcxliii{%
It is neither your wealth nor your children that bring you closer to Us, but it is he who believes and does good deeds. These will have a double reward for what they did; and they will reside in the Chambers, in peace and security.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcxliv{%
But those who work against Our revelations, seeking to undermine them—those will be summoned to the punishment.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcxlv{%
Say, “My Lord extends the provision to whomever He wills of His servants, or withholds it. Anything you spend, He will replace it. He is the Best of providers.”\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcxlvi{%
On the Day when He gathers them all together, then say to the angels, “Was it you these used to worship?”\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcxlvii{%
They will say, “Be You glorified; You are our Master, not them. In fact, they used to worship the jinn, and most of them had faith in them.”\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdcxlviii{%
“Today, none of you has the power to profit or harm the other.” And We will say to those who did wrong, “Taste the agony of the Fire which you used to deny.”\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcxlix{%
And when Our enlightening Verses are recited to them, they say, “This is nothing but a man who wants to divert you from what your ancestors used to worship.” And they say, “This is nothing but a fabricated lie.” And when the Truth comes to them, the blasphemers say of the Truth, “This is nothing but plain magic.”\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcl{%
But We gave them no book to study, and We did not send them any warner before you.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdcli{%
Those before them also denied the Truth, yet they have not attained one-tenth of what We had given them. They rejected My messengers, so how was My disapproval?\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdclii{%
Say, “I offer you a single advice: devote yourselves to God, in pairs, or individually; and reflect. There is no madness in your friend. He is just a warner to you, before the advent of a severe punishment.”\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcliii{%
Say, “Whatever compensation I have asked of you, is yours. My compensation comes only from God, and He is Witness over all things.”\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdcliv{%
Say, “My Lord projects the truth. He is the Knower of the Unseen.”\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdclv{%
Say, “The Truth has come; while falsehood can neither originate, nor regenerate.”\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdclvi{%
Say, “If I err, I err only to my own loss; but if I am guided, it is by what my Lord inspires me. He is Hearing and Near.”\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdclvii{%
If you could only see when they are terrified, and there is no escape, and they are seized from a nearby place.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdclviii{%
And they say, “We have believed in it.” But how can they attain it from a distant place?\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdclix{%
They have rejected it in the past, and made allegations from a far-off place.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdclx{%
A barrier will be placed between them and what they desire, as was done formerly with their counterparts. They were in disturbing doubt.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdclxi{%
\basmalahen Praise be to God, Originator of the heavens and the earth, Maker of the angels messengers with wings—double, triple, and quadruple. He adds to creation as He wills. God is Able to do all things.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdclxii{%
Whatever mercy God unfolds for the people, none can withhold it. And if He withholds it, none can release it thereafter. He is the Exalted in Power, Full of Wisdom.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdclxiii{%
O people! Remember God’s blessings upon you. Is there a creator other than God who provides for you from the heaven and the earth? There is no god but He. So how are you misled?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdclxiv{%
If they reject you, messengers before you were also rejected. To God all matters are returned.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdclxv{%
O people! The promise of God is true; so let not the lowly life seduce you, and let not the Tempter tempt you away from God.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdclxvi{%
Satan is an enemy to you, so treat him as an enemy. He only invites his gang to be among the inmates of the Inferno.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdclxvii{%
Those who disbelieve will suffer a harsh punishment, but those who believe and do righteous deeds will have forgiveness and a great reward.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdclxviii{%
What of him whose evil deed was made attractive to him, and so he regards it as good? God leads astray whomever He wills, and He guides whomever He wills. Therefore, do not waste yourself sorrowing over them. God knows exactly what they do.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdclxix{%
God is He who sends the winds, which agitate clouds, which We drive to a dead land, and thereby revive the ground after it had died. Likewise is the Resurrection.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdclxx{%
Whoever desires honor—all honor belongs to God. To Him ascends speech that is pure, and He elevates righteous conduct. As for those who plot evil, a terrible punishment awaits them, and the planning of these will fail.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdclxxi{%
God created you from dust, then from a small drop; then He made you pairs. No female conceives, or delivers, except with His knowledge. No living thing advances in years, or its life is shortened, except it be in a Record. That is surely easy for God.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdclxxii{%
The two seas are not the same. One is fresh, sweet, good to drink, while the other is salty and bitter. Yet from each you eat tender meat, and extract jewelry which you wear. And you see the ships plowing through them, so that you may seek of His bounty, so that you may give thanks.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdclxxiii{%
He merges the night into the day, and He merges the day into the night; and He regulates the sun and the moon, each running for a stated term. Such is God, your Lord; His is the sovereignty. As for those you call upon besides Him, they do not possess a speck.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdclxxiv{%
If you pray to them, they cannot hear your prayer. And even if they heard, they would not answer you. And on the Day of Resurrection, they will reject your partnership. None informs you like an Expert.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdclxxv{%
O people! It is you who are the poor, in need of God; while God is the Rich, the Praiseworthy.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdclxxvi{%
If He wills, He can do away with you, and produce a new creation.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdclxxvii{%
And that would not be difficult for God.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdclxxviii{%
No burdened soul can carry the burden of another. Even if one weighted down calls for help with its burden, nothing can be lifted from it, even if they were related. You are to warn those who fear their Lord inwardly, and perform the prayer. He who purifies himself purifies himself for his own good. To God is the ultimate return.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdclxxix{%
Not equal are the blind and the seeing.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdclxxx{%
Nor are the darkness and the light.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdclxxxi{%
Nor are the shade and the torrid heat.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdclxxxii{%
Nor are equal the living and the dead. God causes whomever He wills to hear, but you cannot make those in the graves hear.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdclxxxiii{%
You are only a warner.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdclxxxiv{%
We sent you with the truth; a bearer of good news, and a warner. There is no community but a warner has passed through it.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdclxxxv{%
If they disbelieve you, those before them also disbelieved. Their messengers came to them with the clear proofs, with the Psalms, and with the Enlightening Scripture.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdclxxxvi{%
Then I seized those who disbelieved—so how was My rejection?\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdclxxxvii{%
Have you not seen that God sends down water from the sky? With it We produce fruits of various colors. And in the mountains are streaks of white and red—varying in their hue—and pitch-black.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdclxxxviii{%
Likewise, human beings, animals, and livestock come in various colors. From among His servants, the learned fear God. God is Almighty, Oft-Forgiving.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdclxxxix{%
Those who recite the Book of God, and perform the prayer, and spend of what We have provided for them, secretly and publicly, expect a trade that will not fail.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcxc{%
He will pay them their dues in full, and will increase them from His bounty. He is Forgiving and Appreciative.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcxci{%
What We inspired in you, of the Book, is the truth, confirming what preceded it. God is Well-Informed of His servants, All-Seeing.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcxcii{%
Then We passed the Book to those of Our servants whom We chose. Some of them wrong their souls, and some follow a middle course, and some are in the foremost in good deeds by God’s leave; that is the greatest blessing.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcxciii{%
The Gardens of Eden, which they will enter. They will be adorned therein with gold bracelets and pearls, and their garments therein will be of silk.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcxciv{%
And they will say, “Praise God, who has lifted all sorrow from us. Our Lord is Most Forgiving, Most Appreciative.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcxcv{%
He Who settled us in the Home of Permanence, by His grace, where boredom will not touch us, and fatigue will not afflict us.”\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcxcvi{%
As for those who disbelieve, for them is the Fire of Hell, wherein they will never be finished off and die, nor will its punishment be lightened for them. Thus We will repay every ingrate.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcxcvii{%
And they will scream therein, “Our Lord, let us out, and we will act righteously, differently from the way we used to act.” Did We not give you a life long enough, in which anyone who wanted to understand would have understood? And the warner did come to you. So taste. The evildoers will have no helper.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcxcviii{%
God is the Knower of the future of the heavens and the earth. He knows what the hearts contain.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcxcix{%
It is He who made you successors on earth. Whoever disbelieves, his disbelief will recoil upon him. The disbelief of the disbelievers adds only to their Lord's disfavor of them. The disbelief of the disbelievers adds only to their perdition.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcc{%
Say, “Have you considered those partners of yours that you worship instead of God? Show me what they have created on earth. Or do they have any share in the heavens?” Or have We given them a book whose clear teachings they follow? In fact, the wrongdoers promise one another nothing but delusions.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcci{%
God holds the heavens and the earth, lest they fall apart. And were they to fall apart, there is none to hold them together except He. He is Most Clement, Most Forgiving.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdccii{%
And they swore by God with their solemn oaths, that if a warner came to them, they would be more guided than any other people. Yet when a warner came to them, it only increased them in aversion.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcciii{%
Priding themselves on earth, and scheming evil. But evil scheming overwhelms none but its authors. Do they expect anything but the precedent of the ancients? You will not find any change in God’s practice, and you will not find any substitute to God’s practice.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcciv{%
Have they not journeyed in the land and observed the fate of those who preceded them? They were superior to them in strength. But nothing can defeat God in the heavens or on Earth. He is indeed Omniscient and Omnipotent.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdccv{%
If God were to punish the people for what they have earned, He would not leave a single living creature on its surface. But He defers them until a stated time. Then, when their time has arrived—God is Observant of His creatures.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdccvi{%
\basmalahen Ya, Seen.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdccvii{%
By the Wise Quran.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdccviii{%
You are one of the messengers.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdccix{%
On a straight path.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdccx{%
The revelation of the Almighty, the Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdccxi{%
To warn a people whose ancestors were not warned, and so they are unaware.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdccxii{%
The Word was realized against most of them, for they do not believe.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdccxiii{%
We placed shackles around their necks, up to their chins, so they are stiff-necked.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdccxiv{%
And We placed a barrier in front of them, and a barrier behind them, and We have enshrouded them, so they cannot see.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdccxv{%
It is the same for them, whether you warn them, or do not warn them—they will not believe.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdccxvi{%
You warn only him who follows the Message, and fears the Most Gracious inwardly. So give him good news of forgiveness, and a generous reward.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdccxvii{%
It is We who revive the dead; and We write down what they have forwarded, and their traces. We have tallied all things in a Clear Record.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdccxviii{%
And cite for them the parable of the landlords of the town—when the messengers came to it.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdccxix{%
We sent them two messengers, but they denied them both, so We reinforced them with a third. They said, “We are messengers to you.”\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdccxx{%
They said, “You are nothing but humans like us, and the Gracious did not send down anything; you are only lying.”\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdccxxi{%
They said, “Our Lord knows that we are messengers to you.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdccxxii{%
And our only duty is clear communication.”\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdccxxiii{%
They said, “We see an evil omen in you; if you do not give up, we will stone you, and a painful punishment from us will befall you.”\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdccxxiv{%
They said, “Your evil omen is upon you. Is it because you were reminded? But you are an extravagant people.”\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdccxxv{%
Then a man came running from the remotest part of the city. He said, “O my people, follow the messengers.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdccxxvi{%
Follow those who ask you of no wage, and are themselves guided.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdccxxvii{%
“And why should I not worship Him Who created me, and to Whom you will be returned?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdccxxviii{%
Shall I take other gods instead of Him? If the Merciful desires harm for me, their intercession will not avail me at all, nor will they save me.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdccxxix{%
In that case, I would be completely lost.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdccxxx{%
I have believed in your Lord, so listen to me.”\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdccxxxi{%
It was said, “Enter Paradise.” He said, “If only my people knew.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdccxxxii{%
How my Lord has forgiven me, and made me one of the honored.”\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdccxxxiii{%
After him, We sent down no hosts from heaven to his people; nor would We ever send any down.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdccxxxiv{%
It was just one Cry, and they were stilled.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdccxxxv{%
Alas for the servants. No messenger ever came to them, but they ridiculed him.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdccxxxvi{%
Have they not considered how many generations We destroyed before them; and that unto them they will not return?\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdccxxxvii{%
All of them, every single one of them, will be arraigned before Us.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdccxxxviii{%
And there is a sign for them in the dead land: We give it life, and produce from it grains from which they eat.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdccxxxix{%
And We place in it gardens of palm-trees and vines, and cause springs to gush out of it.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdccxl{%
That they may eat from its fruits, although their hands did not make it. Will they not be appreciative?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdccxli{%
Glory be to Him who created all the pairs; of what the earth produces, and of their own selves, and of what they do not know.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdccxlii{%
Another sign for them is the night: We strip the day out of it—and they are in darkness.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdccxliii{%
And the sun runs towards its destination. Such is the design of the Almighty, the All-Knowing.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdccxliv{%
And the moon: We have disposed it in phases, until it returns like the old twig.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdccxlv{%
The sun is not to overtake the moon, nor is the night to outpace the day. Each floats in an orbit.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdccxlvi{%
Another sign for them is that We carried their offspring in the laden Ark.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdccxlvii{%
And We created for them the like of it, in which they ride.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdccxlviii{%
If We will, We can drown them—with no screaming to be heard from them, nor will they be saved.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdccxlix{%
Except by a mercy from Us, and enjoyment for a while.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdccl{%
Yet when it is said to them, “Beware of what lies before you, and what lies behind you, that you may receive mercy.”\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdccli{%
Yet never came to them a sign of their Lord’s signs, but they turned away from it.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcclii{%
And when it is said to them, “Spend of what God has provided for you,” those who disbelieve say to those who believe, “Shall we feed someone whom God could feed, if He so willed? You must be deeply misguided.”\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdccliii{%
And they say, “When will this promise be, if you are truthful?”\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdccliv{%
All they can expect is a single blast, which will seize them while they feud.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdcclv{%
They will not be able to make a will, nor will they return to their families.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdcclvi{%
The Trumpet will be blown, then behold, they will rush from the tombs to their Lord.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdcclvii{%
They will say, “Woe to us! Who resurrected us from our resting-place?” This is what the Most Gracious had promised, and the messengers have spoken the truth.”\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdcclviii{%
It will be but a single scream; and behold, they will all be brought before Us.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdcclix{%
On that Day, no soul will be wronged in the least, and you will be recompensed only for what you used to do.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdcclx{%
The inhabitants of Paradise, on that Day, will be happily busy.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdcclxi{%
They and their spouses, in shades, reclining on couches.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdcclxii{%
They will have therein fruits. They will have whatever they call for.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdcclxiii{%
Peace—a saying from a Most Merciful Lord.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdcclxiv{%
But step aside today, you criminals.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdcclxv{%
Did I not covenant with you, O Children of Adam, that you shall not serve the devil? That he is your sworn enemy?\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdcclxvi{%
And that you shall serve Me? This is a straight path.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdcclxvii{%
He has misled a great multitude of you. Did you not understand?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdcclxviii{%
This is Hellfire, which you were promised.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdcclxix{%
Roast in it today, because you persistently disbelieved.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdcclxx{%
On this Day, We will seal their mouths, and their hands will speak to Us, and their feet will testify to everything they had done.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdcclxxi{%
If We will, We can blind their eyes as they rush towards the path—but how will they see?\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdcclxxii{%
And if We will, We can cripple them in their place; so they can neither move forward, nor go back.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdcclxxiii{%
Whomever We grant old age, We reverse his development. Do they not understand?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdcclxxiv{%
We did not teach him poetry, nor is it proper for him. It is only a reminder, and a Clear Quran.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdcclxxv{%
That he may warn whoever is alive, and prove the Word against the faithless.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdcclxxvi{%
Have they not seen that We created for them, of Our Handiwork, livestock that they own?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdcclxxvii{%
And We subdued them for them. Some they ride, and some they eat.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdcclxxviii{%
And they have in them other benefits, and drinks. Will they not give thanks?\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdcclxxix{%
Yet they have taken to themselves gods other than God, that perhaps they may be helped.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmdcclxxx{%
They cannot help them, although they are arrayed as troops for them.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxi{%
So let their words not sadden you. We know what they conceal, and what they reveal.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxii{%
Does the human being not consider that We created him from a seed? Yet he becomes a fierce adversary.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxiii{%
And he produces arguments against Us, and he forgets his own creation. He says, “Who will revive the bones when they have decayed?”\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxiv{%
Say, “He who initiated them in the first instance will revive them. He has knowledge of every creation.”\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxv{%
He who produced fuel for you from the green trees, with which you kindle a fire.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxvi{%
Is not He who created the heavens and the earth able to create the like of them? Certainly. He is the Supreme All-Knowing Creator.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxvii{%
His command, when He wills a thing, is to say to it, “Be,” and it comes to be.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxviii{%
So glory be to Him in whose hand is the dominion of everything, and to Him you will be returned.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxix{%
\basmalahen By the aligners aligning.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdccxc{%
And the drivers driving.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdccxci{%
And the reciters of the Reminder.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdccxcii{%
Your God is indeed One.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdccxciii{%
Lord of the heavens and the earth, and everything between them; and Lord of the Easts.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdccxciv{%
We have adorned the lower heaven with the beauty of the planets.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdccxcv{%
And guarded it against every defiant devil.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdccxcvi{%
They cannot eavesdrop on the Supernal Elite, for they get bombarded from every side.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdccxcvii{%
Repelled—they will have a lingering torment.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdccxcviii{%
Except for him who snatches a fragment—he gets pursued by a piercing projectile.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdccxcix{%
Inquire of them, “Are they more difficult to create, or the others We created?” We created them from sticky clay.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdccc{%
But you wonder, and they ridicule.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdccci{%
And when reminded, they pay no attention.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdcccii{%
And when they see a sign, they ridicule.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdccciii{%
And they say, “This is nothing but plain magic.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdccciv{%
When we have died and become dust and bones, shall we be resurrected?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdcccv{%
And our ancestors of old?”\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdcccvi{%
Say, “Yes indeed, and you will be totally subdued.”\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdcccvii{%
It will be a single nudge, and they will be staring.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdcccviii{%
They will say, “Woe to us. This is the Day of Judgment.”\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdcccix{%
“This is the Day of Separation which you used to deny.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdcccx{%
Gather those who did wrong, and their mates, and what they used to worship.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdcccxi{%
Besides God, and lead them to the way to Hell.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdcccxii{%
And stop them. They are to be questioned.”\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdcccxiii{%
What is the matter with you? Why do you not help one another?\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdcccxiv{%
In fact, on that Day, they will be submissive.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdcccxv{%
They will come to one another, questioning one another.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdcccxvi{%
They will say, “You used to come at us from the right.”\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdcccxvii{%
They will say, “You yourselves were not believers.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcccxviii{%
We had no authority over you. You yourselves were rebellious people.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcccxix{%
The Word of our Lord has been realized against us. We are tasting it.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcccxx{%
We seduced you. We were seducers.”\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcccxxi{%
On that Day, they will share in the punishment.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcccxxii{%
Thus We deal with the sinners.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcccxxiii{%
When it was said to them, “There is no god except God,” they grew arrogant.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcccxxiv{%
And said, “Are we to abandon our gods for a mad poet?”\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcccxxv{%
In fact, he came with the truth, and he confirmed the messengers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcccxxvi{%
Most assuredly, you will taste the painful punishment.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcccxxvii{%
And you will be repaid only for what you used to do.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcccxxviii{%
Except for God’s sincere servants.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcccxxix{%
For them is a known provision.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdcccxxx{%
Fruits; and they will be honored.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxi{%
In the Gardens of Bliss.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxii{%
On furnishings, facing one another.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxiii{%
They will be offered a cup of pure drink.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxiv{%
White; a delight to those who drink.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxv{%
Never polluted, and never intoxicating.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxvi{%
With them will be bashful women with lovely eyes.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxvii{%
As if they were closely guarded pearls.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxviii{%
Then they will approach one another, questioning.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxix{%
One of them will say, “I used to have a friend.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdcccxl{%
Who used to say, “Are you of those who believe?\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdcccxli{%
That after we die and become dust and bones, we will be called to account?”\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdcccxlii{%
He will say, “Will you have a look?”\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdcccxliii{%
He will look, and will see him in the pit of Hell.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdcccxliv{%
He will say, “By God, you almost ruined me.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdcccxlv{%
Were it not for the grace of my Lord, I would have been among the arraigned.”\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdcccxlvi{%
“We will not die.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdcccxlvii{%
Except for our first death, and we will not be punished.”\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdcccxlviii{%
This is the supreme triumph.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdcccxlix{%
For the like of this let the workers work.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdcccl{%
Is this a better hospitality, or the Tree of Bitterness?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdcccli{%
We made it an ordeal for the unjust.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdccclii{%
It is a tree that grows from the bottom of Hell.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdcccliii{%
Its fruits are like the devils’ heads.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdcccliv{%
They will eat from it, and fill their bellies with it.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdccclv{%
Then, on top of it, they will have a brew of boiling liquid.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdccclvi{%
Then their return will be to the Blaze.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdccclvii{%
They had found their parents astray.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdccclviii{%
And rushed along in their footsteps.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdccclix{%
And most of the ancients before them went astray.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdccclx{%
Even though We sent messengers to warn them.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdccclxi{%
So observe the end of those who were warned.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdccclxii{%
Except for the sincere servants of God.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmdccclxiii{%
And Noah called out to Us, and We are the Best of responders.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmdccclxiv{%
And We saved him and his family from the great calamity.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmdccclxv{%
And We made his descendants the survivors.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmdccclxvi{%
And We left mention of him among those who succeeded.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmdccclxvii{%
Peace be upon Noah among all people.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmdccclxviii{%
We thus reward the righteous.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmdccclxix{%
He was one of Our believing servants.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmdccclxx{%
Then We drowned the others.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmdccclxxi{%
Of his kind was Abraham.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmdccclxxii{%
When he came to his Lord with a sound heart.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmdccclxxiii{%
He said to his father and his people, “What are you worshiping?\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmdccclxxiv{%
Is it falsified gods, instead of God, that you want?\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmdccclxxv{%
So what is your opinion about the Lord of the Worlds?”\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmdccclxxvi{%
Then he took a glance at the stars.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmdccclxxvii{%
And said, “I am sick.”\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmdccclxxviii{%
But they turned their backs on him, and went away.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmdccclxxix{%
Then he turned to their gods, and said, “will you not eat?\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmdccclxxx{%
What is it with you, that you do not speak?”\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxi{%
Then he turned on them, striking with his right hand.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxii{%
And they came running towards him.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxiii{%
He said, “Do you worship what you carve?\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxiv{%
When God created you, and what you manufacture?”\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxv{%
They said, “Build a pyre for him, and throw him into the furnace.”\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxvi{%
They wished him ill, but We made them the losers.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxvii{%
He said, “I am going towards my Lord, and He will guide me.”\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxviii{%
“My Lord, give me one of the righteous.”\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxix{%
So We gave him good news of a clement boy.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmmdcccxc{%
Then, when he was old enough to accompany him, he said, “O My son, I see in a dream that I am sacrificing you; see what you think.” He said, “O my Father, do as you are commanded; you will find me, God willing, one of the steadfast.”\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmmdcccxci{%
Then, when they had submitted, and he put his forehead down.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmmdcccxcii{%
We called out to him, “O Abraham!\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmmdcccxciii{%
You have fulfilled the vision.” Thus We reward the doers of good.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmmdcccxciv{%
This was certainly an evident test.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmmdcccxcv{%
And We redeemed him with a great sacrifice.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmmdcccxcvi{%
And We left with him for later generations.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmmdcccxcvii{%
Peace be upon Abraham.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmmdcccxcviii{%
Thus We reward the doers of good.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmmdcccxcix{%
He was one of Our believing servants.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmmcm{%
And We gave him good news of Isaac, a prophet, one of the righteous.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmmcmi{%
And We blessed him, and Isaac. But among their descendants are some who are righteous, and some who are clearly unjust to themselves.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmmcmii{%
And We blessed Moses and Aaron.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmmcmiii{%
And We delivered them and their people from the terrible disaster.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmmcmiv{%
And We supported them, and so they were the victors.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmmcmv{%
And We gave them the Clarifying Scripture.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmmcmvi{%
And We guided them upon the straight path.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmmcmvii{%
And We left with them for later generations.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmmcmviii{%
Peace be upon Moses and Aaron.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmmcmix{%
Thus We reward the righteous.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmmcmx{%
They were of Our believing servants.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmmcmxi{%
Also Elijah was one of the messengers.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmmcmxii{%
He said to his people, “Do you not fear?\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmmcmxiii{%
Do you call on Baal, and forsake the Best of creators?\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmmcmxiv{%
God is your Lord, and the Lord of your ancestors.”\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmmcmxv{%
But they called him a liar, and thus they will be brought forward.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmmcmxvi{%
Except for God’s sincere servants.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmmcmxvii{%
And We left with him for later generations.\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmmcmxviii{%
Peace be upon the House of Elijah.\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmmcmxix{%
Thus We reward the virtuous.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmmcmxx{%
He was one of Our believing servants.\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmmcmxxi{%
And Lot was one of the messengers.\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmmcmxxii{%
We saved him and his family, all of them.\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmmcmxxiii{%
Except for an old woman who lagged behind.\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmmcmxxiv{%
Then We annihilated the others.\qt@no{136}}%
\qt@newcmd\qurantrans@en@mmmcmxxv{%
You pass by them in the morning.\qt@no{137}}%
\qt@newcmd\qurantrans@en@mmmcmxxvi{%
And at night. Do you not understand?\qt@no{138}}%
\qt@newcmd\qurantrans@en@mmmcmxxvii{%
And Jonah was one of the messengers.\qt@no{139}}%
\qt@newcmd\qurantrans@en@mmmcmxxviii{%
When he fled to the laden boat.\qt@no{140}}%
\qt@newcmd\qurantrans@en@mmmcmxxix{%
He gambled and lost.\qt@no{141}}%
\qt@newcmd\qurantrans@en@mmmcmxxx{%
Then the fish swallowed him, and he was to blame.\qt@no{142}}%
\qt@newcmd\qurantrans@en@mmmcmxxxi{%
Had he not been one of those who praised.\qt@no{143}}%
\qt@newcmd\qurantrans@en@mmmcmxxxii{%
He would have stayed in its belly until the Day they are raised.\qt@no{144}}%
\qt@newcmd\qurantrans@en@mmmcmxxxiii{%
Then We threw him into the wilderness, and he was sick.\qt@no{145}}%
\qt@newcmd\qurantrans@en@mmmcmxxxiv{%
And We made a gourd tree grow over him.\qt@no{146}}%
\qt@newcmd\qurantrans@en@mmmcmxxxv{%
Then We sent him to a hundred thousand, or more.\qt@no{147}}%
\qt@newcmd\qurantrans@en@mmmcmxxxvi{%
And they believed, so We gave them enjoyment for a while.\qt@no{148}}%
\qt@newcmd\qurantrans@en@mmmcmxxxvii{%
Ask them, “Are the daughters for your Lord, while for them the sons?”\qt@no{149}}%
\qt@newcmd\qurantrans@en@mmmcmxxxviii{%
Or did We create the angels females, as they witnessed?”\qt@no{150}}%
\qt@newcmd\qurantrans@en@mmmcmxxxix{%
No indeed! It is one of their lies when they say.\qt@no{151}}%
\qt@newcmd\qurantrans@en@mmmcmxl{%
“God has begotten.” They are indeed lying.\qt@no{152}}%
\qt@newcmd\qurantrans@en@mmmcmxli{%
So He preferred girls over boys?\qt@no{153}}%
\qt@newcmd\qurantrans@en@mmmcmxlii{%
What is the matter with you? How do you judge?\qt@no{154}}%
\qt@newcmd\qurantrans@en@mmmcmxliii{%
Will you not reflect?\qt@no{155}}%
\qt@newcmd\qurantrans@en@mmmcmxliv{%
Or do you have some clear proof?\qt@no{156}}%
\qt@newcmd\qurantrans@en@mmmcmxlv{%
Then bring your book, if you are telling the truth.\qt@no{157}}%
\qt@newcmd\qurantrans@en@mmmcmxlvi{%
And they invented a relationship between Him and the jinn. But the jinn know that they will be arraigned.\qt@no{158}}%
\qt@newcmd\qurantrans@en@mmmcmxlvii{%
God be glorified, far above what they allege.\qt@no{159}}%
\qt@newcmd\qurantrans@en@mmmcmxlviii{%
Except for God’s sincere servants.\qt@no{160}}%
\qt@newcmd\qurantrans@en@mmmcmxlix{%
Surely, you and what you serve.\qt@no{161}}%
\qt@newcmd\qurantrans@en@mmmcml{%
Cannot seduce away from Him.\qt@no{162}}%
\qt@newcmd\qurantrans@en@mmmcmli{%
Except for he who will be roasting in Hell.\qt@no{163}}%
\qt@newcmd\qurantrans@en@mmmcmlii{%
“There is not one of us but has an assigned position.\qt@no{164}}%
\qt@newcmd\qurantrans@en@mmmcmliii{%
And we are the arrangers.\qt@no{165}}%
\qt@newcmd\qurantrans@en@mmmcmliv{%
And we are the glorifiers.”\qt@no{166}}%
\qt@newcmd\qurantrans@en@mmmcmlv{%
Even though they used to say.\qt@no{167}}%
\qt@newcmd\qurantrans@en@mmmcmlvi{%
“Had we received advice from the ancients.\qt@no{168}}%
\qt@newcmd\qurantrans@en@mmmcmlvii{%
We would have been God's faithful servants.”\qt@no{169}}%
\qt@newcmd\qurantrans@en@mmmcmlviii{%
But they rejected it, so they will find out.\qt@no{170}}%
\qt@newcmd\qurantrans@en@mmmcmlix{%
Our Word has already gone out to our servant messengers.\qt@no{171}}%
\qt@newcmd\qurantrans@en@mmmcmlx{%
It is they who will be supported.\qt@no{172}}%
\qt@newcmd\qurantrans@en@mmmcmlxi{%
And Our troops will be the victors.\qt@no{173}}%
\qt@newcmd\qurantrans@en@mmmcmlxii{%
So disregard them for a while.\qt@no{174}}%
\qt@newcmd\qurantrans@en@mmmcmlxiii{%
And watch them—they will soon see.\qt@no{175}}%
\qt@newcmd\qurantrans@en@mmmcmlxiv{%
Are they seeking to hasten Our punishment?\qt@no{176}}%
\qt@newcmd\qurantrans@en@mmmcmlxv{%
When it descends into their yard, miserable will be the morning of those forewarned.\qt@no{177}}%
\qt@newcmd\qurantrans@en@mmmcmlxvi{%
So avoid them for a while.\qt@no{178}}%
\qt@newcmd\qurantrans@en@mmmcmlxvii{%
And watch—they will soon see.\qt@no{179}}%
\qt@newcmd\qurantrans@en@mmmcmlxviii{%
Exalted be your Lord, the Lord of Glory, beyond their allegations.\qt@no{180}}%
\qt@newcmd\qurantrans@en@mmmcmlxix{%
And peace be upon the messengers.\qt@no{181}}%
\qt@newcmd\qurantrans@en@mmmcmlxx{%
And praise be to God, the Lord of the Worlds.\qt@no{182}}%
\qt@newcmd\qurantrans@en@mmmcmlxxi{%
\basmalahen Saad. By the renowned Quran.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcmlxxii{%
Those who disbelieve are steeped in arrogance and defiance.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcmlxxiii{%
How many generations have We destroyed before them? They cried out when it was too late to escape.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcmlxxiv{%
And they marveled that a warner has come to them from among them. The disbelievers said, “This is a lying magician.”\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcmlxxv{%
“Did he turn all the gods into one God? This is something strange.”\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcmlxxvi{%
The notables among them announced: “Go on, and hold fast to your gods. This is something planned.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcmlxxvii{%
We never heard of this in the former faith. This is nothing but a fabrication.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcmlxxviii{%
Was the message sent down to him, out of all of us?” In fact, they are doubtful of My warning. In fact, they have not yet tasted My punishment.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcmlxxix{%
Or do they possess the treasuries of the mercy of your Lord—the Majestic, the Giver?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcmlxxx{%
Or do they possess the sovereignty of the heavens and the earth and what is between them? Then let them ascend the ropes.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxi{%
An army of confederates with be defeated there.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxii{%
Before them the people of Noah denied the truth; as did Aad, and Pharaoh of the Stakes.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxiii{%
And Thamood, and the people of Lot, and the dwellers of the Woods—these were the confederates.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxiv{%
None of them but denied the messengers, so My retribution was deserved.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxv{%
These can expect only a single scream, from which there is no recovery.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxvi{%
And they say, “Our Lord, hasten Your writ upon us, before the Day of Account.”\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxvii{%
Be patient in the face of what they say, and mention Our servant David, the resourceful. He was obedient.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxviii{%
We committed the mountains to glorify with him, in the evening and at daybreak.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxix{%
And the birds, gathered together. All obedient to him.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcmxc{%
And We strengthened his kingdom, and gave him wisdom and decisive speech.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcmxci{%
Has the story of the two disputants reached you? When they scaled the sanctuary?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcmxcii{%
When they entered upon David, and he was startled by them. They said, “Do not fear. Two disputants; one of us has wronged the other; so judge between us fairly, and do not be biased, and guide us to the straight way.”\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcmxciii{%
“This brother of mine has ninety nine ewes, and I have one ewe, and he said, ‘Entrust it to me,’ and he pressured me with words.”\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcmxciv{%
He said, “He has done you wrong by asking your ewe in addition to his ewes. Many partners take advantage of one another, except those who believe and do good deeds, but these are so few.” David realized that We were testing him, so he sought forgiveness from his Lord, and fell down to his knees, and repented.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcmxcv{%
So We forgave him that. And for him is nearness to Us, and a good place of return.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcmxcvi{%
“O David, We made you a ruler in the land, so judge between the people with justice, and do not follow desire, lest it diverts you from God’s path. Those who stray from God’s path will have a painful punishment, for having ignored the Day of Account.”\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcmxcvii{%
We did not create the heaven and the earth and everything between them in vain. That is the assumption of those who disbelieve—so woe to those who disbelieve because of the Fire.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcmxcviii{%
Or are We to treat those who believe and do righteous deeds like those who make trouble on earth? Or are We to treat the pious like the shameless?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcmxcix{%
A blessed Book that We sent down to you, that they may ponder its Verses, and for those with intelligence to take heed.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmm{%
And We granted David, Solomon, an excellent servant. He was penitent.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmi{%
When the beautiful horses were paraded before him in the evening.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmii{%
He said, “I have preferred the love of niceties to the remembrance of my Lord—until it disappeared behind the veil.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmiii{%
Bring them back to me.” And he began caressing their legs and necks.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmiv{%
We tested Solomon, and placed a body on his throne; then he repented.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmv{%
He said, “My Lord, forgive me, and grant me a kingdom never to be attained by anyone after me. You are the Giver.”\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmvi{%
So We placed the wind at his service, blowing gently by his command, wherever he directed.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmvii{%
And the demons—every builder and diver.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmviii{%
And others fettered in chains.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmix{%
“This is Our gift; so give generously, or withhold; without account.”\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmx{%
For him is nearness to Us, and a beautiful resort.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmxi{%
And mention Our servant Job, when he called out to his Lord, “Satan has afflicted me with hardship and pain.”\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmxii{%
“Stamp with your foot—here is cool water to wash with, and to drink.”\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmxiii{%
And We restored his family for him, and their like with them; as a mercy from Us, and a lesson for those who possess insight.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmxiv{%
“Take with your hand a bundle, and strike with it, and do not break your oath.” We found him patient. What an excellent servant! He was obedient.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmxv{%
And mention Our servants Abraham, Isaac, and Jacob—endowed with ability and vision.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmxvi{%
We distinguished them with a distinct quality: the remembrance of the Home.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmxvii{%
To Us they are among the chosen, the outstanding.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmxviii{%
And mention Ishmael, Elisha, and Ezekiel; all are among the outstanding.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmxix{%
This is a reminder. The devout will have a good place of return.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmxx{%
The Gardens of Eden, with their doors wide-open for them.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmxxi{%
Relaxing therein, and calling for abundant fruit and beverage.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmxxii{%
With them will be attendants with modest gaze, of same age.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmxxiii{%
This is what you are promised for the Day of Account.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmxxiv{%
Such is Our bounty, inexhaustible.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmxxv{%
All This. But the transgressors will have a miserable return.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmxxvi{%
Hell; in which they will roast; what a miserable abode!\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmxxvii{%
All this. Let them taste it—boiling and bitter cold.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmxxviii{%
And similar torments of diverse kinds.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmxxix{%
“This is a crowd rushing headlong with you.” There is no welcome for them. They will be scorched by the Fire.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmxxx{%
They will say, “But it is you! There is no welcome for you! It is you who brought it upon us! What a miserable end!”\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmxxxi{%
They will say, “Our Lord, whoever brought this upon us, give him double torment in the Fire.”\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmxxxii{%
And they will say, “What is it with us that we do not see men we used to count among the wicked?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmxxxiii{%
Did we take them for mockery, or have our eyes swerved from them?\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmxxxiv{%
This is certainly true—the feuding of the people of the Fire.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmxxxv{%
Say, “I am only a warner, and there is no god except God—the One, the Conqueror.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmxxxvi{%
The Lord of the heavens and the earth, and everything between them; the Mighty, the Forgiver.”\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmxxxvii{%
Say, “It is a message of great importance.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmxxxviii{%
From which you are turning away.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmxxxix{%
I have no knowledge of the Highest Assembly as they dispute.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmxl{%
It is only revealed to me that I am a clear warner.”\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmxli{%
Your Lord said to the angels, “I am creating a human being from clay.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmxlii{%
When I have formed him, and breathed into him of My spirit, fall prostrate before him.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmxliii{%
So the angels fell prostrate, all of them.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmxliv{%
Except for Satan. He was too proud, and one of the faithless.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmxlv{%
He said, “O Satan, what prevented you from prostrating before what I created with My Own hands? Are you too proud, or were you one of the exalted?”\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmxlvi{%
He said, “I am better than he; You created me from fire, and You created him from clay.”\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmxlvii{%
He said, “Then get out of here! You are an outcast!\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmxlviii{%
And My curse will be upon you until the Day of Judgment.”\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmxlix{%
He said, “Lord, defer me until the Day they are resurrected.”\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmml{%
He said, “You are one of those deferred.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmli{%
Until the Day of the Time Appointed.”\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmlii{%
He said, “By Your majesty, I will seduce them all.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmliii{%
Except for your loyal servants among them.”\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmliv{%
He said, “The truth is, and I say the truth.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmlv{%
I will fill Hell with you, and with every one of them who follows you.”\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmlvi{%
Say, “I ask of you no wage for this, and I am not a pretender.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmlvii{%
It is but a reminder to mankind.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmlviii{%
And you will know its message after a while.”\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmlix{%
\basmalahen The revelation of the Book is from God, the Mighty and Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmlx{%
We sent down to you the Book with the truth, so serve God, devoting your religion to Him.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmlxi{%
Is not to God that sincere faith is due? As for those who take guardians besides Him, “We only worship them that they may bring us nearer to God.” God will judge between them regarding their differences. God does not guide the lying blasphemer.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmlxii{%
If God wanted to have a son, He could have selected from His creation at will. Glory be to Him. He is God, the One, the Prevailing.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmlxiii{%
He created the heavens and the earth with reason. He wraps the night around the day, and He wraps the day around the night. And He regulates the sun and the moon, each running along a specific course. He is indeed the Almighty, the Forgiver.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmlxiv{%
He created you from one person, then made from it its mate, and brought down livestock for you—eight kinds in pairs. He creates you in the wombs of your mothers, in successive formations, in a triple darkness. Such is God, your Lord. His is the kingdom. There is no god but He. So what made you deviate?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmlxv{%
If you disbelieve, God is Independent of you, yet He does not approve ingratitude on the part of His servants. And if you are thankful, He will approve that in you. No bearer of burden can bear the burden of another. Then to your Lord is your return; and He will inform you of what you used to do. He is aware of what the hearts contain.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmlxvi{%
When some adversity touches the human being, he prays to his Lord, repenting to Him. But then, when He confers on him a grace of His, he forgets what he was praying for before, and he attributes rivals to God, in order to lead astray from His way. Say, “Enjoy your disbelief for a little while; you will be among the inmates of the Fire.”\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmlxvii{%
Is he who worships devoutly during the watches of the night, prostrating himself and standing up, mindful of the Hereafter, and placing his hope in the mercy of his Lord? Say, “Are those who know and those who do not know equal?” Only those possessed of reason will remember.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmlxviii{%
Say, “O My devotees who have believed, keep your duty to your Lord. For those who do good in this world, is goodness. And God’s earth is vast. The steadfast will be paid their wages in full, without reckoning.”\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmlxix{%
Say, “I was commanded to serve God, devoting my religion exclusively to Him.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmlxx{%
And I was commanded to be the first of those who submit.”\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmlxxi{%
Say, “I fear, if I disobeyed my Lord, the punishment of a horrendous Day.”\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmlxxii{%
Say, “It is God I worship, sincere in my faith in Him.”\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmlxxiii{%
“But you can worship whatever you wish besides Him.” Say, “The losers are those who lose their souls and their people on the Day of Resurrection.” That is indeed the obvious loss.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmlxxiv{%
They will have layers of Fire above them, and layers beneath them. That is how God strikes fear into His servants—“O My servants! Beware of Me!”\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmlxxv{%
As for those who avoid the worship of idols, and devote themselves to God—theirs is the good news. So give good news to My servants.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmlxxvi{%
Those who listen to the Word, and follow the best of it. These are they whom God has guided. These are they who possess intellect.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmlxxvii{%
What about someone who has deserved the sentence of punishment? Is it you who can save those in the Fire?\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmlxxviii{%
But those who fear their Lord will have mansions upon mansions, built high, with streams flowing beneath them. The promise of God; and God never breaks a promise.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmlxxix{%
Have you not considered how God sends down water from the sky, then He makes it flow into underground wells, then He produces with it plants of various colors, then they wither and you see them yellowing, then He turns them into debris? Surely in this is a reminder for those with understanding.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmlxxx{%
What about someone whose heart God has opened to Islam, so that he follows a light from His Lord? Woe to those whose hearts are hardened against the mention of God. Those are in manifest error.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmlxxxi{%
God has sent down the best of narrations: a Scripture consistent and paired. The skins of those who reverence their Lord shiver from it, then their skins and their hearts soften up to the remembrance of God. Such is God’s guidance; He guides with it whomever He wills. But whomever God leaves astray, for him there is no guide.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmlxxxii{%
What about someone who covers his face against the terrible misery of the Day of Resurrection? To the evildoers it will be said, “Taste what you used to earn.”\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmlxxxiii{%
Those before them also denied the truth, so the penalty came upon them from where they did not perceive.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmlxxxiv{%
God made them taste disgrace in the present life, but the punishment of the Hereafter is worse, if they only knew.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmlxxxv{%
We have cited in this Quran for mankind every ideal, that they may take heed.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmlxxxvi{%
An Arabic Quran, without any defect, so they may become righteous.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmlxxxvii{%
God cites the example of a man shared by partners at odds, and a man belonging exclusively to one man. Are they equal in status? Praise be to God, but most of them do not know.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmlxxxviii{%
You will die, and they will die.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmlxxxix{%
Then, on the Day of Resurrection, you will be quarrelling before your Lord.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmxc{%
Who is more evil than he who lies about God, and denies the truth when it has come to him? Is there not in Hell room for the ungrateful?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmxci{%
But he who promotes the truth, and testifies to it—these are the righteous.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmxcii{%
They will have whatever they please with their Lord. Such is the reward for the virtuous.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmxciii{%
God will acquit them of the worst of their deeds, and will reward them according to the best of what they used to do.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmxciv{%
Is God not enough for His servant? And they frighten you with those besides Him. Whomever God sends astray, for him there is no guide.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmxcv{%
And whomever God guides, for him there is no misleader. Is God not Powerful and Vengeful?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmxcvi{%
And if you asked them, “Who created the heavens and the earth?” they would say, “God.” Say, “Have you seen those you pray to instead of God? If God willed any harm for me, can they lift His harm? And if He willed a blessing for me, can they hold back His mercy?” Say, “God suffices for me. On Him the reliant rely.”\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmxcvii{%
Say: “O my people, work according to your ability; and so will I. Then you will know.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmxcviii{%
Who will receive a humiliating punishment, and on whom will fall a lasting torment.”\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmxcix{%
We sent down upon you the Book for mankind in truth. He who follows guidance does so for the good of his soul. And he who strays in error does so to its detriment. You are not their overseer.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmc{%
God takes the souls at the time of their death, and those that have not died during their sleep. He retains those for which He has decreed death, and He releases the others until a predetermined time. In that are signs for people who reflect.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmci{%
Or have they chosen intercessors other than God? Say, “Even though they have no power over anything, and are devoid of reason?”\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcii{%
Say, “All intercession is up to God. To Him belongs the kingdom of the heavens and the earth. Then to Him you will be returned.”\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmciii{%
When God alone is mentioned, the hearts of those who do not believe in the Hereafter shrink with resentment. But when those other than Him are mentioned, they become filled with joy.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmciv{%
Say, “Our God, Initiator of the heavens and the earth, Knower of all secrets and declarations. You will judge between your servants regarding what they had differed about.”\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcv{%
If those who did wrong owned everything on earth, and the like of it with it, they would redeem themselves with it from the terrible suffering on the Day of Resurrection. But there will appear to them from God what they never anticipated.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcvi{%
There will appear to them the evils of their deeds, and they will be surrounded by what they used to ridicule.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcvii{%
When adversity touches the human being, he calls on Us. But then, when We favor him with a blessing from Us, he says, “I have attained this by virtue of my knowledge.” However, it is a test, but most of them do not know.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcviii{%
Those before them said it, but what they had earned did not avail them.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcix{%
The evils of their deeds caught up with them. And the wrongdoers among these will also be afflicted by the evils of what they earned, and they cannot prevent it.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcx{%
Do they not know that God extends the provision to whomever He wills, and constricts it? In that are signs for people who believe.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcxi{%
Say, “O My servants who have transgressed against themselves: do not despair of God’s mercy, for God forgives all sins. He is indeed the Forgiver, the Clement.”\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcxii{%
And turn to your Lord, and submit to Him, before the retribution comes upon you. Then you will not be helped.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcxiii{%
And follow the best of what was revealed to you from your Lord, before the punishment comes upon you suddenly, while you are unaware.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcxiv{%
So that a soul may not say, “How sorry I am, for having neglected my duty to God, and for having been of the scoffers.”\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcxv{%
Or say, “Had God guided me; I would have been of the pious.”\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcxvi{%
Or say, when it sees the penalty, “If only I had another chance, I would be of the virtuous.”\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcxvii{%
Yes indeed! My Verses did come to you, but you called them lies, turned arrogant, and were of the faithless.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcxviii{%
On the Day of Resurrection, you will see those who told lies about God with their faces blackened. Is there not a place in Hell for the arrogant?\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcxix{%
And God will save those who maintained righteousness to their place of salvation. No harm will touch them, nor will they grieve.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcxx{%
God is the Creator of all things, and He is in Charge of all things.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcxxi{%
To Him belong the reins of the heavens and the earth. But those who blaspheme against the revelations of God—it is they who are the losers.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcxxii{%
Say, “Is it other than God you instruct me to worship, you ignorant ones?”\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcxxiii{%
It was revealed to you, and to those before you, that if you idolize, your works will be in vain, and you will be of the losers.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcxxiv{%
Rather, worship God, and be of the appreciative.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcxxv{%
They have not esteemed God as He ought to be esteemed. The entire earth will be in His grip on the Day of Resurrection, and the heavens will be folded in His righ. Immaculate is He, and Transcendent He is beyond the associations they make.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcxxvi{%
And the Trumpet will be sounded, whereupon everyone in the heavens and the earth will be stunned, except whomever God wills. Then it will be sounded another time, whereupon they will rise up, looking on.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcxxvii{%
And the earth will shine with the Light of its Lord; and the Book will be put in place; and the prophets and the witnesses will be brought in; and Judgment will be passed among them equitably, and they will not be wronged.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcxxviii{%
And every soul will be fully compensated for what it had done. He is well aware of what they do.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcxxix{%
Those who disbelieved will be driven to Hell in throngs. Until, when they have reached it, and its gates are opened, its keepers will say to them, “Did not messengers from among you come to you, reciting to you the revelations of your Lord, and warning you of the meeting of this Day of yours?” They will say, “Yes, but the verdict of punishment is justified against the disbelievers.”\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcxxx{%
It will be said, “Enter the gates of Hell, to abide therein eternally.” How wretched is the destination of the arrogant.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcxxxi{%
And those who feared their Lord will be led to Paradise in throngs. Until, when they have reached it, and its gates are opened, its keepers will say to them, “Peace be upon you, you have been good, so enter it, to abide therein eternally.”\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcxxxii{%
And they will say, “Praise be to God, who has fulfilled His promise to us, and made us inherit the land, enjoying Paradise as we please.” How excellent is the reward of the workers.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcxxxiii{%
And you will see the angels hovering around the Throne, glorifying their Lord with praise. And it will be judged between them equitably, and it will be said, “Praise be to God, Lord of the Worlds.”\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcxxxiv{%
\basmalahen Ha, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcxxxv{%
The sending down of the Scripture is from God the Almighty, the Omniscient.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcxxxvi{%
Forgiver of sins, Accepter of repentance, Severe in punishment, Bountiful in bounty. There is no god but He. To Him is the ultimate return.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcxxxvii{%
None argues against God’s revelations except those who disbelieve. So do not be impressed by their activities in the land.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcxxxviii{%
Before them the people of Noah rejected the truth, as did the confederates after them. Every community plotted against their messenger, to capture him. And they argued with falsehood, to defeat with it the truth. But I seized them. What a punishment it was!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcxxxix{%
Thus the sentence of your Lord became realized against those who disbelieve, that they are to be inmates of the Fire.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcxl{%
Those who carry the Throne, and those around it, glorify their Lord with praise, and believe in Him, and ask for forgiveness for those who believe: “Our Lord, You have encompassed everything in mercy and knowledge; so forgive those who repent and follow Your path, and protect them from the agony of the Blaze.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcxli{%
And admit them, Our Lord, into the Gardens of Eternity, which You have promised them, and the righteous among their parents, and their spouses, and their offspring. You are indeed the Almighty, the Most Wise.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcxlii{%
And shield them from the evil deeds. Whomever You shield from the evil deeds, on that Day, You have had mercy on him. That is the supreme achievement.”\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcxliii{%
Those who disbelieved will be addressed, “The loathing of God is greater than your loathing of yourselves—for you were invited to the faith, but you refused.”\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcxliv{%
They will say, “Our Lord, you made us die twice, and twice you gave us life. Now we acknowledge our sins. Is there any way out?”\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcxlv{%
That is because when God alone was called upon, you disbelieved; but when others were associated with Him, you believed. Judgment rests with God the Sublime, the Majestic.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcxlvi{%
It is He who shows you His wonders, and sends down sustenance from the sky for you. But none pays heed except the repentant.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcxlvii{%
So call upon God, with sincere devotion to Him, even though the disbelievers resent it.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcxlviii{%
Exalted in rank, Owner of the Throne. He conveys the Spirit, by His command, upon whomever He wills of His servants, to warn of the Day of Encounter.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcxlix{%
The Day when they will emerge, nothing about them will be concealed from God. “To whom does the sovereignty belong today?” “To God, the One, the Irresistible.”\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcl{%
On that Day, every soul will be recompensed for what it had earned. There will be no injustice on that Day. God is quick to settle accounts.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcli{%
And warn them of the Day of Imminence, when the hearts are at the throats, choking them. The evildoers will have no intimate friend, and no intercessor to be obeyed.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmclii{%
He knows the deceptions of the eyes, and what the hearts conceal.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcliii{%
God judges with justice, while those whom they invoke besides Him cannot judge with anything. It is God who is the Hearing, the Seeing.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcliv{%
Have they not travelled through the earth, and seen the consequences for those before them? They were stronger than them, and they left more impact on earth. But God seized them for their sins, and they had no defender against God.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmclv{%
That is because their messengers used to come to them with clear proofs, but they disbelieved, so God seized them. He is Strong, Severe in retribution.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmclvi{%
We sent Moses with Our signs, and a clear authority.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmclvii{%
To Pharaoh, Hamaan, and Quaroon. But they said, “A lying sorcerer.”\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmclviii{%
Then, when he came to them with the truth from Us, they said, “Kill the sons of those who have believed with him, and spare their daughters.” But the scheming of the unbelievers can only go astray.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmclix{%
Pharaoh said, “Leave me to kill Moses, and let him appeal to his Lord. I fear he may change your religion, or spread disorder in the land.”\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmclx{%
Moses said, “I have sought the protection of my Lord and your Lord, from every tyrant who does not believe in the Day of Account.”\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmclxi{%
A believing man from Pharaoh's family, who had concealed his faith, said, “Are you going to kill a man for saying, `My Lord is God,’ and he has brought you clear proofs from your Lord? If he is a liar, his lying will rebound upon him; but if he is truthful, then some of what he promises you will befall you. God does not guide the extravagant imposter.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmclxii{%
O my people! Yours is the dominion today, supreme in the land; but who will help us against God’s might, should it fall upon us?” Pharaoh said, “I do not show you except what I see, and I do not guide you except to the path of prudence.”\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmclxiii{%
The one who had believed said, “O my people, I fear for you the like of the day of the confederates.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmclxiv{%
Like the fate of the people of Noah, and Aad, and Thamood, and those after them. God wants no injustice for the servants.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmclxv{%
O my people, I fear for you the Day of Calling Out.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmclxvi{%
The Day when you will turn and flee, having no defender against God. Whomever God misguides has no guide.”\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmclxvii{%
Joseph had come to you with clear revelations, but you continued to doubt what he came to you with. Until, when he perished, you said, “God will never send a messenger after him.” Thus God leads astray the outrageous skeptic.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmclxviii{%
Those who argue against God’s revelations, without any proof having come to them—a heinous sin in the sight of God, and of those who believe. Thus God seals the heart of every proud bully.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmclxix{%
And Pharaoh said, “O Hamaan, build me a tower, that I may reach the pathways.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmclxx{%
The pathways of the heavens, so that I may glance at the God of Moses; though I think he is lying.” Thus Pharaoh’s evil deeds were made to appear good to him, and he was averted from the path. Pharaoh's guile was only in defeat.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmclxxi{%
The one who had believed said, “O my people, follow me, and I will guide you to the path of rectitude.”\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmclxxii{%
“O my people, the life of this world is nothing but fleeting enjoyment, but the Hereafter is the Home of Permanence.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmclxxiii{%
Whoever commits a sin will be repaid only with its like. But whoever works righteousness, whether male or female, and is a believer—these will enter Paradise, where they will be provided for without account.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmclxxiv{%
O my people, how is it that I call you to salvation, and you call me to the Fire?\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmclxxv{%
You call me to reject God, and to associate with Him what I have no knowledge of, while I call you to the Mighty Forgiver.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmclxxvi{%
Without a doubt, what you call me to has no say in this world, or in the Hereafter; and our turning back is to God; and the transgressors are the inmates of the Fire.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmclxxvii{%
You will remember what I am telling you, so I commit my case to God. God is Observant of the servants.”\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmclxxviii{%
So God protected him from the evils of their scheming, while a terrible torment besieged Pharaoh’s clan.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmclxxix{%
The Fire. They will be exposed to it morning and evening. And on the Day the Hour takes place: “Admit the clan of Pharaoh to the most intense agony.”\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmclxxx{%
As they quarrel in the Fire, the weak will say to those who were arrogant, “We were followers of yours; will you then spare us a portion of the Fire?”\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmclxxxi{%
Those who were arrogant will say, “We are all in it; God has judged between the servants.”\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmclxxxii{%
And those in the Fire will say to the keepers of Hell, “Call to your Lord to lessen our suffering for one day.”\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmclxxxiii{%
They will say, “Did not your messengers come to you with clear signs?” They will say, “Yes.” They will say, “Then pray, but the prayers of the disbelievers will always be in vain.”\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmclxxxiv{%
Most surely We will support Our messengers and those who believe, in this life, and on the Day the witnesses arise.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmclxxxv{%
The Day when their excuses will not profit the wrongdoers, and the curse will be upon them, and they will have the Home of Misery.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmclxxxvi{%
We gave Moses guidance, and made the Children of Israel inherit the Scripture.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmclxxxvii{%
A guide and a reminder for those endowed with reason.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmclxxxviii{%
So be patient. The promise of God is true. And ask forgiveness for your sin, and proclaim the praise of your Lord evening and morning.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmclxxxix{%
Those who dispute regarding God’s revelations without any authority having come to them—there is nothing in their hearts but the feeling of greatness, which they will never attain. So seek refuge in God; for He is the All-Hearing, the All-Seeing.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcxc{%
Certainly the creation of the heavens and the earth is greater than the creation of humanity, but most people do not know.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcxci{%
Not equal are the blind and the seeing. Nor are those who believe and work righteousness equal to the sinners. How little you reflect.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcxcii{%
Indeed, the Hour is coming; there is no doubt about it; but most people do not believe.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcxciii{%
Your Lord has said, “Pray to Me, and I will respond to you. But those who are too proud to worship Me will enter Hell forcibly.”\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcxciv{%
It is God Who made the night for you, that you may rest therein; and the day allowing sight. God is gracious towards the people, but most people do not give thanks.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcxcv{%
Such is God, your Lord, Creator of all things. There is no god except Him; so how could you turn away?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcxcvi{%
Thus are turned away those who dispute the signs of God.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcxcvii{%
It is God who made the earth a habitat for you, and the sky a structure. And He designed you, and designed you well; and He provided you with the good things. Such is God, your Lord; so Blessed is God, Lord of the Worlds.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcxcviii{%
He is the Living One. There is no god except He. So pray to Him, devoting your religion to Him. Praise be to God, the Lord of the Worlds.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcxcix{%
Say, “I was prohibited from worshiping those you invoke besides God, now that clear revelations have come to me from my Lord; and I was commanded to submit to the Lord of the Worlds.”\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcc{%
It is He who created you from dust, then from a seed, then from an embryo, then He brings you out as an infant, then He lets you reach your maturity, then you become elderly—although some of you die sooner—so that you may reach a predetermined age, so that you may understand.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcci{%
It is He who gives life and death; and when He decides on a thing, He just says to it, “Be,” and it comes to be.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmccii{%
Have you not observed those who dispute regarding God's revelations, how they have deviated?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcciii{%
Those who call the Book a lie, and what We sent Our messengers with—they will surely know.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcciv{%
When the yokes are around their necks, and they will be dragged by the chains.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmccv{%
Into the boiling water, then in the Fire they will be consumed.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmccvi{%
Then it will be said to them, “Where are those you used to deify?\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmccvii{%
Instead of God?” They will say, “They have abandoned us. In fact, we were praying to nothing before.” Thus God sends the disbelievers astray.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmccviii{%
That is because you used to rejoice on earth in other than the truth, and because you used to behave with vanity.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmccix{%
Enter the gates of Hell, to remain therein forever. What a terrible dwelling for the arrogant.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmccx{%
So be patient. The promise of God is true. Whether We show you some of what We have promised them, or take you to Us, to Us they will be returned.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmccxi{%
We sent messengers before you. Some of them We told you about, and some We did not tell you about. No messenger can bring a miracle except by leave of God. Then, when the command of God is issued, fair judgment will be passed, and there and then the seekers of vanity will lose.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmccxii{%
God is He who created the domestic animals for you—some for you to ride, and some you eat.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmccxiii{%
And in them you have other benefits as well, and through them you satisfy your needs. And on them, and on the ships, you are transported.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmccxiv{%
And He shows you His signs. So which of God’s signs will you deny?\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmccxv{%
Have they not journeyed through the land, and seen the outcome for those before them? They were more numerous than they, and had greater power and influence in the land. But what they had achieved availed them nothing.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmccxvi{%
When their messengers came to them with clear proofs, they rejoiced in the knowledge they had, and the very things they used to ridicule besieged them.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmccxvii{%
Then, when they witnessed Our might, they said, “We believe in God alone, and we reject what we used to associate with Him.”\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmccxviii{%
But their faith could not help them once they witnessed Our might. This has been God’s way of dealing with His servants. And there and then the disbelievers lost.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmccxix{%
\basmalahen Ha, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmccxx{%
A revelation from the Most Gracious, the Most Merciful.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmccxxi{%
A Scripture whose Verses are detailed, a Quran in Arabic for people who know.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmccxxii{%
Bringing good news, and giving warnings. But most of them turn away, so they do not listen.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmccxxiii{%
And they say, “Our hearts are screened from what you call us to, and in our ears is deafness, and between us and you is a barrier. So do what you want, and so will we.”\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmccxxiv{%
Say, “I am only a human like you; it is inspired in me that your God is One God. So be upright towards Him, and seek forgiveness from Him.” And woe to the idolaters.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmccxxv{%
Those who do not pay the alms; and regarding the Hereafter, they are disbelievers.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmccxxvi{%
As for those who believe and do righteous deeds—for them is a reward uninterrupted.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmccxxvii{%
Say, “Do you reject the One who created the earth in two days? And you attribute equals to Him? That is the Lord of the Universe.”\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmccxxviii{%
He placed stabilizers over it; and blessed it; and planned its provisions in four days, equally to the seekers.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmccxxix{%
Then He turned to the sky, and it was smoke, and said to it and to the earth, “Come, willingly or unwillingly.” They said, “We come willingly.”\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmccxxx{%
So He completed them as seven universes in two days, and He assigned to each universe its laws. And We decorated the lower universe with lamps, and for protection. That is the design of the Almighty, the All-Knowing.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmccxxxi{%
But if they turn away, say, “I have warned you of a thunderbolt, like the thunderbolt of Aad and Thamood.”\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmccxxxii{%
Their messengers came to them, from before them and from behind them, saying, “Do not worship anyone but God.” They said, “Had our Lord willed, He would have sent down angels; Therefore, we reject what you are sent with.”\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmccxxxiii{%
As for Aad, they turned arrogant on earth, and opposed justice, and said, “Who is more powerful than us?” Have they not considered that God, who created them, is more powerful than they? And they went on denying Our revelations.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmccxxxiv{%
So We unleashed upon them a screaming wind, for a few miserable days, to make them taste the punishment of shame in this life; but the punishment of the Hereafter is more shameful; and they will not be saved.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmccxxxv{%
And as for Thamood, We guided them, but they preferred blindness over guidance. So the thunderbolt of the humiliating punishment seized them, because of what they used to earn.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmccxxxvi{%
And We saved those who believed and were righteous.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmccxxxvii{%
The Day when God’s enemies are herded into the Fire, forcibly.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmccxxxviii{%
Until, when they have reached it, their hearing, and their sight, and their skins will testify against them regarding what they used to do.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmccxxxix{%
And they will say to their skins, “Why did you testify against us?” They will say, “God, Who made all things speak, made us speak. It is He who created you the first time, and to Him you are returned.”\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmccxl{%
You were unable to hide yourselves from your hearing, and your sight, and your skins, to prevent them from testifying against you, and you imagined that God was unaware of much of what you do.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmccxli{%
It is that thought of yours about your Lord that led you to ruin—so you became of the losers.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmccxlii{%
If they endure patiently, the Fire will be their residence; and if they make up excuses, they will not be pardoned.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmccxliii{%
We had assigned companions for them, who glamorized to them what was in front of them, and what was behind them. And the Word proved true against them in communities of jinn and humans that have passed away before them. They were losers.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmccxliv{%
Those who disbelieve say, “Do not listen to this Quran, and talk over it, so that you may prevail.”\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccxlv{%
We will make those who disbelieve taste an intense agony, and We will recompense them according to the worst of what they used to do.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmccxlvi{%
Such is the recompense of God’s enemies—the Fire—where they will have their permanent home, in recompense for having disregarded Our revelations.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmccxlvii{%
Those who disbelieved will say, “Our Lord, show us those who led us astray—among jinn and humans—and we will trample them under our feet, so they become among of the lowest.”\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmccxlviii{%
Surely, those who say: “Our Lord is God,” and then go straight, the angels will descend upon them: “Do not fear, and do not grieve, but rejoice in the news of the Garden which you were promised.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccxlix{%
We are your allies in this life and in the Hereafter, wherein you will have whatever your souls desire, and you will have therein whatever you call for.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccl{%
As Hospitality from an All-Forgiving, Merciful One.”\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmccli{%
And who is better in speech than someone who calls to God, and acts with integrity, and says, “I am of those who submit”?\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcclii{%
Good and evil are not equal. Repel evil with good, and the person who was your enemy becomes like an intimate friend.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmccliii{%
But none will attain it except those who persevere, and none will attain it except the very fortunate.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmccliv{%
When a temptation from the Devil provokes you, seek refuge in God; He is the Hearer, the Knower.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcclv{%
And of His signs are the night and the day, and the sun and the moon. Do not bow down to the sun, nor to the moon, but bow down to God, Who created them both, if it is Him that you serve.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcclvi{%
But if they are too proud—those in the presence of your Lord praise Him night and day, and without ever tiring.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcclvii{%
And of His signs is that you see the land still. But when We send down water upon it, it stirs and grows. Surely, He Who revived it will revive the dead. He is Able to do all things.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcclviii{%
Those who despise Our revelations are not hidden from Us. Is he who is hurled into the Fire better? Or he who arrives safely on the Day of Resurrection? Do as you please; He is Seeing of everything you do.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcclix{%
Those who reject the Reminder when it has come to them—it is an invincible Book.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcclx{%
Falsehood cannot approach it, from before it or behind it. It is a revelation from One Wise and Praiseworthy.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcclxi{%
Nothing is said to you but was said to the Messengers before you: your Lord is Possessor of Forgiveness, and Possessor of Painful Repayment.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcclxii{%
Had We made it a Quran in a foreign language, they would have said, “If only its verses were made clear.” Non-Arabic and an Arab? Say, “For those who believe, it is guidance and healing. But as for those who do not believe: there is heaviness in their ears, and it is blindness for them. These are being called from a distant place.”\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcclxiii{%
We gave Moses the Book, but disputes arose concerning it. Were it not for a prior decree from your Lord, judgment would have been pronounced between them. But they are in perplexing doubt concerning it.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcclxiv{%
Whoever acts righteously does so for himself; and whoever works evil does so against himself. Your Lord is not unjust to the servants.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcclxv{%
To Him is referred the knowledge of the Hour. No fruit emerges from its sheath, and no female conceives or delivers, except with His knowledge. And on the Day when He calls out to them, “Where are My associates?” They will say, “We admit to you, none of us is a witness.”\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcclxvi{%
What they used to pray to before will forsake them, and they will realize that they have no escape.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcclxvii{%
The human being never tires of praying for good things; but when adversity afflicts him, he despairs and loses hope.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcclxviii{%
And when We let him taste a mercy from Us, after the adversity that had afflicted him, he will say, “This is mine, and I do not think that the Hour is coming; and even if I am returned to my Lord, I will have the very best with Him.” We will inform those who disbelieve of what they did, and We will make them taste an awful punishment.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcclxix{%
When We provide comfort for the human being, he withdraws and distances himself; but when adversity befalls him, he starts lengthy prayers.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcclxx{%
Say, “Have you considered? If it is from God and you reject it—who is further astray than he who is cutoff and alienated?”\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcclxxi{%
We will show them Our proofs on the horizons, and in their very souls, until it becomes clear to them that it is the truth. Is it not sufficient that your Lord is witness over everything?\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcclxxii{%
Surely they are in doubt about the encounter with their Lord. Surely He comprehends everything.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcclxxiii{%
\basmalahen Ha, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcclxxiv{%
Ayn, Seen, Qaf.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcclxxv{%
Thus He inspires you, and those before you—God the Almighty, the Wise.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcclxxvi{%
To him belongs everything in the heavens and everything on earth. He is the Sublime, the Magnificent.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcclxxvii{%
The heavens above them almost burst apart, while the angels glorify the praises of their Lord, and ask forgiveness for those on earth. God is indeed the Forgiver, the Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcclxxviii{%
As for those who take masters other than Him: God is in charge of them, and you are not responsible for them.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcclxxix{%
Thus We inspired you with an Arabic Quran, that you may warn the Central City and whoever is around it, and to warn of the Day of Assembly, of which there is no doubt; a group in the Garden, and a group in the Furnace.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcclxxx{%
Had God willed, He could have made them one community, but He admits into His mercy whomever He wills. As for the wrongdoers, they will have no protector and no savior.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxi{%
Or have they adopted protectors besides him? But God is the Protector, and He gives life to the dead, and He has power over all things.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxii{%
Whatever matter you differ about, its judgment rests with God. “Such is God, my Lord, in Whom I trust, and unto Him I repent.”\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxiii{%
Originator of the heavens and the earth. He made for you mates from among yourselves, and pairs of animals, by means of which He multiplies you. There is nothing like Him. He is the Hearing, the Seeing.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxiv{%
To Him belongs absolute control of the heavens and the earth. He spreads the bounties to whomever He wills, or reduces it. He is aware of all things.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxv{%
He prescribed for you the same religion He enjoined upon Noah, and what We inspired to you, and what We enjoined upon Abraham, and Moses, and Jesus: “You shall uphold the religion, and be not divided therein.” As for the idolaters, what you call them to is outrageous to them. God chooses to Himself whom He wills, and He guides to Himself whoever repents.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxvi{%
They became divided only after knowledge came to them, out of resentment among themselves. Were it not for a predetermined decision from your Lord, judgment would have been pronounced between them. Indeed, those who were made to inherit the Book after them are in grave doubt about it.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxvii{%
To this go on inviting, and be upright as you were commanded, and do not follow their inclinations, and say, “I believe in whatever Book God has sent down, and I was commanded to judge between you equitably. God is our Lord and your Lord. We have our deeds, and you have your deeds. Let there be no quarrel between us and you. God will bring us together, and to Him is the ultimate return.”\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxviii{%
As for those who dispute about God after having answered His call, their argument is invalid with their Lord; and upon them falls wrath; and a grievous torment awaits them.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxix{%
It is God who revealed the Book with the truth, and the Balance. And what will make you realize that perhaps the Hour is near?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmccxc{%
Those who do not believe in it seek to hasten it; but those who believe are apprehensive of it, and they know it to be the truth. Absolutely, those who question the Hour are in distant error.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmccxci{%
God is kind towards His worshipers. He provides for whomever He wills. He is the Powerful, the Honorable.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmccxcii{%
Whoever desires the harvest of the Hereafter, We increase for him his harvest; and whoever desires the harvest of this world, We give him thereof, and he has no share of the Hereafter.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmccxciii{%
Or is it that they have partners who litigate for them religious laws never authorized by God? Were it not for the conclusive decision, it would have been settled between them. The wicked will have a painful punishment.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmccxciv{%
You will see the unjust terrified of what they have earned, and it will befall them. As for those who believe and do good deeds, they will be in the Meadows of the Gardens; they will have whatever they please in the presence of their Lord; that is the supreme blessing.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmccxcv{%
That is the good news God gives to His servants who believe and do good deeds. Say, “I ask of you no wage for it, except affection among the near of kin.” Whoever does a good deed, We will increase its goodness for him. God is Forgiving and Appreciative.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmccxcvi{%
Or do they say, “He forged a lie about God.” If God so willed, He could have sealed your heart. But God obliterates the false, and confirm the true by His Words. He knows what is in the hearts.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmccxcvii{%
It is He who accepts the repentance of His worshipers, and remits the sins, and knows what you do.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmccxcviii{%
And He answers those who believe and do good deeds, and He increases them of His grace. But the disbelievers will suffer a terrible punishment.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccxcix{%
If God were to increase the provision to His servants, they would transgress on earth; but He sends down in precise measure whatever He wills. Surely, regarding His servants, He is Expert and Observant.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmccc{%
It is He who brings down the rain after they have despaired, and unfolds His mercy. He is the Guardian, the Praised.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmccci{%
And of His signs are the creation of the heavens and the earth, and the creatures He has spread throughout them; and He is Able to gather them at will.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcccii{%
Whatever misfortune befalls you, it is because of what your hands have earned; and yet He pardons much.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccciii{%
You are not the ones to interfere on earth; and besides God, you have no ally, and no helper.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccciv{%
And of His signs are the ships sailing the sea like flags.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcccv{%
If He willed, He could have stilled the winds, leaving them motionless on its surface. Surely in that are signs for every disciplined, grateful person.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcccvi{%
Or He could wreck them, because of what they have earned. And yet He pardons much.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcccvii{%
Those who dispute Our signs know that there is no asylum for them.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcccviii{%
Whatever thing you are given is only the provision of this life. But what God possesses is better and more lasting for those who believe and rely on their Lord.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcccix{%
And those who avoid major sins and indecencies; and if they become angry, they forgive.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcccx{%
And those who respond to their Lord, and pray regularly, and conduct their affairs by mutual consultation, and give of what We have provided them.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcccxi{%
And those who, when wronged, defend themselves.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcccxii{%
The repayment of a bad action is one equivalent to it. But whoever pardons and makes reconciliation, his reward lies with God. He does not love the unjust.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcccxiii{%
As for those who retaliate after being wronged, there is no blame on them.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcccxiv{%
Blame lies on those who wrong people, and commit aggression in the land without right. These will have a painful punishment.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcccxv{%
But whoever endures patiently and forgives—that is a sign of real resolve.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcccxvi{%
Whoever God leaves astray has no protector apart from Him. And you will see the transgressors, when they see the torment, saying, “Is there a way of going back?”\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcccxvii{%
And you will see them exposed to it, cowering from disgrace, looking with concealed eyes. Those who believed will say, “The losers are those who lost themselves and their families on the Day of Resurrection.” Indeed, the evildoers are in a lasting torment.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcccxviii{%
They will have no allies to support them against God. Whomever God leaves astray has no way out.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcccxix{%
Respond to your Lord before there comes from God a Day that cannot be turned back. You will have no refuge on that Day, and no possibility of denial.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcccxx{%
But if they turn away—We did not send you as a guardian over them. Your only duty is communication. Whenever We let man taste mercy from Us, he rejoices in it; but when misfortune befalls them, as a consequence of what their hands have perpetrated, man turns blasphemous.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcccxxi{%
To God belongs the dominion of the heavens and the earth. He creates whatever He wills. He grants daughters to whomever He wills, and He grants sons to whomever He wills.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcccxxii{%
Or He combines them together, males and females; and He renders whomever He wills sterile. He is Knowledgeable and Capable.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcccxxiii{%
It is not for any human that God should speak to him, except by inspiration, or from behind a veil, or by sending a messenger to reveal by His permission whatever He wills. He is All-High, All-Wise.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcccxxiv{%
We thus inspired you spiritually, by Our command. You did not know what the Scripture is, nor what faith is, but We made it a light, with which We guide whomever We will of Our servants. You surely guide to a straight path.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcccxxv{%
The path of God, to whom belongs everything in the heavens and everything on earth. Indeed, to God all matters revert.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcccxxvi{%
\basmalahen Ha, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcccxxvii{%
By the Book that makes things clear.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcccxxviii{%
We made it an Arabic Quran, so that you may understand.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcccxxix{%
And it is with Us, in the Source Book, sublime and wise.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcccxxx{%
Shall We hold back the Reminder from you, since you are a transgressing people?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxi{%
How many a prophet did We send to the ancients?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxii{%
No messenger came to them, but they ridiculed him.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxiii{%
We destroyed people more powerful than they, and so the example of the ancients has passed away.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxiv{%
And if you asked them, “Who created the heavens and the earth?” They would say, “The Mighty, the Knower created them.”\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxv{%
He who made the earth a habitat for you, and traced pathways for you on it, that you may be guided.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxvi{%
He who sends down water from the sky in due proportion; and so We revive thereby a dead land. Thus you will be brought out.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxvii{%
He Who created all the pairs; and provided you with ships, and animals on which you ride.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxviii{%
That you may mount their backs, and remember the favor of your Lord as you sit firmly upon them, and say, “Glory be to Him Who placed these at our service; surely we could not have done it by ourselves.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxix{%
And surely, to our Lord we will return.”\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcccxl{%
Yet they turn one of His servants into a part of Him. Man is clearly ungrateful.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcccxli{%
Or has He chosen for Himself daughters from what He creates, and favored you with sons?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcccxlii{%
Yet when one of them is given news of what he attributes to the Most Gracious, his face darkens, and he suppresses grief.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcccxliii{%
“Someone brought up to be beautiful, and unable to help in a fight?”\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcccxliv{%
And they appoint the angels, who are servants to the Most Gracious, as females. Have they witnessed their creation? Their claim will be recorded, and they will be questioned.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcccxlv{%
And they say, “Had the Most Gracious willed, we would not have worshiped them.” But they have no knowledge of that; they are merely guessing.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcccxlvi{%
Or have We given them a book prior to this one, to which they adhere?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcccxlvii{%
But they say, “We found our parents on a course, and we are guided in their footsteps.”\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcccxlviii{%
Likewise, We sent no warner before you to any town, but the wealthy among them said, “We found our parents on a course, and we are following in their footsteps.”\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcccxlix{%
He would say, “Even if I bring you better guidance than what you found your parents following?” They would say, “We reject what you are sent with.”\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcccl{%
So We wreaked vengeance upon them. Behold, then, what was the fate of those who deny.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcccli{%
When Abraham said to his father and his people, “I am innocent of what you worship.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccclii{%
Except for He who created me, for He will guide me.”\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcccliii{%
And he made it an enduring word in his progeny, so that they may return.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcccliv{%
I gave these and their forefathers some enjoyment, until the truth and a manifest messenger came to them.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmccclv{%
But when the truth came to them, they said, “This is sorcery, and we refuse to believe in it.”\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccclvi{%
They also said, “If only this Quran was sent down to a man of importance from the two cities.”\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccclvii{%
Is it they who allocate the mercy of your Lord? It is We who have allocated their livelihood in this life, and We elevated some of them in rank above others, that some of them would take others in service. But your Lord’s mercy is better than what they amass.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmccclviii{%
Were it not that humanity would become a single community, We would have provided those who disbelieve in the Most Gracious with roofs of silver to their houses, and stairways by which they ascend.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmccclix{%
And doors to their houses, and furnishings on which they recline.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmccclx{%
And decorations. Yet all that is nothing but the stuff of this life. Yet the Hereafter, with your Lord, is for the righteous.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmccclxi{%
Whoever shuns the remembrance of the Most Gracious, We assign for him a devil, to be his companion.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmccclxii{%
They hinder them from the path, though they think they are guided.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmccclxiii{%
Until, when He comes to Us, he will say, “If only there were between me and you the distance of the two Easts.” What an evil companion!\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmccclxiv{%
It will not benefit you on that Day, since you did wrong. You are partners in the suffering.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmccclxv{%
Can you make the deaf hear, or guide the blind, and him who is in evident error?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmccclxvi{%
Even if We take you away, We will wreak vengeance upon them.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmccclxvii{%
Or show you what We have promised them; for We have absolute power over them.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmccclxviii{%
So adhere to what is revealed to you. You are upon a straight path.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmccclxix{%
It is a message for you, and for your people; and you will be questioned.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmccclxx{%
Ask those of Our messengers We sent before you: “Did We appoint gods besides the Most Gracious to be worshiped?”\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmccclxxi{%
We sent Moses with Our revelations to Pharaoh and his dignitaries. He said, “I am the Messenger of the Lord of the Worlds.”\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmccclxxii{%
But when he showed them Our signs, they started laughing at them.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmccclxxiii{%
Each sign We showed them was more marvelous than its counterpart. And We afflicted them with the plagues, so that they may repent.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmccclxxiv{%
They said, “O sorcerer, pray to your Lord for us, according to His pledge to you, and then we will be guided.”\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmccclxxv{%
But when We lifted the torment from them, they immediately broke their promise.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmccclxxvi{%
Pharaoh proclaimed among his people, saying, “O my people, do I not own the Kingdom of Egypt, and these rivers flow beneath me? Do you not see?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmccclxxvii{%
Am I not better than this miserable wretch, who can barely express himself?\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmccclxxviii{%
Why are bracelets of gold not dropped on him, or they angels came with him in procession?”\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmccclxxix{%
Thus he fooled his people, and they obeyed him. They were wicked people.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmccclxxx{%
And when they provoked Our wrath, We took retribution from them, and We drowned them all.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxi{%
Thus We made them a precedent and an example for the others.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxii{%
And when the son of Mary was cited as an example, your people opposed.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxiii{%
They said, “Are our gods better, or he?” They cited him only for argument. In fact, they are a quarrelsome people.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxiv{%
He was just a servant whom We blessed, and We made him an example for the Children of Israel.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxv{%
Had We willed, We would have made of you angels to be successors on earth.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxvi{%
He is a portent of the Hour, so have no doubt about it, and follow Me. This is a straight way.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxvii{%
And let not Satan divert you. He is an open enemy to you.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxviii{%
When Jesus came with the clarifications, he said, “I have come to you with wisdom, and to clarify for you some of what you differ about. So fear God, and obey me.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxix{%
God is my Lord and your Lord, so worship Him—this is a straight path.”\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcccxc{%
But the factions differed among themselves. So woe to the wrongdoers from the suffering of a painful Day.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcccxci{%
Are they only waiting for the Hour to come upon them suddenly, while they are unaware?\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcccxcii{%
On that Day, friends will be enemies of one another, except for the righteous.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcccxciii{%
O My servants, you have nothing to fear on that Day, nor will you grieve.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcccxciv{%
Those who believed in Our revelations, and were submissive.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcccxcv{%
Enter the Garden, you and your spouses, Joyfully.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcccxcvi{%
They will be served around with trays of gold, and cups. Therein is whatever the souls desire and delights the eyes. Therein you will stay forever.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcccxcvii{%
Such is the Garden you are made to inherit, because of what you used to do.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcccxcviii{%
Therein you will have abundant fruit, from which you eat.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcccxcix{%
As for the sinners, they will be in the torment of Hell forever.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcd{%
It will never be eased for them. In it, they will be devastated.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcdi{%
We did them no injustice, but it was they who were the unjust.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmcdii{%
And they will cry, “O Malek, let your Lord finish us off.” He will say, “You are staying.”\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmcdiii{%
We have given you the truth, but most of you hate the truth.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmcdiv{%
Have they contrived some scheme? We too are contriving.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmcdv{%
Or do they think that We cannot hear their secrets and their conspiracies? Yes indeed, Our messengers are by them, writing down.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmcdvi{%
Say, “If the Most Gracious had a son, I would be the first to worship.”\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmcdvii{%
Glorified be the Lord of the heavens and the earth, the Lord of the Throne, beyond what they describe.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmcdviii{%
So leave them to blunder and play, until they encounter their Day which they are promised.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmcdix{%
It is He who is God in heaven, and God on earth. He is the Wise, the Knower.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmcdx{%
And blessed is He Who has sovereignty over the heavens and the earth and what is between them. He alone has knowledge of the Hour, and to Him you will be returned.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmcdxi{%
Those they invoke besides Him are incapable of intercession; only those who testify to the truth and have knowledge.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmcdxii{%
And if you asked them, “Who created them?”, they would say, “God.” Why then do they deviate?\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmcdxiii{%
As for his statement: “My Lord, these are a people who do not believe.”\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmcdxiv{%
Pardon them, and say, “Peace.” They will come to know.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmmcdxv{%
\basmalahen Ha, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcdxvi{%
By the Enlightening Scripture.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcdxvii{%
We have revealed it on a Blessed Night—We have warned.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcdxviii{%
In it is distinguished every wise command.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcdxix{%
A decree from Us. We have been sending messages.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcdxx{%
As mercy from your Lord. He is the Hearer, the Knower.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcdxxi{%
Lord of the heavens and the earth and what is between them, if you know for sure.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcdxxii{%
There is no god but He. He gives life and causes death—your Lord and Lord of your ancestors of old.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcdxxiii{%
Yet they play around in doubt.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcdxxiv{%
So watch out for the Day when the sky produces a visible smoke.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcdxxv{%
Enveloping mankind; this is a painful punishment.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcdxxvi{%
“Our Lord, lift the torment from us, we are believers.”\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcdxxvii{%
But how can they be reminded? An enlightening messenger has already come to them.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcdxxviii{%
But they turned away from him, and said, “Educated, but crazy!”\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcdxxix{%
We will ease the punishment a little, but you will revert.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcdxxx{%
The Day when We launch the Great Assault—We will avenge.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxi{%
Before them We tested the people of Pharaoh; a noble messenger came to them.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxii{%
Saying, “Hand over God’s servants to me. I am an honest messenger to you.”\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxiii{%
And, “Do not exalt yourselves above God. I come to you with clear authority.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxiv{%
I have taken refuge in my Lord and your Lord, lest you stone me.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxv{%
But if you do not believe in me, keep away from me.”\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxvi{%
He appealed to his Lord: “These are a sinful people.”\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxvii{%
“Set out with My servants by night—you will be followed.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxviii{%
And cross the sea quickly; they are an army to be drowned.”\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxix{%
How many gardens and fountains did they leave behind?\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcdxl{%
And plantations, and splendid buildings.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmcdxli{%
And comforts they used to enjoy.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcdxlii{%
So it was; and We passed it on to another people.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcdxliii{%
Neither heaven nor earth wept over them, nor were they reprieved.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcdxliv{%
And We delivered the Children of Israel from the humiliating persecution.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmcdxlv{%
From Pharaoh. He was a transgressing tyrant.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmcdxlvi{%
And We chose them knowingly over all other people.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcdxlvii{%
And We gave them many signs, in which was an obvious test.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcdxlviii{%
These people say.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcdxlix{%
“There is nothing but our first death, and we will not be resurrected.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcdl{%
Bring back our ancestors, if you are truthful.”\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcdli{%
Are they better, or the people of Tubba and those before them? We annihilated them. They were evildoers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcdlii{%
We did not create the heavens and the earth and what is between them to play.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcdliii{%
We created them only for a specific purpose, but most of them do not know.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcdliv{%
The Day of Sorting Out is the appointed time for them all.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcdlv{%
The Day when no friend will avail a friend in any way, and they will not be helped.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcdlvi{%
Except for him upon whom God has mercy. He is the Mighty, the Merciful.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcdlvii{%
The Tree of Bitterness.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcdlviii{%
The food of the sinner.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcdlix{%
Like molten lead; boiling inside the bellies.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcdlx{%
Like the boiling of seething water.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcdlxi{%
Seize him and drag him into the midst of Hell!\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcdlxii{%
Then pour over his head the suffering of the Inferno!\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcdlxiii{%
Taste! You who were powerful and noble.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcdlxiv{%
This is what you used to doubt.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcdlxv{%
As for the righteous, they will be in a secure place.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcdlxvi{%
Amidst gardens and springs.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcdlxvii{%
Dressed in silk and brocade, facing one another.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcdlxviii{%
So it is, and We will wed them to lovely companions.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcdlxix{%
They will call therein for every kind of fruit, in peace and security.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcdlxx{%
Therein they will not taste death, beyond the first death; and He will protect them from the torment of Hell.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxi{%
A favor from your Lord. That is the supreme salvation.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxii{%
We made it easy in your language, so that they may remember.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxiii{%
So wait and watch. They too are waiting and watching.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxiv{%
\basmalahen Ha, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxv{%
The revelation of the Book is from God, the Exalted in Might, the Wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxvi{%
In the heavens and the earth are proofs for the believers.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxvii{%
And in your own creation, and in the creatures He scattered, are signs for people of firm faith.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxviii{%
And in the alternation of night and day, and in the sustenance God sends down from the sky, with which He revives the earth after its death, and in the circulation of the winds, are marvels for people who reason.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxix{%
These are God’s Verses which We recite to you in truth. In which message, after God and His revelations, will they believe?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxx{%
Woe to every sinful liar.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxi{%
Who hears God's revelations being recited to him, yet he persists arrogantly, as though he did not hear them. Announce to him a painful punishment.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxii{%
And when he learns something of Our revelations, he takes them in mockery. For such there is a shameful punishment.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxiii{%
Beyond them lies Hell. What they have earned will not benefit them at all, nor will those they adopted as lords instead of God. They will have a terrible punishment.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxiv{%
This is guidance. Those who blaspheme their Lord’s revelations will have a punishment of agonizing pain.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxv{%
It is God who placed the sea at your service, so that ships may run through it by His command, and that you may seek of His bounty, and that you may give thanks.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxvi{%
And He placed at your service whatever is in the heavens and whatever is on earth—all is from Him. In that are signs for a people who think.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxvii{%
Tell those who believe to forgive those who do not hope for the Days of God. He will fully recompense people for whatever they have earned.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxviii{%
Whoever does a good deed, it is for his soul; and whoever commits evil, it is against it; then to your Lord you will be returned.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxix{%
We gave the Children of Israel the Book, and wisdom, and prophecy; and We provided them with the good things; and We gave them advantage over all other people.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcdxc{%
And We gave them precise rulings. They fell into dispute only after knowledge came to them, out of mutual rivalry. Your Lord will judge between them on the Day of Resurrection regarding the things they differed about.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcdxci{%
Then We set you upon a pathway of faith, so follow it, and do not follow the inclinations of those who do not know.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcdxcii{%
They will not help you against God in any way. The wrongdoers are allies of one another, while God is the Protector of the righteous.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcdxciii{%
This is an illumination for mankind, and guidance, and mercy for people who believe with certainty.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcdxciv{%
Do those who perpetrate the evil deeds assume that We will regard them as equal to those who believe and do righteous deeds, whether in their life or their death? Evil is their judgment!\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcdxcv{%
God created the heavens and the earth with justice, so that every soul will be repaid for what it has earned. And they will not be wronged.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcdxcvi{%
Have you considered him who has taken his desire for his god? God has knowingly led him astray, and has sealed his hearing and his heart, and has placed a veil over his vision. Who will guide him after God? Will you not reflect?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcdxcvii{%
And they say, “There is nothing but this our present life; we die and we live, and nothing destroys us except time.” But they have no knowledge of that; they are only guessing.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcdxcviii{%
When Our clarifying Verses are recited to them, their only argument is to say, “Bring back our ancestors, if you are truthful.”\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcdxcix{%
Say, “God gives you life, then He makes you die; then He gathers you for the Day of Resurrection, about which there is no doubt. But most people do not know.”\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmd{%
To God belongs the kingship of the heavens and the earth. On the Day when the Hour takes place, on that Day the falsifiers will lose.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdi{%
You will see every community on its knees; every community will be called to its Book: “Today you are being repaid for what you used to do.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdii{%
This Book of Ours speaks about you in truth. We have been transcribing what you have been doing.”\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdiii{%
As for those who believed and did righteous deeds, their Lord will admit them into His mercy. That is the clear triumph.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdiv{%
But as for those who disbelieved: “Were My revelations not recited to you? But you turned arrogant, and were guilty people.”\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdv{%
And when it was said, “The promise of God is true, and of the Hour there is no doubt,” you said, “We do not know what the Hour is; we think it is only speculation; we are not convinced.”\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdvi{%
The evils of what they did will become evident to them, and the very thing they ridiculed will haunt them.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdvii{%
And it will be said, “Today We forget you, as you forgot the encounter of this Day of yours. Your abode is the Fire, and there are no saviors for you.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdviii{%
That is because you took God’s revelations for a joke, and the worldly life lured you.” So today they will not be brought out of it, and they will not be allowed to repent.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdix{%
Praise belongs to God; Lord of the heavens, Lord of the earth, Lord of humanity.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdx{%
To Him belongs all supremacy in the heavens and the earth. He is the Majestic, the Wise.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdxi{%
\basmalahen Ha, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdxii{%
The sending down of the Scripture is from God, the Honorable, the Wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdxiii{%
We did not create the heavens and the earth and what lies between them except with reason, and for a finite period. But the blasphemers continue to ignore the warnings they receive.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdxiv{%
Say, “Have you considered those you worship instead of God? Show me which portion of the earth they have created. Or do they own a share of the heavens? Bring me a scripture prior to this one, or some trace of knowledge, if you are truthful.”\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdxv{%
Who is more wrong than him who invokes, besides God, those who will not answer him until the Day of Resurrection, and are heedless of their prayers?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdxvi{%
And when humanity is gathered, they will be enemies to them, and will renounce their worship of them.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdxvii{%
When Our revelations are recited to them, plain and clear, those who disbelieve say of the truth when it has come to them, “This is obviously magic.”\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdxviii{%
Or do they say, “He invented it himself”? Say, “If I invented it myself, there is nothing you can do to protect me from God. He knows well what you are engaged in. He is sufficient witness between me and you. He is the Forgiver, the Merciful.”\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdxix{%
Say, “I am not different from the other messengers; and I do not know what will be done with me, or with you. I only follow what is inspired in me, and I am only a clear warner.”\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdxx{%
Say, “Have you considered? What if it is from God and you disbelieve in it? A witness from the Children of Israel testified to its like, and has believed, while you turned arrogant. God does not guide the unjust people.”\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdxxi{%
Those who disbelieve say to those who believe, “If it were anything good, they would not have preceded us to it.” And since they were not guided by it, they will say, “This is an ancient lie.”\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdxxii{%
And before it was the Book of Moses, a model and a mercy. And this is a confirming Book, in the Arabic language, to warn those who do wrong—and good news for the doers of good.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdxxiii{%
Those who say, “Our Lord is God,” then lead a righteous life—they have nothing to fear, nor shall they grieve.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdxxiv{%
These are the inhabitants of Paradise, where they will dwell forever—a reward for what they used to do.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdxxv{%
We have enjoined upon man kindness to his parents. His mother carried him with difficulty, and delivered him with difficulty. His bearing and weaning takes thirty months. Until, when he has attained his maturity, and has reached forty years, he says, “Lord, enable me to appreciate the blessings You have bestowed upon me and upon my parents, and to act with righteousness, pleasing You. And improve my children for me. I have sincerely repented to You, and I am of those who have surrendered.”\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdxxvi{%
Those are they from whom We accept the best of their deeds, and We overlook their misdeeds, among the dwellers of Paradise—the promise of truth which they are promised.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdxxvii{%
As for him who says to his parents, “Enough of you! Are you promising me that I will be raised up, when generations have passed away before me?” While they cry for God’s help, “Woe to you! Believe! The promise of God is true!” But he says, “These are nothing but tales of the ancients.”\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdxxviii{%
Those are they upon whom the sentence is justified, among the communities that have passed away before them, of jinn and humans. They are truly losers.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdxxix{%
There are degrees for everyone, according to what they have done, and He will repay them for their works in full, and they will not be wronged.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdxxx{%
On the Day when the faithless will be paraded before the Fire: “You have squandered your good in your worldly life, and you took pleasure in them. So today you are being repaid with the torment of shame, because of your unjust arrogance on earth, and because you used to sin.”\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdxxxi{%
And mention the brother of Aad, as he warned his people at the dunes. Warnings have passed away before him, and after him: “Worship none but God; I fear for you the punishment of a tremendous Day.”\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdxxxii{%
They said, “Did you come to us to divert us from our gods? Then bring us what you threaten us with, if you are being truthful.”\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdxxxiii{%
He said, “The knowledge is only with God, and I inform you of what I was sent with; but I see you are an ignorant people.”\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdxxxiv{%
Then, when they saw a cloud approaching their valley, they said, “This is a cloud that will bring us rain.” “In fact, it is what you were impatient for: a wind in which is grievous suffering.”\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdxxxv{%
It will destroy everything by the command of its Lord. And when the morning came upon them, there was nothing to be seen except their dwellings. Thus We requite the guilty people.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdxxxvi{%
We had empowered them in the same way as We empowered you; and We gave them the hearing, and the sight, and the minds. But neither their hearing, nor their sight, nor their minds availed them in any way. That is because they disregarded the revelations of God; and so they became surrounded by what they used to ridicule.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdxxxvii{%
We have destroyed many townships around you, and diversified the signs, so that they may return.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdxxxviii{%
Why then did the idols, whom they worshiped as means of nearness to God, not help them? In fact, they abandoned them. It was their lie, a fabrication of their own making.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdxxxix{%
Recall when We dispatched towards you a number of jinn, to listen to the Quran. When they came in its presence, they said, “Pay attention!” Then, when it was concluded, they rushed to their people, warning them.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdxl{%
They said, “O our people, we have heard a Scripture, sent down after Moses, confirming what came before it. It guides to the truth, and to a straight path.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdxli{%
O our people! Answer the caller to God, and believe in Him; and He will forgive you your sins, and will save you from a painful punishment.”\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdxlii{%
He who does not answer the caller to God will not escape on earth, and has no protectors besides Him. Those are in obvious error.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdxliii{%
Do they not realize that God, who created the heavens and the earth, and was never tired by creating them, is Able to revive the dead? Yes indeed; He is Capable of everything.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdxliv{%
On the Day when those who disbelieved are presented to the Fire: “Is this not real?” They will say, “Yes, indeed, by our Lord.” He will say, “Then taste the suffering for having disbelieved.”\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdxlv{%
So be patient, as the messengers with resolve were patient, and do not be hasty regarding them. On the Day when they witness what they are promised, it will seem as if they had lasted only for an hour of a day. A proclamation: Will any be destroyed except the sinful people?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdxlvi{%
\basmalahen Those who disbelieve and repel from the path of God—He nullifies their works.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdxlvii{%
While those who believe, and work righteousness, and believe in what was sent down to Muhammad—and it is the truth from their Lord—He remits their sins, and relieves their concerns.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdxlviii{%
That is because those who disbelieve follow falsehoods, while those who believe follow the truth from their Lord. God thus cites for the people their examples.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdxlix{%
When you encounter those who disbelieve, strike at their necks. Then, when you have routed them, bind them firmly. Then, either release them by grace, or by ransom, until war lays down its burdens. Had God willed, He could have defeated them Himself, but He thus tests some of you by means of others. As for those who are killed in the way of God, He will not let their deeds go to waste.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdl{%
He will guide them, and will improve their state of mind.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdli{%
And will admit them into Paradise, which He has identified for them.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdlii{%
O you who believe! If you support God, He will support you, and will strengthen your foothold.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdliii{%
But as for those who disbelieve, for them is perdition, and He will waste their deeds.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdliv{%
That is because they hated what God revealed, so He nullified their deeds.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdlv{%
Have they not journeyed through the earth and seen the consequences for those before them? God poured destruction upon them, and for the unbelievers is something comparable.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdlvi{%
That is because God is the Master of those who believe, while the disbelievers have no master.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdlvii{%
God will admit those who believe and do good deeds into gardens beneath which rivers flow. As for those who disbelieve, they enjoy themselves, and eat as cattle eat, and the Fire will be their dwelling.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdlviii{%
How many a town was more powerful than your town which evicted you? We destroyed them, and there was no helper for them.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdlix{%
Is he who stands upon evidence from his Lord, like someone whose evil deed is made to appear good to him? And they follow their own desires?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdlx{%
The likeness of the Garden promised to the righteous: in it are rivers of pure water, and rivers of milk forever fresh, and rivers of wine delightful to the drinkers, and rivers of strained honey. And therein they will have of every fruit, and forgiveness from their Lord. Like one abiding in the Fire forever, and are given to drink boiling water, that cuts-up their bowels?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdlxi{%
Among them are those who listen to you, but when they leave your presence, they say to those given knowledge, “What did he say just now?” Those are they whose hearts God has sealed, and they follow their own desires.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdlxii{%
As for those who are guided, He increases them in guidance, and He has granted them their righteousness.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdlxiii{%
Are they just waiting until the Hour comes to them suddenly? Its tokens have already come. But how will they be reminded when it has come to them?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdlxiv{%
Know that there is no god but God, and ask forgiveness for your sin, and for the believing men and believing women. God knows your movements, and your resting-place.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdlxv{%
Those who believe say, “If only a chapter is sent down.” Yet when a decisive chapter is sent down, and fighting is mentioned in it, you see those in whose hearts is sickness looking at you with the look of someone fainting at death. So woe to them!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdlxvi{%
Obedience and upright speech. Then, when the matter is settled, being true to God would have been better for them.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdlxvii{%
If you turn away, you are likely to make mischief on earth, and sever your family ties.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdlxviii{%
Those are they whom God has cursed. He made them deaf, and blinded their sight.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdlxix{%
Will they not ponder the Quran? Or are there locks upon their hearts?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdlxx{%
Those who reverted after the guidance became clear to them—Satan has enticed them, and has given them latitude.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdlxxi{%
That is because they said to those who hated what God has revealed, “We will obey you in certain matters.” But God knows their secret thoughts.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdlxxii{%
How about when the angels take them at death, beating their faces and their backs?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdlxxiii{%
That is because they pursued what displeases God, and they disliked His approval, so He nullified their works.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdlxxiv{%
Do those in whose hearts is sickness think that God will not expose their malice?\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdlxxv{%
Had We willed, We could have shown them to you, and you would have recognized them by their marks. Yet you will recognize them by their tone of speech. And God knows your actions.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdlxxvi{%
We will certainly test you, until We know those among you who strive, and those who are steadfast, and We will test your reactions.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdlxxvii{%
Those who disbelieve, and hinder from the path of God, and oppose the Messenger after guidance has become clear to them—they will not hurt God in the least, but He will nullify their deeds.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdlxxviii{%
O you who believe! obey God, and obey the Messenger, and do not let your deeds go to waste.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdlxxix{%
Those who disbelieve, and hinder from God’s path, and then die as disbelievers—God will not forgive them.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdlxxx{%
So do not waver and call for peace while you have the upper hand. God is with you, and He will not waste your efforts.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxi{%
The life of this word is nothing but play and pastime. But if you have faith and lead a righteous life, He will grant you your rewards, and He will not ask you for your possessions.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxii{%
Were He to ask you for it, and press you, you would become tightfisted, and He would expose your unwillingness.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxiii{%
Here you are, being called to spend in the cause of God. Among you are those who withhold; but whoever withholds is withholding against his own soul. God is the Rich, while you are the needy. And if you turn away, He will replace you with another people, and they will not be like you.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxiv{%
\basmalahen We have granted you a conspicuous victory.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxv{%
That God may forgive you your sin, past and to come, and complete His favors upon you, and guide you in a straight path.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxvi{%
And help you with an unwavering support.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxvii{%
It is He who sent down tranquility into the hearts of the believers, to add faith to their faith. To God belong the forces of the heavens and the earth. God is Knowing and Wise.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxviii{%
He will admit the believers, male and female, into Gardens beneath which rivers flow, to abide therein forever, and He will remit their sins. That, with God, is a great triumph.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxix{%
And He will punish the hypocrites, male and female, and the idolaters, male and female, those who harbor evil thoughts about God. They are surrounded by evil; and God is angry with them, and has cursed them, and has prepared for them Hell—a miserable destination.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdxc{%
To God belong the troops of the heavens and the earth. God is Mighty and Wise.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdxci{%
We sent you as a witness, and a bearer of good news, and a warner.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdxcii{%
That you may believe in God and His Messenger, and support Him, and honor Him, and praise Him morning and evening.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdxciii{%
Those who pledge allegiance to you are pledging allegiance to God. The hand of God is over their hands. Whoever breaks his pledge breaks it to his own loss. And whoever fulfills his covenant with God, He will grant him a great reward.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdxciv{%
The Desert-Arabs who remained behind will say to you, “Our belongings and our families have preoccupied us, so ask forgiveness for us.” They say with their tongues what is not in their hearts. Say, “Who can avail you anything against God, if He desires loss for you, or desires gain for you?” In fact, God is Informed of what you do.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdxcv{%
But you thought that the Messenger and the believers will never return to their families, and this seemed fine to your hearts; and you harbored evil thoughts, and were uncivilized people.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdxcvi{%
He who does not believe in God and His Messenger—We have prepared for the disbelievers a Blazing Fire.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdxcvii{%
To God belongs the kingdom of the heavens and the earth. He forgives whomever He wills, and He punishes whomever He wills. God is Forgiving and Merciful.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdxcviii{%
Those who lagged behind will say when you depart to collect the gains, “Let us follow you.” They want to change the Word of God. Say, “You will not follow us; God has said so before.” Then they will say, “But you are jealous of us.” In fact, they understand only a little.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdxcix{%
Say to the Desert-Arabs who lagged behind, “You will be called against a people of great might; you will fight them, unless they submit. If you obey, God will give you a fine reward. But if you turn away, as you turned away before, He will punish you with a painful punishment.”\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdc{%
There is no blame on the blind, nor any blame on the lame, nor any blame on the sick. Whoever obeys God and His Messenger—He will admit him into gardens beneath which rivers flow; but whoever turns away—He will punish him with a painful punishment.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdci{%
God was pleased with the believers, when they pledged allegiance to you under the tree. He knew what was in their hearts, and sent down serenity upon them, and rewarded them with an imminent conquest.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcii{%
And abundant gains for them to capture. God is Mighty and Wise.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdciii{%
God has promised you abundant gains, which you will capture. He has expedited this for you, and has restrained people’s hands from you; that it may be a sign to the believers, and that He may guide you on a straight path.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdciv{%
And other things, of which you were incapable, but God has encompassed them. God is Capable of everything.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcv{%
If those who disbelieve had fought you, they would have turned back and fled, then found neither protector nor helper.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcvi{%
It is God’s pattern, ongoing since the past. You will never find any change in God’s pattern.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcvii{%
It is He who withheld their hands from you, and your hands from them, in the valley of Mecca, after giving you advantage over them. God is Observer of what you do.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcviii{%
It is they who disbelieved, and barred you from the Sacred Mosque, and prevented the offering from reaching its destination. Were it not for faithful men and faithful women, whom you did not know, you were about to hurt them, and became guilty of an unintentional crime. Thus God admits into His mercy whomever He wills. Had they dispersed, We would have punished those who disbelieved among them with a painful penalty.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcix{%
Those who disbelieved filled their hearts with rage—the rage of the days of ignorance. But God sent His serenity down upon His Messenger, and upon the believers, and imposed on them the words of righteousness—of which they were most worthy and deserving. God is aware of everything.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcx{%
God has fulfilled His Messenger’s vision in truth: “You will enter the Sacred Mosque, God willing, in security, heads shaven, or hair cut short, not fearing. He knew what you did not know, and has granted besides that an imminent victory.”\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcxi{%
It is He who sent His Messenger with the guidance and the religion of truth, to make it prevail over all religions. God suffices as Witness.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcxii{%
Muhammad is the Messenger of God. Those with him are stern against the disbelievers, yet compassionate amongst themselves. You see them kneeling, prostrating, seeking blessings from God and approval. Their marks are on their faces from the effects of prostration. Such is their description in the Torah, and their description in the Gospel: like a plant that sprouts, becomes strong, grows thick, and rests on its stem, impressing the farmers. Through them He enrages the disbelievers. God has promised those among them who believe and do good deeds forgiveness and a great reward.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcxiii{%
\basmalahen O you who believe! Do not place your opinions above that of God and His Messenger, and fear God. God is Hearing and Knowing.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcxiv{%
O you who believe! Do not raise your voices above the voice of the Prophet, and do not speak loudly to him, as you speak loudly to one another, lest your works be in vain without you realizing.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcxv{%
Those who lower their voices before God’s Messenger—those are they whose hearts God has tested for piety. They will have forgiveness and a great reward.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcxvi{%
Those who call you from behind the chambers—most of them do not understand.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcxvii{%
Had they remained patient until you came out to them, it would have been better for them. But God is Forgiving and Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdcxviii{%
O you who believe! If a troublemaker brings you any news, investigate, lest you harm people out of ignorance, and you become regretful for what you have done.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcxix{%
And know that among you is the Messenger of God. Had he obeyed you in many things, you would have suffered hardship. But God has given you the love of faith, and adorned it in your hearts, and made disbelief, mischief, and rebellion hateful to you. These are the rightly guided.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcxx{%
A Grace and Favor from God. God is Knowing and Wise.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdcxxi{%
If two groups of believers fight each other, reconcile between them. But if one group aggresses against the other, fight the aggressing group until it complies with God’s command. Once it has complied, reconcile between them with justice, and be equitable. God loves the equitable.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdcxxii{%
The believers are brothers, so reconcile between your brothers, and remain conscious of God, so that you may receive mercy.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdcxxiii{%
O you who believe! No people shall ridicule other people, for they may be better than they. Nor shall any women ridicule other women, for they may be better than they. Nor shall you slander one another, nor shall you insult one another with names. Evil is the return to wickedness after having attained faith. Whoever does not repent—these are the wrongdoers.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdcxxiv{%
O you who believe! Avoid most suspicion—some suspicion is sinful. And do not spy on one another, nor backbite one another. Would any of you like to eat the flesh of his dead brother? You would detest it. So remain mindful of God. God is Most Relenting, Most Merciful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdcxxv{%
O people! We created you from a male and a female, and made you races and tribes, that you may know one another. The best among you in the sight of God is the most righteous. God is All-Knowing, Well-Experienced.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdcxxvi{%
The Desert-Arabs say, “We have believed.” Say, “You have not believed; but say, ‘We have submitted,’ for faith has not yet entered into your hearts. But if you obey God and His Messenger, He will not diminish any of your deeds. God is Forgiving and Merciful.”\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxxvii{%
The believers are those who believe in God and His Messenger, and then have not doubted, and strive for God’s cause with their wealth and their persons. These are the sincere.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxxviii{%
Say, “Are you going to teach God about your religion, when God knows everything in the heavens and the earth, and God is aware of all things?”\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxxix{%
They regarded it a favor to you that they have submitted. Say, “Do not consider your submission a favor to me; it is God who has done you a favor by guiding you to the faith, if you are sincere.”\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxxx{%
God knows the secrets of the heavens and the earth, and God is seeing of everything you do.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxi{%
\basmalahen Qaf. By the Glorious Quran.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxii{%
They marveled that a warner has come to them from among them. The disbelievers say, “This is something strange.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxiii{%
When we have died and become dust? This is a farfetched return.”\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxiv{%
We know what the earth consumes of them, and with Us is a comprehensive book.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxv{%
But they denied the truth when it has come to them, so they are in a confused state.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxvi{%
Have they not observed the sky above them, how We constructed it, and decorated it, and it has no cracks?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxvii{%
And the earth, how We spread it out, and set on it mountains, and grew in it all kinds of delightful pairs?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxviii{%
A lesson and a reminder for every penitent worshiper.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxix{%
And We brought down from the sky blessed water, and produced with it gardens and grain to harvest.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdcxl{%
And the soaring palm trees, with clustered dates.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdcxli{%
As sustenance for the servants. And We revive thereby a dead town. Likewise is the resurrection.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdcxlii{%
Before them the people of Noah denied the truth, and so did the dwellers of Russ, and Thamood.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdcxliii{%
And Aad, and Pharaoh, and the brethren of Lot.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdcxliv{%
And the Dwellers of the Woods, and the people of Tubba. They all rejected the messengers, so My threat came true.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxlv{%
Were We fatigued by the first creation? But they are in doubt of a new creation.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxlvi{%
We created the human being, and We know what his soul whispers to him. We are nearer to him than his jugular vein.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxlvii{%
As the two receivers receive, seated to the right and to the left.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxlviii{%
Not a word does he utter, but there is a watcher by him, ready.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxlix{%
The daze of death has come in truth: “This is what you tried to evade.”\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcl{%
And the Trumpet is blown: “This is the Promised Day.”\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcli{%
And every soul will come forward, accompanied by a driver and a witness.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdclii{%
“You were in neglect of this, so We lifted your screen from you, and your vision today is keen.”\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcliii{%
And His escort will say, “This is what I have ready with me.”\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcliv{%
“Throw into Hell every stubborn disbeliever.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdclv{%
Preventer of good, aggressor, doubter.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdclvi{%
Who fabricated another god with God; toss him into the intense agony.”\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdclvii{%
His escort will say, “Our Lord, I did not make him rebel, but he was far astray.”\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdclviii{%
He will say, “Do not feud in My presence—I had warned you in advance.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdclix{%
The decree from Me will not be changed, and I am not unjust to the servants.”\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdclx{%
On the Day when We will say to Hell, “Are you full?” And it will say, “Are there any more?”\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdclxi{%
And Paradise will be brought closer to the pious, not far away.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdclxii{%
“This is what you were promised—for every careful penitent.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdclxiii{%
Who inwardly feared the Most Gracious, and came with a repentant heart.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdclxiv{%
Enter it in peace. This is the Day of Eternity.”\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdclxv{%
Therein they will have whatever they desire—and We have even more.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdclxvi{%
How many generations before them, who were more powerful than they, did We destroy? They explored the lands—was there any escape?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdclxvii{%
In that is a reminder for whoever possesses a heart, or cares to listen and witness.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdclxviii{%
We created the heavens and the earth and what is between them in six days, and no fatigue touched Us.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdclxix{%
So endure what they say, and proclaim the praises of your Lord before the rising of the sun, and before sunset.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdclxx{%
And glorify Him during the night, and at the end of devotions.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdclxxi{%
And listen for the Day when the caller calls from a nearby place.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdclxxii{%
The Day when they will hear the Shout in all truth. That is the Day of Emergence.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdclxxiii{%
It is We who control life and death, and to Us is the destination.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdclxxiv{%
The Day when the earth will crack for them at once. That is an easy gathering for Us.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdclxxv{%
We are fully aware of what they say, and you are not a dictator over them. So remind by the Quran whoever fears My warning.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdclxxvi{%
\basmalahen By the spreaders spreading.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdclxxvii{%
And those carrying loads.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdclxxviii{%
And those moving gently.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdclxxix{%
And those distributing as commanded.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdclxxx{%
What you are promised is true.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxi{%
Judgment will take place.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxii{%
By the sky that is woven.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxiii{%
You differ in what you say.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxiv{%
Averted from it is he who is averted.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxv{%
Perish the imposters.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxvi{%
Those who are dazed in ignorance.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxvii{%
They ask, “When is the Day of Judgment?”\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxviii{%
The Day they are presented to the Fire.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxix{%
“Taste your ordeal. This is what you used to challenge.”\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxc{%
But the pious are amidst gardens and springs.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxci{%
Receiving what their Lord has given them. They were virtuous before that.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxcii{%
They used to sleep a little at night.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxciii{%
And at dawn, they would pray for pardon.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxciv{%
And in their wealth, there was a share for the beggar and the deprived.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcxcv{%
And on earth are signs for the convinced.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcxcvi{%
And within yourselves. Do you not see?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcxcvii{%
And in the heaven is your livelihood, and what you are promised.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcxcviii{%
By the Lord of the heaven and the earth, it is as true as the fact that you speak.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcxcix{%
Has the story of Abraham’s honorable guests reached you?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcc{%
When they entered upon him, they said, “Peace.” He said, “Peace, strangers.”\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcci{%
Then he slipped away to his family, and brought a fatted calf.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdccii{%
He set it before them. He said, “Will you not eat?”\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcciii{%
And he harbored fear of them. They said, “Do not fear,” and they announced to him the good news of a knowledgeable boy.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcciv{%
His wife came forward crying. She clasped her face, and said, “A barren old woman?”\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdccv{%
They said, “Thus spoke your Lord. He is the Wise, the Knowing.”\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdccvi{%
He said, “What is your business, O envoys?”\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdccvii{%
They said, “We are sent to a people guilty of sin.”\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdccviii{%
“To unleash upon them rocks of clay.”\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdccix{%
“Marked by your Lord for the excessive.”\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdccx{%
We evacuated all the believers who were in it.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdccxi{%
But found in it only one household of Muslims.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdccxii{%
And We left in it a sign for those who fear the painful punishment.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdccxiii{%
And in Moses. We sent him to Pharaoh with a clear authority.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdccxiv{%
But he turned away with his warlords, and said, “A sorcerer or a madman.”\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdccxv{%
So We seized him and his troops, and threw them into the sea, and He was to blame.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdccxvi{%
And in Aad. We unleashed against them the devastating wind.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdccxvii{%
It spared nothing it came upon, but rendered it like decayed ruins.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdccxviii{%
And in Thamood. They were told, “Enjoy yourselves for a while.”\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdccxix{%
But they defied the command of their Lord, so the lightning struck them as they looked on.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdccxx{%
They could not rise up, nor could they find help.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdccxxi{%
And before that, the people of Noah. They were immoral people.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdccxxii{%
We constructed the universe with power, and We are expanding it.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdccxxiii{%
And the earth—We spread it out—How well We prepared it!\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdccxxiv{%
We created all things in pairs, so that you may reflect and ponder.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdccxxv{%
“So flee towards God. I am to you from Him a clear warner.”\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdccxxvi{%
“And do not set up any other god with God. I am to you from Him a clear warner.”\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdccxxvii{%
Likewise, no messenger came to those before them, but they said, “A sorcerer or a madman.”\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdccxxviii{%
Did they recommend it to one another? In fact, they are rebellious people.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmdccxxix{%
So turn away from them; you are not to blame.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmdccxxx{%
And remind, for the reminder benefits the believers.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxi{%
I did not create the jinn and the humans except to worship Me.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxii{%
I need no livelihood from them, nor do I need them to feed Me.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxiii{%
God is the Provider, the One with Power, the Strong.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxiv{%
Those who do wrong will have their turn, like the turn of their counterparts, so let them not rush Me.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxv{%
So woe to those who disbelieve because of that Day of theirs which they are promised.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxvi{%
\basmalahen By the Mount.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxvii{%
And a Book inscribed.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxviii{%
In a published scroll.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxix{%
And the frequented House.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdccxl{%
And the elevated roof.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccxli{%
And the seething sea.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdccxlii{%
The punishment of your Lord is coming.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdccxliii{%
There is nothing to avert it.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccxliv{%
On the Day when the heaven sways in agitation.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccxlv{%
And the mountains go into motion.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccxlvi{%
Woe on that Day to the deniers.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccxlvii{%
Those who play with speculation.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccxlviii{%
The Day when they are shoved into the Fire of Hell forcefully.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccxlix{%
“This is the Fire which you used to deny.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccl{%
Is this magic, or do you not see?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccli{%
Burn in it. Whether you are patient, or impatient, it is the same for you. You are only being repaid for what you used to do.”\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcclii{%
But the righteous will be amid gardens and bliss.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdccliii{%
Enjoying what their Lord has given them, and their Lord has spared them the suffering of Hell.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccliv{%
Eat and drink happily, for what you used to do.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcclv{%
Relaxing on luxurious furnishings; and We will couple them with gorgeous spouses.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcclvi{%
Those who believed and their offspring followed them in faith—We will unite them with their offspring, and We will not deprive them of any of their works. Every person is hostage to what he has earned.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcclvii{%
And We will supply them with fruit, and meat; such as they desire.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcclviii{%
They will exchange therein a cup; wherein is neither harm, nor sin.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcclix{%
Serving them will be youths like hidden pearls.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcclx{%
And they will approach one another, inquiring.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcclxi{%
They will say, “Before this, we were fearful for our families.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcclxii{%
But God blessed us, and spared us the agony of the Fiery Winds.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcclxiii{%
Before this, we used to pray to Him. He is the Good, the Compassionate.”\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcclxiv{%
So remind. By the grace of your Lord, you are neither a soothsayer, nor a madman.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcclxv{%
Or do they say, “A poet—we await for him a calamity of time”?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdcclxvi{%
Say, “Go on waiting; I will be waiting with you.”\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdcclxvii{%
Or is it that their dreams compel them to this? Or are they aggressive people?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdcclxviii{%
Or do they say, “He made it up”? Rather, they do not believe.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdcclxix{%
So let them produce a discourse like it, if they are truthful.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdcclxx{%
Or were they created out of nothing? Or are they the creators?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxi{%
Or did they create the heavens and the earth? In fact, they are not certain.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxii{%
Or do they possess the treasuries of your Lord? Or are they the controllers?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxiii{%
Or do they have a stairway by means of which they listen? Then let their listener produce a clear proof.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxiv{%
Or for Him the daughters, and for you the sons?\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxv{%
Or do you demand a payment from them, and they are burdened by debt?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxvi{%
Or do they know the future, and they are writing it down?\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxvii{%
Or are they planning a conspiracy? The conspiracy will befall the disbelievers.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxviii{%
Or do they have a god besides God? God transcends what they associate.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxix{%
Even if they were to see lumps of the sky falling down, they would say, “A mass of clouds.”\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxx{%
So leave them until they meet their Day in which they will be stunned.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxi{%
The Day when their ploys will avail them nothing; and they will not be helped.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxii{%
For those who do wrong, there is a punishment besides that; but most of them do not know.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxiii{%
So patiently await the decision of your Lord, for you are before Our Eyes; and proclaim the praises of your Lord when you arise.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxiv{%
And glorify Him during the night, and at the receding of the stars.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxv{%
\basmalahen By the star as it goes down.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxvi{%
Your friend has not gone astray, nor has he erred.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxvii{%
Nor does he speak out of desire.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxviii{%
It is but a revelation revealed.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxix{%
Taught to him by the Extremely Powerful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccxc{%
The one of vigor. He settled.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdccxci{%
While he was at the highest horizon.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdccxcii{%
Then he came near, and hovered around.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccxciii{%
He was within two bows’ length, or closer.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccxciv{%
Then He revealed to His servant what He revealed.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccxcv{%
The heart did not lie about what it saw.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccxcvi{%
Will you dispute with him concerning what he saw?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccxcvii{%
He saw him on another descent.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccxcviii{%
At the Lotus Tree of the Extremity.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccxcix{%
Near which is the Garden of Repose.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccc{%
As there covered the Lotus Tree what covered it.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdccci{%
The sight did not waver, nor did it exceed.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcccii{%
He saw some of the Great Signs of his Lord.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccciii{%
Have you considered al-Lat and al-Uzza?\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdccciv{%
And Manat, the third one, the other?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcccv{%
Are you to have the males, and He the females?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcccvi{%
What a bizarre distribution.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcccvii{%
These are nothing but names, which you have devised, you and your ancestors, for which God sent down no authority. They follow nothing but assumptions, and what the ego desires, even though guidance has come to them from their Lord.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcccviii{%
Or is the human being to have whatever he desires?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcccix{%
To God belong the Last and the First.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcccx{%
How many an angel is there in the heavens whose intercession avails nothing, except after God gives permission to whomever He wills, and approves?\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcccxi{%
Those who do not believe in the Hereafter give the angels the names of females.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcccxii{%
They have no knowledge of that. They only follow assumptions, and assumptions are no substitute for the truth.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcccxiii{%
So avoid him who has turned away from Our remembrance, and desires nothing but the present life.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcccxiv{%
That is the extent of their knowledge. Your Lord knows best who has strayed from His path, and He knows best who has accepted guidance.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdcccxv{%
To God belongs whatever is in the heavens and whatever is on earth. He will repay those who do evil according to their deeds, and recompense those who do good with the best.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdcccxvi{%
Those who avoid gross sins and indecencies—except for minor lapses—your Lord is of Vast Forgiveness. He knows you well, ever since He created you from the earth, and ever since you were embryos in your mothers’ wombs. So do not acclaim your own virtue; He is fully aware of the righteous.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdcccxvii{%
Have you considered him who turned away?\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdcccxviii{%
And gave a little, and held back?\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdcccxix{%
Does he possess knowledge of the unseen, and can therefore foresee?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdcccxx{%
Or was he not informed of what is in the Scrolls of Moses?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxi{%
And of Abraham, who fulfilled?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxii{%
That no soul bears the burdens of another soul.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxiii{%
And that the human being attains only what he strives for.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxiv{%
And that his efforts will be witnessed.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxv{%
Then he will be rewarded for it the fullest reward.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxvi{%
And that to your Lord is the finality.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxvii{%
And that it is He who causes laughter and weeping.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxviii{%
And that it is He who gives death and life.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxix{%
And that it is He who created the two kinds—the male and the female.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxx{%
From a sperm drop, when emitted.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxi{%
And that upon Him is the next existence.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxii{%
And that it is He who enriches and impoverishes.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxiii{%
And that it is He who is the Lord of Sirius.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxiv{%
And that it is He who destroyed the first Aad.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxv{%
And Thamood, sparing no one.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxvi{%
And the people of Noah before that; for they were most unjust and most oppressive.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxvii{%
And He toppled the ruined cities.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxviii{%
And covered them with whatever covered them.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxix{%
So which of your Lord's marvels can you deny?\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmdcccxl{%
This is a warning, just like the first warnings.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmdcccxli{%
The inevitable is imminent.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlii{%
None besides God can unveil it.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmdcccxliii{%
Do you marvel at this discourse?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmdcccxliv{%
And laugh, and do not weep?\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlv{%
Lost in your frivolity?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlvi{%
So bow down to God, and worship!\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlvii{%
\basmalahen The Hour has drawn near, and the moon has split.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlviii{%
Yet whenever they see a miracle, they turn away, and say, “Continuous magic.”\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlix{%
They lied, and followed their opinions, but everything has its time.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcccl{%
And there came to them news containing a deterrent.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcccli{%
Profound wisdom—but warnings are of no avail.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccclii{%
So turn away from them. On the Day when the Caller calls to something terrible.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcccliii{%
Their eyes humiliated, they will emerge from the graves, as if they were swarming locusts.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcccliv{%
Scrambling towards the Caller, the disbelievers will say, “This is a difficult Day.”\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccclv{%
Before them the people of Noah disbelieved. They rejected Our servant, and said, “Crazy,” and he was rebuked.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccclvi{%
So he appealed to his Lord, “I am overwhelmed, so help me.”\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccclvii{%
So We opened the floodgates of heaven with water pouring down.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccclviii{%
And We made the earth burst with springs, and the waters met for a purpose already destined.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccclix{%
And We carried him on a craft of planks and nails.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccclx{%
Sailing before Our eyes; a reward for him who was rejected.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccclxi{%
And We left it as a sign. Is there anyone who would take heed?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccclxii{%
So how were My punishment and My warnings?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdccclxiii{%
We made the Quran easy to learn. Is there anyone who would learn?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdccclxiv{%
Aad denied the truth. So how were My punishment and My warnings?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccclxv{%
We unleashed upon them a screaming wind, on a day of unrelenting misery.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdccclxvi{%
Plucking the people away, as though they were trunks of uprooted palm-trees.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdccclxvii{%
So how were My punishment and My warnings?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdccclxviii{%
We made the Quran easy to remember. Is there anyone who would remember?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdccclxix{%
Thamood rejected the warnings.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdccclxx{%
They said, “Are we to follow one of us, a human being? We would then go astray, and end up in Hell.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxi{%
Was the message given to him, out of all of us? In fact, he is a wicked liar.”\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxii{%
They will know tomorrow who the wicked liar is.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxiii{%
We are sending the she-camel as a test for them; so watch them and be patient.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxiv{%
And inform them that the water is to be shared between them; each share of drink made available.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxv{%
But they called their friend, and he dared, and he slaughtered.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxvi{%
So how were My punishment and My warnings?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxvii{%
We sent against them a single Scream, and they became like crushed hay.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxviii{%
We made the Quran easy to understand. Is there anyone who would understand?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxix{%
The people of Lot rejected the warnings.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxx{%
We unleashed upon them a shower of stones, except for the family of Lot; We rescued them at dawn.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxi{%
A blessing from Us. Thus We reward the thankful.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxii{%
He had warned them of Our onslaught, but they dismissed the warnings.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxiii{%
They even lusted for his guest, so We obliterated their eyes. “So taste My punishment and My warnings.”\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxiv{%
Early morning brought upon them enduring punishment.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxv{%
So taste My punishment and My warnings.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxvi{%
We made the Quran easy to memorize. Is there anyone who would memorize?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxvii{%
The warnings also came to the people of Pharaoh.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxviii{%
They rejected Our signs, all of them, so We seized them—the seizure of an Almighty Omnipotent.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxix{%
Are your unbelievers better than all those? Or do you have immunity in the scriptures?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcccxc{%
Or do they say, “We are united, and we will be victorious”?\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcccxci{%
The multitude will be defeated, and they will turn their backs.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcii{%
The Hour is their appointed time—the Hour is more disastrous, and most bitter.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcccxciii{%
The wicked are in confusion and madness.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcccxciv{%
The Day when they are dragged upon their faces into the Fire: “Taste the touch of Saqar.”\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcv{%
Everything We created is precisely measured.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcvi{%
And Our command is but once, like the twinkling of an eye.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcvii{%
We have destroyed your likes. Is there anyone who would ponder?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcviii{%
Everything they have done is in the Books.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcix{%
Everything, small or large, is written down.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcm{%
The righteous will be amidst gardens and rivers.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcmi{%
In an assembly of virtue, in the presence of an Omnipotent King.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcmii{%
\basmalahen The Compassionate.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcmiii{%
Has taught the Quran.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcmiv{%
He created man.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcmv{%
And taught him clear expression.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcmvi{%
The sun and the moon move according to plan.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcmvii{%
And the stars and the trees prostrate themselves.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcmviii{%
And the sky, He raised; and He set up the balance.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcmix{%
So do not transgress in the balance.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcmx{%
But maintain the weights with justice, and do not violate the balance.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcmxi{%
And the earth; He set up for the creatures.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcmxii{%
In it are fruits, and palms in clusters.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcmxiii{%
And grains in the blades, and fragrant plants.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcmxiv{%
So which of your Lord’s marvels will you deny?\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcmxv{%
He created man from hard clay, like bricks.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcmxvi{%
And created the jinn from a fusion of fire.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcmxvii{%
So which of your Lord’s marvels will you deny?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcmxviii{%
Lord of the two Easts and Lord of the two Wests.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcmxix{%
So which of your Lord’s marvels will you deny?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcmxx{%
He merged the two seas, converging together.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcmxxi{%
Between them is a barrier, which they do not overrun.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcmxxii{%
So which of your Lord’s marvels will you deny?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcmxxiii{%
From them emerge pearls and coral.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcmxxiv{%
So which of your Lord’s marvels will you deny?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcmxxv{%
His are the ships, raised above the sea like landmarks.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcmxxvi{%
So which of your Lord’s marvels will you deny?\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcmxxvii{%
Everyone upon it is perishing.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmcmxxviii{%
But will remain the Presence of your Lord, Full of Majesty and Splendor.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcmxxix{%
So which of your Lord’s marvels will you deny?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcmxxx{%
Everyone in the heavens and the earth asks Him. Every day He is managing.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxi{%
So which of your Lord’s marvels will you deny?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxii{%
We will attend to you, O prominent two.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxiii{%
So which of your Lord’s marvels will you deny?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxiv{%
O society of jinn and humans! If you can pass through the bounds of the heavens and the earth, go ahead and pass. But you will not pass except with authorization.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxv{%
So which of your Lord’s marvels will you deny?\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxvi{%
You will be bombarded with flares of fire and brass, and you will not succeed.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxvii{%
So which of your Lord’s marvels will you deny?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxviii{%
When the sky splits apart, and becomes rose, like paint.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxix{%
So which of your Lord’s marvels will you deny?\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcmxl{%
On that Day, no human and no jinn will be asked about his sins.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcmxli{%
So which of your Lord’s marvels will you deny?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcmxlii{%
The guilty will be recognized by their marks; they will be taken by the forelocks and the feet.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcmxliii{%
So which of your Lord’s marvels will you deny?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcmxliv{%
This is Hell that the guilty denied.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcmxlv{%
They circulate between it and between a seething bath.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcmxlvi{%
So which of your Lord’s marvels will you deny?\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcmxlvii{%
But for him who feared the standing of his Lord are two gardens.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcmxlviii{%
So which of your Lord’s marvels will you deny?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcmxlix{%
Full of varieties.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcml{%
So which of your Lord’s marvels will you deny?\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcmli{%
In them are two flowing springs.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcmlii{%
So which of your Lord’s marvels will you deny?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcmliii{%
In them are fruits of every kind, in pairs.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcmliv{%
So which of your Lord’s marvels will you deny?\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcmlv{%
Reclining on furnishings lined with brocade, and the fruits of the two gardens are near at hand.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcmlvi{%
So which of your Lord’s marvels will you deny?\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcmlvii{%
In them are maidens restraining their glances, untouched before by any man or jinn.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcmlviii{%
So which of your Lord’s marvels will you deny?\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcmlix{%
As though they were rubies and corals.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcmlx{%
So which of your Lord’s marvels will you deny?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcmlxi{%
Is the reward of goodness anything but goodness?\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcmlxii{%
So which of your Lord’s marvels will you deny?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcmlxiii{%
And beneath them are two gardens.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcmlxiv{%
So which of your Lord’s marvels will you deny?\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcmlxv{%
Deep green.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcmlxvi{%
So which of your Lord’s marvels will you deny?\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcmlxvii{%
In them are two gushing springs.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcmlxviii{%
So which of your Lord’s marvels will you deny?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcmlxix{%
In them are fruits, and date-palms, and pomegranates.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcmlxx{%
So which of your Lord’s marvels will you deny?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxi{%
In them are good and beautiful ones.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxii{%
So which of your Lord’s marvels will you deny?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxiii{%
Companions, secluded in the tents.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxiv{%
So which of your Lord’s marvels will you deny?\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxv{%
Whom no human has touched before, nor jinn.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxvi{%
So which of your Lord’s marvels will you deny?\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxvii{%
Reclining on green cushions, and exquisite carpets.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxviii{%
So which of your Lord’s marvels will you deny?\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxix{%
Blessed be the name of your Lord, Full of Majesty and Splendor.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxx{%
\basmalahen When the inevitable occurs.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxi{%
Of its occurrence, there is no denial.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxii{%
Bringing low, raising high.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxiii{%
When the earth is shaken with a shock.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxiv{%
And the mountains are crushed and crumbled.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxv{%
And they become scattered dust.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxvi{%
And you become three classes.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxvii{%
Those on the Right—what of those on the Right?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxviii{%
And those on the Left—what of those on the Left?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxix{%
And the forerunners, the forerunners.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcmxc{%
Those are the nearest.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcmxci{%
In the Gardens of Bliss.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcmxcii{%
A throng from the ancients.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcmxciii{%
And a small band from the latecomers.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcmxciv{%
On luxurious furnishings.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcmxcv{%
Reclining on them, facing one another.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcmxcvi{%
Serving them will be immortalized youth.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcmxcvii{%
With cups, pitchers, and sparkling drinks.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcmxcviii{%
Causing them neither headache, nor intoxication.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcmxcix{%
And fruits of their choice.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmm{%
And meat of birds that they may desire.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmi{%
And lovely companions.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmii{%
The likenesses of treasured pearls.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmiii{%
As a reward for what they used to do.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmiv{%
Therein they will hear no nonsense, and no accusations.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmv{%
But only the greeting: “Peace, peace.”\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmvi{%
And those on the Right—what of those on the Right?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmvii{%
In lush orchards.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmviii{%
And sweet-smelling plants.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmix{%
And extended shade.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmx{%
And outpouring water.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmxi{%
And abundant fruit.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmxii{%
Neither withheld, nor forbidden.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmxiii{%
And uplifted mattresses.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmxiv{%
We have created them of special creation.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmxv{%
And made them virgins.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmxvi{%
Tender and un-aging.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmxvii{%
For those on the Right.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmxviii{%
A throng from the ancients.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmxix{%
And a throng from the latecomers.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmxx{%
And those on the Left—what of those on the Left?\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmxxi{%
Amid searing wind and boiling water.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmxxii{%
And a shadow of thick smoke.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmxxiii{%
Neither cool, nor refreshing.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmxxiv{%
They had lived before that in luxury.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmxxv{%
And they used to persist in immense wrongdoing.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmxxvi{%
And they used to say, “When we are dead and turned into dust and bones, are we to be resurrected?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmxxvii{%
And our ancient ancestors too?”\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmxxviii{%
Say, “The first and the last.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmxxix{%
Will be gathered for the appointment of a familiar Day.”\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmxxx{%
Then you, you misguided, who deny the truth.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmxxxi{%
Will be eating from the Tree of Bitterness.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmxxxii{%
Will be filling your bellies with it.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmmxxxiii{%
Will be drinking on top of it boiling water.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmmxxxiv{%
Drinking like thirsty camels drink.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmmxxxv{%
That is their hospitality on the Day of Retribution.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmmxxxvi{%
We created you—if only you would believe!\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmmxxxvii{%
Have you seen what you ejaculate?\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmmxxxviii{%
Is it you who create it, or are We the Creator?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmmxxxix{%
We have decreed death among you, and We will not be outstripped.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmmxl{%
In replacing you with your likes, and transforming you into what you do not know.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmmxli{%
You have known the first formation; if only you would remember.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmmxlii{%
Have you seen what you cultivate?\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmmxliii{%
Is it you who make it grow, or are We the Grower?\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmmxliv{%
If We will, We can turn it into rubble; then you will lament.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmmxlv{%
“We are penalized.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmmxlvi{%
No, we are being deprived.”\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmmxlvii{%
Have you seen the water you drink?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmmxlviii{%
Is it you who sent it down from the clouds, or are We the Sender?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmmxlix{%
If We will, We can make it salty. Will you not be thankful?\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmml{%
Have you seen the fire you kindle?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmmli{%
Is it you who produce its tree, or are We the Producer?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmmlii{%
We have made it a reminder, and a comfort for the users.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmmliii{%
So glorify the Name of your Great Lord.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmmliv{%
I swear by the locations of the stars.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmmlv{%
It is an oath, if you only knew, that is tremendous.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmmlvi{%
It is a noble Quran.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmmlvii{%
In a well-protected Book.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmmlviii{%
None can grasp it except the purified.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmmlix{%
A revelation from the Lord of the Worlds.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmmlx{%
Is it this discourse that you take so lightly?\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmmlxi{%
And you make it your livelihood to deny it?\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmmlxii{%
So when it has reached the throat.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmmlxiii{%
As you are looking on.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmmlxiv{%
We are nearer to it than you are, but you do not see.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmmlxv{%
If you are not held to account.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmmlxvi{%
Then bring it back, if you are truthful.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmmlxvii{%
But if he is one of those brought near.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmmlxviii{%
Then happiness, and flowers, and Garden of Delights.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmmmlxix{%
And if he is one of those on the Right.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmmmlxx{%
Then, “Peace upon you,” from those on the Right.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmmmlxxi{%
But if he is one of the deniers, the mistaken.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmmmlxxii{%
Then a welcome of Inferno.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmmmlxxiii{%
And burning in Hell.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmmmlxxiv{%
This is the certain truth.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmmmlxxv{%
So glorify the Name of your Lord, the Magnificent\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmmmlxxvi{%
\basmalahen Glorifying God is everything in the heavens and the earth. He is the Almighty, the Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmlxxvii{%
To Him belongs the kingdom of the heavens and the earth. He gives life and causes death, and He has power over all things.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmlxxviii{%
He is the First and the Last, and the Outer and the Inner, and He has knowledge of all things.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmlxxix{%
It is He who created the heavens and the earth in six days, then settled over the Throne. He knows what penetrates into the earth, and what comes out of it, and what descends from the sky, and what ascends to it. And He is with you wherever you may be. God is Seeing of everything you do.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmlxxx{%
To Him belongs the kingship of the heavens and the earth, and to God all matters are referred.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxi{%
He merges the night into the day, and He merges the day into the night; and He knows what the hearts contains.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxii{%
Believe in God and His Messenger, and spend from what He made you inherit. Those among you who believe and give will have a great reward.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxiii{%
What is the matter with you that you do not believe in God, when the Messenger calls you to believe in your Lord, and He has received a pledge from you, if you are believers?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxiv{%
It is He who sends down upon His servant clear revelations, to bring you out of darkness into the light. God is Gentle towards you, Most Compassionate.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxv{%
And why is it that you do not spend in the cause of God, when to God belongs the inheritance of the heavens and the earth? Not equal among you are those who contributed before the conquest, and fought. Those are higher in rank than those who contributed afterwards, and fought. But God promises both a good reward. God is Well Experienced in what you do.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxvi{%
Who is he who will lend God a loan of goodness, that He may double it for him, and will have a generous reward?\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxvii{%
On the Day when you see the believing men and believing women—their light radiating ahead of them, and to their right: “Good news for you today: gardens beneath which rivers flow, dwelling therein forever. That is the great triumph.”\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxviii{%
On the Day when the hypocritical men and hypocritical women will say to those who believed, “Wait for us; let us absorb some of your light.” It will be said, “Go back behind you, and seek light.” A wall will be raised between them, in which is a door; within it is mercy, and outside it is agony.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxix{%
They will call to them, “Were we not with you?” They will say, “Yes, but you cheated your souls, and waited, and doubted, and became deluded by wishful thinking, until the command of God arrived; and arrogance deceived you regarding God.”\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmxc{%
“Therefore, today no ransom will be accepted from you, nor from those who disbelieved. The Fire is your refuge. It is your companion—what an evil fate!”\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmxci{%
Is it not time for those who believe to surrender their hearts to the remembrance of God, and to the truth that has come down, and not be like those who were given the Book previously, but time became prolonged for them, so their hearts hardened, and many of them are sinners?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmxcii{%
Know that God revives the earth after its death. We thus explain the revelations for you, so that you may understand.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmxciii{%
The charitable men and charitable women, who have loaned God a loan of righteousness—it will be multiplied for them, and for them is a generous reward.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmxciv{%
Those who believe in God and His messengers—these are the sincere and the witnesses with their Lord; they will have their reward and their light. But as for those who disbelieve and deny Our revelations—these are the inmates of the Blaze.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmxcv{%
Know that the worldly life is only play, and distraction, and glitter, and boasting among you, and rivalry in wealth and children. It is like a rainfall that produces plants, and delights the disbelievers. But then it withers, and you see it yellowing, and then it becomes debris. While in the Hereafter there is severe agony, and forgiveness from God, and acceptance. The life of this world is nothing but enjoyment of vanity.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmxcvi{%
Race towards forgiveness from your Lord; and a Garden as vast as the heavens and the earth, prepared for those who believe in God and His messengers. That is the grace of God; He bestows it on whomever He wills. God is the Possessor of Immense Grace.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmxcvii{%
No calamity occurs on earth, or in your souls, but it is in a Book, even before We make it happen. That is easy for God.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmxcviii{%
That you may not sorrow over what eludes you, nor exult over what He has given you. God does not love the proud snob.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmxcix{%
Those who are stingy, and induce people to be stingy. Whoever turns away—God is the Independent, the Praiseworthy.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmc{%
We sent Our messengers with the clear proofs, and We sent down with them the Book and the Balance, that humanity may uphold justice. And We sent down iron, in which is violent force, and benefits for humanity. That God may know who supports Him and His messengers invisibly. God is Strong and Powerful.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmci{%
We sent Noah and Abraham, and established in their line Prophethood and the Scripture. Some of them are guided, but many of them are sinners.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcii{%
Then We sent in their wake Our messengers, and followed up with Jesus son of Mary, and We gave him the Gospel, and instilled in the hearts of those who followed him compassion and mercy. But as for the monasticism which they invented—We did not ordain it for them—only to seek God’s approval. But they did not observe it with its due observance. So We gave those of them who believed their reward, but many of them are sinful.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmciii{%
O you who believe! Fear God, and believe in His Messenger: He will give you a double portion of His mercy, and will give you a light by which you walk, and will forgive you. God is Forgiving and Merciful.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmciv{%
That the People of the Book may know that they have no power whatsoever over God’s grace, and that all grace is in God’s hand; He gives it to whomever He wills. God is Possessor of Great Grace.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcv{%
\basmalahen God has heard the statement of she who argued with you concerning her husband, as she complained to God. God heard your conversation. God is Hearing and Seeing.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcvi{%
Those of you who estrange their wives by equating them with their mothers—they are not their mothers. Their mothers are none else but those who gave birth to them. What they say is evil, and a blatant lie. But God is Pardoning and Forgiving.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcvii{%
Those who estrange their wives by equating them with their mothers, then go back on what they said, must set free a slave before they may touch one another. To this you are exhorted, and God is well aware of what you do.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcviii{%
But whoever cannot find the means must fast for two consecutive months before they may touch one another. And if he is unable, then the feeding of sixty needy people. This, in order that you affirm your faith in God and His Messenger. These are the ordinances of God. The unbelievers will have a painful punishment.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcix{%
Those who oppose God and His Messenger will be subdued, as those before them were subdued. We have revealed clear messages. The unbelievers will have a demeaning punishment.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcx{%
On the Day when God resurrects them all, and informs them of what they did. God has kept count of it, but they have forgotten it. God is Witness over everything.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxi{%
Do you not realize that God knows everything in the heavens and everything on earth? There is no secret counsel between three, but He is their fourth; nor between five, but He is their sixth; nor less than that, nor more, but He is with them wherever they may be. Then, on the Day of Resurrection, He will inform them of what they did. God has knowledge of everything.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxii{%
Have you noted those who were prohibited from conspiring secretly, but then reverted to what they were prohibited from? They conspire to commit sin, and aggression, and defiance of the Messenger. And when they come to you, they greet you with a greeting that God never greeted you with. And they say within themselves, “Why does God not punish us for what we say?” Hell is enough for them. They will roast in it. What a miserable destiny!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxiii{%
O you who believe! When you converse secretly, do not converse in sin, and aggression, and disobedience of the Messenger; but converse in virtue and piety; And fear God, to Whom you will be gathered.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxiv{%
Conspiracies are from Satan, that he may dishearten those who believe; but he will not harm them in the least, except by leave of God. So let the believers put their trust in God.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxv{%
O you who believe! When you are told to make room in your gatherings, make room; God will make room for you. And when you are told to disperse, disperse. God elevates those among you who believe, and those given knowledge, many steps. God is Aware of what you do.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcxvi{%
O you who believe! When you converse privately with the Messenger, offer something in charity before your conversation. That is better for you, and purer. But if you do not find the means—God is Forgiving and Merciful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcxvii{%
Are you reluctant to offer charity before your conversation? If you do not do so, and God pardons you, then perform the prayer, and give alms, and obey God and His Messenger. God is Aware of what you do.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcxviii{%
Have you considered those who befriended a people with whom God has become angry? They are not of you, nor of them. And they swear to a lie while they know.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcxix{%
God has prepared for them a terrible punishment. Evil is what they used to do.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcxx{%
They took their oaths as a screen, and prevented others from God’s path. They will have a shameful punishment.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcxxi{%
Neither their possessions nor their children will avail them anything against God. These are the inhabitants of the Fire, dwelling therein forever.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcxxii{%
On the Day when God will resurrect them altogether—they will swear to Him, as they swear to you, thinking that they are upon something. Indeed, they themselves are the liars.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcxxiii{%
Satan has taken hold of them, and so has caused them to forget the remembrance of God. These are the partisans of Satan. Indeed, it is Satan’s partisans who are the losers.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcxxiv{%
Those who oppose God and His Messenger are among the lowliest.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcxxv{%
God has written: “I will certainly prevail, I and My messengers.” God is Strong and Mighty.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcxxvi{%
You will not find a people who believe in God and the Last Day, loving those who oppose God and His Messenger, even if they were their parents, or their children, or their siblings, or their close relatives. These—He has inscribed faith in their hearts, and has supported them with a spirit from Him. And He will admit them into Gardens beneath which rivers flow, wherein they will dwell forever. God is pleased with them, and they are pleased with Him. These are the partisans of God. Indeed, it is God’s partisans who are the successful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcxxvii{%
\basmalahen Glorifying God is all that exists in the heavens and the earth. He is the Almighty, the Most Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcxxviii{%
It is He who evicted those who disbelieved among the People of the Book from their homes at the first mobilization. You did not think they would leave, and they thought their fortresses would protect them from God. But God came at them from where they never expected, and threw terror into their hearts. They wrecked their homes with their own hands, and by the hands of the believers. Therefore, take a lesson, O you who have insight.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcxxix{%
Had God not decreed exile for them, He would have punished them in this life. But in the Hereafter they will have the punishment of the Fire.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcxxx{%
That is because they opposed God and His Messenger. Whoever opposes God—God is stern in retribution.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxi{%
Whether you cut down a tree, or leave it standing on its trunk, it is by God’s will. He will surely disgrace the sinners.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxii{%
Whatever God has bestowed upon His Messenger from them; you spurred neither horse nor camel for them, but God gives authority to His messengers over whomever He will. God is Able to do all things.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxiii{%
Whatever God restored to His Messenger from the inhabitants of the villages belongs to God, and to the Messenger, and to the relatives, and to the orphans, and to the poor, and to the wayfarer; so that it may not circulate solely between the wealthy among you. Whatever the Messenger gives you, accept it; and whatever he forbids you, abstain from it. And fear God. God is severe in punishment.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxiv{%
To the poor refugees who were driven out of their homes and their possessions, as they sought the favor of God and His approval, and came to the aid of God and His Messenger. These are the sincere.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxv{%
And those who, before them, had settled in the homeland, and had accepted faith. They love those who emigrated to them, and find no hesitation in their hearts in helping them. They give them priority over themselves, even if they themselves are needy. Whoever is protected from his natural greed—it is they who are the successful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxvi{%
And those who came after them, saying, “Our Lord, forgive us, and our brethren who preceded us in faith, and leave no malice in our hearts towards those who believe. Our Lord, You are Clement and Merciful.”\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxvii{%
Have you not considered those who act hypocritically? They say to their brethren who disbelieved among the People of the Book, “If you are evicted, we will leave with you, and will not obey anyone against you; and should anyone fight you, we will certainly support you.” But God bears witness that they are liars.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxviii{%
If they are evicted, they will not leave with them; and if anyone fights them, they will not support them; and if they go to their aid, they will turn their backs and flee; then they will receive no support.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxix{%
Fear of you is more intense in their hearts than fear of God. That is because they are a people who do not understand.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcxl{%
They will not fight you all together except from fortified strongholds, or from behind walls. Their hostility towards each other is severe. You would think they are united, but their hearts are diverse. That is because they are a people who do not understand.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcxli{%
Like those shortly before them. They experienced the consequences of their decisions. For them is a painful punishment.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcxlii{%
Like the devil, when he says to the human being, “Disbelieve.” But when he has disbelieved, he says, “I am innocent of you; I fear God, the Lord of the Worlds.”\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcxliii{%
The ultimate end for both of them is the Fire, where they will dwell forever. Such is the requital for the wrongdoers.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcxliv{%
O you who believe! Fear God, and let every soul consider what it has forwarded for the morrow, and fear God. God is Aware of what you do.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcxlv{%
And do not be like those who forgot God, so He made them forget themselves. These are the sinners.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcxlvi{%
Not equal are the inhabitants of the Fire and the inhabitants of Paradise. It is the inhabitants of Paradise who are the winners.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcxlvii{%
Had We sent this Quran down on a mountain, you would have seen it trembling, crumbling in awe of God. These parables We cite for the people, so that they may reflect.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcxlviii{%
He is God. There is no god but He, the Knower of secrets and declarations. He is the Compassionate, the Merciful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcxlix{%
He is God; besides Whom there is no god; the Sovereign, the Holy, the Peace-Giver, the Faith-Giver, the Overseer, the Almighty, the Omnipotent, the Overwhelming. Glory be to God, beyond what they associate.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcl{%
He is God; the Creator, the Maker, the Designer. His are the Most Beautiful Names. Whatever is in the heavens and the earth glorifies Him. He is the Majestic, the Wise.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcli{%
\basmalahen O you who believe! Do not take My enemies and your enemies for supporters, offering them affection, when they have disbelieved in what has come to you of the Truth. They have expelled the Messenger, and you, because you believed in God, your Lord. If you have mobilized to strive for My cause, seeking My approval, how can you secretly love them? I know what you conceal and what you reveal. Whoever among you does that has strayed from the right way.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclii{%
Whenever they encounter you, they treat you as enemies, and they stretch their hands and tongues against you with malice. They wish that you would disbelieve.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcliii{%
Neither your relatives nor your children will benefit you on the Day of Resurrection. He will separate between you. God is Observant of what you do.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcliv{%
You have had an excellent example in Abraham and those with him; when they said to their people, “We are quit of you, and what you worship apart from God. We denounce you. Enmity and hatred has surfaced between us and you, forever, until you believe in God alone.” Except for the words of Abraham to his father, “I will ask forgiveness for you, though I have no power from God to do anything for you.” “Our Lord, in You we trust, and to You we repent, and to You is the ultimate resort.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclv{%
Our Lord, do not make us a target for those who disbelieve, and forgive us, our Lord. You are indeed the Mighty and Wise.”\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclvi{%
There is an excellent example in them for you—for anyone who seeks God and the Last Day. But whoever turns away—God is the Self-Sufficient, the Most Praised.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclvii{%
Perhaps God will plant affection between you and those of them you consider enemies. God is Capable. God is Forgiving and Merciful.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclviii{%
As for those who have not fought against you for your religion, nor expelled you from your homes, God does not prohibit you from dealing with them kindly and equitably. God loves the equitable.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclix{%
But God prohibits you from befriending those who fought against you over your religion, and expelled you from your homes, and aided in your expulsion. Whoever takes them for friends—these are the wrongdoers.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclx{%
O you who believe! When believing women come to you emigrating, test them. God is Aware of their faith. And if you find them to be faithful, do not send them back to the unbelievers. They are not lawful for them, nor are they lawful for them. But give them what they have spent. You are not at fault if you marry them, provided you give them their compensation. And do not hold on to ties with unbelieving women, but demand what you have spent, and let them demand what they have spent. This is the rule of God; He rules among you. God is Knowing and Wise.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxi{%
If any of your wives desert you to the unbelievers, and you decide to penalize them, give those whose wives have gone away the equivalent of what they had spent. And fear God, in whom you are believers.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxii{%
O prophet! If believing women come to you, pledging allegiance to you, on condition that they will not associate anything with God, nor steal, nor commit adultery, nor kill their children, nor commit perjury as to parenthood, nor disobey you in anything righteous, accept their allegiance and ask God’s forgiveness for them. God is Forgiving and Merciful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmclxiii{%
O you who believe! Do not befriend people with whom God has become angry, and have despaired of the Hereafter, as the faithless have despaired of the occupants of the graves.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmclxiv{%
\basmalahen Everything in the heavens and the earth praises God. He is the Almighty, the Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclxv{%
O you who believe! Why do you say what you do not do?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmclxvi{%
It is most hateful to God that you say what you do not do.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmclxvii{%
God loves those who fight in His cause, in ranks, as though they were a compact structure.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclxviii{%
When Moses said to his people, “O my people, why do you hurt me, although you know that I am God’s Messenger to you?” And when they swerved, God swerved their hearts. God does not guide the sinful people.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclxix{%
And when Jesus son of Mary said, “O Children of Israel, I am God’s Messenger to you, confirming what preceded me of the Torah, and announcing good news of a messenger who will come after me, whose name is Ahmad.” But when he showed them the miracles, they said, “This is obvious sorcery.”\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclxx{%
And who is a greater wrongdoer than he who attributes falsehoods to God, when he is being invited to Islam? God does not guide the wrongdoing people.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclxxi{%
They want to extinguish God’s Light with their mouths; but God will complete His Light, even though the disbelievers dislike it.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclxxii{%
It is He who sent His Messenger with the guidance and the true religion, to make it prevail over all religions, even though the idolaters dislike it.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclxxiii{%
O you who believe! Shall I inform you of a trade that will save you from a painful torment?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxxiv{%
That you believe in God and His Messenger, and strive in the cause of God with your possessions and yourselves. That is best for you, if you only knew.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxxv{%
He will forgive you your sins; and will admit you into gardens beneath which rivers flow, and into beautiful mansions in the Gardens of Eden. That is the supreme success.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmclxxvi{%
And something else you love: support from God, and imminent victory. So give good news to the believers.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmclxxvii{%
O you who believe! Be supporters of God, as Jesus son of Mary said to the disciples, “Who are my supporters towards God?” The disciples said, “We are God's supporters.” So a group of the Children of Israel believed, while another group disbelieved. We supported those who believed against their foe, so they became dominant.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmclxxviii{%
\basmalahen Everything in the heavens and the earth glorifies God the Sovereign, the Holy, the Almighty, the Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclxxix{%
It is He who sent among the unlettered a messenger from themselves; reciting His revelations to them, and purifying them, and teaching them the Scripture and wisdom; although they were in obvious error before that.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmclxxx{%
And others from them, who have not yet joined them. He is the Glorious, the Wise.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxi{%
That is God’s grace, which He grants to whomever He wills. God is Possessor of limitless grace.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxii{%
The example of those who were entrusted with the Torah, but then failed to uphold it, is like the donkey carrying works of literature. Miserable is the example of the people who denounce God’s revelations. God does not guide the wrongdoing people.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxiii{%
Say, “O you who follow Judaism; if you claim to be the chosen of God, to the exclusion of the rest of mankind, then wish for death if you are sincere.”\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxiv{%
But they will not wish for it, ever, due to what their hands have advanced. God knows well the wrongdoers.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxv{%
Say, “The death from which you flee will catch up with you; then you will be returned to the Knower of the Invisible and the Visible, and He will inform you of what you used to do.”\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxvi{%
O you who believe! When the call is made for prayer on Congregation Day, hasten to the remembrance of God, and drop all business. That is better for you, if you only knew.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxvii{%
Then, when the prayer is concluded, disperse through the land, and seek God’s bounty, and remember God much, so that you may prosper.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxviii{%
Yet whenever they come across some business, or some entertainment, they scramble towards it, and leave you standing. Say, “What is with God is better than entertainment and business; and God is the Best of providers.”\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxix{%
\basmalahen When the hypocrites come to you, they say, “We bear witness that you are God’s Messenger.” God knows that you are His Messenger, and God bears witness that the hypocrites are liars.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcxc{%
They treat their oaths as a cover, and so they repel others from God’s path. Evil is what they do.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcxci{%
That is because they believed, and then disbelieved; so their hearts were sealed, and they cannot understand.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcxcii{%
When you see them, their appearance impresses you. And when they speak, you listen to what they say. They are like propped-up timber. They think every shout is aimed at them. They are the enemy, so beware of them. God condemns them; how deluded they are!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcxciii{%
And when it is said to them, “Come, the Messenger of God will ask forgiveness for you,” they bend their heads, and you see them turning away arrogantly.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcxciv{%
It is the same for them, whether you ask forgiveness for them, or do not ask forgiveness for them; God will not forgive them. God does not guide the sinful people.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxcv{%
It is they who say: “Do not spend anything on those who side with God’s Messenger, unless they have dispersed.” To God belong the treasures of the heavens and the earth, but the hypocrites do not understand.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxcvi{%
They say, “If we return to the City, the more powerful therein will evict the weak.” But power belongs to God, and His Messenger, and the believers; but the hypocrites do not know.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxcvii{%
O you who believe! Let neither your possessions nor your children distract you from the remembrance of God. Whoever does that—these are the losers.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxcviii{%
And give from what We have provided for you, before death approaches one of you, and he says, “My Lord, if only You would delay me for a short while, so that I may be charitable, and be one of the righteous.”\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxcix{%
But God will not delay a soul when its time has come. God is Informed of what you do.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcc{%
\basmalahen Everything in the heavens and the earth praises God. To Him belongs the Kingdom, and to Him all praise is due, and He is Able to do all things.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcci{%
It is He who created you. Some of you are unbelievers, and some of you are believers. And God perceives what you do.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccii{%
He created the heavens and the earth with truth, and He designed you, and designed you well, and to Him is the final return.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcciii{%
He knows everything in the heavens and the earth, and He knows what you conceal and what you reveal. And God knows what is within the hearts.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcciv{%
Has the news not reached you, of those who disbelieved before? They tasted the ill consequences of their conduct, and a painful torment awaits them.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccv{%
That is because their messengers came to them with clear explanations, but they said, “Are human beings going to guide us?” So they disbelieved and turned away. But God is in no need. God is Independent and Praiseworthy.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccvi{%
Those who disbelieve claim that they will not be resurrected. Say, “Yes indeed, by my Lord, you will be resurrected; then you will be informed of everything you did; and that is easy for God.”\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccvii{%
So believe in God and His Messenger, and the Light which We sent down. God is Aware of everything you do.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccviii{%
The Day when He gathers you for the Day of Gathering—that is the Day of Mutual Exchange. Whoever believes in God and acts with integrity, He will remit his misdeeds, and will admit him into gardens beneath which rivers flow, to dwell therein forever. That is the supreme achievement.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccix{%
But as for those who disbelieve and denounce Our revelations—these are the inmates of the Fire, dwelling therein forever; and what a miserable fate!\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccx{%
No disaster occurs except by God’s leave. Whoever believes in God, He guides his heart. God is Aware of everything.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxi{%
So obey God, and obey the Messenger. But if you turn away—it is only incumbent on Our Messenger to deliver the clear message.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxii{%
God, there is no god but He; and in God let the believers put their trust.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmccxiii{%
O you who believe! Among your wives and your children are enemies to you, so beware of them. But if you pardon, and overlook, and forgive—God is Forgiver and Merciful.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmccxiv{%
Your possessions and your children are a test, but with God is a splendid reward.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmccxv{%
So be conscious of God as much as you can, and listen, and obey, and give for your own good. He who is protected from his stinginess—these are the prosperous.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmccxvi{%
If you lend God a good loan, He will multiply it for you, and will forgive you. God is Appreciative and Forbearing.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmccxvii{%
The Knower of the Unseen and the Seen, the Almighty, the Wise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmccxviii{%
\basmalahen O Prophet! If any of you divorce women, divorce them during their period of purity, and calculate their term. And be pious before God, your Lord. And do not evict them from their homes, nor shall they leave, unless they have committed a proven adultery. These are the limits of God—whoever oversteps God’s limits has wronged his own soul. You never know; God may afterwards bring about a new situation.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxix{%
Once they have reached their term, either retain them honorably, or separate from them honorably. And call to witness two just people from among you, and give upright testimony for God. By that is exhorted whoever believes in God and the Last Day. And whoever fears God—He will make a way out for him.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxx{%
And will provide for him from where he never expected. Whoever relies on God—He will suffice him. God will accomplish His purpose. God has set a measure to all things.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxxi{%
As for those of your women who have reached menopause, if you have any doubts, their term shall be three months—and also for those who have not yet menstruated. As for those who are pregnant, their term shall be until they have delivered. Whoever fears God—He will make things easy for him.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxxii{%
This is the ordinance of God, which He sent down to you. Whoever fears God—He will remit his sins, and will amplify his reward.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxxiii{%
Allow them to reside where you reside, according to your means, and do not harass them in order to make things difficult for them. If they are pregnant, spend on them until they give birth. And if they nurse your infant, give them their payment. And conduct your relation in amity. But if you disagree, then let another woman nurse him.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxxiv{%
The wealthy shall spend according to his means; and he whose resources are restricted shall spend according to what God has given him. God never burdens a soul beyond what He has given it. God will bring ease after hardship.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxxv{%
How many a town defied the command of its Lord and His messengers? So We held it strictly accountable, and We punished it with a dreadful punishment.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccxxvi{%
It tasted the result of its decisions, and the outcome of its decisions was perdition.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccxxvii{%
God has prepared for them a severe retribution. So beware of God, O you who possess intellect and have faith. God has sent down to you a Reminder.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccxxviii{%
A messenger who recites to you God’s Verses, clear and distinct, that he may bring those who believe and work righteousness from darkness into light. Whoever believes in God and acts with integrity, He will admit him into gardens beneath which rivers flow, therein to abide forever. God has given him an excellent provision.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxxix{%
God is He Who created seven heavens, and their like of earth. The command descends through them, so that you may know that God is Capable of everything, and that God Encompasses everything in knowledge.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxxx{%
\basmalahen O prophet! Why do you prohibit what God has permitted for you, seeking to please your wives? God is Forgiving and Merciful.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxi{%
God has decreed for you the dissolution of your oaths. God is your Master. He is the All-Knowing, the Most Wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxii{%
The Prophet told something in confidence to one of his wives. But when she disclosed it, and God made it known to him; he communicated part of it, and he avoided another part. Then, when he informed her of it, she said, “Who informed you of this?” He said, “The All-Knowing, the All-Informed, informed me.”\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxiii{%
If you repent to God, then your hearts have listened. But if you band together against him, then God is his Ally, as is Gabriel, and the righteous believers. In addition, the angels will assist him.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxiv{%
Perhaps, if he divorces you, his Lord will give him in exchange wives better than you: submissive, believing, obedient, penitent, devout, fasting—previously married, or virgins.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxv{%
O you who believe! Protect yourselves and your families from a Fire, whose fuel is people and stones. Over it are angels, fierce and powerful. They never disobey God in anything He commands them, and they carry out whatever they are commanded.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxvi{%
O you who disbelieved! Make no excuses today. You are being repaid for what you used to do.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxvii{%
O you who believe! Repent to God with sincere repentance. Perhaps your Lord will remit your sins, and admit you into gardens beneath which rivers flow, on the Day when God will not disappoint the Prophet and those who believed with him. Their light streaming before them, and to their right, they will say, “Our Lord, complete our light for us, and forgive us; You are capable of all things.”\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxviii{%
O prophet! Strive hard against the disbelievers and the hypocrites, and be stern with them. Their abode is Hell. What a miserable destination!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxix{%
God illustrates an example of those who disbelieve: the wife of Noah and the wife of Lot. They were under two of Our righteous servants, but they betrayed them. They availed them nothing against God, and it was said, “Enter the Fire with those who are entering.”\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccxl{%
And God illustrates an example of those who believe: the wife of Pharaoh, when she said, “My Lord, build for me, with you, a house in Paradise, and save me from Pharaoh and his works, and save me from the wrongdoing people.”\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxli{%
And Mary, the daughter of Imran, who guarded her womb, and so We breathed into her of Our Spirit; and she believed in the truth of her Lord’s Words and His Books, and was one of the devout.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxlii{%
\basmalahen Blessed is He in whose hand is the sovereignty, and Who has power over everything.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxliii{%
He who created death and life—to test you—as to which of you is better in conduct. He is the Almighty, the Forgiving.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxliv{%
He who created seven heavens in layers. You see no discrepancy in the creation of the Compassionate. Look again. Can you see any cracks?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxlv{%
Then look again, and again, and your sight will return to you dazzled and exhausted.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxlvi{%
We have adorned the lower heaven with lanterns, and made them missiles against the devils; and We have prepared for them the punishment of the Blaze.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxlvii{%
For those who reject their Lord, there is the torment of Hell. What an evil destination!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxlviii{%
When they are thrown into it, they will hear it roaring, as it seethes.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxlix{%
It almost bursts with fury. Every time a batch is thrown into it, its keepers will ask them, “Has no warner come to you?”\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccl{%
They will say, “Yes, a warner did come to us, but we disbelieved, and said, ‘God did not send down anything; you are very much mistaken.’”\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccli{%
And they will say, “Had we listened or reasoned, we would not have been among the inmates of the Blaze.”\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcclii{%
So they will acknowledge their sins. So away with the inmates of the Blaze.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccliii{%
As for those who fear their Lord in secret—for them is forgiveness and a great reward.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccliv{%
Whether you keep your words secret, or declare them—He is Aware of the inner thoughts.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcclv{%
Would He not know, He Who created? He is the Refined, the Expert.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcclvi{%
It is He who made the earth manageable for you, so travel its regions, and eat of His provisions. To Him is the Resurgence.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcclvii{%
Are you confident that the One in heaven will not cause the earth to collapse beneath you as it spins?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcclviii{%
Or are you confident that the One in Heaven will not unleash against you a violent storm? Then you will know what My warning is like.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcclix{%
Those before them also denied the truth; and how was My disapproval?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcclx{%
Have they not seen the birds above them, spreading their wings, and folding them? None holds them except the Compassionate. He is Perceiver of everything.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcclxi{%
Or who is this who is a force for you to protect you against the Compassionate? The disbelievers are in nothing but delusion.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcclxii{%
Or who is this that will provide for you, if He withholds His provision? Yet they persist in defiance and aversion.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcclxiii{%
Is he who walks bent on his own design better guided, or he who walks upright on a straight path?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcclxiv{%
Say, “It is He who produced you; and made for you the hearing, and the vision, and the organs. But rarely do you give thanks.”\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcclxv{%
Say, “It is He who scattered you on earth, and to Him you will be rounded up.”\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcclxvi{%
And they say, “When will this promise be fulfilled, if you are truthful?”\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcclxvii{%
Say, “Knowledge is with God, and I am only a clear warner.”\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcclxviii{%
But when they see it approaching, the faces of those who disbelieved will turn gloomy, and it will be said, “This is what you used to call for.”\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcclxix{%
Say, “Have you considered? Should God make me perish, and those with me; or else He bestows His mercy on us; who will protect the disbelievers from an agonizing torment?”\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcclxx{%
Say, “He is the Compassionate. We have faith in Him, and in Him we trust. Soon you will know who is in evident error.”\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxi{%
Say, “Have you considered? If your water drains away, who will bring you pure running water?”\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxii{%
\basmalahen Noon. By the pen, and by what they inscribe.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxiii{%
By the grace of your Lord, you are not insane.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxiv{%
In fact, you will have a reward that will never end.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxv{%
And you are of a great moral character.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxvi{%
You will see, and they will see.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxvii{%
Which of you is the afflicted.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxviii{%
Your Lord knows best who has strayed from His path, and He knows best the well-guided.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxix{%
So do not obey the deniers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxx{%
They would like you to compromise, so they would compromise.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxi{%
And do not obey any vile swearer.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxii{%
Backbiter, spreader of slander.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxiii{%
Preventer of good, transgressor, sinner.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxiv{%
Rude and fake besides.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxv{%
Just because he has money and children.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxvi{%
When Our Verses are recited to him, he says, “Myths of the ancients!”\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxvii{%
We will brand him on the muzzle.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxviii{%
We tested them, as We tested the owners of the garden, when they vowed to harvest it in the morning.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxix{%
Without any reservation.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmccxc{%
But a calamity from your Lord went around it while they slept.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmccxci{%
And in the morning it was as if picked.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmccxcii{%
In the morning, they called to one another.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmccxciii{%
“Go early to your plantation, if you are going to harvest.”\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmccxciv{%
So off they went, murmuring to one another.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmccxcv{%
“No poor person is to enter it upon you today.”\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmccxcvi{%
And early they went, resolved in intent.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmccxcvii{%
But when they saw it, they said, “We were wrong.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmccxcviii{%
We are now deprived.”\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmccxcix{%
The most reasonable of them said, “Did I not say to you, ‘if only you would glorify?’”\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmccc{%
They said, “Glory to our Lord—We were indeed in the wrong.”\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmccci{%
Then they turned to one another, blaming one another.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcccii{%
They said, “Woe to us—we were indeed domineering.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmccciii{%
Perhaps our Lord will give us a better substitute for it. We are turning to our Lord.”\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmccciv{%
Such is the punishment; but the punishment of the Hereafter is greater, if they only knew.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmcccv{%
For the righteous are Gardens of Delight with their Lord.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmcccvi{%
Shall We treat the Muslims like the villains?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmcccvii{%
What is the matter with you? How do you judge?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmcccviii{%
Or do you have a scripture in which you study.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmcccix{%
Wherein there is whatever you choose?\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmcccx{%
Or do you have oaths from Us, binding until the Day of Resurrection, that you will have whatever you demand?\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmcccxi{%
Ask them, which of them will guarantee that.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmcccxii{%
Or do they have partners? Then let them produce their partners, if they are truthful.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmcccxiii{%
On the Day when the Shin will be exposed, and they will be called to bow down, but they will be unable.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmcccxiv{%
Their eyes subdued, shame will cover them. They were invited to bow down when they were sound.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmcccxv{%
So leave Me to those who reject this discourse; We will proceed against them gradually, from where they do not know.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmcccxvi{%
And I will give them respite. My plan is firm.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmcccxvii{%
Or do you ask them for a fee, so they are burdened with debt?\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmcccxviii{%
Or do they know the future, and so they write it down?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmcccxix{%
So wait patiently for the Decision of your Lord, and do not be like the Fellow of the Fish who cried out in despair.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmcccxx{%
Were it not for his Lord’s favor that reached him, he would have been thrown into the wilderness, fully despised.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxi{%
But his Lord chose him, and made him one of the righteous.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxii{%
Those who disbelieve almost stab you with their glances when they hear the message, and say, “He is crazy!”\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxiii{%
But it is no less than a reminder to all the Worlds.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxiv{%
\basmalahen The Reality.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxv{%
What is the Reality?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxvi{%
What will make you understand what the Reality is?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxvii{%
Thamood and Aad denied the Catastrophe.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxviii{%
As for Thamood, they were annihilated by the Overwhelming.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxix{%
And as for Aad; they were annihilated by a furious, roaring wind.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxx{%
He unleashed it upon them for seven nights and eight days, in succession. You could see the people tossed around, as though they were stumps of hollow palm-trees.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxi{%
Can you see any remnant of them?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxii{%
Then Pharaoh came, and those before him, and the Overturned Cities steeped in sin.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxiii{%
But they disobeyed the messenger of their Lord, so He seized them with an overpowering grip.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxiv{%
When the waters overflowed, We carried you in the cruising ship.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxv{%
To make it a lesson for you—so that retaining ears may retain it.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxvi{%
Then, when the Trumpet is sounded a single time.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxvii{%
And the earth and the mountains are lifted up, and crushed, with a single crush.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxviii{%
On that Day, the Event will come to pass.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxix{%
And the heaven will crack; so on that Day it will be frail.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcccxl{%
And the angels will be ranged around its borders, while eight will be carrying the Throne of your Lord above them that Day.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcccxli{%
On that Day you will be exposed, and no secret of yours will remain hidden.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlii{%
As for him who is given his book in his right hand, he will say, “Here, take my book and read it.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcccxliii{%
I knew I would be held accountable.”\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcccxliv{%
So he will be in pleasant living.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlv{%
In a lofty Garden.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlvi{%
Its pickings are within reach.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlvii{%
“Eat and drink merrily for what you did in the days gone by.”\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlviii{%
But as for him who is given his book in his left hand, he will say, “I wish I was never given my book.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlix{%
And never knew what my account was.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcccl{%
If only it was the end.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcccli{%
My money cannot avail me.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmccclii{%
My power has vanished from me.”\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcccliii{%
“Take him and shackle him.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcccliv{%
Then scorch him in the Blaze.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmccclv{%
Then in a chain which length is seventy cubits tie him up.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmccclvi{%
For he would not believe in God the Great.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmccclvii{%
Nor would he advocate the feeding of the destitute.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmccclviii{%
So he has no friend here today.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmccclix{%
And no food except scum.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmccclx{%
Which only the sinners eat.”\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmccclxi{%
Indeed, I swear by what you see.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmccclxii{%
And by what you do not see.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmccclxiii{%
It is the speech of a noble messenger.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmccclxiv{%
And it is not the speech of a poet—little do you believe.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmccclxv{%
Nor is it the speech of a soothsayer—little do you take heed.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmccclxvi{%
It is a revelation from the Lord of the Worlds.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmccclxvii{%
Had he falsely attributed some statements to Us.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmccclxviii{%
We would have seized him by the right arm.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmccclxix{%
Then slashed his lifeline.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmccclxx{%
And none of you could have restrained Us from him.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxi{%
Surely, it is a message for the righteous.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxii{%
And We know that some of you will reject it.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxiii{%
And it is surely a source of grief for the unbelievers.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxiv{%
Yet it is the absolute truth.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxv{%
So glorify the name of your Lord, the Magnificent.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxvi{%
\basmalahen A questioner questioned the imminent torment.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxvii{%
For the disbelievers; none can repel it.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxviii{%
From God, Lord of the Ways of Ascent.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxix{%
Unto Him the angels and the Spirit ascend on a Day the duration of which is fifty thousand years.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxx{%
So be patient, with sweet patience.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxi{%
They see it distant.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxii{%
But We see it near.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxiii{%
On the Day when the sky will be like molten brass.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxiv{%
And the mountains will be like tufted wool.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxv{%
No friend will care about his friend.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxvi{%
They will be shown each other. The criminal wishes he would be redeemed from the punishment of that Day by his children.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxvii{%
And his spouse, and his brother.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxviii{%
And his family that sheltered him.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxix{%
And everyone on earth, in order to save him.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcccxc{%
By no means! It is a Raging Fire.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcccxci{%
It strips away the scalps.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcii{%
It invites him who once turned his back and fled.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcccxciii{%
And accumulated and hoarded.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcccxciv{%
Man was created restless.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcv{%
Touched by adversity, he is fretful.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcvi{%
Touched by good, he is ungenerous.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcvii{%
Except the prayerful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcviii{%
Those who are constant at their prayers.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcix{%
And those in whose wealth is a rightful share.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcd{%
For the beggar and the deprived.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdi{%
And those who affirm the Day of Judgment.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdii{%
And those who fear the punishment of their Lord.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdiii{%
Their Lord’s punishment is not to be taken for granted.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdiv{%
And those who guard their chastity.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcdv{%
Except from their spouses or those living under their control, for then they are free of blame.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcdvi{%
But whoever seeks to go beyond that—these are the transgressors.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmcdvii{%
And those who honor their trusts and their pledges.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmcdviii{%
And those who stand by their testimonies.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmcdix{%
And those who are dedicated to their prayers.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmcdx{%
These will be honored in Gardens.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmcdxi{%
What is with those who disbelieve, stretching their necks towards you.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmcdxii{%
From the right, and from the left, banding together?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmcdxiii{%
Is every one of them aspiring to be admitted into a Garden of Bliss?\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmcdxiv{%
No indeed! We created them from what they know.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmcdxv{%
I swear by the Lord of the Easts and the Wests, that We are Able.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmcdxvi{%
To replace them with better than they, and We are not to be outdone.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmcdxvii{%
So leave them to blunder and play, until they meet their Day which they are promised.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmcdxviii{%
The Day when they will emerge from the tombs in a rush, as though they were hurrying towards a target.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmcdxix{%
Their eyes cast down; overwhelmed by humiliation. This is the Day which they were promised.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmcdxx{%
\basmalahen We sent Noah to his people: “Warn your people before there comes upon them a painful punishment.”\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxi{%
He said, “O my people, I am to you a clear warner.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxii{%
Worship God and reverence Him, and obey me.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxiii{%
And He will forgive you of your sins, and reprieve you until a stated term. God’s term cannot be deferred once it has arrived, if you only knew.”\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxiv{%
He said, “My Lord, I have called my people night and day.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxv{%
But my call added only to their flight.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxvi{%
Whenever I called them to Your forgiveness, they thrust their fingers into their ears, and wrapped themselves in their garments, and insisted, and became more and more arrogant.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxvii{%
Then I called them openly.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxviii{%
Then I appealed to them publicly, and I spoke to them privately.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxix{%
I said, ‘Ask your Lord for forgiveness; He is Forgiving.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxx{%
He will let loose the sky upon you in torrents.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxi{%
And provide you with wealth and children, and allot for you gardens, and allot for you rivers.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxii{%
What is the matter with you, that you do not appreciate God’s Greatness?\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxiii{%
Although He created you in stages.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxiv{%
Do you not realize that God created seven heavens in layers?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxv{%
And He set the moon in their midst for light, and He made the sun a lamp.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxvi{%
And God germinated you from the earth like plants.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxvii{%
Then He will return you into it, and will bring you out again.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxviii{%
And God made the earth a spread for you.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxix{%
That you may travel its diverse roads.’”\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdxl{%
Noah said, “My Lord, they have defied me, and followed him whose wealth and children increase him only in perdition.”\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcdxli{%
And they schemed outrageous schemes.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlii{%
And they said, “Do not give up your gods; do not give up Wadd, nor Souwa, nor Yaghoos, and Yaooq, and Nassr.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcdxliii{%
They have misled many, so do not increase the wrongdoers except in confusion.”\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcdxliv{%
Because of their wrongs, they were drowned, and were hurled into a Fire. They did not find apart from God any helpers.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlv{%
Noah said, “My Lord, do not leave of the unbelievers a single dweller on earth.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlvi{%
If You leave them, they will mislead your servants, and will breed only wicked unbelievers.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlvii{%
My Lord! Forgive me and my parents, and anyone who enters my home in faith, and all the believing men and believing women; and do not increase the wrongdoers except in perdition.”\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlviii{%
\basmalahen Say, “It was revealed to me that a band of jinn listened in, and said, ‘We have heard a wondrous Quran.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlix{%
It guides to rectitude, so we have believed in it; and we will never associate anyone with our Lord.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdl{%
And Exalted is the Grandeur of our Lord—He never had a mate, nor a child.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdli{%
But the fools among us used to say nonsense about God.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdlii{%
And we thought that humans and jinn would never utter lies about God.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdliii{%
Some individual humans used to seek power through some individual jinn, but they only increased them in confusion.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdliv{%
They thought, as you thought, that God would never resurrect anyone.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdlv{%
We probed the heaven, and found it filled with stern guards and projectiles.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdlvi{%
We used to take up positions to listen in; but whoever listens now finds a projectile in wait for him.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdlvii{%
We do not know whether ill is intended for those on earth, or if their Lord intends goodness for them.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdlviii{%
Some of us are righteous, but some of us are less than that; we follow divergent paths.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdlix{%
We realized that we cannot defeat God on earth, and that we cannot escape Him by fleeing.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdlx{%
And when we heard the guidance, we believed in it. Whoever believes in his Lord fears neither loss, nor burden.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxi{%
Among us are those who are submitting, and among us are the compromisers. As for those who have submitted—it is they who pursue rectitude.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxii{%
But as for the compromisers—they will be firewood for Hell.’”\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxiii{%
Had they kept true to the Path, We would have given them plenty water to drink.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxiv{%
To test them with it. Whoever turns away from the remembrance of his Lord, He will direct him to torment ever mounting.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxv{%
The places of worship are for God. So do not call, besides God, upon anyone else.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxvi{%
And when the servant of God got up calling on Him, they almost fell on him in a mass.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxvii{%
Say, “I pray only to my Lord, and I never associate anyone with Him.”\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxviii{%
Say, “It is not in my power to harm you, nor to bring you to right conduct.”\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxix{%
Say, “No one can protect me from God, and I will not find any refuge except with Him.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxx{%
Except for a proclamation from God and His messages. He who defies God and His Messenger—for him is the Fire of Hell, in which they will dwell forever.”\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxi{%
Until, when they see what they were promised, they will know who is weaker in helpers, and fewer in numbers.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxii{%
Say, “I do not know whether what you are promised is near, or whether my Lord will extend it for a period.”\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxiii{%
The Knower of the Invisible; He does not disclose His Invisible to anyone.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxiv{%
Except to a Messenger of His choosing. He then dispatches guards before him and behind him.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxv{%
That He may know that they have conveyed the messages of their Lord. He encompasses what they have, and has tallied everything by number.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxvi{%
\basmalahen O you Enwrapped one.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxvii{%
Stay up during the night, except a little.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxviii{%
For half of it, or reduce it a little.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxix{%
Or add to it; and chant the Quran rhythmically.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxx{%
We are about to give you a heavy message.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxi{%
The vigil of night is more effective, and better suited for recitation.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxii{%
In the daytime, you have lengthy work to do.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiii{%
So remember the Name of your Lord, and devote yourself to Him wholeheartedly.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiv{%
Lord of the East and the West. There is no god but He, so take Him as a Trustee.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxv{%
And endure patiently what they say, and withdraw from them politely.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvi{%
And leave Me to those who deny the truth, those of luxury, and give them a brief respite.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvii{%
With Us are shackles, and a Fierce Fire.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxviii{%
And food that chokes, and a painful punishment.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxix{%
On the Day when the earth and the mountains tremble, and the mountains become heaps of sand.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdxc{%
We have sent to you a messenger, a witness over you, as We sent to Pharaoh a messenger.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdxci{%
But Pharaoh defied the Messenger, so We seized him with a terrible seizing.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcii{%
So how will you, if you persist in unbelief, save yourself from a Day which will turn the children gray-haired?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdxciii{%
The heaven will shatter thereby. His promise is always fulfilled.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdxciv{%
This is a reminder. So whoever wills, let him take a path to his Lord.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcv{%
Your Lord knows that you stay up nearly two-thirds of the night, or half of it, or one-third of it, along with a group of those with you. God designed the night and the day. He knows that you are unable to sustain it, so He has pardoned you. So read of the Quran what is possible for you. He knows that some of you may be ill; and others travelling through the land, seeking God’s bounty; and others fighting in God’s cause. So read of it what is possible for you, and observe the prayers, and give regular charity, and lend God a generous loan. Whatever good you advance for yourselves, you will find it with God, better and generously rewarded. And seek God’s forgiveness, for God is Forgiving and Merciful.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcvi{%
\basmalahen O you Enrobed one.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcvii{%
Arise and warn.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcviii{%
And magnify your Lord.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcix{%
And purify your clothes.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmd{%
And abandon abominations.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdi{%
And show no favor seeking gain.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdii{%
And be constant for your Lord.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdiii{%
When the Trumpet is blown.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdiv{%
That Day will be a difficult day.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdv{%
For the disbelievers—not easy.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdvi{%
Leave Me to him whom I created alone.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdvii{%
And gave him vast wealth.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdviii{%
And children as witnesses.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdix{%
And smoothed things for him.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdx{%
Then he wants Me to add yet more!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdxi{%
By no means! He was stubborn towards Our revelations.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdxii{%
I will exhaust him increasingly.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdxiii{%
He thought and analyzed.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdxiv{%
May he perish, how he analyzed.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdxv{%
Again: may he perish, how he analyzed.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdxvi{%
Then he looked.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdxvii{%
Then he frowned and whined.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdxviii{%
Then he turned back and was proud.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdxix{%
And said, “This is nothing but magic from the past.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdxx{%
This is nothing but the word of a mortal.”\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdxxi{%
I will roast him in Saqar.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdxxii{%
But what will explain to you what Saqar is?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdxxiii{%
It neither leaves, nor spares.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdxxiv{%
It scorches the flesh.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdxxv{%
Over it are Nineteen.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdxxvi{%
We have appointed only angels to be wardens of the Fire, and caused their number to be a stumbling block for those who disbelieve; so that those given the Scripture may attain certainty; and those who believe may increase in faith; and those given the Scripture and the believers may not doubt; and those in whose hearts is sickness and the unbelievers may say, “What did God intend by this parable?” Thus God leads astray whom He wills, and guides whom He wills. None knows the soldiers of your Lord except He. This is nothing but a reminder for the mortals.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdxxvii{%
Nay! By the moon.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdxxviii{%
And the night as it retreats.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdxxix{%
And the morning as it lights up.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdxxx{%
It is one of the greatest.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxi{%
A warning to the mortals.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxii{%
To whomever among you wishes to advance, or regress.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxiii{%
Every soul is hostage to what it has earned.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxiv{%
Except for those on the Right.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxv{%
In Gardens, inquiring.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxvi{%
About the guilty.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxvii{%
“What drove you into Saqar?”\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxviii{%
They will say, “We were not of those who prayed.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxix{%
Nor did we feed the destitute.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdxl{%
And we used to indulge with those who indulge.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdxli{%
And we used to deny the Day of Judgment.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdxlii{%
Until the Inevitable came upon us.”\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmdxliii{%
But the intercession of intercessors will not help them.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmdxliv{%
Why are they turning away from the Reminder?\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmdxlv{%
As though they were panicked donkeys.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmdxlvi{%
Fleeing from a lion?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmdxlvii{%
Yet every one of them desires to be given scrolls unrolled.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmdxlviii{%
No indeed! But they do not fear the Hereafter.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmmdxlix{%
Nevertheless, it is a reminder.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmmdl{%
So whoever wills, shall remember it.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmmdli{%
But they will not remember, unless God wills. He is the Source of Righteousness, and the Source of Forgiveness.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmmdlii{%
\basmalahen I swear by the Day of Resurrection.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdliii{%
And I swear by the blaming soul.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdliv{%
Does man think that We will not reassemble his bones?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdlv{%
Yes indeed; We are Able to reconstruct his fingertips.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdlvi{%
But man wants to deny what is ahead of him.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdlvii{%
He asks, “When is the Day of Resurrection?”\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdlviii{%
When vision is dazzled.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdlix{%
And the moon is eclipsed.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdlx{%
And the sun and the moon are joined together.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdlxi{%
On that Day, man will say, “Where is the escape?”\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdlxii{%
No indeed! There is no refuge.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdlxiii{%
To your Lord on that Day is the settlement.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdlxiv{%
On that Day man will be informed of everything he put forward, and everything he left behind.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdlxv{%
And man will be evidence against himself.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdlxvi{%
Even as he presents his excuses.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdlxvii{%
Do not wag your tongue with it, to hurry on with it.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdlxviii{%
Upon Us is its collection and its recitation.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdlxix{%
Then, when We have recited it, follow its recitation.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdlxx{%
Then upon Us is its explanation.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxi{%
Alas, you love the fleeting life.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxii{%
And you disregard the Hereafter.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxiii{%
Faces on that Day will be radiant.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxiv{%
Looking towards their Lord.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxv{%
And faces on that Day will be gloomy.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxvi{%
Realizing that a back-breaker has befallen them.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxvii{%
Indeed, when it has reached the breast-bones.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxviii{%
And it is said, “Who is the healer?”\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxix{%
And He realizes that it is the parting.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxx{%
And leg is entwined with leg.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxi{%
To your Lord on that Day is the drive.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxii{%
He neither believed nor prayed.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxiii{%
But he denied and turned away.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxiv{%
Then he went to his family, full of pride.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxv{%
Woe to you; and woe.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxvi{%
Then again: Woe to you; and woe.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxvii{%
Does man think that he will be left without purpose?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxviii{%
Was he not a drop of ejaculated semen?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxix{%
Then he became a clot. And He created and proportioned?\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdxc{%
And made of him the two sexes, the male and the female?\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdxci{%
Is He not Able to revive the dead?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdxcii{%
\basmalahen Has there come upon man a period of time when he was nothing to be mentioned?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdxciii{%
We created man from a liquid mixture, to test him; and We made him hearing and seeing.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdxciv{%
We guided him to the way, be he appreciative or unappreciative.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdxcv{%
We have prepared for the faithless chains, and yokes, and a Searing Fire.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdxcvi{%
But the righteous will drink from a cup whose mixture is aroma.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdxcvii{%
A spring from which the servants of God will drink, making it gush abundantly.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdxcviii{%
They fulfill their vows, and dread a Day whose ill is widespread.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdxcix{%
And they feed, for the love of Him, the poor, and the orphan, and the captive.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdc{%
“We only feed you for the sake of God. We want from you neither compensation, nor gratitude.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdci{%
We dread from our Lord a frowning grim Day.”\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcii{%
So God will protect them from the ills of that Day, and will grant them radiance and joy.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdciii{%
And will reward them for their patience with a Garden and silk.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdciv{%
Reclining therein on the thrones; experiencing therein neither sun, nor frost.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcv{%
Its shade hovering over them, and its fruit brought low within reach.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcvi{%
Passing around them are vessels of silver, and cups of crystal.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcvii{%
Crystal of silver—they measured them exactly.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcviii{%
They will be served therein with a cup whose flavor is Zanjabeel.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcix{%
A spring therein named Salsabeel.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcx{%
Passing among them are eternalized youths. If you see them, you would think them sprinkled pearls.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxi{%
Wherever you look, you see bliss, and a vast kingdom.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxii{%
Upon them are garments of green silk, and satin. And they will be adorned with bracelets of silver. And their Lord will offer them a pure drink.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxiii{%
“This is a reward for you. Your efforts are well appreciated.”\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxiv{%
It is We who sent down the Quran upon you—a gradual revelation.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxv{%
So be patient for the decision of your Lord, and do not obey the sinner or the blasphemer among them.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxvi{%
And mention the Name of your Lord, morning and evening.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxvii{%
And for part of the night, prostrate yourself to Him, and glorify Him long into the night.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxviii{%
As for these: they love the fleeting life, and leave behind a Heavy Day.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcxix{%
We created them, and strengthened their frame; and whenever We will, We can replace them with others like them.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcxx{%
This is a reminder; so whoever wills, let him take a path to his Lord.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxi{%
Yet you cannot will, unless God wills. God is Knowing and Wise.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxii{%
He admits into His mercy whomever He wills. But as for the wrongdoers, He has prepared for them a painful punishment.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxiii{%
\basmalahen By those unleashed in succession.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxiv{%
Storming turbulently.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxv{%
Scattering far and wide.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxvi{%
Separating decisively.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxvii{%
Delivering a message.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxviii{%
Excusing or warning.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxix{%
Surely what you are promised will happen.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxx{%
When the stars are obliterated.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxi{%
And the sky is fractured.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxii{%
And the mountains are blown away.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxiii{%
And the messengers are alerted.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxiv{%
Until which day is it deferred?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxv{%
Until the Day of Decision.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxvi{%
And what will teach you what the Day of Decision is?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxvii{%
Woe on that Day to the liars.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxviii{%
Did We not destroy the ancients?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxix{%
Then succeeded them with the others?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcxl{%
This is how We deal with the guilty.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcxli{%
Woe on that Day to the rejecters.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlii{%
Did We not create you from an insignificant fluid?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxliii{%
Then lodged it in a secure place?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxliv{%
For a known term?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlv{%
We measured precisely. We are the best to measure.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlvi{%
Woe on that Day to the falsifiers.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlvii{%
Did We not make the earth a homestead?\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlviii{%
For the living and the dead?\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlix{%
And set on it lofty mountains, and given you pure water to drink?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcl{%
Woe on that Day to the deniers.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcli{%
“Proceed to what you used to deny.”\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdclii{%
“Proceed to a shadow of three different masses.”\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcliii{%
Offering no shade, and unavailing against the flames.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcliv{%
It shoots sparks as castles.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdclv{%
As if they were yellow camels.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdclvi{%
Woe on that Day to the liars.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdclvii{%
This is a Day when they will not speak.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdclviii{%
And they will not be allowed to apologize.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdclix{%
Woe on that Day to the rejecters.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdclx{%
This is the Day of Separation; We have gathered you, together with the ancients.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdclxi{%
So if you have a strategy, use it against Me.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdclxii{%
Woe on that Day to the falsifiers.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdclxiii{%
The righteous will be amidst shades and fountains.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdclxiv{%
And fruits as they desire.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdclxv{%
“Eat and drink pleasantly, for what you used to do.”\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdclxvi{%
This is how We reward the doers of good.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdclxvii{%
Woe on that Day to the deniers.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdclxviii{%
“Eat and enjoy yourselves a little; you are indeed criminals.”\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdclxix{%
Woe on that Day to the liars.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmdclxx{%
And when it is said to them, “Kneel”, they do not kneel.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxi{%
Woe on that Day to the rejecters.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxii{%
In what message, beyond this, will they believe?\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxiii{%
\basmalahen What are they asking one another about?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxiv{%
About the Great Event.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxv{%
About which they disagree.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxvi{%
Surely, they will find out.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxvii{%
Most certainly, they will find out.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxviii{%
Did We not make the earth a cradle?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxix{%
And the mountains pegs?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxx{%
And created you in pairs?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxi{%
And made your sleep for rest?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxii{%
And made the night a cover?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxiii{%
And made the day for livelihood?\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxiv{%
And built above you seven strong ones?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxv{%
And placed a blazing lamp?\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxvi{%
And brought down from the clouds pouring water?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxvii{%
To produce with it grains and vegetation?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxviii{%
And luxuriant gardens?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxix{%
The Day of Sorting has been appointed.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcxc{%
The Day when the Trumpet is blown, and you will come in droves.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcxci{%
And the sky is opened up, and becomes gateways.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcii{%
And the mountains are set in motion, and become a mirage.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxciii{%
Hell is lying in ambush.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxciv{%
For the oppressors, a destination.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcv{%
Where they will remain for eons.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcvi{%
They will taste therein neither coolness, nor drink.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcvii{%
Except boiling water, and freezing hail.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcviii{%
A fitting requital.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcix{%
For they were not anticipating any reckoning.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcc{%
And they denied Our signs utterly.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcci{%
But We have enumerated everything in writing.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccii{%
So taste! We will increase you only in suffering.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcciii{%
But for the righteous there is triumph.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcciv{%
Gardens and vineyards.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccv{%
And splendid spouses, well matched.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccvi{%
And delicious drinks.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccvii{%
They will hear therein neither gossip, nor lies.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccviii{%
A reward from your Lord, a fitting gift.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccix{%
Lord of the heavens and the earth, and everything between them—The Most Merciful—none can argue with Him.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccx{%
On the Day when the Spirit and the angels stand in row. They will not speak, unless it be one permitted by the Most Merciful, and he will say what is right.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccxi{%
That is the Day of Reality. So whoever wills, let him take a way back to his Lord.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdccxii{%
We have warned you of a near punishment—the Day when a person will observe what his hands have produced, and the faithless will say, “O, I wish I were dust.”\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccxiii{%
\basmalahen By those who snatch violently.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdccxiv{%
And those who remove gently.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccxv{%
And those who glide smoothly.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccxvi{%
And those who race swiftly.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdccxvii{%
And those who regulate events.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdccxviii{%
On the Day when the Quake quakes.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdccxix{%
And is followed by the Successor.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdccxx{%
Hearts on that Day will be pounding.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxi{%
Their sights downcast.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxii{%
They say, “Are we to be restored to the original condition?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxiii{%
When we have become hollow bones?”\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxiv{%
They say, “This is a losing proposition.”\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxv{%
But it will be only a single nudge.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxvi{%
And they will be awake.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxvii{%
Has the story of Moses reached you?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxviii{%
When His Lord called out to him in the sacred valley of Tuwa.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxix{%
“Go to Pharaoh—he has transgressed.”\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxx{%
And say, “Do you care to be cleansed?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxi{%
And I will guide you to your Lord, and you will turn reverent.”\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxii{%
He showed him the Greatest Miracle.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxiii{%
But he denied and defied.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxiv{%
Then turned his back, and tried.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxv{%
And gathered and proclaimed.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxvi{%
He said, “I am your Lord, the most high.”\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxvii{%
So God seized him with an exemplary punishment, in the last and in the first.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxviii{%
In this is a lesson for whoever fears.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxix{%
Are you more difficult to create, or the heaven? He constructed it.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdccxl{%
He raised its masses, and proportioned it.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdccxli{%
And He dimmed its night, and brought out its daylight.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlii{%
And the earth after that He spread.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdccxliii{%
And from it, He produced its water and its pasture.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccxliv{%
And the mountains, He anchored.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlv{%
A source of enjoyment for you and for your animals.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlvi{%
But when the Great Cataclysm arrives.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlvii{%
A Day when man will remember what he has endeavored.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlviii{%
And Hell will be displayed to whoever sees.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlix{%
As for him who was defiant.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccl{%
And preferred the life of this world.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccli{%
Then Hell is the shelter.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdcclii{%
But as for him who feared the Standing of his Lord, and restrained the self from desires.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccliii{%
Then Paradise is the shelter.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdccliv{%
They ask you about the Hour, “When will it take place?”\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdcclv{%
You have no knowledge of it.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdcclvi{%
To your Lord is its finality.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdcclvii{%
You are just a warner for whoever dreads it.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdcclviii{%
On the Day when they witness it—as though they only stayed an evening, or its morning.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdcclix{%
\basmalahen He frowned and turned away.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcclx{%
When the blind man approached him.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxi{%
But how do you know? Perhaps he was seeking to purify himself.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxii{%
Or be reminded, and the message would benefit him.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxiii{%
But as for him who was indifferent.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxiv{%
You gave him your attention.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxv{%
Though you are not liable if he does not purify himself.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxvi{%
But as for him who came to you seeking.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxvii{%
In awe.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxviii{%
To him you were inattentive.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxix{%
Do not. This is a Lesson.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxx{%
Whoever wills, shall remember it.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxi{%
On honorable pages.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxii{%
Exalted and purified.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxiii{%
By the hands of scribes.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxiv{%
Noble and devoted.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxv{%
Perish man! How thankless he is!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxvi{%
From what did He create him?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxvii{%
From a sperm drop He created him, and enabled him.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxviii{%
Then He eased the way for him.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxix{%
Then He puts him to death, and buries him.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxx{%
Then, when He wills, He will resurrect him.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxi{%
But no, he did not fulfill what He has commanded him.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxii{%
Let man consider his food.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiii{%
We pour down water in abundance.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiv{%
Then crack the soil open.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxv{%
And grow in it grains.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvi{%
And grapes and herbs.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvii{%
And olives and dates.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxviii{%
And luscious gardens.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxix{%
And fruits and vegetables.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccxc{%
Enjoyment for you, and for your livestock.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccxci{%
But when the Deafening Noise comes to pass.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcii{%
The Day when a person will flee from his brother.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccxciii{%
And his mother and his father.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccxciv{%
And his consort and his children.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcv{%
Every one of them, on that Day, will have enough to preoccupy him.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcvi{%
Faces on that Day will be radiant.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcvii{%
Laughing and rejoicing.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcviii{%
And Faces on that Day will be covered with misery.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcix{%
Overwhelmed by remorse.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdccc{%
These are the faithless, the vicious.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdccci{%
\basmalahen When the sun is rolled up.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccii{%
When the stars are dimmed.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccciii{%
When the mountains are set in motion.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccciv{%
When the relationships are suspended.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccv{%
When the beasts are gathered.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccvi{%
When the oceans are set aflame.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccvii{%
When the souls are paired.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccviii{%
When the girl, buried alive, is asked:\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccix{%
For what crime was she killed?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccx{%
When the records are made public.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxi{%
When the sky is peeled away.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxii{%
When the Fire is set ablaze.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxiii{%
When Paradise is brought near.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxiv{%
Each soul will know what it has readied.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxv{%
I swear by the galaxies.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxvi{%
Precisely running their courses.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxvii{%
And by the night as it recedes.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxviii{%
And by the morn as it breathes.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxix{%
This is the speech of a noble messenger.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxx{%
Endowed with power, eminent with the Lord of the Throne.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxi{%
Obeyed and honest.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxii{%
Your friend is not possessed.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxiii{%
He saw him on the luminous horizon.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxiv{%
And He does not withhold knowledge of the Unseen.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxv{%
And it is not the word of an accursed devil.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxvi{%
So where are you heading?\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxvii{%
It is only a Reminder to all mankind.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxviii{%
To whoever of you wills to go straight.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxix{%
But you cannot will, unless God wills—The Lord of the Worlds.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxx{%
\basmalahen When the sky breaks apart.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxi{%
When the planets are scattered.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxii{%
When the oceans are exploded.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiii{%
When the tombs are strewn around.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiv{%
Each soul will know what it has advanced, and what it has deferred.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxv{%
O man! What deluded you concerning your Lord, the Most Generous?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvi{%
He Who created you, and formed you, and proportioned you?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvii{%
In whatever shape He willed, He assembled you.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxviii{%
But you reject the religion.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxix{%
Though over you are watchers.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxl{%
Honest recorders.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxli{%
They know everything you do.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlii{%
The virtuous will be in bliss.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxliii{%
While the wicked will be in Hell.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxliv{%
They will enter it on the Day of Justice.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlv{%
And they will not be absent from it.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlvi{%
But what will convey to you what the Day of Justice is?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlvii{%
Then again, what will convey to you what the Day of Justice is?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlviii{%
The Day when no soul will avail another soul anything; and the decision on that Day is God’s.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlix{%
\basmalahen Woe to the defrauders.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccl{%
Those who, when they take a measure from people, they take in full.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcccli{%
But when they measure or weigh to others, they cheat.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccclii{%
Do these not know that they will be resurrected?\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccliii{%
For a Great Day?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccliv{%
The Day when mankind will stand before the Lord of the Worlds?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdccclv{%
Not at all. The record of the wicked is in Sijjeen.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdccclvi{%
But how can you know what Sijjeen is?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdccclvii{%
A numerical book.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdccclviii{%
Woe on that Day to the deniers.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdccclix{%
Those who deny the Day of Reckoning.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdccclx{%
But none denies it except the sinful aggressor.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxi{%
When Our revelations are recited to him, he says, “Legends of the ancients.”\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxii{%
Not at all. Their hearts have become corroded by what they used to earn.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxiii{%
Not at all. On that Day, they will be screened from their Lord.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxiv{%
Then they will roast in Hell.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxv{%
Then it will be said, “This is what you used to deny.”\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxvi{%
No indeed; the record of the righteous is in Elliyyeen.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxvii{%
But how can you know what Elliyyoon is?\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxviii{%
A numerical book.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxix{%
Witnessed by those brought near.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxx{%
Indeed, the righteous will be amid bliss.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxi{%
On thrones, looking on.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxii{%
You will recognize on their faces the radiance of bliss.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxiii{%
They will be given to drink a sealed wine.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxiv{%
Whose seal is musk—this is what competitors should compete for.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxv{%
Its mixture is of Tasneem.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxvi{%
A spring from which those brought near drink.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxvii{%
Those who committed crimes used to laugh at those who believed.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxviii{%
And when they passed by them, they would wink at one another.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxix{%
And when they went back to their families, they would go back exulting.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxx{%
And if they saw them, they would say, “These people are lost.”\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxi{%
Yet they were not sent as guardians over them.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxii{%
But on that Day, those who believed will laugh at the unbelievers.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiii{%
On luxurious furnishings, looking on.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiv{%
Have the unbelievers been repaid for what they used to do?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxv{%
\basmalahen When the sky is ruptured.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvi{%
And hearkens to its Lord, as it must.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvii{%
And when the earth is leveled out.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxviii{%
And casts out what is in it, and becomes empty.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxix{%
And hearkens to its Lord, as it must.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxc{%
O man! You are laboring towards your Lord, and you will meet Him.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxci{%
As for him who is given his book in his right hand.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcii{%
He will have an easy settlement.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxciii{%
And will return to his family delighted.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxciv{%
But as for him who is given his book behind his back.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcv{%
He will call for death.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcvi{%
And will enter the Blaze.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcvii{%
He used to be happy among his family.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcviii{%
He thought he would never return.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcix{%
In fact, his Lord was watching him.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcm{%
I swear by the twilight.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmi{%
And by the night, and what it covers.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmii{%
And by the moon, as it grows full.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmiii{%
You will mount stage by stage.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmiv{%
What is the matter with them that they do not believe?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmv{%
And when the Quran is read to them, they do not bow down?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmvi{%
In fact, those who disbelieve are in denial.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmvii{%
But God knows what they hide inside.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcmviii{%
So inform them of a painful punishment.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcmix{%
Except those who believe and do good deeds; they will have an undiminished reward.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcmx{%
\basmalahen By the sky with the constellations.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxi{%
And by the Promised Day.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxii{%
And by the witness and the witnessed.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxiii{%
Destroyed were the People of the Trench.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxiv{%
The fire supplied with fuel.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxv{%
While they sat around it.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmxvi{%
And were witnessing what they did to the believers.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmxvii{%
They begrudged them only because they believed in God the Almighty, the Praiseworthy.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmxviii{%
To Whom belongs the sovereignty of the heavens and the earth. God is witness over everything.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmxix{%
Those who tempt the believers, men and women, then do not repent; for them is the punishment of Hell; for them is the punishment of Burning.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmxx{%
Those who believe and do righteous deeds will have Gardens beneath which rivers flow. That is the great triumph.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxi{%
The onslaught of your Lord is severe.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxii{%
It is He who begins and repeats.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxiii{%
And He is the Forgiving, the Loving.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxiv{%
Possessor of the Glorious Throne.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxv{%
Doer of whatever He wills.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxvi{%
Has there come to you the story of the legions?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxvii{%
Of Pharaoh and Thamood?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxviii{%
In fact, those who disbelieve are in denial.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxix{%
And God encloses them from beyond.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxx{%
In fact, it is a Glorious Quran.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxi{%
In a Preserved Tablet.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxii{%
\basmalahen By the sky and at-Tariq.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxiii{%
But what will let you know what at-Tariq is?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxiv{%
The Piercing Star.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxv{%
There is no soul without a Protector over it.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxvi{%
Let man consider what he was created from.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxvii{%
He was created from gushing liquid.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxviii{%
Issuing from between the backbone and the breastbones.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxix{%
He is certainly able to return him.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmxl{%
On the Day when the secrets are disclosed.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmxli{%
He will have no strength, and no supporter.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlii{%
By the sky that returns.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmxliii{%
And the earth that cracks open.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmxliv{%
It is a Decisive Word.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlv{%
It is no joke.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlvi{%
They plot and scheme.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlvii{%
But I plot and scheme.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlviii{%
Therefore, give the blasphemers respite, a brief respite.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlix{%
\basmalahen Praise the Name of your Lord, the Most High.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcml{%
He who creates and regulates.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmli{%
He who measures and guides.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmlii{%
He who produces the pasture.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmliii{%
And then turns it into light debris.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmliv{%
We will make you read, so do not forget.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmlv{%
Except what God wills. He knows what is declared, and what is hidden.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmlvi{%
We will ease you into the Easy Way.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmlvii{%
So remind, if reminding helps.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmlviii{%
The reverent will remember.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmlix{%
But the wretched will avoid it.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmlx{%
He who will enter the Gigantic Fire.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxi{%
Where he will neither die, nor live.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxii{%
Successful is he who purifies himself.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxiii{%
And mentions the name of his Lord, and prays.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxiv{%
But you prefer the present life.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxv{%
Though the Hereafter is better, and more lasting.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxvi{%
This is in the former scriptures.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxvii{%
The Scriptures of Abraham and Moses.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxviii{%
\basmalahen Has there come to you the news of the overwhelming?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxix{%
Faces on that Day will be shamed.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxx{%
Laboring and exhausted.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxi{%
Roasting in a scorching Fire.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxii{%
Given to drink from a flaming spring.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxiii{%
They will have no food except thorns.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxiv{%
That neither nourishes, nor satisfies hunger.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxv{%
Faces on that Day will be joyful.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxvi{%
Satisfied with their endeavor.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxvii{%
In a lofty Garden.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxviii{%
In it you will hear no nonsense.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxix{%
In it is a flowing spring.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxx{%
In it are raised beds.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxi{%
And cups set in place.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxii{%
And cushions set in rows.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiii{%
And carpets spread around.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiv{%
Do they not look at the camels—how they are created?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxv{%
And at the sky—how it is raised?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvi{%
And at the mountains—how they are installed?\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvii{%
And at the earth—how it is spread out?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxviii{%
So remind. You are only a reminder.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxix{%
You have no control over them.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmxc{%
But whoever turns away and disbelieves.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcmxci{%
God will punish him with the greatest punishment.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcii{%
To Us is their return.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcmxciii{%
Then upon Us rests their reckoning.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcmxciv{%
\basmalahen By the daybreak.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcv{%
And ten nights.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcvi{%
And the even and the odd.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcvii{%
And the night as it recedes.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcviii{%
Is there in this an oath for a rational person?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcix{%
Have you not seen how your Lord dealt with Aad?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmm{%
Erum of the pillars.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmi{%
The like of which was never created in the land.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmii{%
And Thamood—those who carved the rocks in the valley.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmiii{%
And Pharaoh of the Stakes.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmiv{%
Those who committed excesses in the lands.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmv{%
And spread much corruption therein.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmvi{%
So your Lord poured down upon them a scourge of punishment.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmvii{%
Your Lord is on the lookout.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmviii{%
As for man, whenever his Lord tests him, and honors him, and prospers him, he says, “My Lord has honored me.”\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmix{%
But whenever He tests him, and restricts his livelihood for him, he says, “My Lord has insulted me.”\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmx{%
Not at all. But you do not honor the orphan.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmxi{%
And you do not urge the feeding of the poor.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmxii{%
And you devour inheritance with all greed.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmxiii{%
And you love wealth with immense love.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmxiv{%
No—when the earth is leveled, pounded, and crushed.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmmxv{%
And your Lord comes, with the angels, row after row.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmmxvi{%
And on that Day, Hell is brought forward. On that Day, man will remember, but how will remembrance avail him?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmmxvii{%
He will say, “If only I had forwarded for my life.”\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmmxviii{%
On that Day, none will punish as He punishes.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmmxix{%
And none will shackle as He shackles.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmmxx{%
But as for you, O tranquil soul.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmmxxi{%
Return to your Lord, pleased and accepted.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmmxxii{%
Enter among My servants.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmmxxiii{%
Enter My Paradise.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmmxxiv{%
\basmalahen I swear by this land.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxxv{%
And you are a resident of this land.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxxvi{%
And by a father and what he fathered.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxxvii{%
We created man in distress.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxxviii{%
Does he think that no one has power over him?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxxix{%
He says, “I have used up so much money.”\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmxxx{%
Does he think that no one sees him?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxi{%
Did We not give him two eyes?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxii{%
And a tongue, and two lips?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxiii{%
And We showed him the two ways?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxiv{%
But he did not brave the ascent.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxv{%
And what will explain to you what the ascent is?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxvi{%
The freeing of a slave.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxvii{%
Or the feeding on a day of hunger.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxviii{%
An orphan near of kin.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxix{%
Or a destitute in the dust.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmxl{%
Then he becomes of those who believe, and advise one another to patience, and advise one another to kindness.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmxli{%
These are the people of happiness.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmxlii{%
But as for those who defy Our revelations—these are the people of misery.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmxliii{%
Upon them is a padlocked Fire.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmxliv{%
\basmalahen By the sun and its radiance.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxlv{%
And the moon as it follows it.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxlvi{%
And the day as it reveals it.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxlvii{%
And the night as it conceals it.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxlviii{%
And the sky and He who built it.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxlix{%
And the earth and He who spread it.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmml{%
And the soul and He who proportioned it.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmli{%
And inspired it with its wickedness and its righteousness.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlii{%
Successful is he who purifies it.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmliii{%
Failing is he who corrupts it.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmliv{%
Thamood denied in its pride.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmlv{%
When it followed its most wicked.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmlvi{%
The messenger of God said to them, “This is the she-camel of God, so let her drink.”\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmlvii{%
But they called him a liar, and hamstrung her. So their Lord crushed them for their sin, and leveled it.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmlviii{%
And He does not fear its sequel.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmlix{%
\basmalahen By the night as it covers.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmlx{%
And the day as it reveals.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmlxi{%
And He who created the male and the female.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmlxii{%
Your endeavors are indeed diverse.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmlxiii{%
As for him who gives and is righteous.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmlxiv{%
And confirms goodness.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmlxv{%
We will ease his way towards ease.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmlxvi{%
But as for him who is stingy and complacent.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlxvii{%
And denies goodness.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmlxviii{%
We will ease his way towards difficulty.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmlxix{%
And his money will not avail him when he plummets.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmlxx{%
It is upon Us to guide.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxi{%
And to Us belong the Last and the First.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxii{%
I have warned you of a Fierce Blaze.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxiii{%
None will burn in it except the very wicked.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxiv{%
He who denies and turns away.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxv{%
But the devout will avoid it.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxvi{%
He who gives his money to become pure.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxvii{%
Seeking no favor in return.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxviii{%
Only seeking the acceptance of his Lord, the Most High.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxix{%
And he will be satisfied.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxx{%
\basmalahen By the morning light.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxi{%
And the night as it settles.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxii{%
Your Lord did not abandon you, nor did He forget.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxiii{%
The Hereafter is better for you than the First.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxiv{%
And your Lord will give you, and you will be satisfied.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxv{%
Did He not find you orphaned, and sheltered you?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxvi{%
And found you wandering, and guided you.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxvii{%
And found you in need, and enriched you?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxviii{%
Therefore, do not mistreat the orphan.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxix{%
Nor rebuff the seeker.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmxc{%
But proclaim the blessings of your Lord.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmxci{%
\basmalahen Did We not soothe your heart?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxcii{%
And lift from you your burden.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxciii{%
Which weighed down your back?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxciv{%
And raised for you your reputation?\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxcv{%
With hardship comes ease.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxcvi{%
With hardship comes ease.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmxcvii{%
When your work is done, turn to devotion.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmxcviii{%
And to your Lord turn for everything.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmxcix{%
\basmalahen By the fig and the olive.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmc{%
And Mount Sinai.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmci{%
And this safe land.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcii{%
We created man in the best design.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmciii{%
Then reduced him to the lowest of the low.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmciv{%
Except those who believe and do righteous deeds; for them is a reward without end.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcv{%
So why do you still reject the religion?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcvi{%
Is God not the Wisest of the wise?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcvii{%
\basmalahen Read: In the Name of your Lord who created.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcviii{%
Created man from a clot.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcix{%
Read: And your Lord is the Most Generous.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcx{%
He who taught by the pen.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxi{%
Taught man what he never knew.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxii{%
In fact, man oversteps all bounds.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxiii{%
When he considers himself exempt.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxiv{%
But to your Lord is the return.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxv{%
Have you seen him who prevents?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmcxvi{%
A servant when he prays?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmcxvii{%
Do you think he is upon guidance?\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmcxviii{%
Or advocates righteousness?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmcxix{%
Do you see how he disbelieved and turned away?\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmcxx{%
Does he not know that God sees?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxi{%
No. If he does not desist, We will drag him by the forelock.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxii{%
A deceitful, sinful forelock.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxiii{%
Let him call on his gang.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxiv{%
We will call the Guards.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxv{%
No, do not obey him; but kneel down, and come near.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxvi{%
\basmalahen We sent it down on the Night of Decree.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxvii{%
But what will convey to you what the Night of Decree is?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxviii{%
The Night of Decree is better than a thousand months.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxix{%
In it descend the angels and the Spirit, by the leave of their Lord, with every command.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxx{%
Peace it is; until the rise of dawn.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxi{%
\basmalahen Those who disbelieved among the People of the Scripture, and the Polytheists, were not apart, until the Clear Evidence came to them.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxii{%
A messenger from God reciting purified scripts.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxiii{%
In them are valuable writings.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxiv{%
Those who were given the Scripture did not splinter, except after the Clear Evidence came to them.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxv{%
They were commanded only to worship God, devoting their faith to Him alone, and to practice regular prayer, and to give alms. That is the upright religion.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxvi{%
Those who disbelieve among the People of the Scripture, and the Polytheists, will be in the Fire of Hell, where they will abide forever. These are the worst of creatures.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxvii{%
As for those who believe and lead a righteous life—these are the best of creatures.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxviii{%
Their reward is with their Lord: Gardens of Eternity beneath which rivers flow, where they will abide forever. God is pleased with them, and they are pleased with Him. That is for whoever fears His Lord.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxix{%
\basmalahen When the earth is shaken with its quake.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxl{%
And the earth brings out its loads.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxli{%
And man says, “What is the matter with it?”\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlii{%
On that Day, it will tell its tales.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxliii{%
For your Lord will have inspired it.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxliv{%
On that Day, the people will emerge in droves, to be shown their works.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlv{%
Whoever has done an atom's weight of good will see it.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlvi{%
And whoever has done an atom's weight of evil will see it.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlvii{%
\basmalahen By the racers panting.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlviii{%
Igniting sparks.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlix{%
Raiding at dawn.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcl{%
Raising clouds of dust.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcli{%
Storming into the midst.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclii{%
Indeed, the human being is ungrateful to his Lord.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcliii{%
And he bears witness to that.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcliv{%
And he is fierce in his love of wealth.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclv{%
Does he not know? When the contents of the graves are scattered around.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclvi{%
And the contents of the hearts are obtained.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmclvii{%
Their Lord, on that Day, is fully informed of them.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmclviii{%
\basmalahen The Shocker.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclix{%
What is the Shocker?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclx{%
What will explain to you what the Shocker is?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxi{%
The Day when the people will be like scattered moths.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxii{%
And the mountains will be like tufted wool.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxiii{%
As for he whose scales are heavy.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxiv{%
He will be in a pleasant life.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxv{%
But as for he whose scales are light.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxvi{%
His home is the Abyss.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclxvii{%
Do you know what it is?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmclxviii{%
A Raging Fire.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmclxix{%
\basmalahen Abundance distracts you.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxx{%
Until you visit the graveyards.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxi{%
Indeed, you will know.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxii{%
Certainly, you will know.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxiii{%
If you knew with knowledge of certainty.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxiv{%
You would see the Inferno.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxv{%
Then you will see it with the eye of certainty.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxvi{%
Then, on that Day, you will be questioned about the Bliss.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxvii{%
\basmalahen By time.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxviii{%
The human being is in loss.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxix{%
Except those who believe, and do good works, and encourage truth, and recommend patience.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxx{%
\basmalahen Woe to every slanderer backbiter.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxi{%
Who gathers wealth and counts it over.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxii{%
Thinking that his wealth has made him immortal.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxiii{%
By no means. He will be thrown into the Crusher.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxiv{%
And what will make you realize what the Crusher is?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxv{%
God's kindled Fire.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxvi{%
That laps to the hearts.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxvii{%
It closes in on them.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxviii{%
In extended columns.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxix{%
\basmalahen Have you not considered how your Lord dealt with the People of the Elephant?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxc{%
Did He not make their plan go wrong?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxci{%
He sent against them swarms of birds.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcii{%
Throwing at them rocks of baked clay.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxciii{%
Leaving them like chewed-up leaves.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxciv{%
\basmalahen For the security of Quraish.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcv{%
Their security during winter and summer journeys.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcvi{%
Let them worship the Lord of this House.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcvii{%
Who has fed them against hunger, and has secured them against fear.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcviii{%
\basmalahen Have you considered him who denies the religion?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcix{%
It is he who mistreats the orphan.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcc{%
And does not encourage the feeding of the poor.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcci{%
So woe to those who pray.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccii{%
Those who are heedless of their prayers.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcciii{%
Those who put on the appearance.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcciv{%
And withhold the assistance.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmccv{%
\basmalahen We have given you plenty.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccvi{%
So pray to your Lord and sacrifice.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccvii{%
He who hates you is the loser.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccviii{%
\basmalahen Say, “O disbelievers.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccix{%
I do not worship what you worship.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccx{%
Nor do you worship what I worship.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxi{%
Nor do I serve what you serve.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxii{%
Nor do you serve what I serve.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxiii{%
You have your way, and I have my way.”\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmccxiv{%
\basmalahen When there comes God’s victory, and conquest.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxv{%
And you see the people entering God’s religion in multitudes.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxvi{%
Then celebrate the praise of your Lord, and seek His forgiveness. He is the Accepter of Repentance.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxvii{%
\basmalahen Condemned are the hands of Abee Lahab, and he is condemned.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxviii{%
His wealth did not avail him, nor did what he acquired.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxix{%
He will burn in a Flaming Fire.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxx{%
And his wife—the firewood carrier.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxi{%
Around her neck is a rope of thorns.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxii{%
\basmalahen Say, “He is God, the One.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxiii{%
God, the Absolute.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxiv{%
He begets not, nor was He begotten.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxv{%
And there is nothing comparable to Him.”\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxvi{%
\basmalahen Say, “I take refuge with the Lord of Daybreak.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxvii{%
From the evil of what He created.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxviii{%
And from the evil of the darkness as it gathers.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxix{%
And from the evil of those who practice sorcery.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxx{%
And from the evil of an envious when he envies.”\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxi{%
\basmalahen Say, “I seek refuge in the Lord of mankind.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxii{%
The King of mankind.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxiii{%
The God of mankind.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxiv{%
From the evil of the sneaky whisperer.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxv{%
Who whispers into the hearts of people.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxvi{%
From among jinn and among people.”\qt@no{6}}%
%% End of file `qurantext-envi.translation.def'
